(************** Content-type: application/mathematica **************

                    Mathematica-Compatible Notebook

This notebook can be used with any Mathematica-compatible
application, such as Mathematica, MathReader or Publicon. The data
for the notebook starts with the line containing stars above.

To get the notebook into a Mathematica-compatible application, do
one of the following:

* Save the data starting with the line of stars above into a file
  with a name ending in .nb, then open the file inside the
  application;

* Copy the data starting with the line of stars above to the
  clipboard, then use the Paste menu command inside the application.

Data for notebooks contains only printable 7-bit ASCII and can be
sent directly in email or through ftp in text mode.  Newlines can be
CR, LF or CRLF (Unix, Macintosh or MS-DOS style).

NOTE: If you modify the data for this notebook not in a Mathematica-
compatible application, you must delete the line below containing
the word CacheID, otherwise Mathematica-compatible applications may
try to use invalid cache data.

For more information on notebooks and Mathematica-compatible 
applications, contact Wolfram Research:
  web: http://www.wolfram.com
  email: info@wolfram.com
  phone: +1-217-398-0700 (U.S.)

Notebook reader applications are available free of charge from 
Wolfram Research.
*******************************************************************)

(*CacheID: 232*)


(*NotebookFileLineBreakTest
NotebookFileLineBreakTest*)
(*NotebookOptionsPosition[    369745,       9146]*)
(*NotebookOutlinePosition[    370461,       9171]*)
(*  CellTagsIndexPosition[    370417,       9167]*)
(*WindowFrame->Normal*)



Notebook[{

Cell[CellGroupData[{
Cell["NMR", "Title",
  TextAlignment->Center],

Cell[CellGroupData[{

Cell["Introduction", "Section"],

Cell[TextData[{
  "In NMR experiments, transitions between different states of a quantum \
mechanical system are induced via a periodic field, usually much weaker than \
typical fields of the system itself. Its frequency, however, must be \
comparable to the energy difference between the states (\[HBar]\[Omega] \
\[TildeTilde] \[CapitalDelta]E) to have any effect. If \[HBar]\[Omega] = \
\[CapitalDelta]E, all particles can be transferred from their original state \
to another and back again in a periodic cycle. Its frequency is the so called \
",
  StyleBox["Rabi frequency",
    FontWeight->"Bold"],
  ".\nThis notebook considers a two-state system, namely a ",
  Cell[BoxData[
      \(TraditionalForm\`Spin - 1\/2\)]],
  "particle in a constant magnetic field. The time dependent \
Schr\[ODoubleDot]dinger equation for this system with an additional periodic \
magnetic field is solved numerically. The Rabi frequency and the minimal \
population of the original state are then determined for different strengths \
and frequencies of the perturbation."
}], "Text"],

Cell[BoxData[{
    \(\(Clear["\<Global`*\>"];\)\  (*Clear\ all\ previous\ global\ settings\ \
from\ currently\ open\ sessions*) \), "\n", 
    \(Needs["\<Statistics`NonlinearFit`\>"]; 
    Needs["\<Graphics`MultipleListPlot`\>"];\)}], "Input"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Schr\[ODoubleDot]dinger equation", "Section"],

Cell[TextData[{
  "The Hamiltonian of a Spin-1/2 particle in a homogenous, constant magnetic \
field in z-direction is:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`H\_0 = \ \(\(e\ g\)\/\(2\ m\)\) \(B\_z\) S\_z\)],
    FontColor->GrayLevel[0]],
  StyleBox["\t,\t",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`S\_z = \(\[HBar]\/2\) \[Sigma]\_3\)],
    FontColor->GrayLevel[0]],
  "\n\nwith ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FormBox[\(\[Omega]\_0\),
              "TraditionalForm"], "=", \(\(e\ g\ B\_z\)\/\(2  m\)\)}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  ", this becomes:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`H\_0 = \ \(\[Omega]\_0\) S\_z\)],
    FontColor->GrayLevel[0]],
  "\n\nThe eigenvalues of this Hamiltonian are ",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{\(E\_\[Sigma]\), "=", 
            RowBox[{
              FractionBox[
                StyleBox["\[Sigma]",
                  FontColor->GrayLevel[0]], "2"], 
              " ", \(\[HBar]\[Omega]\_0\)}]}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  ", with ",
  StyleBox["\[Sigma]=\[PlusMinus]1",
    FontColor->GrayLevel[0]],
  ". The probability of finding the system in one of these eigenvectors is \
time-independent:\n\n",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            RowBox[{
              FormBox["|",
                
                "TraditionalForm"], \(\[LeftAngleBracket]\[Sigma] | \[Psi](
                    t)\[RightAngleBracket]\), \( | \^2\)}], "="}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            FormBox["|",
              
              "TraditionalForm"], \(\[LeftAngleBracket]\[Sigma] | 
                e\^\(\(\(-it\)\/\[HBar]\) H\) | \[Psi](
                  t = 0)\[RightAngleBracket]\), \( | \^2\)}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  StyleBox["= ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            FormBox[\(\(|\)\(e\^\(\(it\/\[HBar]\) E\_\[Sigma]\)\)\),
              
              "TraditionalForm"], \(\[LeftAngleBracket]\[Sigma] | \[Psi](
                  0)\[RightAngleBracket]\)}], \( | \^2\)}], TraditionalForm]],
    
    FontColor->GrayLevel[0]],
  StyleBox["= ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(\[LeftAngleBracket]\[Sigma] | \[Psi](
              0)\[RightAngleBracket]\)\( | \^2\)\)\)],
    FontColor->GrayLevel[0]],
  "\n\nIn order to obtain a transition between the eigenstates, we need a \
time-dependent Hamiltonian. One possibility is an additional periodic field \
in x-direction:\n\n",
  Cell[BoxData[
      FormBox[
        StyleBox[\(H = H\_0\),
          FontColor->GrayLevel[0]], TraditionalForm]]],
  StyleBox[" + ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          
          FormBox[\(\(\(e\ g\)\/\(2\ m\)\) \(B\_x\) \(cos(\[Omega]t)\) S\_x\),
            
            "TraditionalForm"], "=", 
          RowBox[{
            FormBox[\(\(\[Omega]\_0\) S\_z\),
              "TraditionalForm"], 
            "+", \(\(\[Omega]\_1\) \(cos(\[Omega]t)\) S\_x\)}]}], 
        TraditionalForm]],
    FontColor->GrayLevel[0]],
  "\n\nWe express H and |\[Psi](t)\[RightAngleBracket] in  the ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(S\_z - basis\)\(,\)\)\)]],
  " the eigenbasis of ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(H\_0\)\(,\)\(\ \)\)\)]],
  "the eigenvectors are ",
  StyleBox["|+z\[RightAngleBracket]=",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", GridBox[{
              {"1"},
              {"0"}
              }], ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  " for ",
  StyleBox["\[Sigma]=+1",
    FontColor->GrayLevel[0]],
  " and ",
  StyleBox["|-z\[RightAngleBracket]=",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          RowBox[{
            StyleBox[
              RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                    {"0"},
                    {"1"}
                    }], "\[NegativeThinSpace]", ")"}],
              FontColor->GrayLevel[0]], " ", "for", " ", 
            StyleBox["\[Sigma]",
              FontColor->GrayLevel[0]]}], 
          StyleBox["=",
            FontColor->GrayLevel[0]], 
          StyleBox[\(\(-1\)\(:\)\),
            FontColor->GrayLevel[0]]}], TraditionalForm]]]
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.847059]],

Cell[BoxData[
    RowBox[{
      RowBox[{\(\[Sigma]\_1\), " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0", "1"},
              {"1", "0"}
              }], ")"}]}], ";", "  ", 
      RowBox[{\(\[Sigma]\_2\), " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"0", \(-\[ImaginaryI]\)},
              {"\[ImaginaryI]", "0"}
              }], ")"}]}], ";", "  ", 
      RowBox[{\(\[Sigma]\_3\), " ", "=", " ", 
        RowBox[{"(", GridBox[{
              {"1", "0"},
              {"0", \(-1\)}
              }], ")"}]}], ";"}]], "Input"],

Cell[BoxData[{
    \(\(H\_0 = \[Omega]\_0\ \[Sigma]\_3/2;\)\), "\[IndentingNewLine]", 
    \(H = 
      H\_0 + \(\[Omega]\_1\/2\) Cos[\[Omega]\ t]\ \[Sigma]\_1 // 
        MatrixForm\)}], "Input"],

Cell[TextData[{
  "\nWith \t",
  Cell[BoxData[
      FormBox[
        StyleBox[
          RowBox[{
            RowBox[{
              RowBox[{
                
                FormBox[\(\(\(\(|\)\(\[Psi](
                          t)\)\)\(\[RightAngleBracket]\)\) = \[Sum]\+\[Sigma]\
\),
                  "TraditionalForm"], \(\(C\_\[Sigma]\)(t)\)}], "|", 
              "\[Sigma]"}], "\[RightAngleBracket]"}],
          FontColor->GrayLevel[0]], TraditionalForm]]],
  StyleBox["=",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a(t)\)},
              {\(b(t)\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  ",\n\nthe time-dependent Schroedinger equation becomes:\n\n",
  Cell[BoxData[
      \(TraditionalForm\`i \[PartialD]\/\[PartialD]t\)],
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a(t)\)},
              {\(b(t)\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  StyleBox["=H ",
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{
          FormBox[
            RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
                  {\(a(t)\)},
                  {\(b(t)\)}
                  }], "\[NegativeThinSpace]", ")"}],
            "TraditionalForm"], "=", \(1\/2\)}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(\[Omega]\_0\), \(\(\[Omega]\_1\) \(cos(\[Omega]t)\)\)},
              {\(\(\[Omega]\_1\) \(cos(\[Omega]t)\)\), \(-\[Omega]\_0\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]],
  Cell[BoxData[
      FormBox[
        RowBox[{"(", "\[NegativeThinSpace]", GridBox[{
              {\(a(t)\)},
              {\(b(t)\)}
              }], "\[NegativeThinSpace]", ")"}], TraditionalForm]],
    FontColor->GrayLevel[0]]
}], "Text",
  CellFrame->True,
  TextAlignment->Center,
  FontColor->RGBColor[0, 0, 1],
  Background->GrayLevel[0.847059]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Numerical Solution", "Section"],

Cell["\<\
We solve this equation for the coefficients a(t) and b(t) \
numerically.\
\>", "Text"],

Cell[BoxData[
    \(\(numsol[\[Omega]0_, \[Omega]1_, \ \[Omega]_] := 
        Block[{sol, t}, \[IndentingNewLine]\[Omega]est = 
            Max[\((\[Omega] - \[Omega]0)\), \[Omega]1/
                2]; \[IndentingNewLine]tmax = 
            N[2  \[Pi]/\[Omega]est]; \[IndentingNewLine]sol = 
            NDSolve[{I\ \(a'\)[
                      t] \[Equal] \[Omega]0\ a[t]/
                        2 + \[Omega]1\ Cos[\[Omega]\ t]\ b[t]/2, 
                I\ \(b'\)[
                      t] == \(-\[Omega]0\)\ b[t]/
                        2\  + \[Omega]1\ Cos[\[Omega]\ t]\ a[t]/2, 
                a[0] \[Equal] 1, b[0] \[Equal] 0}, {a[t], b[t]}, {t, 0, \ 
                tmax}]; \[IndentingNewLine]pup[t_] = 
            Abs[a[t]]\^2 /. sol[\([1]\)]; \[IndentingNewLine]pdown[t_] = 
            Abs[b[t]]\^2 /. sol[\([1]\)];\[IndentingNewLine]];\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(numsol[\[Omega]0 = 1, \[Omega]1 = 0.1, \[Omega] = 0.95]; 
    plOsc = Plot[{pup[t], pdown[t]}, {t, 0, \ tmax}, 
        PlotRange \[Rule] {{0, 1.1  tmax}, {0, 1}}, 
        PlotStyle \[Rule] {Hue[1], Hue[0.6]}, 
        AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        DisplayFunction -> Identity];\), "\[IndentingNewLine]", 
    \(\(Show[plOsc, 
        Graphics[{Text[\*"\"\<|a(t)\!\(\( | \^2\)\)\>\"", {1.1\ tmax, 
                pup[tmax]}, TextStyle \[Rule] {FontColor -> Hue[1]}], 
            Text[\*"\"\<|b(t)\!\(\( | \^2\)\)\>\"", {1.1\ tmax, pdown[tmax]}, 
              TextStyle \[Rule] {FontColor -> Hue[0.6]}]}], 
        DisplayFunction \[Rule] $DisplayFunction];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-2.87314e-18 0.00723432 0 0.618034 [
[.14469 -0.0125 -6 -9 ]
[.14469 -0.0125 6 0 ]
[.28937 -0.0125 -6 -9 ]
[.28937 -0.0125 6 0 ]
[.43406 -0.0125 -6 -9 ]
[.43406 -0.0125 6 0 ]
[.57875 -0.0125 -6 -9 ]
[.57875 -0.0125 6 0 ]
[.72343 -0.0125 -9 -9 ]
[.72343 -0.0125 9 0 ]
[.86812 -0.0125 -9 -9 ]
[.86812 -0.0125 9 0 ]
[1.025 0 0 -4.90625 ]
[1.025 0 10 4.90625 ]
[-0.0125 .12361 -18 -4.5 ]
[-0.0125 .12361 0 4.5 ]
[-0.0125 .24721 -18 -4.5 ]
[-0.0125 .24721 0 4.5 ]
[-0.0125 .37082 -18 -4.5 ]
[-0.0125 .37082 0 4.5 ]
[-0.0125 .49443 -18 -4.5 ]
[-0.0125 .49443 0 4.5 ]
[-0.0125 .61803 -6 -4.5 ]
[-0.0125 .61803 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.14469 0 m
.14469 .00625 L
s
[(20)] .14469 -0.0125 0 1 Mshowa
.28937 0 m
.28937 .00625 L
s
[(40)] .28937 -0.0125 0 1 Mshowa
.43406 0 m
.43406 .00625 L
s
[(60)] .43406 -0.0125 0 1 Mshowa
.57875 0 m
.57875 .00625 L
s
[(80)] .57875 -0.0125 0 1 Mshowa
.72343 0 m
.72343 .00625 L
s
[(100)] .72343 -0.0125 0 1 Mshowa
.86812 0 m
.86812 .00625 L
s
[(120)] .86812 -0.0125 0 1 Mshowa
.125 Mabswid
.03617 0 m
.03617 .00375 L
s
.07234 0 m
.07234 .00375 L
s
.10851 0 m
.10851 .00375 L
s
.18086 0 m
.18086 .00375 L
s
.21703 0 m
.21703 .00375 L
s
.2532 0 m
.2532 .00375 L
s
.32554 0 m
.32554 .00375 L
s
.36172 0 m
.36172 .00375 L
s
.39789 0 m
.39789 .00375 L
s
.47023 0 m
.47023 .00375 L
s
.5064 0 m
.5064 .00375 L
s
.54257 0 m
.54257 .00375 L
s
.61492 0 m
.61492 .00375 L
s
.65109 0 m
.65109 .00375 L
s
.68726 0 m
.68726 .00375 L
s
.7596 0 m
.7596 .00375 L
s
.79577 0 m
.79577 .00375 L
s
.83195 0 m
.83195 .00375 L
s
.90429 0 m
.90429 .00375 L
s
.94046 0 m
.94046 .00375 L
s
.97663 0 m
.97663 .00375 L
s
.25 Mabswid
0 0 m
1 0 L
s
gsave
1.025 0 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .12361 m
.00625 .12361 L
s
[(0.2)] -0.0125 .12361 1 0 Mshowa
0 .24721 m
.00625 .24721 L
s
[(0.4)] -0.0125 .24721 1 0 Mshowa
0 .37082 m
.00625 .37082 L
s
[(0.6)] -0.0125 .37082 1 0 Mshowa
0 .49443 m
.00625 .49443 L
s
[(0.8)] -0.0125 .49443 1 0 Mshowa
0 .61803 m
.00625 .61803 L
s
[(1)] -0.0125 .61803 1 0 Mshowa
.125 Mabswid
0 .0309 m
.00375 .0309 L
s
0 .0618 m
.00375 .0618 L
s
0 .09271 m
.00375 .09271 L
s
0 .15451 m
.00375 .15451 L
s
0 .18541 m
.00375 .18541 L
s
0 .21631 m
.00375 .21631 L
s
0 .27812 m
.00375 .27812 L
s
0 .30902 m
.00375 .30902 L
s
0 .33992 m
.00375 .33992 L
s
0 .40172 m
.00375 .40172 L
s
0 .43262 m
.00375 .43262 L
s
0 .46353 m
.00375 .46353 L
s
0 .52533 m
.00375 .52533 L
s
0 .55623 m
.00375 .55623 L
s
0 .58713 m
.00375 .58713 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
0 .61803 m
.00112 .61799 L
.00214 .6179 L
.00332 .61773 L
.00444 .61753 L
.00644 .61713 L
.00754 .61693 L
.00857 .61678 L
.00968 .61666 L
.01091 .61659 L
.01195 .61657 L
.01307 .61658 L
.01369 .6166 L
.01438 .61661 L
.01562 .61661 L
.01683 .61655 L
.01795 .6164 L
.01914 .61612 L
.01981 .6159 L
.02043 .61566 L
.02276 .6144 L
.02711 .61122 L
.0283 .6104 L
.02957 .60963 L
.03077 .60906 L
.03186 .60868 L
.03309 .6084 L
.03425 .60827 L
.03551 .60823 L
.03622 .60823 L
.03688 .60823 L
.03808 .60819 L
.03918 .60805 L
.04039 .60774 L
.041 .60749 L
.04166 .60716 L
.04278 .60641 L
.04399 .60536 L
.04615 .60288 L
.05638 .59229 L
.0771 .57095 L
.11671 .52763 L
.15488 .47154 L
.15588 .47157 L
.15694 .47127 L
.15811 .47043 L
.1592 .46909 L
.16031 .46712 L
.16135 .46474 L
.1633 .45912 L
Mistroke
.16558 .45151 L
.16804 .44363 L
.16913 .4407 L
.17029 .43819 L
.17128 .43657 L
.17236 .43536 L
.17303 .4349 L
.17366 .43464 L
.17484 .43457 L
.17551 .43471 L
.17612 .43491 L
.1775 .43548 L
.17861 .43584 L
.17983 .43591 L
.18044 .43575 L
.1811 .4354 L
.1823 .43425 L
.18343 .43248 L
.18466 .4298 L
.18715 .42248 L
.18944 .41464 L
.19159 .40778 L
.19279 .40467 L
.19342 .40331 L
.19409 .40209 L
.19527 .40052 L
.19635 .39973 L
.1976 .39951 L
.19877 .39982 L
.19944 .40015 L
.20005 .4005 L
.20072 .40091 L
.20143 .40132 L
.20259 .4018 L
.20367 .40188 L
.20483 .40142 L
.2055 .40086 L
.20612 .40013 L
.20723 .39828 L
.20826 .39602 L
.21057 .38932 L
.21301 .3811 L
.21436 .37682 L
.21563 .37331 L
.21681 .37072 L
.21748 .36958 L
.2181 .36876 L
.21919 .36782 L
.22035 .36751 L
.22156 .36782 L
Mistroke
.22269 .36853 L
.22401 .36962 L
.22527 .3706 L
.22591 .37099 L
.22662 .37127 L
.22786 .37128 L
.22856 .37096 L
.22931 .37033 L
.23001 .36946 L
.23065 .36843 L
.25059 .34591 L
.25933 .3304 L
.26172 .32392 L
.26241 .32243 L
.26306 .32122 L
.26429 .3196 L
.26544 .31887 L
.2665 .31886 L
.26767 .31952 L
.26892 .32081 L
.27103 .3237 L
.27214 .32517 L
.27331 .3264 L
.27434 .32705 L
.27546 .32718 L
.27648 .3267 L
.27743 .32574 L
.27866 .3238 L
.27981 .32135 L
.28197 .31581 L
.28433 .30979 L
.28552 .30736 L
.2862 .30625 L
.28682 .30545 L
.288 .30454 L
.28865 .30439 L
.28926 .30448 L
.29036 .30513 L
.29155 .30647 L
.29264 .30813 L
.29381 .31012 L
.2959 .31357 L
.29652 .3144 L
.29718 .31512 L
.2979 .31569 L
.29856 .31598 L
.29975 .3159 L
.30043 .3155 L
.30106 .31491 L
.30224 .31326 L
Mistroke
.30332 .31125 L
.30573 .30578 L
.30688 .30318 L
.30811 .30074 L
.30928 .29899 L
.31034 .29799 L
.31153 .29764 L
.31267 .29809 L
.31389 .29935 L
.31459 .30037 L
.31523 .30148 L
.3174 .30586 L
.31854 .30819 L
.31975 .31035 L
.3208 .31181 L
.32196 .31281 L
.32302 .31309 L
.324 .3128 L
.32465 .31231 L
.32527 .31166 L
.32643 .31 L
.32903 .30506 L
.33018 .30288 L
.33125 .30111 L
.33237 .29973 L
.3336 .29892 L
.33483 .29898 L
.33551 .2994 L
.33615 .30002 L
.33729 .30169 L
.3385 .30406 L
.34125 .31058 L
.34259 .31365 L
.34384 .31598 L
.34495 .31749 L
.34612 .31838 L
.34731 .31849 L
.34798 .31822 L
.34861 .31777 L
.3497 .31658 L
.3507 .31516 L
.35294 .31153 L
.3541 .30986 L
.35533 .30855 L
.35604 .30811 L
.35668 .30793 L
.35793 .30826 L
.35911 .3094 L
.35977 .31039 L
.36037 .31149 L
Mistroke
.36267 .31696 L
.3648 .32283 L
.36597 .32584 L
.36708 .32829 L
.36812 .33008 L
.36924 .3314 L
.37026 .33199 L
.3712 .33204 L
.37219 .33161 L
.37328 .33067 L
.37442 .32933 L
.37549 .32793 L
.3766 .32653 L
.37776 .32533 L
.37837 .32488 L
.37903 .32458 L
.3802 .32459 L
.38082 .3249 L
.38146 .32546 L
.38263 .32708 L
.38388 .32964 L
.38526 .33322 L
.38756 .34013 L
.38883 .34389 L
.39003 .34708 L
.39118 .34959 L
.39244 .35157 L
.39358 .35262 L
.39464 .35295 L
.39563 .35277 L
.39673 .35212 L
.39787 .35109 L
.39895 .35 L
.39956 .34939 L
.40021 .3488 L
.40139 .34802 L
.40262 .34779 L
.40332 .34798 L
.40397 .3484 L
.4051 .34971 L
.40633 .35195 L
.4075 .35478 L
.40857 .35787 L
.41114 .36616 L
.41357 .37343 L
.41492 .37649 L
.41568 .37782 L
.41639 .37877 L
.41763 .37978 L
.41833 .38 L
Mistroke
.41896 .38001 L
.42015 .37961 L
.42124 .37891 L
.42242 .37802 L
.42304 .37756 L
.42371 .37714 L
.42484 .37671 L
.42589 .37674 L
.42709 .37743 L
.42819 .37875 L
.42929 .38075 L
.43032 .38316 L
.43263 .39016 L
.43465 .39705 L
.43684 .40388 L
.43806 .40696 L
.43918 .40914 L
.44025 .41061 L
.44137 .4115 L
.44261 .4118 L
.44377 .41157 L
.44443 .41129 L
.44503 .41098 L
.44569 .41062 L
.44638 .41026 L
.447 .41 L
.44769 .4098 L
.44889 .40983 L
.44956 .4101 L
.45029 .41064 L
.45098 .4114 L
.4516 .41232 L
.45281 .41466 L
.45413 .41803 L
.45653 .42569 L
.45897 .43402 L
.46026 .43794 L
.46162 .4414 L
.46281 .44372 L
.46348 .44472 L
.46411 .44544 L
.46522 .44624 L
.4664 .44652 L
.46748 .4464 L
.46848 .44609 L
.46953 .44571 L
.47069 .44541 L
.47186 .44542 L
.47311 .44599 L
.47428 .44715 L
Mistroke
.47535 .44881 L
.47667 .45162 L
.47811 .45554 L
.48074 .46406 L
.4832 .472 L
.48456 .47567 L
.48583 .47843 L
.48708 .48038 L
.48778 .48116 L
.48843 .48168 L
.48957 .48219 L
.49078 .48227 L
.49192 .48209 L
.49297 .48185 L
.49414 .4817 L
.49538 .48185 L
.49654 .48245 L
.4972 .48304 L
.49782 .48376 L
.49907 .48574 L
.50042 .48865 L
.50508 .50244 L
.50776 .50996 L
.50911 .51285 L
.50988 .51416 L
.51059 .51512 L
.51124 .51583 L
.51185 .51633 L
.5125 .51671 L
.5132 .51697 L
.51382 .51708 L
.51447 .5171 L
.51564 .51701 L
.51683 .51687 L
.51791 .51688 L
.51917 .5172 L
.52036 .51796 L
.52145 .51912 L
.52247 .52063 L
.52478 .52545 L
.52733 .53231 L
.53002 .53963 L
.53232 .5446 L
.53295 .54564 L
.53362 .5466 L
.53484 .54788 L
.53546 .54834 L
.53614 .54869 L
.53738 .54902 L
.53858 .54907 L
Mistroke
.53969 .54901 L
.5409 .549 L
.54159 .54907 L
.54224 .54922 L
.54292 .54949 L
.54354 .54985 L
.54422 .55037 L
.54494 .55109 L
.54608 .55257 L
.54729 .5546 L
.54948 .55918 L
.55187 .56478 L
.55445 .57031 L
.55566 .57237 L
.55694 .57408 L
.55804 .57513 L
.55924 .57588 L
.56037 .57626 L
.56158 .57641 L
.56272 .57642 L
.56376 .57641 L
.56484 .57648 L
.56584 .57668 L
.56693 .57712 L
.5681 .5779 L
.56921 .57896 L
.57026 .58024 L
.57222 .58324 L
.57456 .58742 L
.57706 .59175 L
.57827 .59353 L
.57942 .59493 L
.58045 .59592 L
.58157 .59671 L
.58276 .59725 L
.58402 .59754 L
.5851 .59763 L
.58628 .59765 L
.58694 .59765 L
.58756 .59767 L
.58828 .59772 L
.58894 .59781 L
.59014 .59811 L
.59081 .59838 L
.59144 .5987 L
.59255 .59942 L
.59375 .60044 L
.59592 .60275 L
.59998 .60752 L
.60229 .60963 L
Mistroke
.60345 .61039 L
.60412 .61073 L
.60473 .61099 L
.60581 .61131 L
.60698 .6115 L
.60806 .61157 L
.60909 .61158 L
.61018 .61158 L
.61135 .61161 L
.61245 .6117 L
.61347 .61186 L
.61459 .61214 L
.61582 .61258 L
.6183 .61379 L
.62074 .61517 L
.62303 .61634 L
.62431 .61684 L
.62498 .61705 L
.62568 .61723 L
.62694 .61745 L
.62809 .61755 L
.62917 .61758 L
.63033 .61756 L
.63143 .61752 L
.63243 .61748 L
.6336 .61745 L
.63426 .61745 L
.63487 .61746 L
.636 .61751 L
.6372 .6176 L
.63949 .61783 L
.64061 .61793 L
.64165 .61799 L
.64259 .61801 L
.64358 .61797 L
.64458 .61787 L
.64567 .61768 L
.65027 .61631 L
.65269 .61556 L
.65391 .61528 L
.65461 .61516 L
.65526 .61507 L
.65644 .61497 L
.65753 .61493 L
.65872 .61494 L
.65997 .61495 L
.66105 .61493 L
.66205 .61485 L
.66316 .61466 L
.66433 .61433 L
Mistroke
.66503 .61405 L
.66568 .61373 L
.66715 .61283 L
.66981 .61063 L
.67218 .60839 L
.67344 .60726 L
.67478 .60619 L
.67603 .6054 L
.67718 .60485 L
.67832 .60448 L
.67941 .60428 L
.68063 .60418 L
.68175 .60417 L
.68299 .60416 L
.68361 .60413 L
.6843 .60406 L
.68546 .60381 L
.68654 .6034 L
.68772 .60269 L
.68899 .60162 L
.69032 .60015 L
.69157 .59848 L
.69392 .59488 L
.69598 .5917 L
.69815 .58883 L
.69929 .58769 L
.70054 .58675 L
.70168 .58619 L
.70275 .5859 L
.7051 .58575 L
.70634 .58574 L
.70703 .5857 L
.70766 .58561 L
.70891 .58523 L
.71009 .58456 L
.71117 .58363 L
.71234 .58224 L
.7137 .58015 L
.71514 .57747 L
.71772 .57201 L
.72025 .56688 L
.72149 .56478 L
.72265 .56322 L
.72375 .56209 L
.72491 .56128 L
.72609 .56083 L
.72676 .56071 L
.72738 .56065 L
.72847 .56066 L
.72946 .56069 L
Mistroke
.73055 .56065 L
.7317 .56041 L
.73286 .55984 L
.7341 .55877 L
.73527 .55727 L
.73633 .5555 L
.73894 .54972 L
.7414 .54327 L
.74353 .538 L
.74469 .53556 L
.74577 .53366 L
.7467 .53239 L
.74769 .53137 L
.7488 .53065 L
.7498 .53031 L
.75099 .53021 L
.75165 .53024 L
.75226 .5303 L
.75339 .53038 L
.75458 .53029 L
.75565 .52994 L
.75664 .52929 L
.75774 .52814 L
.75891 .52637 L
.76013 .52392 L
.7613 .52109 L
.76347 .51487 L
.766 .50733 L
.76711 .50433 L
.76834 .50148 L
.76931 .49961 L
.77037 .49805 L
.77148 .49692 L
.77253 .49631 L
.77374 .49605 L
.7749 .49612 L
.77594 .4963 L
.77707 .49646 L
.77772 .49647 L
.77842 .49638 L
.77907 .49616 L
.77968 .49582 L
.78083 .49477 L
.78204 .49302 L
.78335 .49038 L
.78457 .48727 L
.78734 .47865 L
.7897 .47106 L
.79194 .46517 L
.79318 .46281 L
Mistroke
.79387 .46181 L
.79452 .46108 L
.79566 .46027 L
.79687 .45996 L
.79913 .46037 L
.80023 .46069 L
.80123 .46085 L
.80228 .46075 L
.80341 .46019 L
.80465 .45893 L
.80581 .45705 L
.80706 .45429 L
.80822 .45113 L
.81084 .44259 L
.81322 .43465 L
.81438 .43127 L
.81545 .42866 L
.81644 .42672 L
.81739 .42534 L
.81839 .42439 L
.81948 .4239 L
.8206 .42388 L
.82178 .42424 L
.8229 .42475 L
.82392 .42519 L
.82508 .42547 L
.82614 .42537 L
.82731 .42471 L
.82854 .42329 L
.82962 .4214 L
.83062 .41911 L
.83289 .41238 L
.83522 .40444 L
.83768 .39674 L
.83897 .39364 L
.83965 .39233 L
.84039 .3912 L
.84106 .39043 L
.84168 .38994 L
.84289 .38953 L
.84403 .38971 L
.84509 .39022 L
.84635 .39104 L
.8475 .39176 L
.8487 .39224 L
.84984 .39224 L
.85104 .3916 L
.85172 .3909 L
.85235 .39005 L
.87007 .36141 L
Mistroke
.87118 .36234 L
.87237 .363 L
.87299 .36314 L
.87367 .3631 L
.87488 .36245 L
.87601 .36111 L
.87724 .35889 L
.87839 .35613 L
.87945 .35316 L
.88201 .34516 L
.88341 .34101 L
.88472 .33772 L
.88582 .33553 L
.88701 .33395 L
.88769 .33341 L
.88833 .33314 L
.88952 .33322 L
.89057 .33383 L
.89172 .33493 L
.89285 .33624 L
.89406 .33766 L
.89519 .33876 L
.89622 .33943 L
.89726 .33962 L
.89824 .3393 L
.89938 .33826 L
.90059 .33637 L
.90174 .33394 L
.90277 .33131 L
.90532 .32406 L
.90647 .3209 L
.90771 .31794 L
.90909 .31547 L
Mfstroke
0 .4 1 r
0 0 m
.00112 4e-05 L
.00214 .00013 L
.00332 .0003 L
.00444 .0005 L
.00644 .0009 L
.00754 .0011 L
.00857 .00125 L
.00968 .00137 L
.01091 .00144 L
.01195 .00146 L
.01307 .00145 L
.01369 .00143 L
.01438 .00142 L
.01562 .00142 L
.01683 .00148 L
.01795 .00163 L
.01914 .00191 L
.01981 .00213 L
.02043 .00237 L
.02276 .00363 L
.02711 .00681 L
.0283 .00763 L
.02957 .0084 L
.03077 .00897 L
.03186 .00935 L
.03309 .00963 L
.03425 .00976 L
.03551 .0098 L
.03622 .0098 L
.03688 .0098 L
.03808 .00984 L
.03918 .00998 L
.04039 .0103 L
.041 .01054 L
.04166 .01087 L
.04278 .01162 L
.04399 .01267 L
.04615 .01515 L
.05638 .02574 L
.0771 .04708 L
.11671 .0904 L
.15488 .14649 L
.15588 .14646 L
.15694 .14676 L
.15811 .1476 L
.1592 .14894 L
.16031 .15091 L
.16135 .15329 L
.1633 .15891 L
Mistroke
.16558 .16652 L
.16804 .1744 L
.16913 .17733 L
.17029 .17984 L
.17128 .18146 L
.17236 .18267 L
.17303 .18313 L
.17366 .18339 L
.17484 .18346 L
.17551 .18332 L
.17612 .18312 L
.1775 .18255 L
.17861 .18219 L
.17983 .18212 L
.18044 .18228 L
.1811 .18263 L
.1823 .18378 L
.18343 .18555 L
.18466 .18823 L
.18715 .19555 L
.18944 .20338 L
.19159 .21025 L
.19279 .21336 L
.19342 .21472 L
.19409 .21594 L
.19527 .21751 L
.19635 .2183 L
.1976 .21852 L
.19877 .21821 L
.19944 .21788 L
.20005 .21753 L
.20072 .21712 L
.20143 .21671 L
.20259 .21623 L
.20367 .21615 L
.20483 .21661 L
.2055 .21717 L
.20612 .2179 L
.20723 .21975 L
.20826 .22201 L
.21057 .22871 L
.21301 .23693 L
.21436 .24121 L
.21563 .24472 L
.21681 .24731 L
.21748 .24845 L
.2181 .24927 L
.21919 .25021 L
.22035 .25052 L
.22156 .25021 L
Mistroke
.22269 .2495 L
.22401 .24841 L
.22527 .24743 L
.22591 .24704 L
.22662 .24676 L
.22786 .24675 L
.22856 .24707 L
.22931 .2477 L
.23001 .24857 L
.23065 .2496 L
.25059 .27212 L
.25933 .28763 L
.26172 .29411 L
.26241 .2956 L
.26306 .2968 L
.26429 .29843 L
.26544 .29916 L
.2665 .29917 L
.26767 .29851 L
.26892 .29722 L
.27103 .29433 L
.27214 .29285 L
.27331 .29163 L
.27434 .29098 L
.27546 .29085 L
.27648 .29132 L
.27743 .29229 L
.27866 .29423 L
.27981 .29668 L
.28197 .30222 L
.28433 .30824 L
.28552 .31067 L
.2862 .31178 L
.28682 .31258 L
.288 .31348 L
.28865 .31363 L
.28926 .31355 L
.29036 .3129 L
.29155 .31156 L
.29264 .3099 L
.29381 .3079 L
.2959 .30445 L
.29652 .30362 L
.29718 .30291 L
.2979 .30234 L
.29856 .30205 L
.29975 .30213 L
.30043 .30253 L
.30106 .30312 L
.30224 .30477 L
Mistroke
.30332 .30678 L
.30573 .31225 L
.30688 .31485 L
.30811 .31729 L
.30928 .31904 L
.31034 .32004 L
.31153 .32038 L
.31267 .31994 L
.31389 .31868 L
.31459 .31766 L
.31523 .31655 L
.3174 .31217 L
.31854 .30984 L
.31975 .30768 L
.3208 .30621 L
.32196 .30521 L
.32302 .30493 L
.324 .30523 L
.32465 .30571 L
.32527 .30637 L
.32643 .30803 L
.32903 .31297 L
.33018 .31515 L
.33125 .31692 L
.33237 .3183 L
.3336 .31911 L
.33483 .31905 L
.33551 .31863 L
.33615 .31801 L
.33729 .31634 L
.3385 .31397 L
.34125 .30744 L
.34259 .30438 L
.34384 .30204 L
.34495 .30054 L
.34612 .29965 L
.34731 .29953 L
.34798 .2998 L
.34861 .30026 L
.3497 .30145 L
.3507 .30287 L
.35294 .3065 L
.3541 .30817 L
.35533 .30947 L
.35604 .30992 L
.35668 .3101 L
.35793 .30977 L
.35911 .30863 L
.35977 .30764 L
.36037 .30654 L
Mistroke
.36267 .30106 L
.3648 .2952 L
.36597 .29218 L
.36708 .28974 L
.36812 .28794 L
.36924 .28663 L
.37026 .28603 L
.3712 .28599 L
.37219 .28642 L
.37328 .28736 L
.37442 .28869 L
.37549 .2901 L
.3766 .2915 L
.37776 .2927 L
.37837 .29314 L
.37903 .29345 L
.3802 .29344 L
.38082 .29313 L
.38146 .29257 L
.38263 .29094 L
.38388 .28839 L
.38526 .28481 L
.38756 .27789 L
.38883 .27414 L
.39003 .27095 L
.39118 .26844 L
.39244 .26646 L
.39358 .26541 L
.39464 .26507 L
.39563 .26526 L
.39673 .26591 L
.39787 .26693 L
.39895 .26803 L
.39956 .26864 L
.40021 .26923 L
.40139 .27001 L
.40262 .27024 L
.40332 .27004 L
.40397 .26963 L
.4051 .26832 L
.40633 .26607 L
.4075 .26325 L
.40857 .26016 L
.41114 .25187 L
.41357 .2446 L
.41492 .24154 L
.41568 .24021 L
.41639 .23926 L
.41763 .23824 L
.41833 .23802 L
Mistroke
.41896 .23802 L
.42015 .23842 L
.42124 .23912 L
.42242 .24001 L
.42304 .24047 L
.42371 .24088 L
.42484 .24132 L
.42589 .24129 L
.42709 .24059 L
.42819 .23928 L
.42929 .23728 L
.43032 .23486 L
.43263 .22787 L
.43465 .22098 L
.43684 .21415 L
.43806 .21107 L
.43918 .20889 L
.44025 .20742 L
.44137 .20652 L
.44261 .20623 L
.44377 .20645 L
.44443 .20673 L
.44503 .20704 L
.44569 .2074 L
.44638 .20776 L
.447 .20803 L
.44769 .20823 L
.44889 .2082 L
.44956 .20792 L
.45029 .20738 L
.45098 .20662 L
.4516 .20571 L
.45281 .20336 L
.45413 .2 L
.45653 .19234 L
.45897 .18401 L
.46026 .18008 L
.46162 .17662 L
.46281 .1743 L
.46348 .17331 L
.46411 .17259 L
.46522 .17179 L
.4664 .1715 L
.46748 .17163 L
.46848 .17194 L
.46953 .17232 L
.47069 .17262 L
.47186 .1726 L
.47311 .17204 L
.47428 .17088 L
Mistroke
.47535 .16922 L
.47667 .16641 L
.47811 .16249 L
.48074 .15397 L
.4832 .14602 L
.48456 .14235 L
.48583 .13959 L
.48708 .13764 L
.48778 .13687 L
.48843 .13635 L
.48957 .13584 L
.49078 .13576 L
.49192 .13594 L
.49297 .13617 L
.49414 .13633 L
.49538 .13618 L
.49654 .13558 L
.4972 .13499 L
.49782 .13427 L
.49907 .13228 L
.50042 .12938 L
.50508 .11559 L
.50776 .10807 L
.50911 .10518 L
.50988 .10387 L
.51059 .1029 L
.51124 .1022 L
.51185 .10169 L
.5125 .10131 L
.5132 .10106 L
.51382 .10095 L
.51447 .10092 L
.51564 .10102 L
.51683 .10115 L
.51791 .10115 L
.51917 .10083 L
.52036 .10007 L
.52145 .0989 L
.52247 .0974 L
.52478 .09258 L
.52733 .08572 L
.53002 .0784 L
.53232 .07343 L
.53295 .07238 L
.53362 .07143 L
.53484 .07014 L
.53546 .06969 L
.53614 .06933 L
.53738 .06901 L
.53858 .06896 L
Mistroke
.53969 .06901 L
.5409 .06903 L
.54159 .06895 L
.54224 .0688 L
.54292 .06854 L
.54354 .06818 L
.54422 .06766 L
.54494 .06694 L
.54608 .06546 L
.54729 .06343 L
.54948 .05885 L
.55187 .05324 L
.55445 .04772 L
.55566 .04565 L
.55694 .04395 L
.55804 .04289 L
.55924 .04214 L
.56037 .04177 L
.56158 .04162 L
.56272 .04161 L
.56376 .04162 L
.56484 .04155 L
.56584 .04135 L
.56693 .04091 L
.5681 .04013 L
.56921 .03907 L
.57026 .03779 L
.57222 .03479 L
.57456 .0306 L
.57706 .02627 L
.57827 .02449 L
.57942 .0231 L
.58045 .02211 L
.58157 .02132 L
.58276 .02078 L
.58402 .02049 L
.5851 .02039 L
.58628 .02038 L
.58694 .02038 L
.58756 .02036 L
.58828 .02031 L
.58894 .02022 L
.59014 .01992 L
.59081 .01965 L
.59144 .01933 L
.59255 .0186 L
.59375 .01759 L
.59592 .01528 L
.59998 .01051 L
.60229 .0084 L
Mistroke
.60345 .00763 L
.60412 .00729 L
.60473 .00704 L
.60581 .00672 L
.60698 .00652 L
.60806 .00645 L
.60909 .00644 L
.61018 .00645 L
.61135 .00642 L
.61245 .00633 L
.61347 .00617 L
.61459 .00589 L
.61582 .00545 L
.6183 .00424 L
.62074 .00286 L
.62303 .00169 L
.62431 .00119 L
.62498 .00098 L
.62568 .0008 L
.62694 .00058 L
.62809 .00047 L
.62917 .00044 L
.63033 .00046 L
.63143 .00051 L
.63243 .00055 L
.6336 .00057 L
.63426 .00058 L
.63487 .00056 L
.636 .00051 L
.6372 .00042 L
.63949 .00019 L
.64061 9e-05 L
.64165 3e-05 L
.64259 2e-05 L
.64358 6e-05 L
.64458 .00016 L
.64567 .00034 L
.65027 .00171 L
.65269 .00246 L
.65391 .00275 L
.65461 .00287 L
.65526 .00296 L
.65644 .00306 L
.65753 .00309 L
.65872 .00309 L
.65997 .00308 L
.66105 .0031 L
.66205 .00318 L
.66316 .00336 L
.66433 .0037 L
Mistroke
.66503 .00398 L
.66568 .00429 L
.66715 .0052 L
.66981 .0074 L
.67218 .00964 L
.67344 .01077 L
.67478 .01183 L
.67603 .01263 L
.67718 .01318 L
.67832 .01355 L
.67941 .01375 L
.68063 .01384 L
.68175 .01386 L
.68299 .01387 L
.68361 .0139 L
.6843 .01397 L
.68546 .01421 L
.68654 .01463 L
.68772 .01534 L
.68899 .01641 L
.69032 .01788 L
.69157 .01955 L
.69392 .02314 L
.69598 .02633 L
.69815 .02919 L
.69929 .03034 L
.70054 .03127 L
.70168 .03183 L
.70275 .03213 L
.7051 .03228 L
.70634 .03228 L
.70703 .03233 L
.70766 .03242 L
.70891 .03279 L
.71009 .03346 L
.71117 .0344 L
.71234 .03579 L
.7137 .03788 L
.71514 .04055 L
.71772 .04601 L
.72025 .05115 L
.72149 .05324 L
.72265 .0548 L
.72375 .05593 L
.72491 .05674 L
.72609 .05719 L
.72676 .05732 L
.72738 .05737 L
.72847 .05737 L
.72946 .05733 L
Mistroke
.73055 .05737 L
.7317 .05762 L
.73286 .05819 L
.7341 .05926 L
.73527 .06075 L
.73633 .06253 L
.73894 .06831 L
.7414 .07475 L
.74353 .08002 L
.74469 .08247 L
.74577 .08436 L
.7467 .08564 L
.74769 .08665 L
.7488 .08738 L
.7498 .08771 L
.75099 .08782 L
.75165 .08778 L
.75226 .08773 L
.75339 .08765 L
.75458 .08773 L
.75565 .08808 L
.75664 .08874 L
.75774 .08988 L
.75891 .09165 L
.76013 .09411 L
.7613 .09694 L
.76347 .10315 L
.766 .1107 L
.76711 .11369 L
.76834 .11655 L
.76931 .11842 L
.77037 .11997 L
.77148 .1211 L
.77253 .12171 L
.77374 .12197 L
.7749 .12191 L
.77594 .12173 L
.77707 .12157 L
.77772 .12155 L
.77842 .12165 L
.77907 .12186 L
.77968 .1222 L
.78083 .12325 L
.78204 .12501 L
.78335 .12765 L
.78457 .13076 L
.78734 .13938 L
.7897 .14696 L
.79194 .15286 L
.79318 .15521 L
Mistroke
.79387 .15622 L
.79452 .15694 L
.79566 .15776 L
.79687 .15806 L
.79913 .15765 L
.80023 .15733 L
.80123 .15717 L
.80228 .15728 L
.80341 .15784 L
.80465 .1591 L
.80581 .16097 L
.80706 .16374 L
.80822 .1669 L
.81084 .17544 L
.81322 .18337 L
.81438 .18675 L
.81545 .18936 L
.81644 .19131 L
.81739 .19268 L
.81839 .19363 L
.81948 .19413 L
.8206 .19415 L
.82178 .19379 L
.8229 .19328 L
.82392 .19284 L
.82508 .19255 L
.82614 .19265 L
.82731 .19331 L
.82854 .19474 L
.82962 .19663 L
.83062 .19892 L
.83289 .20565 L
.83522 .21359 L
.83768 .22128 L
.83897 .22439 L
.83965 .22569 L
.84039 .22682 L
.84106 .22759 L
.84168 .22808 L
.84289 .2285 L
.84403 .22832 L
.84509 .2278 L
.84635 .22698 L
.8475 .22626 L
.8487 .22578 L
.84984 .22579 L
.85104 .22643 L
.85172 .22712 L
.85235 .22798 L
.87007 .25661 L
Mistroke
.87118 .25569 L
.87237 .25503 L
.87299 .25488 L
.87367 .25493 L
.87488 .25558 L
.87601 .25691 L
.87724 .25914 L
.87839 .26189 L
.87945 .26487 L
.88201 .27286 L
.88341 .27701 L
.88472 .28031 L
.88582 .28249 L
.88701 .28408 L
.88769 .28462 L
.88833 .28489 L
.88952 .2848 L
.89057 .28419 L
.89172 .28309 L
.89285 .28179 L
.89406 .28037 L
.89519 .27926 L
.89622 .2786 L
.89726 .2784 L
.89824 .27873 L
.89938 .27977 L
.90059 .28165 L
.90174 .28408 L
.90277 .28671 L
.90532 .29397 L
.90647 .29712 L
.90771 .30008 L
.90909 .30255 L
Mfstroke
0 g
gsave
1 .31547 -87.75 -10.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
63.000 14.750 moveto
(\\310) show
70.188 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
77.375 14.750 moveto
(H) show
84.562 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
91.750 14.750 moveto
(L) show
98.938 14.750 moveto
(\\310) show
106.125 10.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(2) show
112.500 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
1 .30255 -87.75 -10.9688 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 21.9375 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 14.750 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
63.000 14.750 moveto
(\\310) show
70.188 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(b) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
77.375 14.750 moveto
(H) show
84.562 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
91.750 14.750 moveto
(L) show
98.938 14.750 moveto
(\\310) show
106.125 10.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 8.500 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
(2) show
112.500 14.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.400 1.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000@03Vc806
000000@0i/b00`00000R0>K<P0<000001@3Vc80300000240i/b0100000050>K<P0<000008P3Vc804
000000D0i/b00`00000L0>K<P0H00000103Vc803000000D0i/b00`00000H0>K<P0H000000P3Vc806
000000@0i/b00`00000e0>K<P000@@3Vc8001@000000i/b00>K<P03Vc800000000<0i/b000@00000
0>K<P03Vc80000008`3Vc8000`000000i/b00>K<P0030>K<P0040000003Vc800i/b000000240i/b0
00D000000>K<P03Vc800i/b0000000030>K<P0040000003Vc800i/b000000240i/b000<000000>K<
P03Vc8000P3Vc8001@000000i/b00>K<P03Vc80000000080i/b000<000000>K<P03Vc8007@3Vc800
0`000000i/b00>K<P0030>K<P0040000003Vc800i/b0000000@0i/b000@000000>K<P03Vc8000000
6`3Vc8000`000000i/b00>K<P0030>K<P0050000003Vc800i/b00>K<P00000000`3Vc80010000000
i/b00>K<P000000e0>K<P000@P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080
i/b000<000000>K<P03Vc8007@3Vc805000000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P00M0>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103Vc8000`00
0000i/b00>K<P00N0>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103Vc800
0`000000i/b00>K<P00L0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000P3Vc800
10000000i/b00>K<P00000040>K<P0030000003Vc800i/b001P0i/b000<000000>K<P03Vc800103V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800<P3V
c80004<0i/b00P0000030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8007@3Vc800
10000000i/b00>K<P00000040>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8007@3V
c80010000000i/b00>K<P03Vc80200000080i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P00O0>K<P0030000003Vc800i/b0008000000P3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b001`0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P0040000
003Vc800i/b0000000@0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P0050>K<P080
00000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00380i/b000140>K<P0800000
0P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001h0i/b000<000000>K<P0000000
103Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001d0i/b01@0000030>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8007`3Vc804000000<0i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800
0P3Vc80010000000i/b00>K<P00000040>K<P0030000003Vc800i/b001P0i/b000<000000>K<P03V
c8001P3Vc80200000080i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00b0>K<P000
A@3Vc80010000000i/b00>K<P00000040>K<P0030000003Vc800i/b001l0i/b00P0000040>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P0040>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P0020>K<P004
0000003Vc800i/b0000000@0i/b000<000000>K<P03Vc800703Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P00H
0>K<P0030000003Vc800i/b000L0i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<
P00b0>K<P000@03Vc8000`000000i/b00>K<P0020>K<P0050000003Vc800i/b00>K<P00000000P3V
c8000`000000i/b00>K<P00P0>K<P08000001@3Vc80010000000i/b00>K<P000000Q0>K<P0030000
003Vc800i/b000D0i/b000@000000>K<P03Vc80000008@3Vc8000`000000i/b00>K<P0020>K<P005
0000003Vc800i/b00>K<P00000000P3Vc8000`000000i/b00>K<P00M0>K<P0030000003Vc800i/b0
00<0i/b000@000000>K<P03Vc8000000103Vc80010000000i/b00>K<P000000K0>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<P03Vc80000000080i/b0
00<000000>K<P03Vc800<`3Vc8000400i/b01@0000040>K<P0@000008`3Vc8000`000000i/b00>K<
P0030>K<P0@000008P3Vc804000000<0i/b01000000R0>K<P0@00000103Vc804000001d0i/b00`00
00050>K<P0@00000103Vc804000001T0i/b00`0000040>K<P0D00000103Vc804000003D0i/b0003o
0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P640i/b01000
00040>K<P000o`3Vc81P0>K<P0030000003Vc800i/b000H0i/b0000J0>K<P0@006Ko_`000008001V
ofh00000303Vc8000`000000i/b00>K<P0060>K<P0006P3Vc8000`000000i/b00>K<P005001Vo`<0
i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000P0
i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000P0
i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000P0
i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000T0
i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000T0
i/b000<000000>K<P03Vc800203Vc8000`00000006Ko001Vo`080>K<P0H006Ko1P3Vc8000`000000
i/b00>K<P0080>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800203Vc8000`000000
i/b00>K<P0090>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800203Vc8000`000000
i/b00>K<P0090>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8004@3Vc8000`000000
i/b00>K<P0060>K<P0006P3Vc8000`000000i/b00>K<P0050>K<P08006Ko8`3Vc8000`000000i/b0
0>K<P00Z0>K<P0030000003Vc800i/b002X0i/b000<000000>K<P03Vc800:`3Vc8000`000000i/b0
0>K<P0040>K<P0D006Ko3`3Vc802001Voa00i/b000<000000>K<P03Vc800:P3Vc8000`000000i/b0
0>K<P00c0>K<P0030000003Vc800i/b000H0i/b0000J0>K<P0030000003Vc800i/b000H0i/b01@00
I_n]0>K<P08006Ko5@3Vc8000`00I_l0i/b00>K<P01_0>K<P0D000001@3Vc80001X0i/b000<00000
0>K<P03Vc8002P3Vc802001Voj`0i/b000<006Ko0>K<P03Vc8005@3Vc804001Vofh0i/b000<00000
0>K<P03Vc8001P3Vc80001X0i/b000<000000>K<P03Vc8002`3Vc8000`00I_l0i/b00>K<P02Y0>K<
P003001Vo`3Vc800i/b001T0i/b00P00I_m]0>K<P0030000003Vc800i/b000H0i/b0000J0>K<P003
0000003Vc800i/b000`0i/b000<006Ko0>K<P03Vc800Y03Vc804001Voad0i/b00P00I_me0>K<P000
6P3Vc8000`000000i/b00>K<P00=0>K<P08006KoX`3Vc802001Vob80i/b000<006Ko0>K<P03Vc800
LP3Vc80001X0i/b000<000000>K<P03Vc8003`3Vc8000`00I_l0i/b00>K<P02O0>K<P003001Vo`3V
c800i/b00280i/b000<006Ko0>K<P03Vc800LP3Vc80001X0i/b000<000000>K<P03Vc800403Vc800
0`00I_l0i/b00>K<P02N0>K<P003001Vo`3Vc800i/b002<0i/b000<006Ko0>K<P03Vc800L@3Vc800
01X0i/b00P00000B0>K<P003001Vo`3Vc800i/b009`0i/b000<006Ko0>K<P03Vc800903Vc804001V
og00i/b0000J0>K<P0030000003Vc800i/b00180i/b000<006Ko0>K<P03Vc800V`3Vc8000`00I_l0
i/b00>K<P00X0>K<P003001Vo`3Vc800i/b006d0i/b0000J0>K<P0030000003Vc800i/b00180i/b0
00<006Ko0>K<P03Vc800VP3Vc8000`00I_l0i/b00>K<P00Z0>K<P003001Vo`3Vc800i/b006`0i/b0
000J0>K<P0030000003Vc800i/b001<0i/b000<006Ko0>K<P03Vc800U@3Vc804001Vobd0i/b000<0
06Ko0>K<P03Vc800K03Vc80001X0i/b000<000000>K<P03Vc800503Vc8000`00I_l0i/b00>K<P02C
0>K<P08006Ko<@3Vc8000`00I_l0i/b00>K<P01[0>K<P0006P3Vc8000`000000i/b00>K<P00E0>K<
P003001Vo`3Vc800i/b00980i/b000<006Ko0>K<P03Vc800<03Vc8000`00I_l0i/b00>K<P01[0>K<
P0006P3Vc8000`000000i/b00>K<P00F0>K<P003001Vo`3Vc800i/b00940i/b000<006Ko0>K<P03V
c800<@3Vc8000`00I_l0i/b00>K<P01Z0>K<P0006P3Vc8000`000000i/b00>K<P00G0>K<P003001V
o`3Vc800i/b008l0i/b000<006Ko0>K<P03Vc800<P3Vc802001Vof/0i/b0000J0>K<P0030000003V
c800i/b001P0i/b000<006Ko0>K<P03Vc800SP3Vc8000`00I_l0i/b00>K<P00c0>K<P0@006KoJ03V
c80001X0i/b00P00000J0>K<P003001Vo`3Vc800i/b008d0i/b000<006Ko0>K<P03Vc800=P3Vc802
001VofL0i/b0000J0>K<P0030000003Vc800i/b001X0i/b000<006Ko0>K<P03Vc800R`3Vc8000`00
I_l0i/b00>K<P00h0>K<P003001Vo`3Vc800i/b006D0i/b0000J0>K<P0030000003Vc800i/b001/0
i/b000<006Ko0>K<P03Vc800R03Vc802001Voc`0i/b000<006Ko0>K<P03Vc800I03Vc80001X0i/b0
00<000000>K<P03Vc8006`3Vc8000`00I_l0i/b00>K<P0260>K<P0<006Ko?@3Vc8000`00I_l0i/b0
0>K<P01T0>K<P0006P3Vc8000`000000i/b00>K<P00L0>K<P003001Vo`3Vc800i/b008@0i/b000<0
06Ko0>K<P03Vc800?P3Vc8000`00I_l0i/b00>K<P01T0>K<P0006P3Vc8000`000000i/b00>K<P00M
0>K<P003001Vo`3Vc800i/b008<0i/b000<006Ko0>K<P03Vc800?P3Vc8000`00I_l0i/b00>K<P01T
0>K<P0006P3Vc8000`000000i/b00>K<P00N0>K<P003001Vo`3Vc800i/b00840i/b000<006Ko0>K<
P03Vc800@03Vc8000`00I_l0i/b00>K<P01S0>K<P0006P3Vc8000`000000i/b00>K<P00O0>K<P003
001Vo`3Vc800i/b00800i/b000<006Ko0>K<P03Vc800@03Vc802001Vof@0i/b0000J0>K<P0030000
003Vc800i/b00200i/b000<006Ko0>K<P03Vc800O`3Vc8000`00I_l0i/b00>K<P0110>K<P0@006Ko
H@3Vc80001X0i/b000<000000>K<P03Vc8008@3Vc8000`00I_l0i/b00>K<P01n0>K<P003001Vo`3V
c800i/b004@0i/b00P00I_mP0>K<P0006P3Vc802000002<0i/b000<006Ko0>K<P03Vc800O03Vc800
0`00I_l0i/b00>K<P0160>K<P003001Vo`3Vc800i/b005h0i/b0000J0>K<P0030000003Vc800i/b0
0280i/b000<006Ko0>K<P03Vc800N`3Vc8000`00I_l0i/b00>K<P0180>K<P003001Vo`3Vc800i/b0
05d0i/b0000J0>K<P0030000003Vc800i/b002<0i/b000<006Ko0>K<P03Vc800N@3Vc802001VodX0
i/b000<006Ko0>K<P03Vc800G@3Vc80001X0i/b000<000000>K<P03Vc800903Vc8000`00I_l0i/b0
0>K<P01e0>K<P0@006KoB`3Vc8000`00I_l0i/b00>K<P01M0>K<P0006P3Vc8000`000000i/b00>K<
P00T0>K<P003001Vo`3Vc800i/b007D0i/b000<006Ko0>K<P03Vc800C03Vc8000`00I_l0i/b00>K<
P01M0>K<P0006P3Vc8000`000000i/b00>K<P00U0>K<P003001Vo`3Vc800i/b007<0i/b000<006Ko
0>K<P03Vc800CP3Vc8000`00I_l0i/b00>K<P01L0>K<P0006P3Vc8000`000000i/b00>K<P00V0>K<
P003001Vo`3Vc800i/b00780i/b000<006Ko0>K<P03Vc800CP3Vc8000`00I_l0i/b00>K<P01L0>K<
P00000@0i/b000000000000000001@3Vc802000000@0i/b01P0000050>K<P0030000003Vc800i/b0
02H0i/b000<006Ko0>K<P03Vc800LP3Vc8000`00I_l0i/b00>K<P01>0>K<P08006KoG@3Vc8000004
0000003Vc800i/b0000000D0i/b00P0000050>K<P0050000003Vc800i/b00>K<P00000001@3Vc800
0`000000i/b00>K<P00W0>K<P003001Vo`3Vc800i/b00740i/b000<006Ko0>K<P03Vc800C`3Vc800
0`00I_l0i/b00>K<P01K0>K<P000103Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b0
00H0i/b000<000000>K<P03Vc800:03Vc8000`00I_l0i/b00>K<P01_0>K<P003001Vo`3Vc800i/b0
0500i/b01000I_mJ0>K<P000103Vc8000`000000i/b00>K<P00;0>K<P08000001P3Vc803000002P0
i/b000<006Ko0>K<P03Vc800K`3Vc8000`00I_l0i/b00>K<P01D0>K<P003001Vo`3Vc800i/b005L0
i/b000040>K<P0030000003Vc800i/b000`0i/b00P0000050>K<P0030000003Vc800i/b002T0i/b0
00<006Ko0>K<P03Vc800K@3Vc8000`00I_l0i/b00>K<P01F0>K<P003001Vo`3Vc800i/b005H0i/b0
00040>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P00Z0>K<P003001Vo`3Vc800i/b006`0i/b000<006Ko0>K<P03Vc800EP3Vc8000`00I_l0i/b00>K<
P01F0>K<P00000@000000>K<P03Vc80000002`3Vc8000`000000i/b00>K<P0020>K<P0030000003V
c800i/b000<0i/b000<000000>K<P03Vc800:P3Vc8000`00I_l0i/b00>K<P01Y0>K<P003001Vo`3V
c80006Ko05T0i/b000<006Ko0>K<P03Vc800EP3Vc80000@000002`3Vc805000000H0i/b000<00000
0>K<P03Vc800:`3Vc8000`00I_l0i/b00>K<P01W0>K<P004001Vo`3Vc80006Ko001VoeX0i/b000<0
06Ko0>K<P03Vc800E@3Vc80001X0i/b000<000000>K<P03Vc800;03Vc8000`00I_l0i/b00>K<P01V
0>K<P003001Vo`3Vc800i/b005/0i/b000<006Ko0>K<P03Vc800E@3Vc80001X0i/b000<000000>K<
P03Vc800;03Vc8000`00I_l0i/b00>K<P01U0>K<P003001Vo`3Vc800i/b005`0i/b000<006Ko0>K<
P03Vc800E@3Vc80001X0i/b000<000000>K<P03Vc800;@3Vc802001VofD0i/b000<006Ko0>K<P03V
c800G@3Vc8000`00I_l0i/b00>K<P01D0>K<P0006P3Vc8000`000000i/b00>K<P00_0>K<P003001V
o`3Vc800i/b00680i/b000<006Ko0>K<P03Vc800G@3Vc8000`00I_l0i/b00>K<P01D0>K<P0006P3V
c80200000300i/b000<006Ko0>K<P03Vc800H@3Vc8000`00I_l0i/b00>K<P01N0>K<P003001Vo`3V
c800i/b005@0i/b0000J0>K<P0030000003Vc800i/b002l0i/b000<006Ko0>K<P03Vc800H@3Vc800
0`00I_l0i/b00>K<P01O0>K<P0@006KoDP3Vc80001X0i/b000<000000>K<P03Vc800<03Vc8000`00
I_l0i/b00>K<P01O0>K<P003001Vo`3Vc800i/b006<0i/b00P00I_mA0>K<P0006P3Vc8000`000000
i/b00>K<P00`0>K<P003001Vo`3Vc800i/b005l0i/b000<006Ko0>K<P03Vc800I03Vc8000`00I_l0
i/b00>K<P01?0>K<P0006P3Vc8000`000000i/b00>K<P00a0>K<P003001Vo`3Vc800i/b005h0i/b0
00<006Ko0>K<P03Vc800I03Vc8000`00I_l0i/b00>K<P01?0>K<P0006P3Vc8000`000000i/b00>K<
P00a0>K<P003001Vo`3Vc800i/b005d0i/b000<006Ko0>K<P03Vc800I@3Vc8000`00I_l0i/b00>K<
P01?0>K<P0006P3Vc8000`000000i/b00>K<P00a0>K<P003001Vo`3Vc800i/b005X0i/b01000I_mX
0>K<P003001Vo`3Vc800i/b004h0i/b0000J0>K<P0030000003Vc800i/b00340i/b00P00I_mJ0>K<
P003001Vo`3Vc800i/b006X0i/b000<006Ko0>K<P03Vc800CP3Vc80001X0i/b000<000000>K<P03V
c800<P3Vc8000`00I_l0i/b00>K<P01H0>K<P003001Vo`3Vc800i/b006X0i/b000<006Ko0>K<P03V
c800CP3Vc80001X0i/b000<000000>K<P03Vc800<P3Vc805001VoeH0i/b000<006Ko0>K<P03Vc800
J`3Vc8000`00I_l0i/b00>K<P01=0>K<P0006P3Vc802000003L0i/b000<006Ko0>K<P03Vc800D`3V
c8000`00I_l0i/b00>K<P01/0>K<P003001Vo`3Vc800i/b004d0i/b0000J0>K<P0030000003Vc800
i/b003L0i/b000<006Ko0>K<P03Vc800DP3Vc8000`00I_l0i/b00>K<P01]0>K<P003001Vo`3Vc800
i/b004`0i/b0000J0>K<P0030000003Vc800i/b003L0i/b000<006Ko0>K<P03Vc800D@3Vc8000`00
I_l0i/b00>K<P01^0>K<P004001Vo`3Vc80006Ko001Vod/0i/b0000J0>K<P0030000003Vc800i/b0
03L0i/b000<006Ko0>K<P03Vc800D@3Vc8000`00I_l0i/b00>K<P01^0>K<P0<006Ko00<0i/b0001V
o`3Vc800B@3Vc80001X0i/b000<000000>K<P03Vc800=`3Vc8000`00I_l0i/b00>K<P01A0>K<P003
001Vo`3Vc800i/b00780i/b000<006Ko0>K<P03Vc800B03Vc80001X0i/b000<000000>K<P03Vc800
>03Vc8000`00I_l0i/b00>K<P01@0>K<P003001Vo`3Vc800i/b00780i/b000<006Ko0>K<P03Vc800
B03Vc80001X0i/b000<000000>K<P03Vc800>03Vc8000`00I_l0i/b00>K<P01<0>K<P004001Vo`3V
c800i/b0001VogH0i/b000<006Ko0>K<P03Vc800A`3Vc80001X0i/b000<000000>K<P03Vc800>03V
c8000`00I_l0i/b00>K<P01;0>K<P0D006KoMP3Vc8000`00I_l0i/b00>K<P0170>K<P0006P3Vc800
0`000000i/b00>K<P00i0>K<P003001Vo`3Vc800i/b004X0i/b000<006Ko0>K<P03Vc800N@3Vc800
0`00I_l0i/b00>K<P0160>K<P0006P3Vc8000`000000i/b00>K<P00i0>K<P003001Vo`3Vc800i/b0
04T0i/b000<006Ko0>K<P03Vc800NP3Vc8000`00I_l0i/b00>K<P0160>K<P0006P3Vc802000003/0
i/b01000I_m70>K<P003001Vo`3Vc800i/b007X0i/b000<006Ko0>K<P03Vc800AP3Vc80001X0i/b0
00<000000>K<P03Vc800?P3Vc8000`00I_l0i/b00>K<P0140>K<P003001Vo`3Vc800i/b007/0i/b0
00<006Ko0>K<P03Vc800A@3Vc80001X0i/b000<000000>K<P03Vc800?P3Vc8000`00I_l0i/b00>K<
P0140>K<P003001Vo`3Vc800i/b007/0i/b000<006Ko0>K<P03Vc800A@3Vc80001X0i/b000<00000
0>K<P03Vc800?`3Vc8000`00I_l0i/b00>K<P0120>K<P003001Vo`3Vc800i/b007`0i/b01@00I_m3
0>K<P0006P3Vc8000`000000i/b00>K<P00o0>K<P003001Vo`3Vc800i/b00480i/b000<006Ko0>K<
P03Vc800P@3Vc8000`00I_l0i/b00>K<P0100>K<P0006P3Vc8000`000000i/b00>K<P00o0>K<P003
001Vo`3Vc800i/b00440i/b000<006Ko0>K<P03Vc800PP3Vc8000`00I_l0i/b00>K<P0100>K<P000
6P3Vc8000`000000i/b00>K<P00o0>K<P003001Vo`3Vc800i/b003d0i/b00P00I_l20>K<P003001V
o`3Vc800i/b008<0i/b000<006Ko0>K<P03Vc800?`3Vc80000040>K<P00000000000000000D0i/b0
0P0000060>K<P0<000001P3Vc8000`000000i/b00>K<P0100>K<P003001Vo`3Vc800i/b003`0i/b0
1@00I_n60>K<P003001Vo`3Vc800i/b003h0i/b0000010000000i/b00>K<P00000050>K<P0800000
1`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00400i/b000<006Ko0>K<P03Vc800
>`3Vc8000`00I_l0i/b00>K<P0290>K<P003001Vo`3Vc800i/b003h0i/b000040>K<P0030000003V
c800i/b000P0i/b01@0000060>K<P0<00000@@3Vc8000`00I_l0i/b0001Vo`02001VocP0i/b000<0
06Ko0>K<P03Vc800RP3Vc8000`00I_l0i/b00>K<P00m0>K<P000103Vc8000`000000i/b00>K<P008
0>K<P0040000003Vc800i/b0000000L0i/b000<000000>K<P03Vc800@@3Vc803001Vo`030>K<P000
I_l0i/b003H0i/b000<006Ko0>K<P03Vc800S03Vc8000`00I_l0i/b00>K<P00l0>K<P000103Vc800
0`000000i/b00>K<P0090>K<P0030000003Vc800000000L0i/b000<000000>K<P03Vc800AP3Vc800
0`00I_l0i/b00>K<P00d0>K<P003001Vo`3Vc800i/b008`0i/b000<006Ko0>K<P03Vc800?03Vc800
00@0i/b000<000000>K<P03Vc8002P3Vc802000000L0i/b000<000000>K<P03Vc800A`3Vc8000`00
I_l0i/b00>K<P00c0>K<P003001Vo`3Vc800i/b008d0i/b00P00I_ll0>K<P00000@000000>K<P03V
c80000003@3Vc802000000L0i/b000<000000>K<P03Vc800B03Vc8000`00I_l0i/b00>K<P00a0>K<
P003001Vo`3Vc800i/b00900i/b000<006Ko0>K<P03Vc800>@3Vc80000@000003P3Vc8000`000000
i/b00>K<P0050>K<P0030000003Vc800i/b004P0i/b000<006Ko0>K<P03Vc800<@3Vc8000`00I_l0
i/b00>K<P02@0>K<P003001Vo`3Vc800i/b003T0i/b0000J0>K<P0030000003Vc800i/b004T0i/b0
00<006Ko0>K<P03Vc800:`3Vc803001Vo`80i/b000<006Ko0>K<P03Vc800T@3Vc8000`00I_l0i/b0
0>K<P00h0>K<P0006P3Vc8000`000000i/b00>K<P01:0>K<P003001Vo`3Vc800i/b002X0i/b000<0
06Ko0>K<P000I_l00P00I_nD0>K<P003001Vo`3Vc800i/b003P0i/b0000J0>K<P0030000003Vc800
i/b004/0i/b000<006Ko0>K<P03Vc800:@3Vc8000`00I_l0i/b00>K<P02F0>K<P003001Vo`3Vc800
i/b003P0i/b0000J0>K<P0030000003Vc800i/b004`0i/b000<006Ko0>K<P03Vc8009`3Vc8000`00
I_l0i/b00>K<P02G0>K<P003001Vo`3Vc800i/b003P0i/b0000J0>K<P0800000C@3Vc8000`00I_l0
i/b00>K<P00W0>K<P003001Vo`3Vc800i/b009P0i/b000<006Ko0>K<P03Vc8000`00I_ld0>K<P000
6P3Vc8000`000000i/b00>K<P01=0>K<P003001Vo`3Vc800i/b002H0i/b000<006Ko0>K<P03Vc800
V03Vc804001Vo`030>K<P000I_l0i/b00080i/b000<006Ko0>K<P03Vc8004@3Vc8000`00I_l0i/b0
0>K<P00;0>K<P003001Vo`3Vc800i/b000P0i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b000<0
00000>K<P03Vc800C@3Vc8000`00I_l0i/b00>K<P00Q0>K<P005001Vo`3Vc800i/b00>K<P000I_l0
W03Vc802001Vo`<0i/b000@006Ko0>K<P03Vc80006Ko4P3Vc8000`00I_l0i/b00>K<P00=0>K<P003
001Vo`3Vc800i/b000L0i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b000<000000>K<P03Vc800
CP3Vc8000`00I_l0i/b00>K<P00O0>K<P0<006Ko0P3Vc8000`00I_l0i/b00>K<P02O0>K<P004001V
o`3Vc800i/b0001Voa80i/b000<006Ko0>K<P03Vc8003@3Vc8000`00I_l0i/b00>K<P0070>K<P003
001Vo`3Vc800i/b00040i/b0000J0>K<P0030000003Vc800i/b004h0i/b000@006Ko0>K<P03Vc800
i/b00`00I_lJ0>K<P08006Ko00@0i/b0001Vo`00I_l006KoXP3Vc8001000I_l0i/b00>K<P000I_l4
0>K<P08006Ko00<0i/b0001Vo`00I_l00P00I_l60>K<P003001Vo`3Vc800i/b000H0i/b01000I_l5
0>K<P003001Vo`3Vc800i/b000H0i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b000<000000>K<
P03Vc800C`3Vc8001P00I_l0i/b00>K<P000I_l0i/b0001VoaX0i/b000@006Ko0>K<P03Vc800i/b0
0P00I_nS0>K<P003001Vo`3Vc80006Ko00D0i/b00P00I_l40>K<P003001Vo`3Vc800i/b000<0i/b0
00<006Ko0>K<P03o00001@3Vc8000`00I_l0i/b00>K<P0050>K<P0030?l0003Vc80006Ko00P0i/b0
00<006Ko0>K<P03Vc8000@3Vc80001X0i/b000<000000>K<P03Vc800C`3Vc803001Vo`80i/b000<0
06Ko0>K<P03Vc8001P3Vc8030?l000D0i/b000<0o`000>K<P03Vc8001`3Vc8000`00I_l0i/b00>K<
P02V0>K<P003001Vo`3Vc80006Ko00D0i/b000<006Ko0>K<P03Vc800103Vc8000`00I_l0i/b00>K<
P0020>K<P003001Vo`3o0000i/b000D0i/b000<006Ko0>K<P03Vc8001P3Vc8000`3o000006Ko0>K<
P0070>K<P003001Vo`3Vc800i/b00040i/b0000J0>K<P0030000003Vc800i/b00500i/b000<006Ko
0>K<P03Vc8000P3Vc8000`00I_l0i/b00>K<P0020>K<P08006Ko00@0i/b00?l0003Vc800o`00103V
c8030?l000040>K<P000I_l006Ko001Vo`<0i/b000<006Ko0>K<P03Vc800Y`3Vc8000`00I_l0i/b0
001Vo`050>K<P003001Vo`3Vc800i/b000@0i/b000<006Ko0>K<P03Vc8000P3Vc8000`00I_l0o`00
0>K<P0050>K<P003001Vo`3Vc800i/b000H0i/b000<0o`00001Vo`3Vc8001`3Vc8000`00I_l0i/b0
0>K<P0010>K<P0006P3Vc8000`000000i/b00>K<P01E0>K<P004001Vo`3o0000o`000?l000<006Ko
00D0i/b00?l0003Vc800o`000>K<P002001Vo`080>K<P03o0000i/b00>K<P03o000006Ko0>K<P000
I_l30>K<P003001Vo`3Vc800i/b00:P0i/b00P00I_l50>K<P08006Ko0P3o0000103Vc800o`000?l0
0000I_l40>K<P003001Vo`3Vc800i/b000D0i/b000<006Ko0?l0003o00000P3o00050>K<P003001V
o`3Vc800i/b000H0i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b000<000000>K<P03Vc800EP3V
c8001000I_l0i/b00?l00000I_l20>K<P005001Vo`3Vc800i/b00>K<P03o00000`00I_l0103o0000
i/b00>K<P000I_l30>K<P003001Vo`3o000006Ko0:`0i/b000<006Ko0>K<P03Vc8000`3Vc803001V
o`040>K<P03o0000o`00001Vo`D0i/b000<006Ko0>K<P03Vc8001@3Vc8000`00I_l0i/b00>K<P007
0>K<P003001Vo`3Vc800i/b000H0i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b00P00001G0>K<
P004001Vo`3Vc80006Ko0?l00080i/b000D006Ko0>K<P03Vc800i/b0001Vo`020?l00005001Vo`3V
c800i/b00>K<P000I_l00`3Vc8000`3o000006Ko001Vo`2/0>K<P003001Vo`3Vc800i/b000<0i/b0
00<006Ko0>K<P000I_l00`00I_l60>K<P0030?l00000I_l0i/b000@0i/b01@00I_l50>K<P003001V
o`3o0000i/b000L0i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b000<000000>K<P03Vc800EP3V
c803001Vo`<0o`000P00I_l20>K<P005001Vo`3o0000o`000>K<P000I_l00P3Vc8001000I_l0o`00
0>K<P03o00020>K<P0030?l0003Vc800i/b00:X0i/b000<006Ko0>K<P03Vc8000`3Vc8000`00I_l0
o`000?l000030?l000H0i/b000<0o`00001Vo`3Vc8001@3Vc8000`00I_l0i/b00>K<P0060>K<P003
001Vo`3o0000i/b000L0i/b000<006Ko0>K<P03Vc8000@3Vc80001X0i/b000<000000>K<P03Vc800
E@3Vc8000`3o0000i/b00>K<P0020>K<P080o`0000@0i/b0001Vo`3Vc80006Ko103Vc803001Vo`04
0>K<P03o0000o`000?l000<0i/b000<0o`000>K<P03Vc800Y`3Vc8020?l00003001Vo`3Vc800i/b0
00<0i/b000<006Ko0>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003Vc80006Ko
00D0i/b000<006Ko0>K<P03Vc8001@3Vc8000`00I_l0i/b00?l000080>K<P003001Vo`3Vc800i/b0
0040i/b0000J0>K<P0030000003Vc800i/b004l0i/b00`3o00020>K<P0030?l0003Vc800i/b000H0
i/b00`00I_l50>K<P08006Ko0P3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0003Vc800i/b00:L0
i/b000<0o`000>K<P03o00002P3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003Vc800i/b000D0
i/b000<0o`000>K<P03Vc8001`3Vc8000`3o0000i/b00>K<P0060>K<P0030?l0003Vc800i/b00040
i/b0000J0>K<P0030000003Vc800i/b004l0i/b000H0o`000>K<P03Vc800o`000>K<P03o000J0>K<
P0040?l0003Vc800i/b00>K<P080o`00X`3Vc8000`3o0000i/b00?l000060>K<P0@0o`00203Vc800
0`3o0000i/b00>K<P0030>K<P0D0o`001@3Vc8000`3o0000i/b00>K<P0070>K<P0030?l0003Vc800
i/b00040i/b0000J0>K<P0030000003Vc800i/b004l0i/b000<0o`000>K<P03Vc8000`3o000J0>K<
P0030?l0003Vc800i/b000<0o`00X`3Vc8000`3o0000i/b00?l0000B0>K<P0030?l0003Vc800i/b0
00@0i/b000<0o`000>K<P03Vc8001P3Vc8000`3o0000i/b00>K<P0070>K<P0030?l0003Vc800i/b0
0040i/b0000J0>K<P0030000003Vc800i/b004h0i/b000<0o`000>K<P03Vc8007`3Vc8030?l00080
i/b000<0o`000>K<P03Vc800W`3Vc800103o0000i/b00>K<P03o000C0>K<P0030?l0003Vc800i/b0
00<0i/b000<0o`000>K<P03Vc8001@3Vc8000`3o0000i/b00>K<P0080>K<P0030?l0003Vc800i/b0
0040i/b0000J0>K<P0030000003Vc800i/b004d0i/b000<0o`000>K<P03Vc800803Vc8020?l000<0
i/b000<0o`000>K<P03Vc800VP3Vc8020?l000<0i/b000<0o`000>K<P03Vc800<@3Vc80001X0i/b0
00<000000>K<P03Vc800C@3Vc8000`3o0000i/b00>K<P00U0>K<P0030?l0003Vc800i/b009X0i/b0
0`3o00000`3Vc800o`000>K<P00c0>K<P0006P3Vc802000004d0i/b000<0o`000>K<P03Vc8009`3V
c8000`3o0000i/b00>K<P02H0>K<P0030?l0003Vc800i/b000<0o`00=03Vc80001X0i/b000<00000
0>K<P03Vc800C03Vc8000`3o0000i/b00>K<P00W0>K<P0030?l0003Vc800i/b009P0i/b000<0o`00
0>K<P03Vc800=`3Vc80001X0i/b000<000000>K<P03Vc800B`3Vc8000`3o0000i/b00>K<P00Y0>K<
P0030?l0003Vc800i/b009H0i/b000<0o`000>K<P03Vc800>03Vc80001X0i/b000<000000>K<P03V
c800BP3Vc8000`3o0000i/b00>K<P00Z0>K<P0030?l0003Vc800o`000080o`00U03Vc8000`3o0000
i/b00>K<P00h0>K<P0006P3Vc8000`000000i/b00>K<P0190>K<P0030?l0003Vc800i/b002/0i/b0
0`3o00020>K<P0030?l0003Vc800i/b00940i/b000<0o`000>K<P03Vc800>03Vc80001X0i/b000<0
00000>K<P03Vc800B03Vc8000`3o0000i/b00>K<P00a0>K<P0030?l0003Vc800i/b00900i/b000<0
o`000>K<P03Vc800>@3Vc80001X0i/b000<000000>K<P03Vc800B03Vc8000`3o0000i/b00>K<P00a
0>K<P0030?l0003Vc800i/b00900i/b000<0o`000>K<P03Vc800>@3Vc80000040>K<P00000000000
000000D0i/b00P0000050>K<P0@000001P3Vc8000`000000i/b00>K<P0170>K<P0030?l0003Vc800
i/b00380i/b000<0o`000>K<P03Vc800SP3Vc8020?l003`0i/b0000010000000i/b00>K<P0000005
0>K<P08000001@3Vc8001@000000i/b00>K<P03Vc800000000D0i/b000<000000>K<P03Vc800AP3V
c8000`3o0000i/b00>K<P00d0>K<P0030?l0003Vc800i/b008`0i/b000<0o`000>K<P03Vc800?03V
c80000@0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc800@@3Vc8020?l00080i/b000<0o`000>K<P03Vc800=@3Vc800
0`3o0000i/b00>K<P02<0>K<P0030?l0003Vc800i/b003`0i/b000040>K<P0030000003Vc800i/b0
00P0i/b000@000000>K<P03Vc800i/b00P0000050>K<P0<00000@@3Vc8000`3o0000i/b00?l00002
0?l003P0i/b000<0o`000>K<P03Vc800RP3Vc8000`3o0000i/b00>K<P00m0>K<P000103Vc8000`00
0000i/b00>K<P0080>K<P0D000001P3Vc8000`000000i/b00>K<P0100>K<P0030?l0003Vc800i/b0
03/0i/b000<0o`000>K<P03Vc800R@3Vc8000`3o0000i/b00>K<P00n0>K<P000103Vc8000`000000
i/b00>K<P0090>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800@03Vc8000`3o0000
i/b00>K<P00k0>K<P0H0o`00QP3Vc8000`3o0000i/b00>K<P00n0>K<P00000@000000>K<P03Vc800
0000303Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b003l0i/b000<0o`000>K<P03V
c800?@3Vc8020?l00080i/b000<0o`000>K<P03Vc800P`3Vc8000`3o0000i/b00>K<P00o0>K<P000
1000000=0>K<P0@000001@3Vc8000`000000i/b00>K<P00o0>K<P0030?l0003Vc800i/b00440i/b0
00<0o`000>K<P03Vc800PP3Vc8000`3o0000i/b00>K<P0100>K<P0006P3Vc8000`000000i/b00>K<
P00o0>K<P0030?l0003Vc800i/b00440i/b000<0o`000>K<P03Vc800PP3Vc8000`3o0000i/b00>K<
P0100>K<P0006P3Vc8000`000000i/b00>K<P00o0>K<P0030?l0003Vc800i/b00480i/b000<0o`00
0>K<P03Vc800O03Vc8050?l004<0i/b0000J0>K<P0030000003Vc800i/b003l0i/b000<0o`000>K<
P03Vc800@P3Vc8000`3o0000i/b00>K<P01l0>K<P0040?l0003Vc800i/b00?l004@0i/b0000J0>K<
P0030000003Vc800i/b003h0i/b000<0o`000>K<P03Vc800A03Vc8000`3o0000i/b00>K<P01k0>K<
P0030?l0003Vc800i/b004D0i/b0000J0>K<P0030000003Vc800i/b003X0i/b0103o00170>K<P003
0?l0003Vc800i/b007/0i/b000<0o`000>K<P03Vc800A@3Vc80001X0i/b00P00000j0>K<P080o`00
00<0i/b00?l0003o0000A`3Vc8000`3o0000i/b00>K<P01j0>K<P0030?l0003Vc800i/b004H0i/b0
000J0>K<P0030000003Vc800i/b003T0i/b000<0o`000>K<P03Vc800BP3Vc8000`3o0000i/b00>K<
P01i0>K<P0030?l0003Vc800i/b004H0i/b0000J0>K<P0030000003Vc800i/b003T0i/b000<0o`00
0>K<P03Vc800BP3Vc8000`3o0000i/b00?l000020?l007H0i/b000<0o`000>K<P03Vc800A`3Vc800
01X0i/b000<000000>K<P03Vc800>03Vc8000`3o0000i/b00>K<P01<0>K<P080o`0000<0i/b00?l0
003Vc800M@3Vc8000`3o0000i/b00>K<P0170>K<P0006P3Vc8000`000000i/b00>K<P00h0>K<P003
0?l0003Vc800i/b004l0i/b000<0o`000>K<P03Vc800M03Vc8000`3o0000i/b00>K<P0170>K<P000
6P3Vc8000`000000i/b00>K<P00h0>K<P0030?l0003Vc800i/b00500i/b000<0o`000>K<P03Vc800
LP3Vc8000`3o0000i/b00>K<P0180>K<P0006P3Vc8000`000000i/b00>K<P00g0>K<P0030?l0003V
c800i/b00540i/b000<0o`000>K<P03Vc800K`3Vc800103o0000i/b00>K<P03o001:0>K<P0006P3V
c8000`000000i/b00>K<P00g0>K<P0030?l0003Vc800i/b00540i/b000<0o`000>K<P03Vc800KP3V
c800103o0000i/b00?l0003o001;0>K<P0006P3Vc8000`000000i/b00>K<P00g0>K<P0030?l0003V
c800i/b00540i/b000<0o`000>K<P03Vc800KP3Vc8000`3o0000i/b00>K<P01<0>K<P0006P3Vc802
000003L0i/b000<0o`000>K<P03Vc800D`3Vc8000`3o0000i/b00>K<P01/0>K<P0030?l0003Vc800
i/b004d0i/b0000J0>K<P0030000003Vc800i/b00380i/b01@3o001E0>K<P0030?l0003Vc800i/b0
06`0i/b000<0o`000>K<P03Vc800C@3Vc80001X0i/b000<000000>K<P03Vc800<P3Vc8000`3o0000
i/b00>K<P01H0>K<P0030?l0003Vc800i/b006/0i/b000<0o`000>K<P03Vc800C@3Vc80001X0i/b0
00<000000>K<P03Vc800<P3Vc8000`3o0000i/b00>K<P01H0>K<P0030?l0003Vc800i/b006X0i/b0
00<0o`000>K<P03Vc800CP3Vc80001X0i/b000<000000>K<P03Vc800<@3Vc8000`3o0000i/b00>K<
P01I0>K<P0D0o`00J03Vc8000`3o0000i/b00>K<P01>0>K<P0006P3Vc8000`000000i/b00>K<P00a
0>K<P0030?l0003Vc800i/b005/0i/b000<0o`000>K<P03o0000I`3Vc8000`3o0000i/b00>K<P01?
0>K<P0006P3Vc8000`000000i/b00>K<P00a0>K<P0030?l0003Vc800i/b005h0i/b000<0o`000>K<
P03Vc800I03Vc8000`3o0000i/b00>K<P01?0>K<P0006P3Vc8000`000000i/b00>K<P00a0>K<P003
0?l0003Vc800i/b005h0i/b000<0o`000>K<P03Vc800I03Vc8000`3o0000i/b00>K<P01?0>K<P000
6P3Vc8000`000000i/b00>K<P00`0>K<P0030?l0003Vc800i/b005l0i/b000<0o`000>K<P03Vc800
H`3Vc8020?l00540i/b0000J0>K<P0030000003Vc800i/b00300i/b000<0o`000>K<P03Vc800H03V
c8000`3o0000i/b00>K<P01O0>K<P0@0o`00DP3Vc80001X0i/b00P00000`0>K<P0030?l0003Vc800
i/b00640i/b000<0o`000>K<P03Vc800GP3Vc8020?l005D0i/b0000J0>K<P0030000003Vc800i/b0
02l0i/b000<0o`000>K<P03Vc800H@3Vc8000`3o0000i/b00>K<P01N0>K<P0030?l0003Vc800i/b0
05@0i/b0000J0>K<P0030000003Vc800i/b002d0i/b00`3o001T0>K<P0030?l0003Vc800i/b005d0
i/b000<0o`000>K<P03Vc800E03Vc80001X0i/b000<000000>K<P03Vc800;03Vc8000`3o0000i/b0
0>K<P01U0>K<P0030?l0003Vc800i/b005d0i/b000<0o`000>K<P03Vc800E03Vc80001X0i/b000<0
00000>K<P03Vc800;03Vc8000`3o0000i/b00>K<P01U0>K<P080o`00G@3Vc8000`3o0000i/b00>K<
P01E0>K<P0006P3Vc8000`000000i/b00>K<P00[0>K<P0030?l0003Vc800i/b006L0i/b000<0o`00
0>K<P03Vc800F`3Vc8000`3o0000i/b00>K<P01E0>K<P0006P3Vc8000`000000i/b00>K<P00Z0>K<
P0030?l0003Vc800i/b006T0i/b00`3o001J0>K<P0030?l0003Vc800i/b005D0i/b00000103Vc800
00000000000000050>K<P08000001@3Vc804000000H0i/b000<000000>K<P03Vc800:P3Vc8000`3o
0000i/b00>K<P01/0>K<P0030?l0003Vc800i/b005H0i/b000<0o`000>K<P03Vc800EP3Vc8000004
0000003Vc800i/b0000000D0i/b00P0000040>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8000`3Vc8000`000000i/b00>K<P00Y0>K<P0030?l0003Vc800i/b006d0i/b000<0o`000>K<
P03Vc800EP3Vc8000`3o0000i/b00>K<P01F0>K<P000103Vc8000`000000i/b00>K<P0080>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc803000002P0i/b000<0o`000>K<P03V
c800KP3Vc8000`3o0000i/b00>K<P01E0>K<P0030?l0003Vc800i/b005L0i/b000040>K<P0030000
003Vc800i/b000T0i/b000<000000>K<P03Vc8000P0000050>K<P0030000003Vc800i/b002P0i/b0
00<0o`000>K<P03Vc800K`3Vc8000`3o0000i/b00>K<P01A0>K<P0@0o`00F@3Vc80000@0i/b000<0
00000>K<P03Vc8002@3Vc804000000H0i/b000<000000>K<P03Vc8009`3Vc8000`3o0000i/b00>K<
P01`0>K<P0030?l0003Vc800i/b00500i/b000<0o`000>K<P03Vc800F`3Vc80000@0i/b000<00000
0>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8009P3Vc8000`3o0000i/b00>K<P01b0>K<P0030?l0003Vc800i/b004l0i/b000<0o`00
0>K<P03Vc800F`3Vc80000040000003Vc800i/b0000000/0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800i/b002H0i/b000<0o`000>K<P03Vc800LP3Vc800
0`3o0000i/b00>K<P01>0>K<P0030?l0003Vc800i/b005`0i/b00004000000`0i/b0100000060>K<
P0030000003Vc800i/b002D0i/b000<0o`000>K<P03Vc800L`3Vc8000`3o0000i/b00>K<P01>0>K<
P0030?l0003Vc800i/b005`0i/b0000J0>K<P0030000003Vc800i/b002@0i/b000<0o`000>K<P03V
c800M@3Vc8000`3o0000i/b00>K<P01=0>K<P0030?l0003Vc800i/b005`0i/b0000J0>K<P0030000
003Vc800i/b002@0i/b000<0o`000>K<P03Vc800M@3Vc8040?l004/0i/b000<0o`000>K<P03Vc800
G@3Vc80001X0i/b000<000000>K<P03Vc8008`3Vc8000`3o0000i/b00>K<P01g0>K<P0@0o`00BP3V
c8000`3o0000i/b00>K<P01M0>K<P0006P3Vc8000`000000i/b00>K<P00R0>K<P0030?l0003Vc800
i/b007/0i/b000<0o`000>K<P03Vc800B03Vc8000`3o0000i/b00>K<P01M0>K<P0006P3Vc8020000
02<0i/b000<0o`000>K<P03Vc800O03Vc8000`3o0000i/b00>K<P0160>K<P0030?l0003Vc800i/b0
05h0i/b0000J0>K<P0030000003Vc800i/b00240i/b000<0o`000>K<P03Vc800O@3Vc8000`3o0000
i/b00>K<P0150>K<P080o`00H03Vc80001X0i/b000<000000>K<P03Vc800803Vc8000`3o0000i/b0
0>K<P01o0>K<P0030?l0003Vc800i/b00440i/b0103o001Q0>K<P0006P3Vc8000`000000i/b00>K<
P00O0>K<P0030?l0003Vc800i/b00800i/b000<0o`000>K<P03Vc800@03Vc8020?l006@0i/b0000J
0>K<P0030000003Vc800i/b001h0i/b000<0o`000>K<P03Vc800P@3Vc8000`3o0000i/b00>K<P010
0>K<P0030?l0003Vc800i/b006<0i/b0000J0>K<P0030000003Vc800i/b001d0i/b000<0o`000>K<
P03Vc800PP3Vc8000`3o0000i/b00>K<P0100>K<P0030?l0003Vc800i/b006<0i/b0000J0>K<P003
0000003Vc800i/b001`0i/b000<0o`000>K<P03Vc800Q03Vc8000`3o0000i/b00>K<P00n0>K<P003
0?l0003Vc800i/b006@0i/b0000J0>K<P0030000003Vc800i/b001/0i/b000<0o`000>K<P03Vc800
QP3Vc8000`3o0000i/b00>K<P00m0>K<P0030?l0003Vc800i/b006@0i/b0000J0>K<P0030000003V
c800i/b001/0i/b000<0o`000>K<P03Vc800Q`3Vc8030?l003`0i/b000<0o`000>K<P03Vc800I03V
c80001X0i/b000<000000>K<P03Vc8006P3Vc8000`3o0000i/b00>K<P02:0>K<P080o`00>`3Vc800
0`3o0000i/b00>K<P01T0>K<P0006P3Vc802000001X0i/b000<0o`000>K<P03Vc800S03Vc8000`3o
0000i/b00>K<P00h0>K<P0030?l0003Vc800i/b006D0i/b0000J0>K<P0030000003Vc800i/b001P0
i/b000<0o`000>K<P03Vc800SP3Vc8000`3o0000i/b00>K<P00c0>K<P0@0o`00J03Vc80001X0i/b0
00<000000>K<P03Vc8005`3Vc8000`3o0000i/b00>K<P02?0>K<P0030?l0003Vc800i/b00380i/b0
0P3o001[0>K<P0006P3Vc8000`000000i/b00>K<P00F0>K<P0030?l0003Vc800i/b00900i/b000<0
o`000>K<P03Vc800<P3Vc8000`3o0000i/b00>K<P01Z0>K<P0006P3Vc8000`000000i/b00>K<P00E
0>K<P0030?l0003Vc800i/b00980i/b000<0o`000>K<P03Vc800<@3Vc8000`3o0000i/b00>K<P01Z
0>K<P0006P3Vc8000`000000i/b00>K<P00D0>K<P0030?l0003Vc800i/b009<0i/b00P3o000a0>K<
P0030?l0003Vc800i/b006/0i/b0000J0>K<P0030000003Vc800i/b001<0i/b000<0o`000>K<P03V
c800U@3Vc8040?l002d0i/b000<0o`000>K<P03Vc800K03Vc80001X0i/b000<000000>K<P03Vc800
4P3Vc8000`3o0000i/b00>K<P02I0>K<P080o`00;03Vc8000`3o0000i/b00>K<P01/0>K<P0006P3V
c8000`000000i/b00>K<P00B0>K<P0030?l0003Vc800i/b009/0i/b000<0o`000>K<P03Vc800:03V
c8000`3o0000i/b00>K<P01]0>K<P0006P3Vc80200000180i/b000<0o`000>K<P03Vc800W03Vc800
0`3o0000i/b00>K<P00U0>K<P0@0o`00K`3Vc80001X0i/b000<000000>K<P03Vc800403Vc8000`3o
0000i/b00>K<P02M0>K<P0030?l0003Vc800i/b002@0i/b000<0o`000>K<P03Vc800L@3Vc80001X0
i/b000<000000>K<P03Vc8003`3Vc8000`3o0000i/b00>K<P02O0>K<P0030?l0003Vc800i/b00280
i/b000<0o`000>K<P03Vc800LP3Vc80001X0i/b000<000000>K<P03Vc8003@3Vc8020?l00:<0i/b0
0P3o000R0>K<P0030?l0003Vc800i/b00780i/b0000J0>K<P0030000003Vc800i/b000`0i/b000<0
o`000>K<P03Vc800Y03Vc8040?l001d0i/b00P3o001e0>K<P0006P3Vc8000`000000i/b00>K<P00;
0>K<P0030?l0003Vc800i/b00:P0i/b00P3o000L0>K<P0030?l0003Vc800i/b007@0i/b0000J0>K<
P0030000003Vc800i/b000X0i/b00P3o002[0>K<P0030?l0003Vc800i/b001H0i/b0103o001g0>K<
P0006P3Vc8000`000000i/b00>K<P0060>K<P0D0o`00[@3Vc8020?l001D0i/b000<0o`000>K<P03V
c800N@3Vc80000l0i/b01P0000050>K<P0030000003Vc800i/b000D0i/b00P3o002b0>K<P0D0o`00
3`3Vc8020?l007`0i/b0000B0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8000`3V
c8020?l00;T0i/b00P3o00090>K<P0D0o`00O@3Vc8000180i/b000<000000>K<P03Vc8001@3Vc807
0?l00;/0i/b02P3o00220>K<P0004P3Vc8000`000000i/b00>K<P03o0>K<P5@0i/b0000B0>K<P003
0000003Vc800i/b00?l0i/b0E03Vc8000180i/b000<000000>K<P03Vc800o`3Vc81D0>K<P0004P3V
c8000`000000i/b00>K<P03o0>K<P5@0i/b0000@0>K<P0<00000o`3Vc81F0>K<P000o`3Vc81Y0>K<
P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-11.688, -0.0981885, \
0.553299, 0.00647657}}]
}, Open  ]],

Cell["\<\

The probabilities to find the state in a particular eigenstate are now time \
dependent, we obtain a superposition of a fast and a slow oscillation. The \
frequency of the slow oscillation is called the Rabi frequency.\
\>", "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Rabi Frequency", "Section"],

Cell[TextData[{
  "In order to find the involved frequencies, we perform a Fourier transform \
on ",
  Cell[BoxData[
      \(TraditionalForm\`\(\(|\)\(a(t)\)\( | \^2\)\)\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\( \
(*Fourier*) \)\(\[IndentingNewLine]\)\(numfourier[fname_, tmax_] := 
        Block[{t, n00, n0m1, n0p1, nmax = 250, at, lmax, 
            i}, \[IndentingNewLine]func[t_] = 
            fname[t]; \[IndentingNewLine]meanpop = 
            NIntegrate[func[t], {t, 0, tmax}]/tmax; \[IndentingNewLine]at = 
            Table[func[i\ tmax\/nmax], {i, 0, nmax}] - 
              meanpop; \[IndentingNewLine]fA = 
            Fourier[at]; \[IndentingNewLine]lmax = 
            Position[Abs[Take[fA, Round[nmax/2]]], 
              Max[Abs[Take[fA, Round[nmax/2]]]]]; \[IndentingNewLine]n00 = 
            Min[Flatten[
                lmax]]; \[IndentingNewLine] (*to\ slightly\ impltove\ the\ \
accuracy\ of\ the\ \(\(result\)\(:\)\)*) \[IndentingNewLine]n0m1 = 
            Max[n00 - 1, 1]; \[IndentingNewLine]n0p1 = 
            n00 + 1; \[IndentingNewLine]n0 = \((n00*Abs[fA[\([n00]\)]] + 
                    n0m1*Abs[fA[\([n0m1]\)]] + 
                    n0p1*Abs[fA[\([n0p1]\)]])\)/\((Abs[fA[\([n00]\)]] + 
                    Abs[fA[\([n0m1]\)]] + Abs[fA[\([n0p1]\)]])\) - 
              1;\[IndentingNewLine]];\)\)\)], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(n0p1\)\" is similar to \
existing symbol \"\!\(n0m1\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(lmax\)\" is similar to \
existing symbol \"\!\(tmax\)\"."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(nmax\)\" is similar to \
existing symbols \!\({lmax, tmax}\)."\)], "Message"]
}, Open  ]],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(numfourier[pup, tmax];\)\), "\[IndentingNewLine]", 
    \(\(ListPlot[Abs[fA], \ PlotJoined \[Rule] True, 
        PlotRange \[Rule] {{0, 100}, All}, PlotStyle \[Rule] {Hue[1]}, 
        AxesLabel \[Rule] {"\<\[Omega]\>", "\<\>"}];\)\)}], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-1.04083e-17 0.01 0.0145587 0.469917 [
[.2 .00206 -6 -9 ]
[.2 .00206 6 0 ]
[.4 .00206 -6 -9 ]
[.4 .00206 6 0 ]
[.6 .00206 -6 -9 ]
[.6 .00206 6 0 ]
[.8 .00206 -6 -9 ]
[.8 .00206 6 0 ]
[1 .00206 -9 -9 ]
[1 .00206 9 0 ]
[1.025 .01456 0 -4.90625 ]
[1.025 .01456 10 4.90625 ]
[-0.0125 .10854 -18 -4.5 ]
[-0.0125 .10854 0 4.5 ]
[-0.0125 .20253 -18 -4.5 ]
[-0.0125 .20253 0 4.5 ]
[-0.0125 .29651 -18 -4.5 ]
[-0.0125 .29651 0 4.5 ]
[-0.0125 .39049 -18 -4.5 ]
[-0.0125 .39049 0 4.5 ]
[-0.0125 .48448 -6 -4.5 ]
[-0.0125 .48448 0 4.5 ]
[-0.0125 .57846 -18 -4.5 ]
[-0.0125 .57846 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.2 .01456 m
.2 .02081 L
s
[(20)] .2 .00206 0 1 Mshowa
.4 .01456 m
.4 .02081 L
s
[(40)] .4 .00206 0 1 Mshowa
.6 .01456 m
.6 .02081 L
s
[(60)] .6 .00206 0 1 Mshowa
.8 .01456 m
.8 .02081 L
s
[(80)] .8 .00206 0 1 Mshowa
1 .01456 m
1 .02081 L
s
[(100)] 1 .00206 0 1 Mshowa
.125 Mabswid
.05 .01456 m
.05 .01831 L
s
.1 .01456 m
.1 .01831 L
s
.15 .01456 m
.15 .01831 L
s
.25 .01456 m
.25 .01831 L
s
.3 .01456 m
.3 .01831 L
s
.35 .01456 m
.35 .01831 L
s
.45 .01456 m
.45 .01831 L
s
.5 .01456 m
.5 .01831 L
s
.55 .01456 m
.55 .01831 L
s
.65 .01456 m
.65 .01831 L
s
.7 .01456 m
.7 .01831 L
s
.75 .01456 m
.75 .01831 L
s
.85 .01456 m
.85 .01831 L
s
.9 .01456 m
.9 .01831 L
s
.95 .01456 m
.95 .01831 L
s
.25 Mabswid
0 .01456 m
1 .01456 L
s
gsave
1.025 .01456 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
0 .10854 m
.00625 .10854 L
s
[(0.2)] -0.0125 .10854 1 0 Mshowa
0 .20253 m
.00625 .20253 L
s
[(0.4)] -0.0125 .20253 1 0 Mshowa
0 .29651 m
.00625 .29651 L
s
[(0.6)] -0.0125 .29651 1 0 Mshowa
0 .39049 m
.00625 .39049 L
s
[(0.8)] -0.0125 .39049 1 0 Mshowa
0 .48448 m
.00625 .48448 L
s
[(1)] -0.0125 .48448 1 0 Mshowa
0 .57846 m
.00625 .57846 L
s
[(1.2)] -0.0125 .57846 1 0 Mshowa
.125 Mabswid
0 .03805 m
.00375 .03805 L
s
0 .06155 m
.00375 .06155 L
s
0 .08505 m
.00375 .08505 L
s
0 .13204 m
.00375 .13204 L
s
0 .15553 m
.00375 .15553 L
s
0 .17903 m
.00375 .17903 L
s
0 .22602 m
.00375 .22602 L
s
0 .24952 m
.00375 .24952 L
s
0 .27301 m
.00375 .27301 L
s
0 .32 m
.00375 .32 L
s
0 .3435 m
.00375 .3435 L
s
0 .367 m
.00375 .367 L
s
0 .41399 m
.00375 .41399 L
s
0 .43748 m
.00375 .43748 L
s
0 .46098 m
.00375 .46098 L
s
0 .50797 m
.00375 .50797 L
s
0 .53147 m
.00375 .53147 L
s
0 .55496 m
.00375 .55496 L
s
0 .60196 m
.00375 .60196 L
s
.25 Mabswid
0 0 m
0 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.5 Mabswid
.01 .01472 m
.02 .59227 L
.03 .60332 L
.04 .26104 L
.05 .17791 L
.06 .13855 L
.07 .11508 L
.08 .09934 L
.09 .08798 L
.1 .07937 L
.11 .07261 L
.12 .06714 L
.13 .06263 L
.14 .05885 L
.15 .05562 L
.16 .05283 L
.17 .0504 L
.18 .04827 L
.19 .04637 L
.2 .04468 L
.21 .04315 L
.22 .04177 L
.23 .04052 L
.24 .03937 L
.25 .03832 L
.26 .03735 L
.27 .03644 L
.28 .0356 L
.29 .03481 L
.3 .03407 L
.31 .03336 L
.32 .03268 L
.33 .03203 L
.34 .0314 L
.35 .03078 L
.36 .03022 L
.37 .03019 L
.38 .0236 L
.39 .03783 L
.4 .02204 L
.41 .05032 L
.42 .0351 L
.43 .03227 L
.44 .03094 L
.45 .03009 L
.46 .02947 L
.47 .02898 L
.48 .02856 L
.49 .02819 L
.5 .02786 L
Mistroke
.51 .02756 L
.52 .02729 L
.53 .02704 L
.54 .0268 L
.55 .02657 L
.56 .02636 L
.57 .02617 L
.58 .02598 L
.59 .0258 L
.6 .02563 L
.61 .02546 L
.62 .02531 L
.63 .02516 L
.64 .02502 L
.65 .02488 L
.66 .02475 L
.67 .02462 L
.68 .0245 L
.69 .02439 L
.7 .02428 L
.71 .02417 L
.72 .02407 L
.73 .02397 L
.74 .02387 L
.75 .02378 L
.76 .02369 L
.77 .0236 L
.78 .02352 L
.79 .02345 L
.8 .02337 L
.81 .02329 L
.82 .02322 L
.83 .02315 L
.84 .02309 L
.85 .02303 L
.86 .02296 L
.87 .02291 L
.88 .02285 L
.89 .02279 L
.9 .02274 L
.91 .02269 L
.92 .02264 L
.93 .02259 L
.94 .02255 L
.95 .02251 L
.96 .02246 L
.97 .02242 L
.98 .02239 L
.99 .02235 L
1 .02232 L
Mistroke
Mfstroke
1 .02232 m
1 .02232 L
s
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000D@3Vc806
000000@0i/b00`00000d0>K<P0<000001@3Vc80300000380i/b0100000050>K<P0<00000<`3Vc804
000000D0i/b00`00000]0>K<P0H00000103Vc803000000D0i/b00`00000<0>K<P000DP3Vc8001@00
0000i/b00>K<P03Vc800000000<0i/b000@000000>K<P03Vc8000000=@3Vc8000`000000i/b00>K<
P0030>K<P0040000003Vc800i/b000000380i/b000D000000>K<P03Vc800i/b0000000030>K<P004
0000003Vc800i/b000000380i/b000<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<P03Vc800
00000080i/b000<000000>K<P03Vc800;P3Vc8000`000000i/b00>K<P0030>K<P0040000003Vc800
i/b0000000@0i/b000@000000>K<P03Vc8000000303Vc80005<0i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b002l0i/b01@0000030>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc800;P3Vc8000`000000i/b00>K<P0020>K<P0040000003V
c800i/b0000000@0i/b000<000000>K<P03Vc800;`3Vc8000`000000i/b00>K<P0020>K<P0040000
003Vc800i/b0000000@0i/b000<000000>K<P03Vc800;@3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P0090>K<
P000E03Vc802000000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00_0>K<P004
0000003Vc800i/b0000000@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00^0>K<
P0040000003Vc800i/b00>K<P08000000P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b00300i/b000<000000>K<P03Vc8000P0000020>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc800;@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000@00000
0>K<P03Vc8000000103Vc8000`000000i/b00>K<P0090>K<P000E@3Vc80200000080i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00`0>K<P0030000003Vc800000000@0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00^0>K<P0D000000`3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b00300i/b0100000030>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc800;@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000@00000
0>K<P03Vc8000000103Vc8000`000000i/b00>K<P0090>K<P000EP3Vc80010000000i/b00>K<P000
00040>K<P0030000003Vc800i/b00340i/b00P0000040>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc800;`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc800;`3Vc8000`000000i/b00>K<P0020>K<P0040000003Vc800i/b0000000@0i/b0
00<000000>K<P03Vc800;@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b0
00@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P0090>K<P000D@3Vc8000`000000i/b0
0>K<P0020>K<P0050000003Vc800i/b00>K<P00000000P3Vc8000`000000i/b00>K<P00b0>K<P080
00001@3Vc80010000000i/b00>K<P000000b0>K<P0030000003Vc800i/b000D0i/b000@000000>K<
P03Vc8000000<P3Vc8000`000000i/b00>K<P0020>K<P0050000003Vc800i/b00>K<P00000000P3V
c8000`000000i/b00>K<P00^0>K<P0030000003Vc800i/b000<0i/b000@000000>K<P03Vc8000000
103Vc80010000000i/b00>K<P000000<0>K<P000D@3Vc805000000@0i/b01000000e0>K<P0030000
003Vc800i/b000<0i/b01000000c0>K<P0@000000`3Vc804000003<0i/b0100000040>K<P0@00000
;P3Vc803000000D0i/b0100000040>K<P0@00000303Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc800
01X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0
i/b0000J0>K<P0030000003Vc800i/b00?l0i/b0@P3Vc805000000D0i/b0000J0>K<P0030000003V
c800i/b00?l0i/b0@@3Vc80010000000i/b00>K<P00000020>K<P0030000003Vc800i/b00080i/b0
000J0>K<P0<0000000<0o`00000000000000o`00000d000000X0i/b000@000000>K<P03Vc8000000
0P3Vc8000`000000i/b00>K<P0020>K<P0006P3Vc80010000000i/b00>K<P03o000<0>K<P0030000
003Vc800i/b000`0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00<0>K<P0030000
003Vc800i/b000d0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00<0>K<P0030000
003Vc800i/b000d0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00=0>K<P0030000
003Vc800i/b000d0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00=0>K<P0030000
003Vc800i/b000d0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00=0>K<P0030000
003Vc800i/b000`0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00=0>K<P0030000
003Vc800i/b000`0i/b000<000000>K<P03Vc800203Vc80010000000i/b00>K<P00000020>K<P003
0000003Vc800i/b00080i/b0000J0>K<P0040000003Vc800i/b00?l003X0i/b000<000000>K<P03V
c800?03Vc8000`3o0000i/b00>K<P00k0>K<P0030000003Vc800i/b003`0i/b000<000000>K<P03V
c800>`3Vc8000`3o0000i/b00>K<P0090>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8000P3Vc80001X0i/b000@000000>K<P03Vc800o`00LP3Vc8020?l000@0i/b00P3o00160>K<P7D0
o`00303Vc8001@000000i/b00>K<P03Vc800000000@0i/b0000J0>K<P0040000003Vc800i/b00?l0
0700i/b00P3o00020>K<P0070?l0003Vc800i/b00>K<P03o0000i/b00?l0000I0>K<P2`0o`00RP3V
c80001X0i/b000@000000>K<P03Vc800o`00I@3Vc80;0?l000@0i/b000@0o`000>K<P03Vc800o`00
0P3Vc8000`3o0000i/b00>K<P0070>K<P100o`00]P3Vc80001X0i/b000@000000>K<P03Vc800o`00
E@3Vc80@0?l00100i/b000<0o`000>K<P03o00000P3Vc8000`3o0000i/b00>K<P0040>K<P0<0o`00
aP3Vc80001X0i/b00P0000000`3Vc800o`000>K<P01;0>K<P0T0o`008@3Vc8000`3o0000i/b00>K<
P0020>K<P0040?l0003Vc800i/b00>K<P080o`00b@3Vc80001X0i/b000@000000>K<P03Vc800o`00
@`3Vc8090?l002l0i/b000@0o`000>K<P03Vc800o`00b`3Vc80001X0i/b000@000000>K<P03Vc800
o`00?03Vc8070?l003P0i/b000@0o`000>K<P03Vc800o`00b`3Vc80001X0i/b000@000000>K<P03V
c800o`00=P3Vc8060?l00400i/b00P3o003<0>K<P0006P3Vc80010000000i/b00>K<P03o000`0>K<
P0H0o`00AP3Vc8000`3o0000i/b00>K<P03;0>K<P0006P3Vc80010000000i/b00>K<P03o000]0>K<
P0<0o`00o`3Vc80K0>K<P0006P3Vc80010000000i/b00>K<P03o000Z0>K<P0<0o`00o`3Vc80N0>K<
P0006P3Vc80010000000i/b00>K<P03o000W0>K<P0<0o`00o`3Vc80Q0>K<P0006P3Vc80200000003
0>K<P03o0000i/b002<0i/b00`3o003o0>K<P2@0i/b0000J0>K<P0040000003Vc800i/b00?l00280
i/b00P3o003o0>K<P2L0i/b0000J0>K<P0040000003Vc800i/b00?l00200i/b00P3o003o0>K<P2T0
i/b0000J0>K<P0040000003Vc800i/b00?l001h0i/b00P3o003o0>K<P2/0i/b0000J0>K<P0040000
003Vc800i/b00?l001`0i/b00P3o003o0>K<P2d0i/b0000J0>K<P0040000003Vc800i/b00?l001/0
i/b000<0o`000>K<P03Vc800o`3Vc80]0>K<P0006P3Vc80010000000i/b00>K<P03o000J0>K<P003
0?l0003Vc800i/b00?l0i/b0;P3Vc80001X0i/b00P0000000`3Vc800o`000>K<P00H0>K<P0030?l0
003Vc800i/b00?l0i/b0;`3Vc80001X0i/b000@000000>K<P03Vc800o`00603Vc8000`3o0000i/b0
0>K<P03o0>K<P300i/b0000J0>K<P0040000003Vc800i/b00?l001L0i/b000<0o`000>K<P03Vc800
o`3Vc80a0>K<P0006P3Vc80010000000i/b00>K<P03o000G0>K<P0030?l0003Vc800i/b00?l0i/b0
<@3Vc80001X0i/b000@000000>K<P03Vc800o`005P3Vc8000`3o0000i/b00>K<P03o0>K<P380i/b0
0000103Vc80000000000000000050>K<P0800000103Vc806000000D0i/b000@000000>K<P03Vc800
o`005@3Vc8000`3o0000i/b00>K<P03o0>K<P3<0i/b0000010000000i/b00>K<P00000050>K<P080
00001@3Vc8001@000000i/b00>K<P03Vc800000000D0i/b000@000000>K<P03Vc800o`00503Vc800
0`3o0000i/b00>K<P03o0>K<P3@0i/b000040>K<P0030000003Vc800i/b000X0i/b000<000000>K<
P03Vc8001P3Vc80010000000i/b00>K<P03o000D0>K<P0030?l0003Vc800i/b00?l0i/b0=03Vc800
00@0i/b000<000000>K<P03Vc8002`3Vc802000000H0i/b00`0000000`3o0000i/b00>K<P00A0>K<
P0030?l0003Vc800i/b00?l0i/b0=@3Vc80000@0i/b000<000000>K<P03Vc800303Vc802000000D0
i/b000D000000>K<P03Vc800i/b00?l0000B0>K<P0030?l0003Vc800i/b00?l0i/b0=@3Vc80000@0
i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P0030>K<P0050000003Vc800i/b00>K<
P03o00004@3Vc8000`3o0000i/b00>K<P03o0>K<P3H0i/b0000010000000i/b00>K<P000000;0>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8001@000000i/b00>K<P03Vc800
o`000140i/b000<0o`000>K<P03Vc800o`3Vc80f0>K<P0001000000;0>K<P0D000001P3Vc8001@00
0000i/b00>K<P03Vc800o`000100i/b000<0o`000>K<P03Vc800o`3Vc80g0>K<P0006P3Vc8001@00
0000i/b00>K<P03Vc800o`000100i/b000<0o`000>K<P03Vc800o`3Vc80g0>K<P0006P3Vc8001@00
0000i/b00>K<P03Vc800o`0000l0i/b000<0o`000>K<P03Vc800o`3Vc80h0>K<P0006P3Vc8020000
0080i/b000<0o`000>K<P03Vc8003@3Vc8000`3o0000i/b00>K<P03o0>K<P3P0i/b0000J0>K<P005
0000003Vc800i/b00>K<P03o00003P3Vc8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<P005
0000003Vc800i/b00>K<P03o00003P3Vc8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<P005
0000003Vc800i/b00>K<P03o00003P3Vc8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<P005
0000003Vc800i/b00>K<P03o00003P3Vc8000`3o0000i/b00>K<P03o0>K<P3T0i/b0000J0>K<P005
0000003Vc800i/b00>K<P03o00003@3Vc8000`3o0000i/b00>K<P03o0>K<P3X0i/b0000J0>K<P005
0000003Vc800i/b00>K<P03o00003@3Vc8000`3o0000i/b00>K<P03o0>K<P3X0i/b0000J0>K<P080
00000P3Vc8000`3o0000i/b00>K<P00;0>K<P0030?l0003Vc800i/b00?l0i/b0>P3Vc80001X0i/b0
00D000000>K<P03Vc800i/b00?l0000=0>K<P0030?l0003Vc800i/b00?l0i/b0>P3Vc80001X0i/b0
00D000000>K<P03Vc800i/b00?l0000<0>K<P0030?l0003Vc800i/b00?l0i/b0>`3Vc80001X0i/b0
00D000000>K<P03Vc800i/b00?l0000<0>K<P0030?l0003Vc800i/b00?l0i/b0>`3Vc80001X0i/b0
00D000000>K<P03Vc800i/b00?l0000<0>K<P0030?l0003Vc800i/b00?l0i/b0>`3Vc80001X0i/b0
00D000000>K<P03Vc800i/b00?l0000<0>K<P0030?l0003Vc800i/b00?l0i/b0>`3Vc80001X0i/b0
00D000000>K<P03Vc800i/b00?l0000;0>K<P0030?l0003Vc800i/b00?l0i/b0?03Vc80001X0i/b0
00D000000>K<P03Vc800i/b00?l0000;0>K<P0030?l0003Vc800i/b00?l0i/b0?03Vc80001X0i/b0
0P0000020>K<P0030?l0003Vc800i/b000T0i/b000<0o`000>K<P03Vc800o`3Vc80l0>K<P0006P3V
c8001@000000i/b00>K<P03Vc800o`0000/0i/b000<0o`000>K<P03Vc800o`3Vc80l0>K<P0006P3V
c8001@000000i/b00>K<P03Vc800o`0000/0i/b000<0o`000>K<P03Vc800o`3Vc80l0>K<P0006P3V
c8001@000000i/b00>K<P03Vc800o`0000X0i/b000<0o`000>K<P03Vc800o`3Vc80m0>K<P00000@0
i/b000000000000000001@3Vc802000000H0i/b00`0000060>K<P0050000003Vc800i/b00>K<P03o
00002P3Vc8000`3o0000i/b00>K<P03o0>K<P3d0i/b0000010000000i/b00>K<P00000050>K<P080
00001`3Vc8000`000000i/b00>K<P0050>K<P0050000003Vc800i/b00>K<P03o00002P3Vc8000`3o
0000i/b00>K<P03o0>K<P3d0i/b000040>K<P0030000003Vc800i/b000P0i/b01@0000060>K<P005
0000003Vc800i/b00>K<P03o00002P3Vc8000`3o0000i/b00>K<P03o0>K<P3d0i/b000040>K<P003
0000003Vc800i/b000P0i/b000@000000>K<P03Vc80000001`3Vc803000000030>K<P03o0000i/b0
00T0i/b000<0o`000>K<P03Vc800o`3Vc80m0>K<P000103Vc8000`000000i/b00>K<P0090>K<P003
0000003Vc800000000L0i/b000D000000>K<P03Vc800i/b00?l0000:0>K<P0030?l0003Vc800i/b0
0?l0i/b0?@3Vc80000@0i/b000<000000>K<P03Vc8002P3Vc802000000L0i/b000D000000>K<P03V
c800i/b00?l000090>K<P0030?l0003Vc800i/b00?l0i/b0?P3Vc80000040000003Vc800i/b00000
00d0i/b00P0000070>K<P0050000003Vc800i/b00>K<P03o00002@3Vc8000`3o0000i/b00>K<P03o
0>K<P3h0i/b00004000000h0i/b000<000000>K<P03Vc8001@3Vc8001@000000i/b00>K<P03Vc800
o`0000T0i/b000<0o`000>K<P03Vc800o`3Vc80n0>K<P0006P3Vc8001@000000i/b00>K<P03Vc800
o`0000T0i/b000<0o`000>K<P03Vc800o`3Vc80n0>K<P0006P3Vc8001@000000i/b00>K<P03Vc800
o`0000T0i/b000<0o`000>K<P03Vc800o`3Vc80n0>K<P0006P3Vc80200000080i/b000<0o`000>K<
P03Vc8001`3Vc8000`3o0000i/b00>K<P03o0>K<P3h0i/b0000J0>K<P0050000003Vc800i/b00>K<
P03o00002@3Vc8000`3o0000i/b00>K<P03o0>K<P3h0i/b0000J0>K<P0050000003Vc800i/b00>K<
P03o0000203Vc8000`3o0000i/b00>K<P03o0>K<P3l0i/b0000J0>K<P0050000003Vc800i/b00>K<
P03o0000203Vc8000`3o0000i/b00>K<P03o0>K<P3l0i/b0000J0>K<P0050000003Vc800i/b00>K<
P03o0000203Vc8000`3o0000i/b00>K<P03o0>K<P3l0i/b0000J0>K<P0050000003Vc800i/b00>K<
P03o0000203Vc8000`3o0000i/b00>K<P03o0>K<P3l0i/b0000J0>K<P0050000003Vc800i/b00>K<
P03o0000203Vc8000`3o0000i/b00>K<P03o0>K<P3l0i/b0000J0>K<P0050000003Vc800i/b00>K<
P03o0000203Vc8000`3o0000i/b00>K<P03o0>K<P3l0i/b0000J0>K<P08000000P3Vc8000`3o0000
i/b00>K<P0050>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80001X0i/b000D000000>K<P03Vc800
i/b00?l000070>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80001X0i/b000D000000>K<P03Vc800
i/b00?l000070>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80001X0i/b000D000000>K<P03Vc800
i/b00?l000070>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80001X0i/b000D000000>K<P03Vc800
i/b00?l000070>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80001X0i/b000D000000>K<P03Vc800
i/b00?l000070>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80001X0i/b000D000000>K<P03Vc800
i/b00?l000070>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80001X0i/b00P0000020>K<P0030?l0
003Vc800i/b000D0i/b000<0o`000>K<P03Vc800o`3Vc8100>K<P0006P3Vc8001@000000i/b00>K<
P03Vc800o`0000L0i/b000<0o`000>K<P03Vc800o`3Vc8100>K<P0006P3Vc8001@000000i/b00>K<
P03Vc800o`0000L0i/b000<0o`000>K<P03Vc800o`3Vc8100>K<P0006P3Vc8001@000000i/b00>K<
P03Vc800o`0000L0i/b000<0o`000>K<P03Vc800o`3Vc8100>K<P0006P3Vc8001@000000i/b00>K<
P03Vc800o`0000L0i/b000<0o`000>K<P03Vc800o`3Vc8100>K<P00000@0i/b00000000000000000
1@3Vc802000000D0i/b0100000060>K<P0050000003Vc800i/b00>K<P03o00001`3Vc8000`3o0000
i/b00>K<P03o0>K<P400i/b0000010000000i/b00>K<P00000050>K<P08000001@3Vc8001@000000
i/b00>K<P03Vc800000000D0i/b000D000000>K<P03Vc800i/b00?l000070>K<P0030?l0003Vc800
i/b00?l0i/b0@03Vc80000@0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000<0i/b00`0000000`3Vc800o`000>K<P0060>K<P0030?l0003Vc800i/b0
0?l0i/b0@03Vc80000@0i/b000<000000>K<P03Vc800203Vc80010000000i/b00>K<P03Vc8020000
00D0i/b000D000000>K<P03Vc800i/b00?l000070>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc800
00@0i/b000<000000>K<P03Vc800203Vc805000000H0i/b000D000000>K<P03Vc800i/b00?l00007
0>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80000@0i/b000<000000>K<P03Vc8002@3Vc8000`00
0000i/b00>K<P0070>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc800103Vc8000`3o
0000i/b00>K<P03o0>K<P400i/b0000010000000i/b00>K<P000000<0>K<P0030000003Vc800i/b0
00L0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003Vc800i/b0
0?l0i/b0@03Vc80000@000003@3Vc804000000D0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000
i/b00>K<P0040>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80001X0i/b000<000000>K<P03Vc800
0P3Vc8000`3o0000i/b00>K<P0040>K<P0030?l0003Vc800i/b00?l0i/b0@03Vc80001X0i/b000<0
00000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0i/b0@@3V
c80001X0i/b00P0000030>K<P0030?l0003Vc800i/b000<0i/b000<0o`000>K<P03Vc800o`3Vc811
0>K<P0006P3Vc8000`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b000<0i/b000<0o`000>K<
P03Vc800o`3Vc8110>K<P0006P3Vc8000`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b000<0
i/b000<0o`000>K<P03Vc800o`3Vc8110>K<P0006P3Vc8000`000000i/b00>K<P0020>K<P0030?l0
003Vc800i/b000<0i/b000<0o`000>K<P03Vc800o`3Vc8110>K<P0006P3Vc8000`000000i/b00>K<
P0020>K<P0030?l0003Vc800i/b000<0i/b000<0o`000>K<P03Vc800o`3Vc8110>K<P0006P3Vc800
0`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b000<0i/b000<0o`000>K<P03Vc800o`3Vc811
0>K<P0006P3Vc8000`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b000<0i/b000<0o`000>K<
P03Vc800o`3Vc8110>K<P0006P3Vc802000000<0i/b000<0o`000>K<P03Vc8000`3Vc8000`3o0000
i/b00>K<P03o0>K<P440i/b0000J0>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc800
0`3Vc8000`3o0000i/b00>K<P03o0>K<P440i/b0000J0>K<P0030000003Vc800i/b00080i/b000<0
o`000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P03o0>K<P440i/b0000J0>K<P0030000003Vc800
i/b00080i/b000<0o`000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P03o0>K<P440i/b0000J0>K<
P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P03o0>K<
P440i/b0000J0>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc8000`3Vc8000`3o0000
i/b00>K<P03o0>K<P440i/b0000J0>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc800
0`3Vc8000`3o0000i/b00>K<P03o0>K<P440i/b0000J0>K<P08000000`3Vc8000`3o0000i/b00>K<
P0030>K<P0030?l0003Vc800i/b00?l0i/b0@@3Vc80001X0i/b000<000000>K<P03Vc8000P3Vc800
0`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0i/b0@@3Vc80001X0i/b000<000000>K<
P03Vc8000P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0i/b0@@3Vc80001X0
i/b000<000000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0
i/b0@@3Vc80001X0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0
003Vc800i/b00?l0i/b0@@3Vc80000040>K<P00000000000000000D0i/b00P0000050>K<P0@00000
1P3Vc8000`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b000<0i/b000<0o`000>K<P03Vc800
o`3Vc8110>K<P00000@000000>K<P03Vc80000001@3Vc802000000@0i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc800
0`3Vc8000`3o0000i/b00>K<P03o0>K<P440i/b000040>K<P0030000003Vc800i/b000P0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<0
o`000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P03o0>K<P440i/b000040>K<P0030000003Vc800
i/b000T0i/b000<000000>K<P03Vc8000P0000050>K<P0<000000P3Vc8000`3o0000i/b00>K<P003
0>K<P0030?l0003Vc800i/b00?l0i/b0@@3Vc80000@0i/b000<000000>K<P03Vc8002@3Vc8040000
00H0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b0
0?l0i/b0@@3Vc80000@0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0030>K<P003
0?l0003Vc800i/b00?l0i/b0@@3Vc80000040000003Vc800i/b0000000/0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03V
c8000`3Vc8000`3o0000i/b00>K<P03o0>K<P440i/b00004000000`0i/b0100000060>K<P0030000
003Vc800i/b00080i/b000<0o`000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<P03o0>K<P440i/b0
000J0>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc8000`3Vc8000`3o0000i/b00>K<
P03o0>K<P440i/b0000J0>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc8000`3Vc800
0`3o0000i/b00>K<P03o0>K<P440i/b0000J0>K<P08000000`3Vc8000`3o0000i/b00>K<P0030>K<
P0030?l0003Vc800i/b00?l0i/b0@@3Vc80001X0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000
i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0i/b0@@3Vc80001X0i/b000<000000>K<P03Vc800
0P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0i/b0@@3Vc80001X0i/b000<0
00000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800i/b00?l0i/b0@@3V
c80001X0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0030>K<P0030?l0003Vc800
i/b00?l0i/b0@@3Vc80001X0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0030>K<
P0030?l0003Vc800i/b00?l0i/b0@@3Vc80001X0i/b000<000000>K<P03Vc8000P3Vc8000`3o0000
i/b00>K<P0020>K<P0030?l0003Vc800i/b00?l0i/b0@P3Vc80001X0i/b00P0000030>K<P0030?l0
003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc8120>K<P0006P3Vc8000`000000i/b00>K<
P0020>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc8120>K<P0006P3Vc800
0`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc812
0>K<P0006P3Vc8000`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<
P03Vc800o`3Vc8120>K<P0006P3Vc8000`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b00080
i/b000<0o`000>K<P03Vc800o`3Vc8120>K<P0006P3Vc8000`000000i/b00>K<P0020>K<P0030?l0
003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc8120>K<P0006P3Vc8000`000000i/b00>K<
P0020>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc8120>K<P0006P3Vc800
0`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc812
0>K<P0006P3Vc802000000<0i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P03o0>K<
P480i/b0000J0>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000
i/b00>K<P03o0>K<P480i/b0000J0>K<P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc800
0P3Vc8000`3o0000i/b00>K<P03o0>K<P480i/b0000J0>K<P0030000003Vc800i/b00080i/b000<0
o`000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P03o0>K<P480i/b0000?0>K<P0H000001@3Vc800
0`000000i/b00>K<P0020>K<P0030?l0003Vc800i/b00080i/b000<0o`000>K<P03Vc800o`3Vc812
0>K<P0004P3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00080i/b000<0o`000>K<
P03Vc8000P3Vc8000`3o0000i/b00>K<P03o0>K<P480i/b0000B0>K<P0030000003Vc800i/b000D0
i/b000<000000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0003Vc800i/b00?l0
i/b0@P3Vc8000180i/b000<000000>K<P03Vc8001@3Vc80300000080i/b000<0o`000>K<P03Vc800
0P3Vc8000`3o0000i/b00>K<P03o0>K<P480i/b0000B0>K<P0030000003Vc800i/b000D0i/b000<0
00000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P0020>K<P0030?l0003Vc800i/b00?l0i/b0@P3V
c8000180i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0020>K<P0030?l0003Vc800
i/b00080i/b000<0o`000>K<P03Vc800o`3Vc8120>K<P0004P3Vc8000`000000i/b00>K<P0050>K<
P0030000003Vc800i/b00080i/b000<0o`000>K<P03Vc8000P3Vc8000`3o0000i/b00>K<P03o0>K<
P480i/b0000@0>K<P0<000001`3Vc8000`000000i/b00>K<P0030>K<P0050?l0003Vc800i/b00>K<
P03o0000o`3Vc8140>K<P0006P3Vc8000`000000i/b00>K<P0030>K<P0050?l0003Vc800i/b00>K<
P03o0000o`3Vc8140>K<P0006P3Vc8000`000000i/b00>K<P0030>K<P0050?l0003Vc800i/b00>K<
P03o0000o`3Vc8140>K<P0006P3Vc802000000@0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<
P4@0i/b0000J0>K<P0030000003Vc800i/b000<0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<
P4@0i/b0000J0>K<P0030000003Vc800i/b000<0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<
P4@0i/b0000J0>K<P0030000003Vc800i/b000<0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<
P4@0i/b0000J0>K<P0030000003Vc800i/b000<0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<
P4@0i/b0000J0>K<P0030000003Vc800i/b000<0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<
P4@0i/b0000J0>K<P0030000003Vc800i/b000<0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<
P4@0i/b0000J0>K<P0030000003Vc800i/b000<0i/b000D0o`000>K<P03Vc800i/b00?l0003o0>K<
P4@0i/b0000J0>K<P0800000103Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0A03Vc80001X0
i/b000<000000>K<P03Vc8000`3Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0A03Vc80001X0
i/b000<000000>K<P03Vc8000`3Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0A03Vc80001X0
i/b000<000000>K<P03Vc8000`3Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0A03Vc80001X0
i/b000<000000>K<P03Vc8000`3Vc8001@3o0000i/b00>K<P03Vc800o`000?l0i/b0A03Vc80001X0
i/b000<000000>K<P03Vc8000`3Vc800103o0000i/b00>K<P03o003o0>K<P4D0i/b0000J0>K<P003
0000003Vc800i/b000<0i/b000@0o`000>K<P03Vc800o`00o`3Vc8150>K<P0006P3Vc802000000@0
i/b000@0o`000>K<P03Vc800o`00o`3Vc8150>K<P0006P3Vc8000`000000i/b00>K<P0030>K<P004
0?l0003Vc800i/b00?l00?l0i/b0A@3Vc80001X0i/b000<000000>K<P03Vc8000`3Vc800103o0000
i/b00>K<P03o003o0>K<P4D0i/b0000J0>K<P0030000003Vc800i/b000<0i/b000@0o`000>K<P03V
c800o`00o`3Vc8150>K<P0006P3Vc8000`000000i/b00>K<P0030>K<P0040?l0003Vc800i/b00?l0
0?l0i/b0A@3Vc80000D00000103Vc802000000@0i/b01P0000050>K<P0030000003Vc800i/b000<0
i/b000@0o`000>K<P03Vc800o`00o`3Vc8150>K<P0000P3Vc8000`000000i/b00>K<P0040>K<P080
00001@3Vc8001@000000i/b00>K<P03Vc800000000D0i/b000<000000>K<P03Vc8000`3Vc800103o
0000i/b00>K<P03o003o0>K<P4D0i/b000020>K<P0030000003Vc800i/b000`0i/b000<000000>K<
P03Vc8001P3Vc803000000<0i/b000@0o`000>K<P03Vc800o`00o`3Vc8150>K<P0000P3Vc8000`00
0000i/b00>K<P00=0>K<P08000001P3Vc8000`000000i/b00>K<P0030>K<P0040?l0003Vc800i/b0
0?l00?l0i/b0A@3Vc8000080i/b000<000000>K<P03Vc8003P3Vc802000000D0i/b000<000000>K<
P03Vc8000`3Vc800103o0000i/b00>K<P03o003o0>K<P4D0i/b000020>K<P0030000003Vc800i/b0
00l0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0040?l0003Vc800i/b0
0?l00?l0i/b0A@3Vc8000080i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc800103o0000i/b00>K<P03o003o
0>K<P4D0i/b00003000000`0i/b01@0000060>K<P0030000003Vc800i/b000<0i/b000@0o`000>K<
P03Vc800o`00o`3Vc8150>K<P0006P3Vc8000`000000i/b00>K<P0040>K<P0030?l0003Vc800o`00
0?l0i/b0A@3Vc80001X0i/b000<000000>K<P03Vc8001@3Vc8020?l00?l0i/b0A@3Vc80001X0i/b0
0P0000070>K<P0030?l0003Vc800i/b00?l0i/b0@`3Vc80001X0i/b000<000000>K<P03Vc800o`3V
c81<0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b0
0?l0i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b0
0>K<P03o0>K<P4`0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0
i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b00000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-8.45545, -0.163792, \
0.400274, 0.00851797}}]
}, Open  ]],

Cell["\<\

We get a large peak at a low frequency (the Rabi frequency) and a small peak \
at a high frequency. The approximate Rabi frequency is: \
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(Print[\*"\"\<\!\(\[Omega]\_R\)= \>\"", \[Omega]est\ n0];\)\)], "Input"],

Cell[BoxData[
    InterpretationBox[\("\!\(\[Omega]\_R\)= \
"\[InvisibleSpace]0.08827882149493523`\),
      SequenceForm[ "\!\(\[Omega]\_R\)= ", 0.088278821494935225],
      Editable->False]], "Print"]
}, Open  ]],

Cell["\<\
Unfortunately, the frequency resolution is not very good and we \
need an additional nonlinear fit. We will use the frequency obtained from the \
Fourier transform as a starring value for this fit:\
\>", "Text"],

Cell[BoxData[
    \(\(\( (*Nonlinear\ Fit*) \)\(\[IndentingNewLine]\)\( (*The\ starting\ \
value\ for\ the\ frequency\ needs\ to\ be\ quite\ \(close!\)*) \)\(\
\[IndentingNewLine]\)\(cosfit[funcname_, offset_, amplitude_, frequency_] := 
        Block[{nmax = 250, afit, i, t, amp1, a0, 
            n1}, \[IndentingNewLine]func[t_] = 
            funcname[t]; \[IndentingNewLine]afit = 
            Table[{N[\(\(\ \)\(i\)\)\/nmax], 
                func[N[i\ \(\(\ \)\(tmax\)\)\/nmax]]}, {i, 0, 
                nmax}]; \[IndentingNewLine]fitres = 
            BestFitParameters /. 
              NonlinearRegress[afit, a0 + amp1\ Cos[2\ \[Pi]\ n1\ t], 
                t, {{a0, offset}, {amp1, amplitude}, {n1, frequency}}, 
                RegressionReport \[Rule] 
                  BestFitParameters];\[IndentingNewLine]];\)\)\)], "Input"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(\(cosfit[pup, meanpop, 1 - meanpop, n0];\)\), "\[IndentingNewLine]", 
    \(\(\[Omega]R = \[Omega]est\ n1 /. fitres;\)\), "\[IndentingNewLine]", 
    \(\(ampR = amp1 /. fitres;\)\), "\[IndentingNewLine]", 
    \(\(meanpop = a0 /. fitres;\)\), "\[IndentingNewLine]", 
    \(\(plfit = 
        Plot[{meanpop + ampR\ Cos[\[Omega]R\ t], pup[t]}, {t, 0, tmax}, 
          PlotStyle \[Rule] {{Hue[1], Thickness[0.01]}, {GrayLevel[0]}}, 
          DisplayFunction \[Rule] Identity];\)\), "\[IndentingNewLine]", 
    \(\(Show[plfit, 
        Graphics[{Text["\<fit\>", {\ tmax, meanpop}, 
              TextStyle \[Rule] {FontColor \[Rule] Hue[1]}], 
            Text[\*"\"\<|a(t)\!\(\( | \^2\)\)\>\"", {\ tmax, 
                meanpop - ampR/2}]}], AxesLabel \[Rule] {"\<t\>", "\<\>"}, 
        DisplayFunction \[Rule] $DisplayFunction];\)\), \
"\[IndentingNewLine]", 
    \(\(Print["\<Mean Propability of measuring |+z\[RightAngleBracket]: \>", 
        meanpop];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Amplitude of oscillation: \>", 
        ampR];\)\), "\[IndentingNewLine]", 
    \(\(Print["\<Rabi frequency: \>", \[Omega]R, "\<  Period of \
Rabi-oscillation: \>", 2\ \[Pi]/\[Omega]R];\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell1" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(\[Omega]R\)\" is \
similar to existing symbol \"\!\(\[Omega]\)\"."\)], "Message"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .61803 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
0.0238095 0.00757881 -0.532101 1.13542 [
[.17539 .59082 -6 -9 ]
[.17539 .59082 6 0 ]
[.32696 .59082 -6 -9 ]
[.32696 .59082 6 0 ]
[.47854 .59082 -6 -9 ]
[.47854 .59082 6 0 ]
[.63011 .59082 -6 -9 ]
[.63011 .59082 6 0 ]
[.78169 .59082 -9 -9 ]
[.78169 .59082 9 0 ]
[.93327 .59082 -9 -9 ]
[.93327 .59082 9 0 ]
[1.025 .60332 0 -4.90625 ]
[1.025 .60332 10 4.90625 ]
[.01131 .03561 -18 -4.5 ]
[.01131 .03561 0 4.5 ]
[.01131 .14915 -18 -4.5 ]
[.01131 .14915 0 4.5 ]
[.01131 .26269 -18 -4.5 ]
[.01131 .26269 0 4.5 ]
[.01131 .37624 -18 -4.5 ]
[.01131 .37624 0 4.5 ]
[.01131 .48978 -18 -4.5 ]
[.01131 .48978 0 4.5 ]
[ 0 0 0 0 ]
[ 1 .61803 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
.25 Mabswid
[ ] 0 setdash
.17539 .60332 m
.17539 .60957 L
s
[(20)] .17539 .59082 0 1 Mshowa
.32696 .60332 m
.32696 .60957 L
s
[(40)] .32696 .59082 0 1 Mshowa
.47854 .60332 m
.47854 .60957 L
s
[(60)] .47854 .59082 0 1 Mshowa
.63011 .60332 m
.63011 .60957 L
s
[(80)] .63011 .59082 0 1 Mshowa
.78169 .60332 m
.78169 .60957 L
s
[(100)] .78169 .59082 0 1 Mshowa
.93327 .60332 m
.93327 .60957 L
s
[(120)] .93327 .59082 0 1 Mshowa
.125 Mabswid
.0617 .60332 m
.0617 .60707 L
s
.0996 .60332 m
.0996 .60707 L
s
.13749 .60332 m
.13749 .60707 L
s
.21328 .60332 m
.21328 .60707 L
s
.25117 .60332 m
.25117 .60707 L
s
.28907 .60332 m
.28907 .60707 L
s
.36486 .60332 m
.36486 .60707 L
s
.40275 .60332 m
.40275 .60707 L
s
.44064 .60332 m
.44064 .60707 L
s
.51643 .60332 m
.51643 .60707 L
s
.55433 .60332 m
.55433 .60707 L
s
.59222 .60332 m
.59222 .60707 L
s
.66801 .60332 m
.66801 .60707 L
s
.7059 .60332 m
.7059 .60707 L
s
.7438 .60332 m
.7438 .60707 L
s
.81958 .60332 m
.81958 .60707 L
s
.85748 .60332 m
.85748 .60707 L
s
.89537 .60332 m
.89537 .60707 L
s
.97116 .60332 m
.97116 .60707 L
s
.25 Mabswid
0 .60332 m
1 .60332 L
s
gsave
1.025 .60332 -61 -8.90625 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
69.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.02381 .03561 m
.03006 .03561 L
s
[(0.5)] .01131 .03561 1 0 Mshowa
.02381 .14915 m
.03006 .14915 L
s
[(0.6)] .01131 .14915 1 0 Mshowa
.02381 .26269 m
.03006 .26269 L
s
[(0.7)] .01131 .26269 1 0 Mshowa
.02381 .37624 m
.03006 .37624 L
s
[(0.8)] .01131 .37624 1 0 Mshowa
.02381 .48978 m
.03006 .48978 L
s
[(0.9)] .01131 .48978 1 0 Mshowa
.125 Mabswid
.02381 .05832 m
.02756 .05832 L
s
.02381 .08103 m
.02756 .08103 L
s
.02381 .10373 m
.02756 .10373 L
s
.02381 .12644 m
.02756 .12644 L
s
.02381 .17186 m
.02756 .17186 L
s
.02381 .19457 m
.02756 .19457 L
s
.02381 .21728 m
.02756 .21728 L
s
.02381 .23998 m
.02756 .23998 L
s
.02381 .2854 m
.02756 .2854 L
s
.02381 .30811 m
.02756 .30811 L
s
.02381 .33082 m
.02756 .33082 L
s
.02381 .35353 m
.02756 .35353 L
s
.02381 .39894 m
.02756 .39894 L
s
.02381 .42165 m
.02756 .42165 L
s
.02381 .44436 m
.02756 .44436 L
s
.02381 .46707 m
.02756 .46707 L
s
.02381 .51249 m
.02756 .51249 L
s
.02381 .53519 m
.02756 .53519 L
s
.02381 .5579 m
.02756 .5579 L
s
.02381 .58061 m
.02756 .58061 L
s
.02381 .0129 m
.02756 .0129 L
s
.25 Mabswid
.02381 0 m
.02381 .61803 L
s
0 0 m
1 0 L
1 .61803 L
0 .61803 L
closepath
clip
newpath
1 0 0 r
.01 w
.02381 .60295 m
.02499 .60293 L
.02605 .60288 L
.02729 .60279 L
.02846 .60267 L
.03053 .60237 L
.03279 .60193 L
.03527 .60129 L
.0379 .60044 L
.04262 .59848 L
.04749 .59587 L
.05205 .5929 L
.06244 .58425 L
.07305 .57279 L
.08274 .56007 L
.10458 .52421 L
.14429 .43791 L
.18248 .33888 L
.22313 .23056 L
.26226 .13767 L
.28223 .09874 L
.29274 .08124 L
.30384 .06523 L
.31379 .05318 L
.32471 .0426 L
.3295 .03886 L
.33464 .03547 L
.33913 .03303 L
.34391 .031 L
.34642 .03016 L
.34919 .02942 L
.3504 .02915 L
.35171 .02891 L
.35294 .02872 L
.35408 .02858 L
.35542 .02845 L
.35613 .02841 L
.35689 .02837 L
.35769 .02835 L
.35844 .02834 L
.35912 .02835 L
.35985 .02837 L
.36049 .0284 L
.36119 .02844 L
.36192 .0285 L
.36261 .02856 L
.36515 .02892 L
.36639 .02915 L
.36775 .02945 L
.37021 .03011 L
Mistroke
.37485 .03176 L
.38025 .03437 L
.38527 .03743 L
.39586 .04593 L
.40583 .05636 L
.42445 .08183 L
.46305 .15622 L
.50411 .25779 L
.54365 .36383 L
.58167 .45977 L
.60286 .50604 L
.62215 .54169 L
.63174 .55673 L
.64217 .57084 L
.65194 .58186 L
.66111 .59016 L
.67053 .59658 L
.67553 .59909 L
.67811 .60014 L
.68092 .6011 L
.68369 .60185 L
.68627 .60237 L
.6877 .60259 L
.68899 .60274 L
.68971 .60281 L
.69048 .60287 L
.69122 .60291 L
.69189 .60293 L
.6931 .60295 L
.69422 .60293 L
.69545 .60287 L
.69615 .60282 L
.69678 .60276 L
.69805 .60262 L
.69943 .60242 L
.70194 .60193 L
.70427 .60134 L
.70678 .60054 L
.71133 .5987 L
.71673 .59584 L
.72169 .59258 L
.73192 .58397 L
.74269 .57223 L
.76241 .54406 L
.78077 .51078 L
.81978 .42231 L
.86125 .31307 L
.9012 .208 L
.93963 .12088 L
.97619 .06115 L
Mistroke
Mfstroke
0 g
.5 Mabswid
.02381 .60332 m
.02499 .60325 L
.02605 .60307 L
.02729 .60276 L
.02846 .60239 L
.03056 .60166 L
.03171 .6013 L
.03279 .60101 L
.03395 .60079 L
.03524 .60066 L
.03633 .60063 L
.0375 .60065 L
.03816 .60068 L
.03887 .60071 L
.04017 .60071 L
.04144 .60059 L
.04262 .60031 L
.04386 .5998 L
.04456 .5994 L
.04521 .59896 L
.04765 .59665 L
.05221 .5908 L
.05346 .58929 L
.05479 .58788 L
.05604 .58683 L
.05719 .58613 L
.05848 .58562 L
.05969 .58539 L
.06101 .58532 L
.06176 .58531 L
.06244 .58531 L
.0637 .58523 L
.06486 .58498 L
.06612 .5844 L
.06676 .58396 L
.06745 .58334 L
.06863 .58197 L
.06989 .58003 L
.07216 .57548 L
.08288 .55602 L
.10458 .51682 L
.14608 .43723 L
.18606 .33419 L
.18711 .33424 L
.18823 .3337 L
.18945 .33215 L
.19059 .32969 L
.19175 .32607 L
.19285 .32169 L
.19489 .31137 L
Mistroke
.19727 .29738 L
.19985 .28292 L
.201 .27754 L
.20221 .27291 L
.20324 .26993 L
.20438 .26771 L
.20508 .26687 L
.20574 .2664 L
.20698 .26627 L
.20767 .26653 L
.20831 .2669 L
.20976 .26794 L
.21092 .2686 L
.2122 .26872 L
.21284 .26844 L
.21354 .2678 L
.21479 .26568 L
.21597 .26243 L
.21726 .25751 L
.21987 .24406 L
.22227 .22966 L
.22453 .21706 L
.22578 .21134 L
.22644 .20884 L
.22714 .2066 L
.22837 .20372 L
.22951 .20227 L
.23082 .20185 L
.23204 .20242 L
.23275 .20303 L
.23339 .20368 L
.23409 .20443 L
.23483 .20517 L
.23605 .20606 L
.23718 .20621 L
.2384 .20537 L
.23909 .20434 L
.23974 .20299 L
.24091 .1996 L
.24198 .19545 L
.2444 .18314 L
.24697 .16803 L
.24838 .16017 L
.24971 .15373 L
.25095 .14896 L
.25165 .14688 L
.2523 .14536 L
.25344 .14364 L
.25465 .14307 L
.25591 .14364 L
Mistroke
.2571 .14495 L
.25849 .14694 L
.2598 .14874 L
.26048 .14946 L
.26122 .14997 L
.26252 .14999 L
.26326 .14941 L
.26404 .14825 L
.26478 .14665 L
.26544 .14476 L
.28633 .10338 L
.29548 .07489 L
.29799 .06299 L
.29872 .06024 L
.2994 .05804 L
.30068 .05506 L
.30189 .05371 L
.303 .0537 L
.30423 .0549 L
.30553 .05727 L
.30775 .06259 L
.30891 .06529 L
.31013 .06755 L
.31121 .06874 L
.31239 .06898 L
.31346 .0681 L
.31445 .06633 L
.31573 .06276 L
.31694 .05827 L
.31921 .04809 L
.32168 .03704 L
.32292 .03256 L
.32364 .03052 L
.32429 .02905 L
.32552 .02739 L
.3262 .02712 L
.32685 .02727 L
.32799 .02847 L
.32924 .03093 L
.33039 .03397 L
.33161 .03764 L
.3338 .04398 L
.33445 .0455 L
.33514 .04682 L
.33589 .04786 L
.33659 .04839 L
.33784 .04825 L
.33855 .04752 L
.33921 .04643 L
.34045 .0434 L
Mistroke
.34157 .03971 L
.3441 .02966 L
.3453 .02489 L
.34659 .02041 L
.34781 .01719 L
.34893 .01535 L
.35018 .01472 L
.35137 .01553 L
.35265 .01784 L
.35338 .01972 L
.35405 .02176 L
.35632 .02981 L
.35752 .03409 L
.35878 .03806 L
.35989 .04075 L
.3611 .04258 L
.36221 .0431 L
.36324 .04256 L
.36392 .04167 L
.36457 .04047 L
.36578 .03742 L
.36851 .02834 L
.36971 .02433 L
.37083 .02108 L
.372 .01854 L
.3733 .01706 L
.37458 .01716 L
.3753 .01793 L
.37596 .01908 L
.37716 .02214 L
.37843 .02649 L
.3813 .03849 L
.38272 .04412 L
.38402 .04841 L
.38518 .05118 L
.38642 .05281 L
.38765 .05302 L
.38836 .05252 L
.38902 .05169 L
.39016 .04951 L
.39121 .0469 L
.39356 .04022 L
.39477 .03715 L
.39606 .03476 L
.3968 .03394 L
.39747 .03362 L
.39879 .03422 L
.40002 .03632 L
.40071 .03812 L
.40134 .04014 L
Mistroke
.40375 .05021 L
.40598 .06099 L
.40721 .06652 L
.40837 .07102 L
.40946 .07431 L
.41063 .07673 L
.4117 .07782 L
.41269 .0779 L
.41372 .07711 L
.41487 .07539 L
.41606 .07293 L
.41718 .07036 L
.41834 .06778 L
.41956 .06558 L
.4202 .06476 L
.42089 .0642 L
.42212 .06422 L
.42276 .06478 L
.42344 .06582 L
.42466 .0688 L
.42597 .07349 L
.42741 .08007 L
.42982 .09278 L
.43115 .09968 L
.43241 .10553 L
.43362 .11015 L
.43494 .11379 L
.43613 .11571 L
.43724 .11633 L
.43828 .11599 L
.43943 .11479 L
.44063 .11291 L
.44176 .11089 L
.4424 .10978 L
.44308 .1087 L
.44431 .10727 L
.4456 .10683 L
.44634 .1072 L
.44701 .10796 L
.4482 .11037 L
.44949 .11449 L
.45071 .11968 L
.45184 .12535 L
.45452 .14058 L
.45708 .15395 L
.45849 .15957 L
.45928 .16201 L
.46002 .16375 L
.46133 .16562 L
.46206 .16602 L
Mistroke
.46272 .16603 L
.46396 .1653 L
.46511 .16401 L
.46634 .16237 L
.467 .16154 L
.4677 .16077 L
.46888 .15997 L
.46998 .16003 L
.47124 .1613 L
.47239 .16372 L
.47355 .16739 L
.47462 .17183 L
.47704 .18468 L
.47916 .19734 L
.48145 .20988 L
.48273 .21554 L
.4839 .21955 L
.48502 .22225 L
.4862 .22389 L
.4875 .22444 L
.48871 .22402 L
.4894 .22351 L
.49003 .22294 L
.49072 .22228 L
.49145 .22162 L
.4921 .22112 L
.49281 .22077 L
.49407 .22081 L
.49478 .22132 L
.49554 .22231 L
.49626 .22371 L
.49692 .22539 L
.49818 .2297 L
.49956 .23588 L
.50207 .24995 L
.50464 .26525 L
.50599 .27246 L
.50741 .27882 L
.50865 .28308 L
.50936 .28491 L
.51002 .28623 L
.51118 .2877 L
.51242 .28823 L
.51355 .288 L
.5146 .28743 L
.5157 .28673 L
.51691 .28618 L
.51814 .28621 L
.51945 .28725 L
.52067 .28938 L
Mistroke
.52179 .29242 L
.52317 .29759 L
.52469 .30479 L
.52744 .32045 L
.53002 .33504 L
.53144 .34178 L
.53278 .34685 L
.53408 .35044 L
.53482 .35186 L
.5355 .35281 L
.5367 .35375 L
.53796 .3539 L
.53915 .35357 L
.54026 .35313 L
.54147 .35285 L
.54278 .35313 L
.54399 .35423 L
.54469 .35531 L
.54534 .35664 L
.54665 .36028 L
.54806 .36561 L
.55294 .39095 L
.55575 .40477 L
.55716 .41007 L
.55797 .41248 L
.55871 .41425 L
.55939 .41555 L
.56003 .41648 L
.56071 .41718 L
.56145 .41765 L
.56209 .41785 L
.56278 .4179 L
.564 .41772 L
.56525 .41747 L
.56638 .41748 L
.5677 .41807 L
.56895 .41946 L
.5701 .42161 L
.57116 .42437 L
.57358 .43323 L
.57625 .44583 L
.57907 .45928 L
.58148 .46841 L
.58213 .47033 L
.58284 .47208 L
.58412 .47444 L
.58477 .47528 L
.58548 .47593 L
.58678 .47653 L
.58804 .47662 L
Mistroke
.5892 .47652 L
.59047 .47649 L
.59119 .47663 L
.59187 .47691 L
.59258 .47739 L
.59323 .47805 L
.59395 .47901 L
.5947 .48033 L
.59589 .48305 L
.59716 .48678 L
.59946 .4952 L
.60195 .50549 L
.60466 .51564 L
.60593 .51944 L
.60727 .52257 L
.60842 .5245 L
.60968 .52588 L
.61086 .52657 L
.61213 .52685 L
.61332 .52687 L
.61442 .52685 L
.61554 .52697 L
.61659 .52734 L
.61774 .52816 L
.61896 .52959 L
.62013 .53154 L
.62122 .53388 L
.62327 .53939 L
.62573 .54708 L
.62835 .55504 L
.62962 .55831 L
.63082 .56087 L
.6319 .56269 L
.63308 .56414 L
.63432 .56513 L
.63564 .56567 L
.63677 .56584 L
.63801 .56587 L
.6387 .56587 L
.63935 .5659 L
.64011 .56599 L
.6408 .56616 L
.64205 .56672 L
.64276 .56721 L
.64341 .56779 L
.64457 .56913 L
.64583 .57099 L
.64811 .57524 L
.65236 .58399 L
.65478 .58787 L
Mistroke
.656 .58928 L
.65669 .58991 L
.65733 .59037 L
.65847 .59097 L
.6597 .59132 L
.66083 .59145 L
.6619 .59147 L
.66304 .59146 L
.66427 .59151 L
.66543 .59167 L
.66649 .59197 L
.66767 .59249 L
.66896 .59329 L
.67156 .59552 L
.67411 .59806 L
.67651 .6002 L
.67784 .60112 L
.67855 .6015 L
.67929 .60184 L
.6806 .60225 L
.68181 .60244 L
.68294 .60249 L
.68416 .60245 L
.6853 .60237 L
.68635 .6023 L
.68758 .60225 L
.68827 .60225 L
.68892 .60227 L
.6901 .60236 L
.69135 .60253 L
.69375 .60295 L
.69493 .60314 L
.69601 .60324 L
.697 .60327 L
.69804 .60319 L
.69908 .60301 L
.70023 .60267 L
.70504 .60016 L
.70758 .59878 L
.70886 .59826 L
.70959 .59803 L
.71027 .59787 L
.71151 .59768 L
.71265 .59762 L
.7139 .59763 L
.71521 .59765 L
.71634 .59761 L
.71739 .59746 L
.71854 .59712 L
.71977 .59651 L
Mistroke
.72051 .59599 L
.72119 .59542 L
.72273 .59376 L
.72552 .58971 L
.728 .58559 L
.72931 .58352 L
.73073 .58157 L
.73204 .5801 L
.73323 .5791 L
.73443 .57842 L
.73557 .57804 L
.73685 .57787 L
.73803 .57785 L
.73932 .57783 L
.73998 .57777 L
.7407 .57764 L
.74191 .57719 L
.74304 .57643 L
.74428 .57513 L
.74561 .57316 L
.747 .57046 L
.74831 .56739 L
.75077 .56079 L
.75293 .55493 L
.75521 .54967 L
.7564 .54757 L
.75771 .54585 L
.7589 .54483 L
.76002 .54428 L
.76248 .544 L
.76378 .54399 L
.76451 .54391 L
.76517 .54375 L
.76648 .54306 L
.76771 .54183 L
.76884 .54011 L
.77007 .53756 L
.77149 .53372 L
.773 .5288 L
.77571 .51877 L
.77836 .50934 L
.77966 .50549 L
.78087 .50262 L
.78202 .50054 L
.78324 .49906 L
.78447 .49823 L
.78517 .498 L
.78583 .4979 L
.78696 .49791 L
.78801 .49797 L
Mistroke
.78915 .4979 L
.79035 .49745 L
.79157 .4964 L
.79287 .49444 L
.79409 .49169 L
.79521 .48843 L
.79794 .47781 L
.80052 .46597 L
.80274 .45629 L
.80396 .4518 L
.8051 .44832 L
.80607 .44597 L
.80711 .44411 L
.80826 .44278 L
.80932 .44216 L
.81056 .44197 L
.81126 .44203 L
.8119 .44213 L
.81308 .44228 L
.81432 .44213 L
.81544 .44148 L
.81648 .44028 L
.81763 .43817 L
.81885 .43493 L
.82014 .43041 L
.82136 .42522 L
.82364 .41379 L
.82629 .39994 L
.82745 .39443 L
.82873 .38919 L
.82976 .38575 L
.83086 .38289 L
.83203 .38082 L
.83312 .3797 L
.8344 .37922 L
.83561 .37934 L
.8367 .37967 L
.83789 .37997 L
.83856 .37999 L
.83929 .37982 L
.83998 .37942 L
.84062 .3788 L
.84182 .37687 L
.84309 .37365 L
.84446 .3688 L
.84574 .36308 L
.84864 .34724 L
.85112 .33331 L
.85346 .32248 L
.85476 .31815 L
Mistroke
.85549 .3163 L
.85616 .31497 L
.85736 .31348 L
.85863 .31292 L
.86099 .31367 L
.86214 .31426 L
.86319 .31455 L
.8643 .31436 L
.86548 .31334 L
.86677 .31102 L
.86799 .30757 L
.86931 .30249 L
.87052 .29669 L
.87326 .281 L
.87575 .26642 L
.87697 .26021 L
.87809 .25542 L
.87913 .25184 L
.88012 .24931 L
.88117 .24757 L
.88231 .24666 L
.88348 .24662 L
.88473 .24728 L
.8859 .24822 L
.88696 .24903 L
.88818 .24955 L
.88929 .24937 L
.89051 .24816 L
.89181 .24554 L
.89293 .24207 L
.89398 .23786 L
.89636 .2255 L
.8988 .21091 L
.90138 .19678 L
.90273 .19107 L
.90344 .18867 L
.90421 .1866 L
.90492 .18518 L
.90557 .18428 L
.90683 .18352 L
.90803 .18385 L
.90914 .18479 L
.91046 .1863 L
.91166 .18762 L
.91293 .1885 L
.91412 .1885 L
.91538 .18732 L
.91609 .18605 L
.91674 .18447 L
.93531 .13187 L
Mistroke
.93648 .13357 L
.93772 .13478 L
.93837 .13504 L
.93909 .13496 L
.94035 .13377 L
.94154 .13131 L
.94282 .12723 L
.94403 .12217 L
.94514 .1167 L
.94782 .10201 L
.94929 .09439 L
.95066 .08833 L
.95182 .08432 L
.95306 .08141 L
.95377 .08042 L
.95444 .07992 L
.95569 .08007 L
.95679 .0812 L
.958 .08322 L
.95918 .08562 L
.96044 .08822 L
.96162 .09026 L
.96271 .09147 L
.96379 .09184 L
.96483 .09124 L
.96602 .08933 L
.96729 .08587 L
.96848 .0814 L
.96957 .07657 L
.97223 .06324 L
.97344 .05745 L
.97475 .05201 L
.97619 .04747 L
Mfstroke
gsave
.97619 .31564 -73.7812 -9.875 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 19.75 translate 1 -1 scale
63.000 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
(fit) show
84.562 12.875 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 12.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
1.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
gsave
.97619 .17199 -83.7812 -10 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 20 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 13.188 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
63.000 13.188 moveto
(\\310) show
69.000 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(a) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 13.188 moveto
(H) show
81.000 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(t) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
87.000 13.188 moveto
(L) show
93.000 13.188 moveto
(\\310) show
99.000 9.375 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(2) show
104.562 13.188 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 177.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0000gR000`400?l00000o`00003oo`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P4`0i/b0000J0>K<P0030000003Vc800i/b00?l0
i/b0C03Vc80001X0i/b000<000000>K<P03Vc800o`3Vc81<0>K<P0006P3Vc8000`000000i/b00>K<
P03o0>K<P4`0i/b0000J0>K<P0800000o`3Vc81=0>K<P0006P3Vc8000`000000i/b00>K<P01U0>K<
P0800000i03Vc80001X0i/b000<000000>K<P03Vc800I@3Vc802000000D0i/b00`00003L0>K<P000
6P3Vc8000`000000i/b00>K<P01T0>K<P0040000003Vc8000000000000@0i/b000<000000>K<P000
0000g03Vc80001X0i/b000<000000>K<P03Vc800I03Vc80010000000i/b00?l0000000030?l00004
0>K<P0000000i/b000000=`0i/b00000103Vc80000000000000000050>K<P08000001@3Vc8040000
00H0i/b000<000000>K<P03Vc800G@3Vc802000000<0i/b00P3o000010000000o`000?l000000003
0?l000040000003o0000o`0000000=`0i/b0000010000000i/b00>K<P00000050>K<P08000002@3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b005d0i/b000@000000>K<P0000000i/b0
0P3o00001@000000o`000?l0003o0000000000<0o`0000@000000?l0003o000000000P3o003J0>K<
P000103Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c800G@3Vc8000`000000i/b0000000030?l000030000003o0000o`000080o`0000<000000?l00000
00000`3o00000`000000o`000?l000020?l000030>K<P000000000000=D0i/b000040>K<P0030000
003Vc800i/b000d0i/b000<000000>K<P03Vc8000`3Vc803000005`0i/b000@000000>K<P03o0000
00000`3o00000`000000i/b00>K<P0020>K<P0030000003Vc800000000<0i/b000<0o`000000003o
00000`3o000200000=D0i/b000040>K<P0030000003Vc800i/b000T0i/b0100000060>K<P0030000
003Vc800i/b005`0i/b000@000000?l0003o000000000P3o00000`3Vc80000000>K<P0030>K<P003
0000003Vc800000000@0i/b000H000000?l0003o0000o`000000003o000200000=@0i/b000040>K<
P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P01K0>K<
P0030?l000000000o`000080o`0000<000000>K<P00000001P3Vc802000000D0i/b000@000000?l0
003o000000000P3o00000`000000i/b00>K<P03B0>K<P00000@000000>K<P03Vc8000000303Vc800
0`000000i/b00>K<P0070>K<P0030000003Vc800i/b005X0i/b000<0o`000000003o00000P3o0000
103Vc800000000000000000=0>K<P0030000003Vc800000000<0o`0000<000000>K<P03Vc800]03V
c8000`000000i/b00>K<P00K0>K<P0001000000<0>K<P0@000001P3Vc8000`000000i/b00>K<P01I
0>K<P080o`0000<000000?l0003o00000`3Vc802000000d0i/b000<000000>K<P00000000`3o0000
0`000000o`000>K<P02d0>K<P0030000003Vc800i/b001/0i/b0000J0>K<P0030000003Vc800i/b0
05H0i/b000<000000>K<P03Vc8000P3o00000`000000o`000>K<P00C0>K<P080000000@0i/b00?l0
003o000000000P3o002d0>K<P0030000003Vc800i/b001/0i/b0000J0>K<P0030000003Vc800i/b0
05D0i/b000<000000>K<P00000000`3o00000`000000i/b00>K<P00G0>K<P0040?l000000000o`00
0?l00;@0i/b000<000000>K<P03Vc8006`3Vc80001X0i/b00P00001F0>K<P0030000003Vc8000000
00<0o`0000<000000>K<P03Vc800603Vc800103o000000000?l0003o002b0>K<P0030?l000000000
o`0001`0i/b0000J0>K<P0030000003Vc800i/b005D0i/b000H000000?l0003o000000000?l00000
000L0>K<P0040000003o0000o`000?l00;40i/b000<0o`000000003o0000703Vc80001X0i/b000<0
00000>K<P03Vc800E@3Vc8001P000000o`000?l000000000i/b0000001`0i/b000@000000?l0003o
0000o`000`00002]0>K<P0040?l000000000o`000?l001`0i/b0000J0>K<P0030000003Vc800i/b0
05D0i/b000@000000?l0003o0000o`000P00000M0>K<P0060000003o0000o`000000003Vc8000000
[@3Vc8000`3o000000000?l0000M0>K<P0006P3Vc8000`000000i/b00>K<P01D0>K<P0040000003o
0000o`000?l00200i/b000H000000?l0003o000000000?l00000002/0>K<P080o`0000<000000>K<
P03Vc800703Vc80001X0i/b000<000000>K<P03Vc800D`3Vc800103o000000000?l0003o000Q0>K<
P0030000003Vc800000000<0o`0000<000000>K<P03Vc800Z03Vc8020?l000030000003o0000i/b0
01d0i/b0000J0>K<P0030000003Vc800i/b00580i/b00P3o00000`000000o`000>K<P00R0>K<P080
00000`3o00000`000000i/b00>K<P02X0>K<P080o`0000<000000>K<P03Vc8007@3Vc80001X0i/b0
0P00001C0>K<P0030?l000000000o`0002L0i/b00P3o00000`000000i/b00>K<P02U0>K<P0800000
0`3o00000`000000i/b00>K<P00M0>K<P0006P3Vc8000`000000i/b00>K<P01A0>K<P080o`0000<0
00000?l0003Vc8009P3Vc8020?l000030000003o0000i/b00:D0i/b000<000000>K<P00000000P3o
00000`000000i/b00>K<P00M0>K<P0006P3Vc8000`000000i/b00>K<P01A0>K<P080o`0000<00000
0>K<P03Vc8009`3Vc8000`3o000000000?l0002V0>K<P0030000003o000000000080o`0000<00000
0>K<P03Vc8007@3Vc80001X0i/b000<000000>K<P03Vc800D03Vc8020?l000030000003o0000i/b0
02P0i/b00P3o00000`000000o`000>K<P02S0>K<P0030000003Vc800o`0000<00000803Vc80001X0
i/b000<000000>K<P03Vc800D03Vc8020?l000030000003Vc800i/b002T0i/b000<0o`000000003o
0000Y03Vc8001@000000o`000?l0003o000000000240i/b0000J0>K<P0030000003Vc800i/b004l0
i/b00`3o00000`000000i/b00>K<P00Y0>K<P0040?l000000000o`000?l00:<0i/b000@000000?l0
003o0000o`008P3Vc80001X0i/b000<000000>K<P03Vc800C`3Vc8020?l000030000003Vc800i/b0
02/0i/b000<000000?l0003o0000XP3Vc80010000000o`000?l0003o000S0>K<P0006P3Vc8020000
04l0i/b00`3o00000`000000i/b00>K<P00[0>K<P0040000003o0000o`000?l00:40i/b000@00000
0?l0003o0000o`008`3Vc80001X0i/b000<000000>K<P03Vc800CP3Vc8030?l000030000003Vc800
i/b002`0i/b000D000000?l0003o0000i/b00000002O0>K<P0030000003o0000o`0002@0i/b0000J
0>K<P0030000003Vc800i/b004d0i/b00`3o00000`000000i/b00>K<P00]0>K<P0030000003o0000
o`0000800000WP3Vc800103o000000000?l0003o000T0>K<P0006P3Vc8000`000000i/b00>K<P01<
0>K<P0@0o`0000<000000>K<P03Vc800;@3Vc8001P000000o`00000000000000i/b0000009d0i/b0
00<000000?l0003o00009@3Vc80001X0i/b000<000000>K<P03Vc800C03Vc8030?l000030000003V
c800i/b002h0i/b00`0000020?l000030000003Vc800i/b009X0i/b000<0o`000000003o00009P3V
c80001X0i/b000<000000>K<P03Vc800B`3Vc8040?l000030000003Vc800i/b002l0i/b000D00000
0?l0003o0000o`000000002K0>K<P080o`0000<000000?l0003Vc8009@3Vc80001X0i/b000<00000
0>K<P03Vc800B`3Vc8030?l000030000003Vc800i/b00340i/b00`3o00000`000000i/b00>K<P02I
0>K<P080o`0000<000000>K<P03Vc8009@3Vc80001X0i/b000<000000>K<P03Vc800BP3Vc8040?l0
00030000003Vc800i/b00380i/b00`3o00000`000000i/b00>K<P02G0>K<P0<0o`0000<000000>K<
P03Vc8009@3Vc80001X0i/b00P00001;0>K<P0<0o`0000<000000>K<P03Vc800<`3Vc8030?l00003
0000003Vc800i/b009L0i/b00`3o00000`000000i/b00>K<P00U0>K<P0006P3Vc8000`000000i/b0
0>K<P0190>K<P0<0o`0000<0i/b00000003Vc800=@3Vc8020?l000030000003Vc800i/b009H0i/b0
00@0o`000000003o00000000:03Vc80001X0i/b000<000000>K<P03Vc800B03Vc8040?l000030000
003Vc800i/b003D0i/b00`3o00000`000000i/b00>K<P02E0>K<P0040?l0000000000000000002P0
i/b0000J0>K<P0030000003Vc800i/b004P0i/b00`3o00000`3Vc80000000>K<P00g0>K<P080o`00
00<000000>K<P03Vc800U@3Vc8000`000000o`000?l0000Y0>K<P00000@0i/b00000000000000000
1@3Vc802000000D0i/b0100000060>K<P0030000003Vc800i/b004L0i/b0103o00000`000000i/b0
0>K<P00g0>K<P080o`0000<000000?l0003Vc800U03Vc8000`3o000000000?l0000Z0>K<P00000@0
00000>K<P03Vc80000001@3Vc802000000D0i/b000D000000>K<P03Vc800i/b0000000050>K<P003
0000003Vc800i/b004H0i/b00P0000020?l000030>K<P0000000i/b003T0i/b000<0o`000000003o
0000U@3Vc8000`3o000000000?l0000Z0>K<P000103Vc8000`000000i/b00>K<P0080>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0160>K<P0050000
003o000000000?l000000000>`3Vc800103o000000000?l0003o002C0>K<P0030?l000000000o`00
02/0i/b000040>K<P0030000003Vc800i/b000P0i/b000@000000>K<P03Vc800i/b00P0000050>K<
P0<00000AP3Vc8000`000000o`0000000002000003`0i/b000<000000?l0003o0000T`3Vc8000`3o
000000000?l0000[0>K<P000103Vc8000`000000i/b00>K<P0080>K<P0D000001P3Vc8000`000000
i/b00>K<P0150>K<P0040000003o0000o`000?l003h0i/b000@000000?l0003o0000o`00T@3Vc802
0?l000030000003o0000i/b002X0i/b000040>K<P0030000003Vc800i/b000T0i/b000<000000>K<
P03Vc8001`3Vc8000`000000i/b00>K<P0150>K<P0040000003o0000o`000?l003h0i/b000@00000
0?l0003o0000o`00S03Vc8000`000000i/b00>K<P0020>K<P0030?l000000000o`0000T0i/b000<0
00000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000/0i/b00000
10000000i/b00>K<P000000<0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800A@3V
c8000`000000o`000?l000100>K<P0030000003o0000o`0000800000RP3Vc80010000000i/b00>K<
P03Vc8020?l000030000003o0000i/b000L0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b0
0>K<P0070>K<P0030000003Vc800i/b000/0i/b00004000000d0i/b0100000050>K<P0030000003V
c800i/b004D0i/b000<000000?l0003o0000@03Vc8000`000000o`0000000002000008X0i/b000D0
00000>K<P03Vc800i/b00?l00006000000@0i/b000<000000>K<P03Vc800103Vc804000000<0i/b0
00<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00;0>K<P0006P3Vc8000`000000i/b00>K<
P0140>K<P0040?l000000000o`000?l00400i/b00`0000000`3o000000000>K<P0290>K<P0030000
003Vc800i/b00080o`0000D000000?l0003Vc800i/b0000000050>K<P0030000003Vc800i/b000<0
i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000/0
i/b0000J0>K<P0030000003Vc800i/b004@0i/b000<000000?l0003o0000@`3Vc8030?l000030000
003Vc800i/b008L0i/b000<000000>K<P03Vc8000P3o00001@000000i/b00>K<P03Vc800000000D0
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000H0
i/b000<000000>K<P03Vc8002`3Vc80001X0i/b00P0000140>K<P0040?l000000000o`000?l004<0
i/b00`3o00000`000000i/b00>K<P0270>K<P0060000003Vc800o`000?l000000000o`0010000005
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P006
0>K<P0030000003Vc800i/b000/0i/b0000J0>K<P0030000003Vc800i/b004<0i/b000<0o`000000
003o0000A03Vc8030?l000030000003Vc800i/b008L0i/b000D000000>K<P03o0000o`0000000004
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P005
0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8002`3Vc80001X0i/b000<000000>K<
P03Vc800@`3Vc8000`3o000000000?l000150>K<P080o`0000<000000>K<P03Vc800Q`3Vc8001P00
0000o`000?l0003o000000000>K<P0@000001@3Vc8000`000000i/b00>K<P0020>K<P0D00000103V
c8000`000000i/b00>K<P0060>K<P0040000003Vc800i/b00>K<P0@000001P3Vc80001X0i/b000<0
00000>K<P03Vc800@P3Vc8020?l000030000003o0000i/b004@0i/b00`3o00000`000000i/b00>K<
P0260>K<P0040000003o0000o`00000000`0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P0040>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P0060>K<P0006P3Vc8000`000000i/b00>K<P0120>K<P080o`0000<000000>K<P03Vc800A@3V
c8020?l000030000003Vc800i/b008H0i/b00P0000000`3o000000000>K<P00<0>K<P0050000003V
c800i/b00>K<P00000001@3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8001@3Vc80001X0i/b000<000000>K<P03Vc800@@3Vc8030?l000030000003V
c800i/b004D0i/b00P3o00000`000000i/b00>K<P0250>K<P0D00000:@3Vc8000`000000i/b00>K<
P0040>K<P0006P3Vc8000`000000i/b00>K<P0110>K<P0<0o`0000<000000>K<P03Vc800AP3Vc800
0`3o000000000?l000260>K<P0030000003o0000o`00008000009P3Vc80010000000i/b00>K<P000
00060>K<P0006P3Vc8000`000000i/b00>K<P0110>K<P080o`0000<000000>K<P03Vc800A`3Vc802
0?l000030000003Vc800i/b008@0i/b000<000000?l0003o0000:@3Vc802000000L0i/b0000J0>K<
P0800000@@3Vc8030?l000030000003Vc800i/b004L0i/b00P3o00000`000000o`000>K<P0230>K<
P0040000003o0000o`000?l00380i/b0000J0>K<P0030000003Vc800i/b00400i/b00P3o00000`00
0000i/b00>K<P0190>K<P0030?l000000000o`0008@0i/b000@000000?l0003o0000o`00<P3Vc800
01X0i/b000<000000>K<P03Vc800?P3Vc803000000030?l000000000i/b004X0i/b000<0o`000000
003o0000Q03Vc8000`000000o`000?l0000c0>K<P0006P3Vc8000`000000i/b00>K<P00n0>K<P003
0000003o0000000000800000C03Vc8000`000000o`000?l000220>K<P0040?l000000000o`000?l0
03<0i/b0000J0>K<P0030000003Vc800i/b003h0i/b000@000000?l0003o0000o`00C@3Vc8000`00
0000o`000?l000220>K<P0030?l000000000o`0003@0i/b0000J0>K<P0030000003Vc800i/b003h0
i/b000@000000?l0003o0000o`00C@3Vc80010000000o`000?l0003o00210>K<P0030?l000000000
o`0003@0i/b0000J0>K<P0030000003Vc800i/b003h0i/b000<000000?l0003o0000C`3Vc8000`00
0000o`000?l000200>K<P080o`0000<000000>K<P03Vc800<`3Vc80001X0i/b00P00000n0>K<P004
0000003o0000o`000?l004l0i/b000@000000?l0003o0000o`00O`3Vc8020?l000030000003Vc800
i/b003<0i/b0000J0>K<P0030000003Vc800i/b003d0i/b000<000000?l0003o0000D03Vc8000`00
0000o`0000000002000007d0i/b00P3o00000`000000o`000>K<P00d0>K<P0006P3Vc8000`000000
i/b00>K<P00m0>K<P0030000003o0000o`000540i/b00P0000000`3o000000000>K<P01l0>K<P080
o`0000<000000>K<P03Vc800=03Vc80001X0i/b000<000000>K<P03Vc800?03Vc80010000000o`00
0?l0003o001B0>K<P080o`0000<000000>K<P03Vc800N`3Vc8020?l000030000003Vc800i/b003@0
i/b0000J0>K<P0030000003Vc800i/b003`0i/b000<000000?l0003o0000D`3Vc8030?l000030000
003Vc800i/b007T0i/b00`3o00000`000000i/b00>K<P00d0>K<P0006P3Vc8000`000000i/b00>K<
P00l0>K<P0030000003o0000o`0005<0i/b00`3o00000`000000i/b00>K<P01i0>K<P080o`0000<0
00000>K<P03Vc800=@3Vc80001X0i/b000<000000>K<P03Vc800>`3Vc8000`3o000000000?l0001E
0>K<P080o`0000<000000>K<P03Vc800N@3Vc8020?l000030000003Vc800i/b003D0i/b0000J0>K<
P0800000?03Vc8000`3o000000000?l0001E0>K<P080o`0000<000000?l0003Vc800N03Vc8030?l0
00030000003Vc800i/b003D0i/b0000J0>K<P0030000003Vc800i/b003X0i/b00P3o00000`000000
o`000>K<P01E0>K<P0030?l000000000o`0007T0i/b00`3o00000`000000i/b00>K<P00e0>K<P000
6P3Vc8000`000000i/b00>K<P00j0>K<P080o`0000<000000>K<P03Vc800E@3Vc8020?l000030000
003Vc800i/b007H0i/b00P0000000`3o000000000>K<P00g0>K<P0006P3Vc8000`000000i/b00>K<
P00j0>K<P080o`0000<000000>K<P03Vc800EP3Vc8000`3o000000000?l0001g0>K<P0040000003o
00000000000003P0i/b0000J0>K<P0030000003Vc800i/b003T0i/b00P3o00000`000000o`000>K<
P01G0>K<P0030?l000000000o`0007H0i/b000@000000?l0003o0000o`00>@3Vc80000040>K<P000
00000000000000D0i/b00P0000060>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800
>@3Vc8020?l000030000003Vc800i/b005L0i/b000@0o`000000003o0000o`00M@3Vc80010000000
o`000?l0003o000i0>K<P00000@000000>K<P03Vc80000001@3Vc802000000L0i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P00i0>K<P080o`0000<000000>K<P03Vc800F03Vc8000`3o
000000000?l0001e0>K<P0030000003o0000o`0003X0i/b000040>K<P0030000003Vc800i/b000/0
i/b000<000000>K<P03Vc8001@3Vc803000003P0i/b00P3o00000`000000i/b00>K<P01I0>K<P003
0?l000000000o`0007D0i/b000<000000?l0003o0000>P3Vc80000@0i/b000<000000>K<P03Vc800
2`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b003L0i/b00P0000000`3o00000000
0>K<P01K0>K<P0030000003o0000o`0007<0i/b000@000000?l0003o0000o`00>P3Vc80000@0i/b0
00<000000>K<P03Vc800303Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b003L0i/b0
1000001L0>K<P0030000003o0000o`0007<0i/b000<000000?l0003o0000>`3Vc80000@0i/b000<0
00000>K<P03Vc800303Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b003H0i/b000@0
00000?l0003o0000o`00G@3Vc80010000000o`000?l0003o001b0>K<P0030000003o0000o`0003/0
i/b0000010000000i/b00>K<P000000;0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00f0>K<P0040000003o0000o`000?l005d0i/b000@000000?l0
003o0000o`00L@3Vc8000`3o000000000?l0000l0>K<P0001000000;0>K<P0H000001@3Vc8000`00
0000i/b00>K<P00f0>K<P0040000003o0000o`000?l005h0i/b000<000000?l0003o0000L@3Vc800
0`3o000000000?l0000l0>K<P0006P3Vc8000`000000i/b00>K<P00f0>K<P0030000003o0000o`00
05l0i/b000@000000?l0003o0000o`00L03Vc8000`3o000000000?l0000l0>K<P0006P3Vc8000`00
0000i/b00>K<P00e0>K<P0040000003o0000o`000?l005l0i/b000@000000?l0003o0000o`00K`3V
c8020?l000030000003Vc800i/b003/0i/b0000J0>K<P0800000=P3Vc8000`000000o`000?l0001P
0>K<P0@00000K`3Vc8020?l000030000003Vc800i/b003/0i/b0000J0>K<P0030000003Vc800i/b0
03D0i/b000<000000?l0003o0000H@3Vc8030?l000030000003Vc800i/b006/0i/b00P3o00000`00
0000o`000>K<P00l0>K<P0006P3Vc8000`000000i/b00>K<P00d0>K<P0040000003o0000o`000?l0
0680i/b00P3o00000`000000i/b00>K<P01[0>K<P080o`0000<000000>K<P03Vc800?03Vc80001X0
i/b000<000000>K<P03Vc800=03Vc8000`000000o`000?l0001S0>K<P0<0o`0000<000000>K<P03V
c800JP3Vc8020?l000030000003Vc800i/b003`0i/b0000J0>K<P0030000003Vc800i/b003@0i/b0
00<000000?l0003o0000H`3Vc8030?l000030000003Vc800i/b006T0i/b00`3o00000`000000i/b0
0>K<P00l0>K<P0006P3Vc8000`000000i/b00>K<P00c0>K<P0040?l000000000o`000?l006@0i/b0
0P3o00000`000000i/b00>K<P01Y0>K<P080o`0000<000000>K<P03Vc800?@3Vc80001X0i/b000<0
00000>K<P03Vc800<`3Vc8000`3o000000000?l0001U0>K<P080o`0000<000000>K<P03Vc800J@3V
c8020?l000030000003Vc800i/b001@0i/b01@3o00040>K<P0H0o`001@3Vc8040?l00140i/b0000J
0>K<P0800000=03Vc8000`3o000000000?l0001V0>K<P0030?l000000000o`0006T0i/b00`3o0000
0`000000i/b00>K<P00E0>K<P0030?l0003Vc800i/b000L0i/b000<0o`000>K<P03Vc8001@3Vc800
0`3o0000i/b00>K<P00C0>K<P0006P3Vc8000`000000i/b00>K<P00b0>K<P080o`0000<000000>K<
P03Vc800I@3Vc8000`3o000000000?l0001Y0>K<P0030000003o0000000001P0i/b000<0o`000>K<
P03Vc8001`3Vc8000`3o0000i/b00>K<P0050>K<P0030?l0003Vc800i/b001<0i/b0000J0>K<P003
0000003Vc800i/b00380i/b00P3o00000`000000i/b00>K<P01U0>K<P080o`0000<000000>K<P03V
c800IP3Vc80010000000o`0000000000000H0>K<P0030?l0003Vc800i/b000L0i/b000<0o`000>K<
P03Vc8001@3Vc8000`3o0000i/b00>K<P00C0>K<P0006P3Vc8000`000000i/b00>K<P00a0>K<P080
o`0000<000000?l0003Vc800I`3Vc8000`3o000000000?l0001W0>K<P0030000003o0000o`0001T0
i/b000<0o`000>K<P03Vc8001`3Vc8000`3o0000i/b00>K<P0050>K<P0030?l0003Vc800i/b001<0
i/b0000J0>K<P0030000003Vc800i/b00340i/b00P3o00000`000000i/b00>K<P01W0>K<P0030?l0
00000000o`0006H0i/b000@000000?l0003o0000o`006@3Vc8000`3o0000i/b00>K<P0070>K<P003
0?l0003Vc800i/b000D0i/b000<0o`000>K<P03Vc8004`3Vc80001X0i/b000<000000>K<P03Vc800
<@3Vc8020?l000030000003Vc800i/b006L0i/b000@0o`000000003o0000o`00I@3Vc80010000000
o`000?l0003o000H0>K<P0D0o`00103Vc8030?l000H0i/b01@3o000B0>K<P0006P3Vc8000`000000
i/b00>K<P00`0>K<P0<0o`0000<000000>K<P03Vc800J03Vc8000`000000o`000?l0001U0>K<P003
0000003o0000o`0001X0i/b000<0o`000>K<P03Vc8003`3Vc8000`3o0000i/b00>K<P00C0>K<P000
6P3Vc80200000340i/b00P3o00000`000000i/b00>K<P01Y0>K<P0030?l000000000o`0006@0i/b0
00@000000?l0003o0000o`006P3Vc8050?l000D0i/b000<0o`000>K<P03Vc8001@3Vc8000`3o0000
i/b00>K<P00C0>K<P0006P3Vc8000`000000i/b00>K<P00`0>K<P0030?l000000000000006/0i/b0
00@0o`000000003o0000o`00H`3Vc8000`000000o`000?l0000U0>K<P0030?l0003Vc800i/b001/0
i/b0000J0>K<P0030000003Vc800i/b002l0i/b00P3o00000`000000i/b00>K<P01[0>K<P0030000
003o0000o`0006<0i/b000<000000?l0003o0000@`3Vc80001X0i/b000<000000>K<P03Vc800;`3V
c8000`3o000000000?l0001]0>K<P0030000003o0000o`000680i/b000@0o`000000003o0000o`00
@`3Vc80001X0i/b000<000000>K<P03Vc800;`3Vc8000`3o000000000?l0001]0>K<P0040000003o
0000o`000?l00640i/b000<0o`000000003o0000A03Vc80001X0i/b000<000000>K<P03Vc800;P3V
c8000`3o000000000?l0001_0>K<P0030000003o0000o`000600i/b00P3o00000`000000o`000>K<
P0130>K<P0006P3Vc8000`000000i/b00>K<P00^0>K<P0030?l000000000o`0006l0i/b000<00000
0?l0003o0000H03Vc8020?l000030000003Vc800i/b004<0i/b0000J0>K<P0800000;P3Vc8020?l0
00030000003o0000i/b006h0i/b01000001O0>K<P080o`0000<000000>K<P03Vc800@`3Vc80001X0
i/b000<000000>K<P03Vc800;@3Vc8000`3o000000000?l0001a0>K<P080o`000P00001M0>K<P080
o`0000<000000?l0003Vc800A03Vc80001X0i/b000<000000>K<P03Vc800;@3Vc8000`3o00000000
0?l0001a0>K<P0<0o`0000<000000>K<P03Vc800F`3Vc8020?l000030000003Vc800i/b004@0i/b0
000J0>K<P0030000003Vc800i/b002`0i/b000<0o`000000003o0000L`3Vc8020?l000030000003V
c800i/b005X0i/b00`3o00000`000000i/b00>K<P0140>K<P0006P3Vc8000`000000i/b00>K<P00/
0>K<P0030?l000000000o`0007<0i/b00`3o00000`000000i/b00>K<P01I0>K<P0<0o`0000<00000
0>K<P03Vc800A03Vc80000040>K<P00000000000000000D0i/b00P0000050>K<P0@000001P3Vc800
0`000000i/b00>K<P00[0>K<P080o`0000<000000?l0003Vc800LP3Vc8030?l000030000003Vc800
i/b005T0i/b00P3o00000`000000i/b00>K<P0150>K<P00000@000000>K<P03Vc80000001@3Vc802
000000@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800
i/b002/0i/b000<0o`000000003o0000M@3Vc8020?l000030000003Vc800i/b005P0i/b00`3o0000
0`000000i/b00>K<P0150>K<P000103Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00[0>K<P0030?l000000000o`00
07D0i/b00P3o00000`000000i/b00>K<P01H0>K<P0<0o`0000<000000>K<P03Vc800A@3Vc80000@0
i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P002000000D0i/b00`00000Z0>K<P003
0?l000000000o`0007H0i/b00P3o00000`000000o`000>K<P01G0>K<P0<0o`0000<000000>K<P03V
c800AP3Vc80000@0i/b000<000000>K<P03Vc8002@3Vc804000000H0i/b000<000000>K<P03Vc800
:P3Vc8000`3o000000000?l0001g0>K<P080o`0000<000000>K<P03Vc800EP3Vc804000004P0i/b0
00040>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b002T0i/b00P3o00000`000000o`000>K<P01f0>K<P080o`0000<0
00000?l0003Vc800EP3Vc8000`000000o`000?l000190>K<P00000@000000>K<P03Vc80000002`3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800:@3V
c8000`3o000000000?l0001i0>K<P0030?l000000000o`0005H0i/b000@0o`000000003o0000o`00
B@3Vc80000@00000303Vc804000000H0i/b000<000000>K<P03Vc800:@3Vc8000`3o000000000?l0
001i0>K<P0030?l000000000o`0005H0i/b000<000000?l0003o0000BP3Vc80001X0i/b000<00000
0>K<P03Vc800:03Vc8020?l000030000003o0000i/b007P0i/b000@0o`000000003o0000o`00E03V
c800103o000000000?l0003o001:0>K<P0006P3Vc8000`000000i/b00>K<P00X0>K<P0030?l00000
0000o`0007/0i/b000<000000?l0003o0000E03Vc8000`3o000000000?l0001;0>K<P0006P3Vc802
000002T0i/b000<0o`000000003o0000N`3Vc800103o000000000?l0003o001C0>K<P0030000003o
0000o`0004/0i/b0000J0>K<P0030000003Vc800i/b002L0i/b000<0o`000000003o0000O@3Vc800
0`000000o`000?l0001B0>K<P0040?l000000000o`000?l004/0i/b0000J0>K<P0030000003Vc800
i/b002L0i/b000<0o`000000003o0000O@3Vc8000`000000o`000?l0001B0>K<P0030?l000000000
o`0004`0i/b0000J0>K<P0030000003Vc800i/b002H0i/b00P3o00000`000000o`000>K<P01l0>K<
P0040000003o0000o`000?l00500i/b00P3o00000`000000o`000>K<P01;0>K<P0006P3Vc8000`00
0000i/b00>K<P00V0>K<P0030?l000000000o`0007l0i/b000<000000?l0003o0000D03Vc8020?l0
00030000003Vc800i/b004/0i/b0000J0>K<P0030000003Vc800i/b002H0i/b000<0o`000000003o
0000O`3Vc80010000000o`000?l0003o001?0>K<P080o`0000<000000>K<P03Vc800B`3Vc80001X0
i/b000<000000>K<P03Vc8009@3Vc8000`3o000000000?l000210>K<P0<00000CP3Vc8030?l00003
0000003Vc800i/b004/0i/b0000J0>K<P08000009P3Vc8000`3o000000000?l000210>K<P0<0o`00
00<000000>K<P03Vc800B`3Vc8020?l000030000003Vc800i/b004`0i/b0000J0>K<P0030000003V
c800i/b002@0i/b00P3o00000`000000o`000>K<P0200>K<P0<0o`0000<000000>K<P03Vc800BP3V
c8030?l000030000003Vc800i/b004`0i/b0000J0>K<P0030000003Vc800i/b002@0i/b000<0o`00
0000003o0000P`3Vc8020?l000030000003Vc800i/b004X0i/b00`3o00000`000000i/b00>K<P01<
0>K<P0006P3Vc8000`000000i/b00>K<P00T0>K<P0030?l000000000o`0008<0i/b00`3o00000`00
0000i/b00>K<P0190>K<P0<0o`0000<000000>K<P03Vc800C03Vc80001X0i/b000<000000>K<P03V
c8008`3Vc8000`3o000000000?l000250>K<P080o`0000<000000>K<P03Vc800B03Vc8030?l00003
0000003Vc800i/b004d0i/b0000J0>K<P0030000003Vc800i/b002<0i/b000<0o`000000003o0000
Q@3Vc8020?l000030000003Vc800i/b004P0i/b00`3o00000`000000i/b00>K<P01=0>K<P0006P3V
c8000`000000i/b00>K<P00R0>K<P080o`0000<000000?l0003Vc800Q03Vc8020?l000030000003o
0000i/b004L0i/b00`3o00000`000000i/b00>K<P01>0>K<P0006P3Vc802000002<0i/b000<0o`00
0000003o0000Q`3Vc8020?l000030000003Vc800i/b004H0i/b01000001@0>K<P0006P3Vc8000`00
0000i/b00>K<P00Q0>K<P080o`0000<000000?l0003Vc800QP3Vc8020?l000030000003o0000i/b0
04H0i/b000<000000?l0003o0000D@3Vc80001X0i/b000<000000>K<P03Vc8008@3Vc8000`3o0000
00000?l000290>K<P0030?l000000000o`0004H0i/b000<0o`000000003o0000DP3Vc80001X0i/b0
00<000000>K<P03Vc8008@3Vc8000`3o000000000?l000290>K<P0030?l000000000o`0004H0i/b0
00<000000?l0003o0000DP3Vc80001X0i/b000<000000>K<P03Vc800803Vc8000`3o000000000?l0
002:0>K<P0040?l000000000o`000?l004@0i/b000@0o`000000003o0000o`00DP3Vc80001X0i/b0
00<000000>K<P03Vc800803Vc8000`3o000000000?l0002;0>K<P0030000003o0000o`0004@0i/b0
00<0o`000000003o0000D`3Vc80001X0i/b000<000000>K<P03Vc8007`3Vc8000`3o000000000?l0
002<0>K<P0040000003o0000o`000?l00480i/b000@0o`000000003o0000o`00D`3Vc80001X0i/b0
00<000000>K<P03Vc8007`3Vc8000`3o000000000?l0002=0>K<P0030000003o0000o`000480i/b0
00<0o`000000003o0000E03Vc80001X0i/b00P00000O0>K<P0040?l000000000o`000?l008d0i/b0
00@000000?l0003o0000o`00@@3Vc8000`3o000000000?l0001D0>K<P0006P3Vc8000`000000i/b0
0>K<P00N0>K<P0030?l000000000o`0008h0i/b00P0000020?l00400i/b00P3o00000`000000o`00
0>K<P01C0>K<P0006P3Vc8000`000000i/b00>K<P00M0>K<P0040?l000000000o`000?l008l0i/b0
0P0000000`3o0000i/b00>K<P00n0>K<P0030?l000000000o`0005D0i/b0000J0>K<P0030000003V
c800i/b001d0i/b000<0o`000000003o0000T@3Vc803000003h0i/b00P3o00000`000000o`000>K<
P01D0>K<P00000@0i/b000000000000000001@3Vc802000000@0i/b00`0000080>K<P0030000003V
c800i/b001`0i/b000@0o`000000003o0000o`00T@3Vc8020?l000030000003Vc800i/b003`0i/b0
0P3o00000`000000i/b00>K<P01D0>K<P00000@000000>K<P03Vc80000001@3Vc802000000L0i/b0
00<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00L0>K<P0030?l000000000o`0009<0i/b0
0P3o00000`000000i/b00>K<P00k0>K<P080o`0000<000000>K<P03Vc800E03Vc80000@0i/b000<0
00000>K<P03Vc800303Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b001/0i/b000@0
o`000000003o0000o`00T`3Vc8020?l000030000003Vc800i/b003X0i/b00`3o00000`000000i/b0
0>K<P01D0>K<P000103Vc8000`000000i/b00>K<P0090>K<P0@000001P3Vc803000001/0i/b000<0
o`000000003o0000U@3Vc8000`3o000000000?l0000k0>K<P080o`0000<000000>K<P03Vc800E@3V
c80000@0i/b000<000000>K<P03Vc800203Vc8001@000000i/b00>K<P03Vc800000000H0i/b000<0
00000>K<P03Vc8006P3Vc800103o000000000?l0003o002E0>K<P080o`0000<000000>K<P03Vc800
>03Vc8030?l000030000003Vc800i/b005D0i/b000040>K<P0030000003Vc800i/b000P0i/b000D0
00000>K<P03Vc800i/b0000000060>K<P0030000003Vc800i/b001X0i/b000<0o`000000003o0000
UP3Vc8020?l000030000003o0000i/b003P0i/b00`00001H0>K<P00000@000000>K<P03Vc8000000
2`3Vc8001@000000i/b00>K<P03Vc800000000H0i/b000<000000>K<P03Vc8006P3Vc8000`000000
o`000?l0002G0>K<P0030?l000000000o`0003P0i/b00P0000020?l005P0i/b00004000000`0i/b0
0`0000070>K<P0030000003Vc800i/b001T0i/b000<0o`000000003o0000V03Vc8020?l000030000
003o0000i/b003H0i/b000<000000?l0003o0000F@3Vc80001X0i/b000<000000>K<P03Vc8006@3V
c8000`000000o`000?l0002I0>K<P0030?l000000000o`0003L0i/b000<000000?l0003o0000F@3V
c80001X0i/b000<000000>K<P03Vc800603Vc8000`3o000000000?l0002J0>K<P0040?l000000000
o`000?l003D0i/b000@000000?l0003o0000o`00F@3Vc80001X0i/b00P00000I0>K<P0030000003o
0000o`0009/0i/b000<0o`000000003o0000=@3Vc8000`000000o`000?l0001J0>K<P0006P3Vc800
0`000000i/b00>K<P00G0>K<P0040?l000000000o`000?l009/0i/b000@0o`000000003o0000o`00
<`3Vc80010000000o`000?l0003o001J0>K<P0006P3Vc8000`000000i/b00>K<P00G0>K<P0030000
003o0000o`0009d0i/b000<000000?l0003o0000<`3Vc8000`000000o`000?l0001K0>K<P0006P3V
c8000`000000i/b00>K<P00F0>K<P0040000003o0000o`000?l009d0i/b000@000000?l0003o0000
o`00<@3Vc8000`3o000000000?l0001L0>K<P0006P3Vc8000`000000i/b00>K<P00F0>K<P0030000
003o0000o`0009l0i/b000<000000?l0003o0000<03Vc800103o000000000?l0003o001L0>K<P000
6P3Vc8000`000000i/b00>K<P00E0>K<P0040000003o0000o`000?l00:00i/b00`00000_0>K<P003
0?l000000000o`0005d0i/b0000J0>K<P0030000003Vc800i/b001@0i/b000@0o`000000003o0000
o`00X@3Vc8020?l000800000;@3Vc8020?l000030000003o0000i/b005`0i/b0000J0>K<P0800000
5@3Vc8000`000000o`000?l0002S0>K<P080o`0000<000000>K<P03Vc800:`3Vc8020?l000030000
003Vc800i/b005`0i/b0000J0>K<P0030000003Vc800i/b001<0i/b000@0o`000000003o0000o`00
X`3Vc8020?l000030000003o0000i/b002X0i/b00`3o00000`000000i/b00>K<P01L0>K<P0006P3V
c8000`000000i/b00>K<P00C0>K<P0030000003o0000o`000:D0i/b00P3o00000`000000i/b00>K<
P00X0>K<P0<0o`0000<000000>K<P03Vc800G@3Vc80001X0i/b000<000000>K<P03Vc8004P3Vc800
0`000000o`000?l0002V0>K<P080o`0000<000000?l0003Vc800:03Vc804000005l0i/b0000J0>K<
P0030000003Vc800i/b00140i/b000@0o`000000003o0000o`00Y`3Vc8000`3o000000000?l0000X
0>K<P08000000P3o001P0>K<P0006P3Vc8000`000000i/b00>K<P00A0>K<P0030000003o0000o`00
0:T0i/b000<000000?l0003o00009P3Vc800103o000000000?l0003o001Q0>K<P0006P3Vc8000`00
0000i/b00>K<P00@0>K<P0040?l000000000o`000?l00:T0i/b000@0o`000000003o0000o`009@3V
c8000`3o000000000?l0001R0>K<P0006P3Vc8000`000000i/b00>K<P00?0>K<P0040?l000000000
o`000?l00:/0i/b000<000000?l0003o0000903Vc800103o000000000?l0003o001R0>K<P0006P3V
c80200000100i/b000<000000?l0003o0000503Vc806000000@0i/b00`00000V0>K<P0<000001@3V
c803000002@0i/b0100000050>K<P0<000009@3Vc804000000030>K<P03o000000000080o`000`00
000O0>K<P080o`0000@000000?l0000000000000103Vc803000000D0i/b00`00000L0>K<P0H00000
0P3Vc806000000@0i/b00`00000Q0>K<P0006P3Vc8000`000000i/b00>K<P00>0>K<P0040?l00000
0000o`000?l001D0i/b000D000000>K<P03Vc800i/b0000000030>K<P0040000003Vc800i/b00000
02L0i/b000<000000>K<P03Vc8000`3Vc80010000000i/b00>K<P000000T0>K<P0050000003Vc800
i/b00>K<P00000000`3Vc80010000000i/b00>K<P000000T0>K<P0030000003Vc800i/b00080i/b0
00<000000>K<P00000000`3o00000`3Vc80000000>K<P00N0>K<P0040?l000000000o`00000000D0
i/b000@000000>K<P03Vc8000000103Vc80010000000i/b00>K<P000000O0>K<P0030000003Vc800
i/b000<0i/b000D000000>K<P03Vc800i/b0000000030>K<P0040000003Vc800i/b000000240i/b0
000J0>K<P0030000003Vc800i/b000d0i/b000@0o`000000003o0000o`005`3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8008@3Vc805000000<0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800i/b00080i/b0
00@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P00Q0>K<P0030000003Vc800i/b00080
i/b000<000000>K<P03Vc800100000000`3Vc80000000>K<P00L0>K<P080o`0000<000000?l00000
0000103Vc8000`000000i/b00>K<P0020>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<
P03Vc800703Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P00N0>K<P0006P3Vc8000`000000i/b00>K<P00<0>K<P004
0?l000000000o`000?l001T0i/b00P0000030>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8008@3Vc80010000000i/b00>K<P00000040>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc800803Vc80010000000i/b00>K<P03Vc80200000080i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b0008000000P3Vc8001P000000o`000?l0
00000000o`00000001`0i/b00`3o00000`000000i/b0000000040>K<P0030000003Vc800i/b00080
i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b0
00D0i/b00P0000030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8007P3Vc80001X0
i/b000<000000>K<P03Vc8002`3Vc8020?l000030000003o0000i/b001X0i/b00P0000020>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b0000000040>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc800803Vc805000000<0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P00R0>K<P0@000000`3Vc8001P000000i/b00?l0003o00000000
0?l001/0i/b00`3o000010000000i/b00>K<P00000040>K<P0030000003Vc800i/b00080i/b000@0
00000>K<P03Vc8000000103Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b000H0i/b0
0P0000020>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8007P3Vc80001X0i/b000<0
00000>K<P03Vc8002P3Vc8020?l000030000003o0000o`0001`0i/b000@000000>K<P03Vc8000000
103Vc8000`000000i/b00>K<P00S0>K<P0800000103Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b00240i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b00240i/b000<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<P0000000i/b000<0
o`0000<000000?l0003Vc800603Vc8030?l0008000000P3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b00080i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P00L0>K<
P0030000003Vc800i/b000L0i/b000@000000>K<P03Vc8000000103Vc8000`000000i/b00>K<P00N
0>K<P0006P3Vc8000`000000i/b00>K<P0090>K<P0<0o`0000<000000?l0003Vc8005`3Vc8000`00
0000i/b00>K<P0020>K<P0050000003Vc800i/b00>K<P00000000P3Vc8000`000000i/b00>K<P00T
0>K<P08000001@3Vc80010000000i/b00>K<P000000T0>K<P0030000003Vc800i/b000D0i/b000@0
00000>K<P03Vc8000000903Vc8000`000000i/b00>K<P0020>K<P0060000003Vc800i/b00>K<P000
0000i/b00P3o00000`000000o`000?l0000G0>K<P0030?l0000000000000008000000`3Vc8000`00
0000i/b00>K<P0030>K<P0040000003Vc800i/b0000000@0i/b000@000000>K<P03Vc80000007`3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000D000000>K<P03Vc800i/b0
000000020>K<P0030000003Vc800i/b001l0i/b0000J0>K<P08000002@3Vc8030?l0008000006@3V
c805000000@0i/b01000000W0>K<P0030000003Vc800i/b000<0i/b01000000U0>K<P0@000000`3V
c804000002D0i/b0100000040>K<P0<000000P3o00000`000000o`000?l0000E0>K<P0030?l00000
0000o`000080o`000P3Vc803000000D0i/b0100000040>K<P0@000007@3Vc803000000@0i/b01@00
00040>K<P0@000008@3Vc80001X0i/b000<000000>K<P03Vc8001`3Vc8000`3o0000000000000002
00000;T0i/b000<0o`000000003o00000P3o000C0>K<P0030?l000000000o`000080o`00J@3Vc800
01X0i/b000<000000>K<P03Vc8001P3Vc8000`3o00000000000000020?l00;/0i/b000<0o`000000
003o00000P3o000A0>K<P080o`0000<000000?l0003o0000JP3Vc80001X0i/b000<000000>K<P03V
c8001@3Vc8000`3o000000000?l000020?l00;d0i/b0100000000`3o0000i/b00>K<P00=0>K<P080
o`0000<000000?l0003o0000J`3Vc80001X0i/b000<000000>K<P03Vc800103Vc8020?l000030000
003o0000o`000;l0i/b00P3o000200000080o`002`3Vc8030?l000030000003o0000o`0006`0i/b0
000J0>K<P0040000003Vc800i/b00>K<P0@0o`0000<000000?l0003o0000`P3Vc8020?l000800000
0`3o00050>K<P080o`001@0000000`3o0000i/b00>K<P01S0>K<P0@00000103Vc80001T0i/b0103o
000500000080o`00a03Vc8030?l000030000003o0000o`0000D0o`000`0000030?l006H0i/b000<0
00000>K<P03Vc8001P3Vc8000180i/b01`0000000`3o0000000000000002000000@0o`00a`000002
0?l000P000001@3o001K000000`0i/b000<000000>K<P03Vc8001P3Vc80001T0i/b01`3o00060>K<
P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0090>K<
P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0090>K<
P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0090>K<
P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0090>K<
P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0090>K<
P0030000003Vc800i/b000T0i/b000@000000>K<P03Vc800i/b02@3o000;0>K<P0030000003Vc800
i/b000T0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800
i/b000X0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800
i/b001<0i/b000<000000>K<P03Vc8001P3Vc80001X0i/b000<000000>K<P03Vc800;@3Vc8000`00
0000i/b00>K<P00^0>K<P0030000003Vc800i/b002d0i/b000<000000>K<P03Vc800;P3Vc8000`00
0000i/b00>K<P00]0>K<P0030000003Vc800i/b002h0i/b000<000000>K<P03Vc8007`3Vc8000`00
0000i/b00>K<P0060>K<P0006P3Vc8000`000000i/b00>K<P03o0>K<P480i/b01@0000050>K<P000
6P3Vc8000`000000i/b00>K<P03o0>K<P4<0i/b000<000000>K<P03Vc8001P3Vc80001X0i/b000<0
00000>K<P03Vc800o`3Vc8130>K<P0030000003Vc800i/b000H0i/b0003o0>K<P6T0i/b0003o0>K<
P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<
P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<
P6T0i/b00000\
\>"],
  ImageRangeCache->{{{0, 359}, {221.375, 0}} -> {-10.9384, 0.437764, \
0.516028, 0.00344443}}],

Cell[BoxData[
    InterpretationBox[\("Mean Propability of measuring \
|+z\[RightAngleBracket]: "\[InvisibleSpace]0.7466351778359953`\),
      SequenceForm[ 
      "Mean Propability of measuring |+z\[RightAngleBracket]: ", 
        0.74663517783599531],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Amplitude of oscillation: \
"\[InvisibleSpace]0.25303634809794956`\),
      SequenceForm[ "Amplitude of oscillation: ", 0.25303634809794956],
      Editable->False]], "Print"],

Cell[BoxData[
    InterpretationBox[\("Rabi frequency: \
"\[InvisibleSpace]0.07115959075460786`\[InvisibleSpace]"  Period of \
Rabi-oscillation: "\[InvisibleSpace]88.29709727880534`\),
      SequenceForm[ 
      "Rabi frequency: ", 0.071159590754607857, 
        "  Period of Rabi-oscillation: ", 88.297097278805339],
      Editable->False]], "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{

Cell["Parameter Dependence", "Section"],

Cell["\<\
We want to observe the effect of a variation in \[Omega]1 and \
\[Omega], i.e. the strength and the frequency of the perturbation, on the \
Rabi frequency and the amplitude.\
\>", "Text"],

Cell[BoxData[
    \(\(\(\[Omega]1list = {0.05, 0.075, 0.1, 0.15, 0.2, 0.25, 
        0.3}\)\(;\)\(\[Omega]list = {0.8, 0.9, 0.95, 0.99, 1, 1.01, 1.05, 
        1.1, 1.2}\)\(;\)\(colldata = 
      Table[Table[{0, 0, 0, 
            0\ }, {Length[\[Omega]1list]}], {Length[\[Omega]list]}]\)\(;\)\(\
\[IndentingNewLine]\)\( (*Length[\[Omega]list]\[IndentingNewLine]Length[\
\[Omega]1list]*) \)\)\)], "Input"],

Cell["This may take some time:", "Text"],

Cell[CellGroupData[{

Cell[BoxData[{
    \(imax = Length[\[Omega]list]; 
    jmax = Length[\[Omega]1list];\), "\[IndentingNewLine]", 
    \(\(Do[\(Do[\[IndentingNewLine]numsol[
              1, \[Omega]1list[\([j]\)], \[Omega]list[\([i]\)]]; \
\[IndentingNewLine]numfourier[pup, tmax]; \[IndentingNewLine]cosfit[pup, 
              meanpop, 1 - meanpop, 
              n0]; \[IndentingNewLine]\[Omega]R = \[Omega]est\ n1 /. 
                fitres; \[IndentingNewLine]ampR = 
              amp1 /. fitres; \[IndentingNewLine] (*\(Print["\<\[Omega]1= \
\>", \[Omega]1list[\([j]\)], "\< \[RawEscape]\[Omega]= \>", \
\[Omega]list[\([i]\)], \*"\"\<    \!\(\[Omega]\_R\)= \>\"", \[Omega]R, "\<  \
Amplitude: \>", ampR];\)*) \[IndentingNewLine]colldata[\([i, 
                  j]\)] = {\[Omega]1list[\([j]\)], \[Omega]list[\([i]\)], \
\[Omega]R, ampR};\[IndentingNewLine], {j, 1, 
              jmax}];\)\[IndentingNewLine], {i, 1, imax}];\)\)}], "Input"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(imax\)\" is similar to \
existing symbols \!\({lmax, nmax, tmax}\)."\)], "Message"],

Cell[BoxData[
    \(General::"spell" \(\(:\)\(\ \)\) 
      "Possible spelling error: new symbol name \"\!\(jmax\)\" is similar to \
existing symbols \!\({imax, lmax, nmax, tmax}\)."\)], "Message"]
}, Open  ]],

Cell[TextData[{
  "The Rabi frequency as a function of the frequency \[Omega] of the \
perturbation and of its strength ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_1\)]],
  ":"
}], "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plFreq = 
        Show[Graphics3D[{Line /@ 
                Transpose[colldata[\([All, All, {2, 1, 3}]\)]], 
              Line /@ colldata[\([All, All, {2, 1, 3}]\)]}\ , 
            Boxed \[Rule] True, Axes \[Rule] True, 
            AxesLabel \[Rule] {\*"\"\<\[Omega]1/\!\(\[Omega]\_0\)\>\"", \*"\"\
\<\[Omega]/\!\(\[Omega]\_0\)\>\"", \*"\"\<\!\(\[Omega]\_R\)/\!\(\[Omega]\_0\)\
\>\""}, PlotLabel -> "\<Rabi frequency\>"]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: .9033 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
3.18755e-17 1.00925 -0.0229182 1.00925 [
[.5 .9158 -44 0 ]
[.5 .9158 44 10.125 ]
[.05961 .25341 -18 -8.89977 ]
[.05961 .25341 0 .10023 ]
[.21356 .1943 -17.3574 -9 ]
[.21356 .1943 .64264 0 ]
[.37596 .13196 -5.50323 -9 ]
[.37596 .13196 .49677 0 ]
[.54752 .06614 -15.662 -9 ]
[.54752 .06614 2.33799 0 ]
[.72904 -0.00346 -14.8143 -9 ]
[.72904 -0.00346 3.18566 0 ]
[.33555 .08353 -30.7837 -9.8125 ]
[.33555 .08353 2.77882 0 ]
[.81231 .06777 0 -6.15838 ]
[.81231 .06777 18 2.84162 ]
[.88774 .18636 0 -6.05851 ]
[.88774 .18636 18 2.94149 ]
[.95607 .2938 0 -5.96998 ]
[.95607 .2938 18 3.03002 ]
[.92909 .1369 0 -6.63143 ]
[.92909 .1369 27.5625 3.18107 ]
[.04078 .28129 -6 -2.7862 ]
[.04078 .28129 0 6.2138 ]
[.02194 .42619 -18 -2.89435 ]
[.02194 .42619 0 6.10565 ]
[.00147 .58363 -18 -3.01267 ]
[.00147 .58363 0 5.98733 ]
[-0.04308 .48917 -33.125 -3.1901 ]
[-0.04308 .48917 0 6.6224 ]
[ 0 0 0 0 ]
[ 1 .9033 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 .9158 -105 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Rabi) show
93.000 11.562 moveto
(frequency) show
147.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.05372 .26793 m
.75455 0 L
s
.06863 .26223 m
.07314 .26664 L
s
[(0.8)] .05961 .25341 1 .97773 Mshowa
.22215 .20354 m
.22644 .20816 L
s
[(0.9)] .21356 .1943 .9286 1 Mshowa
.38404 .14165 m
.38809 .14649 L
s
[(1)] .37596 .13196 .83441 1 Mshowa
.55503 .07628 m
.55878 .08135 L
s
[(1.1)] .54752 .06614 .74022 1 Mshowa
.73589 .00713 m
.73931 .01243 L
s
[(1.2)] .72904 -0.00346 .64604 1 Mshowa
.125 Mabswid
.0987 .25074 m
.10138 .25341 L
s
.12908 .23912 m
.13173 .24182 L
s
.15977 .22739 m
.1624 .23011 L
s
.1908 .21553 m
.1934 .21828 L
s
.25383 .19143 m
.25638 .19423 L
s
.28586 .17918 m
.28838 .18201 L
s
.31824 .16681 m
.32072 .16966 L
s
.35096 .15429 m
.35342 .15717 L
s
.41749 .12886 m
.41988 .13179 L
s
.4513 .11593 m
.45366 .11889 L
s
.4855 .10286 m
.48782 .10585 L
s
.52007 .08964 m
.52236 .09266 L
s
.59038 .06276 m
.5926 .06583 L
s
.62614 .04909 m
.62831 .05219 L
s
.6623 .03527 m
.66444 .03839 L
s
.69888 .02128 m
.70098 .02443 L
s
gsave
.33555 .08353 -91.7837 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 11.250 moveto
(\\220) show
81.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
87.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
92.562 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.75455 0 m
.94813 .30408 L
s
.80047 .07214 m
.79455 .07432 L
s
[(0.1)] .81231 .06777 -1 .36853 Mshowa
.87582 .19049 m
.86986 .19255 L
s
[(0.2)] .88774 .18636 -1 .34634 Mshowa
.94408 .29771 m
.93808 .29967 L
s
[(0.3)] .95607 .2938 -1 .32666 Mshowa
.125 Mabswid
.81616 .09678 m
.8126 .09807 L
s
.83153 .12092 m
.82797 .1222 L
s
.84659 .14458 m
.84302 .14584 L
s
.86135 .16776 m
.85778 .16901 L
s
.89 .21277 m
.88642 .214 L
s
.90391 .23462 m
.90033 .23584 L
s
.91756 .25606 m
.91397 .25726 L
s
.93095 .27708 m
.92735 .27827 L
s
.78445 .04698 m
.78091 .0483 L
s
.7681 .02128 m
.76456 .02262 L
s
gsave
.92909 .1369 -61 -10.6314 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 11.250 moveto
(\\220) show
75.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
81.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
86.562 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.05372 .26793 m
0 .68381 L
s
.05257 .2768 m
.05847 .27456 L
s
[(0)] .04078 .28129 1 -0.38085 Mshowa
.03382 .42195 m
.03976 .41983 L
s
[(0.1)] .02194 .42619 1 -0.35681 Mshowa
.01345 .57967 m
.01944 .57769 L
s
[(0.2)] .00147 .58363 1 -0.33052 Mshowa
.125 Mabswid
.04894 .3049 m
.05248 .30357 L
s
.04525 .33345 m
.0488 .33214 L
s
.04151 .36247 m
.04506 .36117 L
s
.0377 .39197 m
.04125 .39068 L
s
.02989 .45244 m
.03346 .45119 L
s
.02588 .48344 m
.02946 .4822 L
s
.02181 .51497 m
.02539 .51375 L
s
.01767 .54704 m
.02125 .54584 L
s
.00916 .61286 m
.01276 .61169 L
s
.0048 .64664 m
.00841 .64549 L
s
.00036 .68102 m
.00397 .67989 L
s
gsave
-0.04308 .48917 -94.125 -7.1901 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
69.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(R) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
74.562 11.250 moveto
(\\220) show
80.562 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
86.562 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
92.125 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.05372 .26793 m
0 .68381 L
s
0 .68381 m
.28589 .9033 L
s
.28589 .9033 m
.30658 .51291 L
s
.30658 .51291 m
.05372 .26793 L
s
.75455 0 m
.94813 .30408 L
s
.94813 .30408 m
1 .71656 L
s
1 .71656 m
.78843 .43699 L
s
.78843 .43699 m
.75455 0 L
s
.05372 .26793 m
0 .68381 L
s
0 .68381 m
.78843 .43699 L
s
.78843 .43699 m
.75455 0 L
s
.75455 0 m
.05372 .26793 L
s
.30658 .51291 m
.94813 .30408 L
s
.94813 .30408 m
1 .71656 L
s
1 .71656 m
.28589 .9033 L
s
.28589 .9033 m
.30658 .51291 L
s
0 0 m
1 0 L
1 .9033 L
0 .9033 L
closepath
clip
newpath
.5 Mabswid
.40964 .65529 m
.45376 .72893 L
s
.45376 .72893 m
.53262 .67051 L
s
.29568 .88442 m
.45376 .72893 L
s
.24848 .82077 m
.29568 .88442 L
s
.48959 .59086 m
.53262 .67051 L
s
.53262 .67051 m
.59645 .63791 L
s
.55404 .55549 m
.59645 .63791 L
s
.59645 .63791 m
.6126 .63213 L
s
.57032 .54943 m
.6126 .63213 L
s
.6126 .63213 m
.62887 .62734 L
s
.58671 .54455 m
.62887 .62734 L
s
.62887 .62734 m
.69527 .618 L
s
.36406 .58109 m
.40964 .65529 L
s
.40964 .65529 m
.48959 .59086 L
s
.24848 .82077 m
.40964 .65529 L
s
.4453 .50981 m
.48959 .59086 L
s
.48959 .59086 m
.55404 .55549 L
s
.19929 .75852 m
.24848 .82077 L
s
.51042 .47075 m
.55404 .55549 L
s
.55404 .55549 m
.57032 .54943 L
s
.52684 .46435 m
.57032 .54943 L
s
.57032 .54943 m
.58671 .54455 L
s
.65361 .5366 m
.69527 .618 L
s
.69527 .618 m
.78221 .62644 L
s
.54334 .45941 m
.58671 .54455 L
s
.58671 .54455 m
.65361 .5366 L
s
.31678 .50798 m
.36406 .58109 L
s
.36406 .58109 m
.4453 .50981 L
s
.19929 .75852 m
.36406 .58109 L
s
.39962 .42815 m
.4453 .50981 L
s
.4453 .50981 m
.51042 .47075 L
s
.46555 .38365 m
.51042 .47075 L
s
.51042 .47075 m
.52684 .46435 L
s
.14784 .69803 m
.19929 .75852 L
s
.48209 .37679 m
.52684 .46435 L
s
.52684 .46435 m
.54334 .45941 L
s
.6107 .45368 m
.65361 .5366 L
s
.65361 .5366 m
.74131 .54903 L
s
.49871 .37188 m
.54334 .45941 L
s
.54334 .45941 m
.6107 .45368 L
s
.35235 .3471 m
.39962 .42815 L
s
.39962 .42815 m
.46555 .38365 L
s
.31678 .50798 m
.39962 .42815 L
s
.26748 .43738 m
.31678 .50798 L
s
.14784 .69803 m
.31678 .50798 L
s
.74131 .54903 m
.78221 .62644 L
s
.78221 .62644 m
.97331 .68824 L
s
.41935 .29422 m
.46555 .38365 L
s
.46555 .38365 m
.48209 .37679 L
s
.43604 .28667 m
.48209 .37679 L
s
.48209 .37679 m
.49871 .37188 L
s
.45276 .28199 m
.49871 .37188 L
s
.49871 .37188 m
.56648 .36992 L
s
.56648 .36992 m
.6107 .45368 L
s
.6107 .45368 m
.69913 .47116 L
s
.0938 .63939 m
.14784 .69803 L
s
.32801 .30781 m
.35235 .3471 L
s
.35235 .3471 m
.41935 .29422 L
s
.26748 .43738 m
.35235 .3471 L
s
.69913 .47116 m
.74131 .54903 L
s
.74131 .54903 m
.93466 .61844 L
s
.39573 .24873 m
.41935 .29422 L
s
.41935 .29422 m
.43604 .28667 L
s
.24193 .40355 m
.26748 .43738 L
s
.0938 .63939 m
.26748 .43738 L
s
.41251 .2406 m
.43604 .28667 L
s
.43604 .28667 m
.45276 .28199 L
s
.42927 .23626 m
.45276 .28199 L
s
.45276 .28199 m
.52081 .28674 L
s
.30308 .2702 m
.32801 .30781 L
s
.32801 .30781 m
.39573 .24873 L
s
.24193 .40355 m
.32801 .30781 L
s
.52081 .28674 m
.56648 .36992 L
s
.56648 .36992 m
.65556 .39402 L
s
.37174 .20299 m
.39573 .24873 L
s
.39573 .24873 m
.41251 .2406 L
s
.38862 .19385 m
.41251 .2406 L
s
.41251 .2406 m
.42927 .23626 L
s
.21567 .37104 m
.24193 .40355 L
s
.06566 .61102 m
.24193 .40355 L
s
.4054 .19027 m
.42927 .23626 L
s
.42927 .23626 m
.49736 .24627 L
s
.06566 .61102 m
.0938 .63939 L
s
.37174 .20299 m
.38862 .19385 L
s
.30308 .2702 m
.37174 .20299 L
s
.21567 .37104 m
.30308 .2702 L
s
.65556 .39402 m
.69913 .47116 L
s
.69913 .47116 m
.8947 .54884 L
s
.38862 .19385 m
.4054 .19027 L
s
.4054 .19027 m
.47345 .20741 L
s
.03669 .58333 m
.21567 .37104 L
s
.49736 .24627 m
.52081 .28674 L
s
.52081 .28674 m
.61045 .31887 L
s
.03669 .58333 m
.06566 .61102 L
s
.47345 .20741 m
.49736 .24627 L
s
.49736 .24627 m
.58723 .28252 L
s
.61045 .31887 m
.65556 .39402 L
s
.65556 .39402 m
.85326 .47964 L
s
.93466 .61844 m
.97331 .68824 L
s
.47345 .20741 m
.56352 .24726 L
s
.58723 .28252 m
.61045 .31887 L
s
.61045 .31887 m
.81016 .41109 L
s
.8947 .54884 m
.93466 .61844 L
s
.56352 .24726 m
.58723 .28252 L
s
.58723 .28252 m
.7879 .37714 L
s
.56352 .24726 m
.76514 .34344 L
s
.85326 .47964 m
.8947 .54884 L
s
.81016 .41109 m
.85326 .47964 L
s
.7879 .37714 m
.81016 .41109 L
s
.76514 .34344 m
.7879 .37714 L
s
.25 Mabswid
.75455 0 m
.94813 .30408 L
s
.94813 .30408 m
1 .71656 L
s
1 .71656 m
.78843 .43699 L
s
.78843 .43699 m
.75455 0 L
s
.05372 .26793 m
0 .68381 L
s
0 .68381 m
.78843 .43699 L
s
.78843 .43699 m
.75455 0 L
s
.75455 0 m
.05372 .26793 L
s
.05372 .26793 m
.75455 0 L
s
.06863 .26223 m
.07314 .26664 L
s
[(0.8)] .05961 .25341 1 .97773 Mshowa
.22215 .20354 m
.22644 .20816 L
s
[(0.9)] .21356 .1943 .9286 1 Mshowa
.38404 .14165 m
.38809 .14649 L
s
[(1)] .37596 .13196 .83441 1 Mshowa
.55503 .07628 m
.55878 .08135 L
s
[(1.1)] .54752 .06614 .74022 1 Mshowa
.73589 .00713 m
.73931 .01243 L
s
[(1.2)] .72904 -0.00346 .64604 1 Mshowa
.125 Mabswid
.0987 .25074 m
.10138 .25341 L
s
.12908 .23912 m
.13173 .24182 L
s
.15977 .22739 m
.1624 .23011 L
s
.1908 .21553 m
.1934 .21828 L
s
.25383 .19143 m
.25638 .19423 L
s
.28586 .17918 m
.28838 .18201 L
s
.31824 .16681 m
.32072 .16966 L
s
.35096 .15429 m
.35342 .15717 L
s
.41749 .12886 m
.41988 .13179 L
s
.4513 .11593 m
.45366 .11889 L
s
.4855 .10286 m
.48782 .10585 L
s
.52007 .08964 m
.52236 .09266 L
s
.59038 .06276 m
.5926 .06583 L
s
.62614 .04909 m
.62831 .05219 L
s
.6623 .03527 m
.66444 .03839 L
s
.69888 .02128 m
.70098 .02443 L
s
gsave
.33555 .08353 -91.7837 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 11.250 moveto
(\\220) show
81.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
87.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
92.562 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{288, 260.125},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40005X0001AB000`400?l00000o`00003oo`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y
0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000m`3Vc806000000@0i/b00P0000040>K<P0H00000
F`3Vc8000?X0i/b000<000000>K<P03Vc800103Vc802000000D0i/b000D000000>K<P03Vc800i/b0
0000001K0>K<P000nP3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b005`0i/b0003j
0>K<P0030000003Vc800i/b000d0i/b00P00001L0>K<P000nP3Vc8000`000000i/b00>K<P00>0>K<
P0800000F`3Vc8000?X0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P01I0>K<P000
nP3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800
F@3Vc8000?P0i/b00`00000<0>K<P0D00000G03Vc8000?l0i/b0J@3Vc8000?l0i/b0J@3Vc8000?l0
i/b0J@3Vc8000?l0i/b04@3Vc802000005H0i/b0003o0>K<P0l0i/b00P0000000`3Vc80000000000
001E0>K<P000o`3Vc80<0>K<P0<000000`3Vc802000005D0i/b0003o0>K<P0T0i/b00`0000020>K<
P0070000003Vc800i/b00>K<P0000000i/b00000001D0>K<P000o`3Vc8070>K<P08000002@3Vc800
10000000i/b00>K<P000001C0>K<P000o`3Vc8040>K<P0<000002`3Vc80010000000i/b00>K<P000
001C0>K<P000o`3Vc8010>K<P0<000003P3Vc8000`000000i/b00>K<P00200000580i/b0003n0>K<
P08000000P3Vc8000`000000i/b00>K<P00=0>K<P0050000003Vc800i/b00>K<P0000000D@3Vc800
0?/0i/b00`00000D0>K<P0050000003Vc800i/b00>K<P0000000D@3Vc8000<40i/b01P0000040>K<
P0800000103Vc80600000280i/b00P00000G0>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc800CP3Vc8000<@0i/b000<000000>K<P03Vc800103Vc802000000L0i/b000<000000>K<P03V
c8007`3Vc803000001T0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P01>0>K<P000
a03Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b001`0i/b00`0000000`3Vc8000000
0>K<P00I0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800C@3Vc8000<@0i/b000<0
00000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00J0>K<P08000007`3Vc8000`000000i/b00>K<
P0040>K<P0030000003Vc800i/b004`0i/b000340>K<P0030000003Vc800i/b000d0i/b000<00000
0>K<P03Vc8005`3Vc80300000240i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P01<
0>K<P000T`3Vc802000002l0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00E0>K<
P0800000903Vc8000`000000i/b00>K<P0040>K<P08000002P3Vc803000000D0i/b00P0000040>K<
P0H00000;`3Vc80008@0i/b000<000000>K<P03Vc8002`3Vc80010000000i/b00>K<P000000^0>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8004P3Vc804000002D0i/b000<000000>K<
P03Vc8001P3Vc8000`000000i/b00>K<P0060>K<P0040000003Vc800i/b0000000D0i/b00P000007
0>K<P0030000003Vc800i/b002l0i/b0001d0>K<P0D000000`3Vc806000000<0i/b000<000000>K<
P03Vc8000`3Vc80500000080i/b000@000000>K<P03Vc8000000;03Vc803000000d0i/b00`00000A
0>K<P0<00000:@3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000D0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b002l0i/b0001c0>K<
P0040000003Vc800i/b000000080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc80000000P3Vc8000`000000i/b00000
00020>K<P0030000003Vc800i/b004`0i/b00P00000/0>K<P0030000003Vc800i/b000L0i/b000<0
00000>K<P03Vc800103Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000/0i/b000<0
00000>K<P03Vc800;`3Vc80007<0i/b000@000000>K<P03Vc80000000P3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b000@0i/b000D000000>K<P03Vc800i/b0000000020>K<P0060000
003Vc800i/b00000003Vc80000000P3Vc8000`000000i/b00>K<P0190>K<P0<00000;P3Vc8000`00
0000i/b00>K<P0080>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P00;0>K<P0030000003Vc800i/b002l0i/b0001c0>K<P0040000003Vc800i/b00000
0080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0040>K<P0050000003Vc800i/b0
0>K<P00000000P3Vc80010000000i/b00>K<P00000020>K<P0800000B@3Vc803000000030>K<P000
0000i/b002h0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00_0>K<P000M03Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800103Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800B@3Vc802
000003D0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0030>K<P0040000003Vc800
i/b0000000h0i/b000<000000>K<P03Vc800;`3Vc80007D0i/b000D000000>K<P03Vc800i/b00000
00050>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<
P03Vc800000004P0i/b00`00000g0>K<P0030000003Vc800i/b000P0i/b00P0000040>K<P0@00000
303Vc80300000340i/b0001o0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800C@3V
c802000003X0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b0000000180>K<P000O@3Vc803
000000P0i/b000<000000>K<P03Vc800B@3Vc804000003/0i/b000<000000>K<P03Vc8002P3Vc800
0`000000i/b00>K<P0150>K<P000d@3Vc803000000@0i/b000<000000>K<P03Vc800>03Vc8000`00
0000i/b00>K<P00;0>K<P0030000003Vc800i/b004@0i/b0003?0>K<P0800000@P3Vc8000`000000
i/b00>K<P00;0>K<P0030000003Vc800i/b004@0i/b0003<0>K<P0<00000A03Vc8000`000000i/b0
0>K<P00<0>K<P0030000003Vc800i/b004<0i/b0003:0>K<P08000000P3Vc8000`000000i/b00>K<
P0120>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800@`3Vc80009d0i/b01P00000T
0>K<P0<00000B@3Vc8000`000000i/b00>K<P00<0>K<P0800000A03Vc8000:00i/b000<000000>K<
P03Vc8008@3Vc803000004`0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P0110>K<
P000X03Vc8000`000000i/b00>K<P00O0>K<P0800000C`3Vc8000`000000i/b00>K<P00>0>K<P003
0000003Vc800i/b00440i/b0002P0>K<P0030000003Vc800i/b001`0i/b00`0000020>K<P0030000
003Vc800i/b004`0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P0100>K<P000X03V
c8000`000000i/b00>K<P00I0>K<P0<00000E@3Vc8000`000000i/b00>K<P00?0>K<P0030000003V
c800i/b003l0i/b0002P0>K<P0030000003Vc800i/b001L0i/b00P00001H0>K<P0030000003Vc800
i/b000l0i/b000<000000>K<P03Vc800?`3Vc8000:00i/b000<000000>K<P03Vc800503Vc8030000
05X0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00e0>K<P08000001`3Vc80009h0
i/b00`00000D0>K<P08000000`3Vc8000`000000i/b00>K<P01G0>K<P0030000003Vc800i/b00100
i/b00P00000W0>K<P0030000003Vc800i/b000/0i/b000@000000>K<P03Vc80000001P3Vc8000;80
i/b00`00001O0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8007@3Vc805000000@0
i/b000<000000>K<P03Vc8000`3Vc80500000080i/b000@000000>K<P03Vc80000001P3Vc8000:l0
i/b00`00001R0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8006`3Vc80010000000
i/b00>K<P00000020>K<P0050000003Vc800i/b00>K<P0000000103Vc80010000000i/b00>K<P000
00020>K<P0030000003Vc80000000080i/b000<000000>K<P03Vc800103Vc8000:d0i/b00P000000
0`3Vc80000000>K<P01R0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8006P3Vc800
10000000i/b00>K<P00000020>K<P0030000003Vc800i/b00080i/b000D000000>K<P03Vc800i/b0
000000020>K<P0060000003Vc800i/b00000003Vc80000000P3Vc8000`000000i/b00>K<P0040>K<
P000ZP3Vc803000006L0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00J0>K<P004
0000003Vc800i/b000000080i/b000<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<P03Vc800
00000080i/b000@000000>K<P03Vc80000000P3Vc802000000L0i/b0002X0>K<P0800000JP3Vc800
0`000000i/b00>K<P00D0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P0090>K<P000Y@3Vc803000006`0i/b000<000000>K<P03Vc8005@3Vc8000`00
0000i/b00>K<P00J0>K<P0050000003Vc800i/b00>K<P00000001@3Vc8000`000000i/b00>K<P002
0>K<P0050000003Vc800i/b00>K<P00000002`3Vc8000:80i/b01000001^0>K<P0030000003Vc800
i/b001@0i/b00P00000V0>K<P0030000003Vc800i/b00180i/b0002P0>K<P0800000103Vc8000`00
0000i/b00>K<P01[0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc800903Vc8000`00
0000i/b00>K<P00A0>K<P000W@3Vc803000007@0i/b000<000000>K<P03Vc8005P3Vc8000`000000
i/b00>K<P00h0>K<P000VP3Vc803000007P0i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b0
0>K<P00g0>K<P000G`3Vc803000000D0i/b00P0000040>K<P0<00000:03Vc80200000080i/b000<0
00000>K<P03Vc800MP3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b003H0i/b0001N
0>K<P0040000003Vc800i/b0000000D0i/b00P0000070>K<P0030000003Vc800i/b00280i/b00`00
001m0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800=P3Vc80005d0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001h0i/b00`000020
0>K<P0030000003Vc800i/b001P0i/b000<000000>K<P03Vc800=@3Vc80005d0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P0090>K<P0@000007P3Vc80400000840i/b000<000000>K<
P03Vc8005`3Vc803000000T0i/b00`0000050>K<P0800000103Vc806000001T0i/b0001M0>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc8001@000000i/b00>K<P03Vc8000000
01/0i/b00`0000250>K<P0030000003Vc800i/b001T0i/b000<000000>K<P03Vc8001P3Vc8001000
0000i/b00>K<P00000050>K<P08000001@3Vc8001@000000i/b00>K<P03Vc800000001T0i/b0001M
0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc8001@000000i/b00>K<P03V
c800000001T0i/b00P0000280>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc800103V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8006P3V
c80005h0i/b000@000000>K<P03Vc80000002`3Vc8001@000000i/b00>K<P03Vc800000001H0i/b0
0`00002:0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P0020>K<P0030000003Vc800i/b000/0i/b00P00000J0>K<P000GP3Vc804000000`0i/b00`00
000E0>K<P080000000<0i/b00000003Vc800RP3Vc8000`000000i/b00>K<P00K0>K<P0030000003V
c800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P08000006@3V
c80008<0i/b00`00002?0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8005`3Vc800
0800i/b00`00000W0>K<P0@00000I`3Vc8000`000000i/b00>K<P00L0>K<P0800000103Vc8001000
0000i/b00>K<P000000;0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8005`3Vc800
07h0i/b00`00000V0>K<P0<000000P3Vc8000`000000i/b000000003000006<0i/b000<000000>K<
P03Vc8006`3Vc8000`000000i/b0000000040>K<P0@000002`3Vc805000001X0i/b0001k0>K<P0<0
00009`3Vc803000000D0i/b000<000000>K<P03Vc8000P3Vc804000005l0i/b000<000000>K<P03V
c8007P3Vc8000`000000i/b00>K<P00_0>K<P000N03Vc803000002P0i/b00P0000030>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8001P3Vc804000005`0i/b000<000000>K<P03Vc800
7P3Vc8000`000000i/b00>K<P00^0>K<P000MP3Vc802000002X0i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000T0i/b01000001H0>K<P0030000003V
c800i/b001h0i/b000<000000>K<P03Vc800;P3Vc80007<0i/b01000000Z0>K<P0030000003Vc800
000000D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00=0>K<P0<00000E@3Vc800
0`000000i/b00>K<P00O0>K<P0030000003Vc800i/b002d0i/b0001a0>K<P0800000103Vc8000`00
0000i/b00>K<P00V0>K<P0040000003Vc800i/b0000000D0i/b000<000000>K<P03Vc8000`3Vc800
0`000000i/b00>K<P00>0>K<P0<00000D`3Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800
i/b002`0i/b0001^0>K<P0<00000;P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b0
00800000D@3Vc8000`000000i/b00>K<P00O0>K<P0800000;P3Vc80006/0i/b01000000_0>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b000l0i/b000@000000>K<P03Vc800i/b00P00001?0>K<P0030000003Vc800i/b0
0240i/b000<000000>K<P03Vc800:`3Vc8000380i/b00`0000050>K<P08000001@3Vc804000002@0
i/b00P00000b0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8000`3Vc8000`000000
i/b00>K<P0020>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8000`3Vc803000004`0
i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P00[0>K<P000<@3Vc80010000000i/b0
0>K<P00000050>K<P0800000103Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001h0
i/b00`00000c0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8000`3Vc8000`000000
i/b00>K<P0020>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8001@3Vc802000004X0
i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P00Z0>K<P000<03Vc8000`000000i/b0
0>K<P0020>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P00L0>K<P0800000=@3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000L0i/b0
0P0000180>K<P0030000003Vc800i/b002<0i/b000<000000>K<P03Vc800:@3Vc8000300i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b0008000006`3V
c803000000030>K<P0000000i/b003<0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<
P0080>K<P0800000AP3Vc8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b002T0i/b0000`
0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002@3Vc804000001T0i/b00`00000h
0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8002@3Vc803000004<0i/b000<00000
0>K<P03Vc800903Vc8000`000000i/b00>K<P00X0>K<P000<03Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00D0>K<
P0800000>P3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8001P00000>0>K<P0030000003Vc800i/b000`0i/b00P0000110>K<P0030000003Vc800i/b0
02<0i/b000<000000>K<P0000000:@3Vc8000340i/b000@000000>K<P03Vc80000002`3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b00140i/b01000000j0>K<P0030000003Vc800i/b0
00h0i/b000<000000>K<P03Vc8000P3Vc803000000<0i/b000<000000>K<P03Vc8001P0000090>K<
P0030000003Vc800i/b000d0i/b00P0000100>K<P0030000003Vc800i/b002@0i/b000<000000>K<
P03Vc8009`3Vc8000340i/b01000000<0>K<P0@000004@3Vc803000003d0i/b000<000000>K<P03V
c8003`3Vc8000`000000i/b00>K<P002000000030>K<P0000000i/b000<0i/b000<000000>K<P03V
c8001P3Vc80700000080i/b000<000000>K<P03Vc8003`3Vc802000003h0i/b000<000000>K<P03V
c8009@3Vc8000`000000i/b00>K<P00V0>K<P000E03Vc802000003l0i/b000<000000>K<P03Vc800
4@3Vc802000000@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P0D00000
4@3Vc803000003/0i/b000<000000>K<P03Vc8009P3Vc8000`000000i/b00>K<P00U0>K<P000D@3V
c80300000400i/b000<000000>K<P03Vc8004@3Vc802000000D0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P00@0>K<P0<000004@3Vc803000003T0i/b000<000000>K<P03Vc8009P3V
c8000`000000i/b00>K<P00U0>K<P000C`3Vc80200000080i/b000<000000>K<P03Vc800?@3Vc800
0`000000i/b00>K<P00A0>K<P0040000003Vc800i/b0000000D0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b000<000003P3Vc8000`000000i/b00>K<
P002000003L0i/b000<000000>K<P03Vc8009`3Vc8000`000000i/b00>K<P00T0>K<P000C03Vc803
000004<0i/b000<000000>K<P03Vc8004@3Vc8001@000000i/b00>K<P03Vc800000000D0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b00080i/b00`00
000<0>K<P0040000003Vc800i/b00>K<P0800000=@3Vc8000`000000i/b00>K<P00V0>K<P0030000
003Vc800000002D0i/b000190>K<P0<00000A@3Vc8000`000000i/b00>K<P00@0>K<P08000001@3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800403V
c8000`000000i/b00>K<P0040>K<P08000002P3Vc8000`000000i/b00>K<P0030>K<P0800000<`3V
c8000`000000i/b00>K<P00X0>K<P0030000003Vc800i/b002<0i/b000170>K<P080000000<0i/b0
0000003Vc800A03Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000D0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00100i/b000<00000
0>K<P03Vc8001P3Vc803000000P0i/b000<000000>K<P03Vc800103Vc80200000340i/b000<00000
0>K<P03Vc800:@3Vc8000`000000i/b00>K<P00R0>K<P000A@3Vc802000000@0i/b000<000000>K<
P03Vc800@@3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000L0i/b000<000000>K<
P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00100i/b000<000000>K<
P03Vc800203Vc802000000L0i/b000<000000>K<P03Vc8001@3Vc802000002l0i/b000<000000>K<
P03Vc800:P3Vc8000`000000i/b00>K<P00Q0>K<P000A@3Vc802000004L0i/b000<000000>K<P03V
c800403Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000X0i/b00`0000040>K<P003
0000003Vc800i/b000L0i/b00P00000]0>K<P0030000003Vc800i/b002X0i/b000<000000>K<P03V
c8008@3Vc80004D0i/b00`0000150>K<P0030000003Vc80000000100i/b000<000000>K<P03Vc800
2P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800
403Vc8000`000000i/b00>K<P00<0>K<P0<000000P3Vc8000`000000i/b00>K<P0080>K<P0800000
:`3Vc8000`000000i/b00>K<P00[0>K<P0030000003Vc800i/b00200i/b000150>K<P0040000003V
c800i/b0000004<0i/b000@000000>K<P03Vc80000003`3Vc8000`000000i/b00>K<P00;0>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00A0>K<P003
0000003Vc800i/b000h0i/b00`00000<0>K<P0800000:@3Vc8000`000000i/b00>K<P00Z0>K<P080
00002@3Vc803000000D0i/b00P0000040>K<P0@000001`3Vc80003`0i/b00`0000050>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc800?`3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b000/0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b000`000002@3Vc8000`000000i/b00>K<P00@0>K<P0<00000303Vc802000002L0i/b0
00<000000>K<P03Vc800;03Vc8000`000000i/b00>K<P0050>K<P0040000003Vc800i/b0000000D0
i/b00P0000080>K<P0030000003Vc800i/b000@0i/b0000k0>K<P0040000003Vc800i/b0000000D0
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00m0>K<P0030000003Vc800i/b000@0
i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000<0
i/b00`0000030>K<P0030000003Vc800i/b000H0i/b03000000B0>K<P0<00000303Vc802000002H0
i/b000<000000>K<P03Vc800;03Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080
i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P0040>K<P000>P3Vc8000`000000i/b0
0>K<P0020>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800103Vc8000`000000i/b0
0>K<P00l0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800203Vc8000`000000i/b0
0>K<P00@0>K<P0030000003Vc800i/b00080000000<0i/b00000003Vc8000`3Vc8000`000000i/b0
0>K<P00A0>K<P0<00000403Vc8000`000000i/b00>K<P002000000`0i/b00P00000T0>K<P0030000
003Vc800i/b002`0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b000`0i/b000<000000>K<P03Vc800103Vc80003X0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800>P3V
c8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000D0i/b00P00000C0>K<P0030000003V
c800000000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000003V
c800i/b000<000003P3Vc80010000000i/b00>K<P03Vc802000000`0i/b00P00000R0>K<P0030000
003Vc800i/b002d0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b000X0i/b00P0000070>K<P000>P3Vc8000`000000i/b00>K<P0020>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00h0>K<P0030000003V
c800i/b000L0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00D0>K<P0030000003V
c800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00A0>K<P0030000003V
c800i/b00080i/b00`00000<0>K<P0030000003Vc800i/b00080i/b00P00000<0>K<P0<000007`3V
c8000`000000i/b00>K<P00^0>K<P0050000003Vc800i/b00>K<P0000000103Vc8000`000000i/b0
0>K<P00<0>K<P0030000003Vc800i/b000@0i/b0000j0>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b003H0i/b000<0
00000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001<0i/b00`00
00050>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<
P0050>K<P08000002P3Vc8000`000000i/b00>K<P0040>K<P08000003@3Vc802000001d0i/b000<0
00000>K<P03Vc800;03Vc803000000@0i/b000@000000>K<P03Vc80000003`3Vc8000`000000i/b0
0>K<P0040>K<P000>`3Vc80010000000i/b00>K<P00000050>K<P08000002@3Vc8000`000000i/b0
0>K<P00d0>K<P0030000003Vc800i/b000/0i/b000@000000>K<P03Vc80000005@3Vc8001@000000
i/b00>K<P03Vc800000000D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00A0>K<
P0030000003Vc800i/b000H0i/b00`0000080>K<P0030000003Vc800i/b000D0i/b00P00000=0>K<
P08000006`3Vc8000`000000i/b00>K<P00^0>K<P08000000`3Vc804000000/0i/b0100000070>K<
P000>`3Vc804000000D0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00b0>K<P003
0000003Vc800i/b000`0i/b000<000000>K<P00000005@3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<P003
0000003Vc800i/b000T0i/b00P0000060>K<P0030000003Vc800i/b000L0i/b00P00000=0>K<P080
00006@3Vc8000`000000i/b00>K<P00[0>K<P0<0000000<0i/b00000003Vc800703Vc80004<0i/b0
00<000000>K<P03Vc8002`3Vc80200000340i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b0
0>K<P00B0>K<P08000001P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b0
00<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00:0>K<P0<00000103Vc8000`000000i/b0
0>K<P0080>K<P08000003@3Vc802000001L0i/b000<000000>K<P03Vc800:03Vc803000000@0i/b0
00<000000>K<P03Vc8006`3Vc80004<0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<
P00]0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P00000004P3Vc8000`000000i/b00>K<
P0060>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P00@0>K<P0030000003Vc800i/b000d0i/b00`0000020>K<P0030000003Vc800i/b000T0i/b00`00
000<0>K<P08000005@3Vc8000`000000i/b00>K<P00U0>K<P0<000001`3Vc8000`000000i/b00>K<
P00K0>K<P000@`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b002/0i/b000<00000
0>K<P03Vc8003P3Vc80010000000i/b00>K<P000000A0>K<P0030000003Vc800i/b000P0i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00140i/b000<0
00000>K<P03Vc8003`3Vc803000000h0i/b00P00000<0>K<P08000004`3Vc8000`000000i/b00>K<
P00R0>K<P0<000002P3Vc8000`000000i/b00>K<P00K0>K<P000@`3Vc8000`000000i/b00>K<P00?
0>K<P0030000003Vc800i/b002T0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000`0i/b00P00000;0>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b00140i/b00`00000>
0>K<P0800000303Vc80200000140i/b000<000000>K<P03Vc8007`3Vc803000000h0i/b000<00000
0>K<P03Vc8006P3Vc80004<0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00X0>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00:0>K<
P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8004P3Vc803000000h0i/b00P00000<0>K<
P08000003`3Vc8000`000000i/b00>K<P00L0>K<P0<000004@3Vc8000`000000i/b00>K<P00J0>K<
P000@`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b002H0i/b000<000000>K<P03V
c8003@3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03V
c8003@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c800403Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b0008000003P3Vc802000000`0
i/b00P00000=0>K<P0030000003Vc800i/b001T0i/b00`00000D0>K<P0030000003Vc800i/b001X0
i/b000130>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800903Vc8000`000000i/b0
0>K<P00=0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8001P3Vc80200000140i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00100i/b0
00<000000>K<P03Vc8004P3Vc80010000000i/b00>K<P03Vc802000000h0i/b00P00000<0>K<P080
0000303Vc8000`000000i/b00>K<P00D0>K<P0@000005`3Vc8000`000000i/b00>K<P00J0>K<P000
@P3Vc803000001@0i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P00>0>K<P0030000
003Vc800i/b000L0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00A0>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000
003Vc800i/b00180i/b000<000000>K<P03Vc8000`3Vc802000000h0i/b00P00000<0>K<P0800000
2P3Vc8000`000000i/b00>K<P00A0>K<P0<000006`3Vc8000`000000i/b00>K<P00J0>K<P000@P3V
c8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8003P3V
c8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004`3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800403V
c8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000@0i/b00P00000>0>K<P0800000303V
c802000000P0i/b000<000000>K<P03Vc8003P3Vc803000001h0i/b000<000000>K<P03Vc8006P3V
c8000480i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b00>K<P00N0>K<P0030000003Vc800
i/b000h0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P002000001H0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00100i/b000<00000
0>K<P03Vc8004`3Vc8000`000000i/b00>K<P0050>K<P08000003P3Vc802000000`0i/b00P000006
0>K<P0030000003Vc800i/b000/0i/b00`00000Q0>K<P0030000003Vc800i/b001X0i/b000120>K<
P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800703Vc8000`000000i/b00>K<P00>0>K<
P0030000003Vc800i/b000`0i/b000<000000>K<P00000006@3Vc8000`000000i/b00>K<P0030>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00B0>K<
P0030000003Vc800i/b000L0i/b00`00000=0>K<P0800000303Vc802000000@0i/b000<000000>K<
P03Vc800203Vc803000002@0i/b000<000000>K<P03Vc8006P3Vc8000480i/b000<000000>K<P03V
c800603Vc8000`000000i/b00>K<P00J0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03V
c8003P3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03V
c8002@3Vc802000000d0i/b00`00000;0>K<P0050000003Vc800i/b00>K<P00000001`3Vc8030000
02P0i/b000<000000>K<P03Vc8006@3Vc8000480i/b000<000000>K<P03Vc8006@3Vc8000`000000
i/b00>K<P00H0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8003P3Vc8000`000000
i/b00000000J0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000
i/b00>K<P00@0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8002`3Vc802000000h0
i/b00P0000090>K<P0050000003Vc800i/b00>K<P0000000103Vc803000002/0i/b000<000000>K<
P03Vc8006@3Vc8000480i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P00F0>K<P003
0000003Vc800i/b000h0i/b000<000000>K<P03Vc8003P3Vc80010000000i/b00>K<P000000J0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<
P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc800303Vc802000000h0i/b00P0000080>K<
P0050000003Vc800i/b00000003Vc8000`00000^0>K<P0030000003Vc800i/b001T0i/b000120>K<
P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00=0>K<
P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00H0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<
P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8003P3Vc802000000h0i/b00P0000070>K<
P0@00000<@3Vc8000`000000i/b00>K<P00I0>K<P000@@3Vc803000001d0i/b000<000000>K<P03V
c8004`3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03V
c8003`3Vc802000000h0i/b00P0000030>K<P0<0000000<0i/b00000003Vc800<@3Vc8000`000000
i/b00>K<P00I0>K<P000@@3Vc8000`000000i/b00>K<P00N0>K<P0030000003Vc800i/b00140i/b0
00<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000D0i/b0
00<000000>K<P03Vc800603Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b00100i/b0
0P00000>0>K<P0<000000`3Vc80200000380i/b000<000000>K<P03Vc8006@3Vc8000440i/b000<0
00000>K<P03Vc8007`3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b000d0i/b000<0
00000>K<P03Vc8003P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001P0i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00100i/b000<0
00000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00B0>K<P0<00000203Vc80300000080i/b00P00
00030>K<P0030000003Vc800i/b00300i/b000<000000>K<P03Vc8006@3Vc8000440i/b000<00000
0>K<P03Vc800803Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000d0i/b000<00000
0>K<P03Vc8003P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b001P0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P1H00000503Vc8000`000000i/b00>K<P00D
0>K<P08000000`3Vc803000000L0i/b00P0000020>K<P0030000003Vc800i/b002l0i/b000<00000
0>K<P03Vc8006@3Vc8000440i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P00;0>K<
P0030000003Vc800000000d0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00:0>K<
P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020000
00030>K<P0000000i/b00180i/b01@00000@0>K<P0030000003Vc800i/b001H0i/b00`00000<0>K<
P0<00000<P3Vc8000`000000i/b00>K<P00H0>K<P000@@3Vc8000`000000i/b00>K<P00R0>K<P003
0000003Vc800i/b000T0i/b000D000000>K<P03Vc800i/b00000000;0>K<P0030000003Vc800i/b0
00h0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b0
0080i/b00`0000040>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8000P3Vc8040000
00d0i/b000<000000>K<P03Vc8004P3Vc80300000080i/b00P00000=0>K<P0800000<@3Vc8000`00
0000i/b00>K<P00H0>K<P000@@3Vc8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b000L0
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000d0
i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b00080
00000P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00140i/b000<000000>K<P03V
c8001@3Vc803000000/0i/b000<000000>K<P03Vc8003@3Vc804000000L0i/b00P00000;0>K<P003
0000003Vc80000000300i/b000<000000>K<P03Vc800603Vc8000440i/b000<000000>K<P03Vc800
903Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800
1P3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc800
603Vc802000000@0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000
003Vc800i/b000P0i/b0100000070>K<P0030000003Vc800i/b000X0i/b00`00000=0>K<P0800000
2@3Vc8000`000000i/b00000000`0>K<P0030000003Vc800i/b001P0i/b000100>K<P0030000003V
c800i/b002H0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0050>K<P0030000003V
c800i/b000D0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00@0>K<P0030000003V
c800i/b001D0i/b00P0000000`3Vc80000000>K<P0040>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00;0>K<P0@00000103Vc8000`000000i/b00>K<
P0060>K<P0<000004P3Vc803000000H0i/b000@000000>K<P03Vc8000000;`3Vc8000`000000i/b0
0>K<P00H0>K<P000@03Vc802000002P0i/b00P0000030>K<P0030000003Vc800i/b000L0i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b00140i/b000<0
00000>K<P03Vc8004`3Vc8001@000000i/b00>K<P03Vc800000000D0i/b000<000000>K<P03Vc800
0`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000l0i/b01@0000050>K<P0<00000
603Vc802000000@0i/b000@000000>K<P03Vc8000000;`3Vc8000`000000i/b00>K<P00H0>K<P000
@03Vc8000`000000i/b00>K<P00Y0>K<P0030000003Vc800000000/0i/b000D000000>K<P03Vc800
i/b00000000@0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8004@3Vc802000000D0
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00140
i/b000<000000>K<P03Vc8004P3Vc806000001d0i/b00P0000020>K<P0050000003Vc800i/b00>K<
P0000000;P3Vc8000`000000i/b00>K<P00H0>K<P000@03Vc8000`000000i/b00>K<P00Z0>K<P003
0000003Vc800i/b000/0i/b000<000000>K<P0000000403Vc8000`000000i/b00>K<P00D0>K<P003
0000003Vc800i/b000l0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0030>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00B0>K<P0D0
0000803Vc803000000@0i/b000<000000>K<P03Vc800:`3Vc8000`000000i/b00>K<P00H0>K<P000
@03Vc8000`000000i/b00>K<P00Y0>K<P0030000003Vc800000000d0i/b000<000000>K<P03Vc800
3P3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000d0i/b00P0000090>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00A0>K<P0030000
003Vc800i/b000h0i/b00`0000020>K<P0030000003Vc800i/b000800000803Vc802000000<0i/b0
00<000000>K<P03Vc800;03Vc8000`000000i/b00>K<P00G0>K<P000@03Vc8000`000000i/b00>K<
P00Y0>K<P0040000003Vc800i/b0000000/0i/b000<000000>K<P00000003P3Vc8000`000000i/b0
0>K<P00G0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800403Vc8000`000000i/b0
0>K<P00;0>K<P0<000001P3Vc80010000000i/b00>K<P03Vc803000001d0i/b000@000000>K<P000
000000000P3Vc8000`000000i/b00>K<P00[0>K<P0030000003Vc800i/b001L0i/b000100>K<P003
0000003Vc800i/b002P0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0070>K<P004
0000003Vc800i/b0000000d0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00:0>K<
P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8001`3Vc803000000T0i/b000<000000>K<
P03Vc800103Vc802000001/0i/b000@000000>K<P03Vc800i/b00`00000]0>K<P0030000003Vc800
i/b001L0i/b0000o0>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc800103Vc8000`00
0000i/b00>K<P0050>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002@3Vc8000`00
0000i/b00>K<P00J0>K<P0030000003Vc800i/b000L0i/b00P00000>0>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b0
00@0i/b00`00000=0>K<P0030000003Vc800i/b000D0i/b00P00000I0>K<P0030000003Vc800i/b0
00<0i/b00P00000/0>K<P0030000003Vc800i/b001L0i/b0000o0>K<P0030000003Vc800i/b002L0
i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000<0
i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b000D0
i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080
i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00300000140i/b000<000000>K<P03V
c8001P3Vc803000001L0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00Y0>K<P003
0000003Vc800i/b001L0i/b0000o0>K<P0<000009P3Vc8000`000000i/b00>K<P0080>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0060>K<P0030000
003Vc800i/b001d0i/b000<000000>K<P03Vc8000`3Vc80200000180i/b000<000000>K<P03Vc800
0`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00100i/b00`00000D0>K<P0030000
003Vc800i/b000T0i/b00P00000E0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800
:@3Vc8000`000000i/b00>K<P00G0>K<P000?`3Vc8000`000000i/b00>K<P00U0>K<P0030000003V
c800i/b000X0i/b000@000000>K<P03Vc8000000203Vc8000`000000i/b00>K<P0040>K<P0030000
003Vc800i/b001l0i/b000D000000>K<P03Vc800i/b00000000E0>K<P0030000003Vc800i/b000<0
i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00=0>K<P0<0000000<0i/b00000003V
c8005@3Vc8000`000000i/b00>K<P00:0>K<P08000004`3Vc8000`000000i/b00>K<P0050>K<P003
0000003Vc800i/b002P0i/b000<000000>K<P03Vc8005`3Vc80002L0i/b00`0000050>K<P0800000
103Vc806000000@0i/b000<000000>K<P03Vc8009@3Vc8000`000000i/b00>K<P00;0>K<P0800000
2P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00200i/b000@000000>K<P0000000
00005P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8002@3Vc803000000D0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00<0>K<P0<0
0000403Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b002L0i/b000<000000>K<P03V
c8005`3Vc80002H0i/b000@000000>K<P03Vc80000001@3Vc802000000L0i/b000<000000>K<P03V
c800103Vc8000`000000i/b00>K<P00T0>K<P0030000003Vc800i/b000`0i/b00P00000;0>K<P004
0000003Vc800i/b0000002@0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P0030>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8001P3Vc803000000P0i/b000<000000>K<
P03Vc800503Vc8000`000000i/b00>K<P00>0>K<P08000003P3Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc8005P3Vc80002D0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03V
c8008`3Vc8000`000000i/b00>K<P00<0>K<P0040000003Vc800i/b0000000X0i/b000<000000>K<
P0000000903Vc8000`000000i/b00000000H0>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8000`3Vc80010000000i/b00>K<P03Vc804000000`0i/b000<000000>K<P03Vc8004`3Vc800
0`000000i/b00>K<P00@0>K<P0800000303Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800
i/b002L0i/b000<000000>K<P03Vc8005P3Vc80002D0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P00;0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8008P3Vc8000`00
0000i/b00>K<P00=0>K<P0050000003Vc800i/b00>K<P00000002P3Vc8000`000000i/b00>K<P00R
0>K<P0040000003Vc800i/b0000001T0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P0020>K<P0@00000403Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b00140i/b00P00
00090>K<P08000002P3Vc8000`000000i/b00>K<P00V0>K<P0030000003Vc800i/b001H0i/b0000U
0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b00280i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P00000008P3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P004
000001<0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00B0>K<P0<000000`3Vc803
00000080i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00V0>K<P0030000003Vc800
i/b001H0i/b0000U0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc8000`00
0000i/b00>K<P0030>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc8003@3Vc8000`00
0000i/b00>K<P0050>K<P0030000003Vc800i/b000@0i/b000@000000>K<P03Vc80000008@3Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc8000P3Vc803
000000<0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800
i/b001D0i/b00`0000060>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8009@3Vc800
0`000000i/b00>K<P00F0>K<P0009P3Vc80010000000i/b00>K<P000000>0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800
i/b000L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b001d0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800
00000080000000<0i/b00000003Vc800103Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800
i/b001@0i/b000<000000>K<P03Vc800403Vc80400000080i/b00P0000050>K<P0030000003Vc800
i/b000L0i/b000<000000>K<P03Vc8009@3Vc8000`000000i/b00>K<P00F0>K<P0009P3Vc8040000
00`0i/b00`0000050>K<P08000008@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b0
00T0i/b000D000000>K<P03Vc800i/b0000000050>K<P0030000003Vc800i/b001/0i/b000<00000
0>K<P03Vc8001P3Vc8000`000000i/b00>K<P00E0>K<P0<000001@3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00=
0>K<P0<00000203Vc803000000<0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00T
0>K<P0030000003Vc800i/b001H0i/b0000n0>K<P0030000003Vc800i/b001l0i/b000<000000>K<
P03Vc800303Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800000000L0i/b000<000000>K<
P03Vc8006@3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b00140i/b00`0000020>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00=0>K<
P0L00000503Vc8000`000000i/b00>K<P0090>K<P0<000003P3Vc80200000080i/b000<000000>K<
P03Vc8001`3Vc8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b001H0i/b0000n0>K<P003
0000003Vc800i/b001h0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00<0>K<P003
0000003Vc800i/b000H0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00:0>K<P003
0000003Vc800i/b000d0i/b00`0000060>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P0030>K<P0X000001@3Vc8000`000000i/b00000000400000100
i/b000<000000>K<P03Vc8001@3Vc803000001<0i/b00P0000000`3Vc80000000>K<P0070>K<P003
0000003Vc800i/b002@0i/b000<000000>K<P03Vc8005@3Vc80003h0i/b000<000000>K<P03Vc800
7@3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P0000000
203Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800
2P3Vc803000000T0i/b000<000000>K<P03Vc8000`3Vc80010000000i/b00>K<P03Vc807000000l0
i/b000<000000>K<P03Vc800103Vc805000000/0i/b000<000000>K<P03Vc8000P3Vc803000001P0
i/b00`0000080>K<P0030000003Vc800i/b002<0i/b000<000000>K<P03Vc8005@3Vc80003d0i/b0
00<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000`0i/b0
00D000000>K<P03Vc800i/b0000000080>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03V
c8003@3Vc8000`000000i/b00>K<P0060>K<P0<000003@3Vc8000`000000i/b00>K<P0020>K<P0@0
00000P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000P0i/b01P0000060>K<P0@0
00007@3Vc803000000L0i/b000<000000>K<P03Vc8008P3Vc8000`000000i/b00>K<P00E0>K<P000
?@3Vc8000`000000i/b00>K<P00M0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800
303Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800
4P3Vc80200000100i/b000<000000>K<P03Vc8000`3Vc80300000100i/b000<000000>K<P03Vc800
0P0000020>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b0
0>K<P00>0>K<P0L000008@3Vc80010000000i/b00000000000050>K<P0030000003Vc800i/b00280
i/b000<000000>K<P03Vc8005@3Vc80003d0i/b000<000000>K<P03Vc800703Vc8000`000000i/b0
0>K<P00<0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800103Vc802000000H0i/b0
00<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800000000800000
503Vc802000000@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00B0>K<P0030000
003Vc800i/b000d0i/b00`0000020>K<P0@00000803Vc8000`000000i/b00>K<P003000000<0i/b0
00<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P00E0>K<P000?@3Vc8000`000000i/b00>K<
P00K0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<
P0070>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<
P00A0>K<P0<000005@3Vc802000000030>K<P0000000i/b000@0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000X0i/b00`0000080>K<P0<000007P3V
c8000`000000i/b00>K<P0030>K<P08000000P3Vc8000`000000i/b00>K<P00P0>K<P0030000003V
c800i/b001D0i/b0000m0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8003@3Vc800
0`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800103Vc800
0`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000l0i/b00`0000020>K<P0030000003Vc800
i/b00140i/b00P0000030>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000H0i/b00`00000;0>K<P0030000003Vc800
i/b000<00000703Vc8000`000000i/b00>K<P0040>K<P0<000008P3Vc8000`000000i/b00>K<P00E
0>K<P000?@3Vc802000001X0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00<0>K<
P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00;0>K<
P0030000003Vc800i/b000d0i/b00`0000050>K<P0030000003Vc800i/b000l0i/b00P0000060>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00A0>K<
P0030000003Vc800i/b00080i/b01000000?0>K<P0030000003Vc800i/b00080i/b00P00000K0>K<
P0030000003Vc800i/b000D0i/b00P00000Q0>K<P0030000003Vc800i/b001D0i/b0000:0>K<P080
00000P3Vc8000`000000i/b00>K<P00@0>K<P08000006P3Vc8000`000000i/b00>K<P00H0>K<P003
0000003Vc800i/b000d0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00=0>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00:0>K<P0@0
00002@3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00180i/b01000000C0>K<P003
0000003Vc800i/b000@0i/b00`00000I0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03V
c8007`3Vc8000`000000i/b00>K<P00D0>K<P0002`3Vc8000`000000i/b0000000040>K<P0030000
003Vc800i/b000/0i/b000@000000>K<P03Vc80000006@3Vc8000`000000i/b00>K<P00G0>K<P003
0000003Vc800i/b000d0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00?0>K<P003
0000003Vc800i/b000<0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0080>K<P0<0
00003P3Vc8000`000000i/b00>K<P00:0>K<P08000002P3Vc8000`000000i/b00>K<P0030>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8003`3Vc803000001L0i/b000<000000>K<P03V
c8001P3Vc802000001L0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00O0>K<P003
0000003Vc800i/b001@0i/b000030>K<P0D000000`3Vc802000000H0i/b000<000000>K<P03Vc800
0`3Vc80500000080i/b000@000000>K<P03Vc8000000603Vc8000`000000i/b00>K<P00H0>K<P003
0000003Vc800i/b000`0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00A0>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0060>K<P0<0
00004@3Vc8000`000000i/b00>K<P0080>K<P0800000303Vc8000`000000i/b00>K<P0030>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc800303Vc803000000<0i/b000<000000>K<P03V
c800503Vc8000`000000i/b00>K<P0080>K<P0<000005@3Vc8000`000000i/b00>K<P0060>K<P003
0000003Vc800i/b001h0i/b000<000000>K<P03Vc800503Vc8000080i/b000@000000>K<P03Vc800
00000P3Vc8001@000000i/b00>K<P0000000i/b000800000103Vc8000`000000i/b00>K<P0020>K<
P0040000003Vc800i/b000000080i/b000<000000>K<P00000000P3Vc8000`000000i/b00>K<P00F
0>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00=
0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P004
0>K<P0030000003Vc800i/b000@0i/b00`00000E0>K<P0030000003Vc800i/b000H0i/b000<00000
0>K<P03Vc8003@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc800203Vc803000000H0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00:
0>K<P0800000503Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b001h0i/b000<00000
0>K<P03Vc800503Vc8000080i/b000@000000>K<P03Vc80000000P3Vc8000`000000i/b000000004
000000D0i/b000D000000>K<P03Vc800i/b0000000020>K<P0060000003Vc800i/b00000003Vc800
00000P3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03V
c8003@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b00`00000H0>K<P003
0000003Vc800i/b000@0i/b00P00000@0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P0040>K<P0@000002P3Vc8000`000000i/b00>K<P00D0>K<P003
0000003Vc800i/b000`0i/b00`00000B0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03V
c8007@3Vc8000`000000i/b00>K<P00D0>K<P0000P3Vc80010000000i/b00>K<P00000020>K<P003
0000003Vc800i/b000T0i/b000D000000>K<P03Vc800i/b0000000020>K<P0040000003Vc800i/b0
00000080i/b00P00000I0>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8003@3Vc800
0`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc8000P3Vc800
10000000i/b00>K<P00000020>K<P0<00000703Vc80010000000i/b00>K<P03Vc802000001<0i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<00000
3`3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000h0i/b00P00000@0>K<P0030000
003Vc800i/b000H0i/b000<000000>K<P03Vc800703Vc8000`000000i/b00>K<P00D0>K<P0000`3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc800503V
c8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800603V
c8001P000000i/b00>K<P03Vc80000000>K<P0@000007`3Vc80010000000i/b000000000000E0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc80300000180i/b000<000000>K<
P03Vc800503Vc8000`000000i/b00>K<P00@0>K<P0<000003P3Vc8000`000000i/b00>K<P0050>K<
P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc800503Vc80000@0i/b000D000000>K<P03V
c800i/b00000000<0>K<P0030000003Vc800i/b00080i/b000D000000>K<P03Vc800i/b00000000M
0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00<
0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8000`00000S0>K<P0030000003Vc800
i/b001H0i/b000<000000>K<P03Vc8000`3Vc804000000030>K<P0000000i/b001<0i/b000<00000
0>K<P03Vc800503Vc8000`000000i/b00>K<P00B0>K<P08000003@3Vc8000`000000i/b00>K<P005
0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc800503Vc80001D0i/b000<000000>K<
P03Vc800903Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000`0i/b000<000000>K<
P03Vc800303Vc8000`000000i/b00>K<P00L0>K<P0<0000000<0i/b00000003Vc8008@3Vc8000`00
0000i/b00000000G0>K<P0040000003Vc800i/b00>K<P0<00000103Vc8000`000000i/b00>K<P00B
0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc800503Vc802000000`0i/b000<00000
0>K<P03Vc800103Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b001<0i/b0000F0>K<
P0030000003Vc800i/b00280i/b00`00000C0>K<P0030000003Vc800i/b000`0i/b000<000000>K<
P03Vc8003@3Vc8000`000000i/b00>K<P00L0>K<P08000000P3Vc8000`000000i/b00>K<P00O0>K<
P0040000003Vc800i/b0000001L0i/b0100000030>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc8004P3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b001D0i/b00`000009
0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P00C
0>K<P000>`3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000d0i/b000<000000>K<
P03Vc800303Vc8000`000000i/b00>K<P00M0>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc800703Vc802000000@0i/b000<000000>K<P03Vc8004@3Vc803000000030>K<P0000000i/b0
00@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b0
01@0i/b000<000000>K<P03Vc800603Vc802000000P0i/b000<000000>K<P03Vc8001@3Vc8000`00
0000i/b00>K<P00J0>K<P0030000003Vc800i/b001<0i/b0000k0>K<P0030000003Vc800i/b00140
i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001d0
i/b00P0000040>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc800103Vc8000`000000
i/b00>K<P00>0>K<P0<000001@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00080
i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b001T0
i/b00`0000060>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8006P3Vc8000`000000
i/b00>K<P00C0>K<P000>`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000d0i/b0
00<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00N0>K<P08000001@3Vc8000`000000i/b0
0>K<P00I0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8002P3Vc803000000P0i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00180i/b0
00<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00L0>K<P08000001@3Vc8000`000000i/b0
0>K<P0040>K<P0030000003Vc800i/b001T0i/b000<000000>K<P03Vc8004`3Vc80003/0i/b000<0
00000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000`0i/b000<0
00000>K<P03Vc8007P3Vc8000`000000i/b0000000060>K<P0030000003Vc800i/b001L0i/b000<0
00000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0070>K<P0<00000303Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<
P00D0>K<P0030000003Vc800i/b001d0i/b00`0000020>K<P0030000003Vc800i/b000@0i/b000<0
00000>K<P03Vc8006@3Vc8000`000000i/b00>K<P00C0>K<P000>`3Vc8000`000000i/b00>K<P00?
0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00N
0>K<P0040000003Vc800i/b0000000H0i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b00>K<
P0090>K<P0030000003Vc800i/b00080i/b01000000?0>K<P0030000003Vc800i/b000<0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b001@0i/b000<0
00000>K<P03Vc800803Vc802000000030>K<P0000000i/b000D0i/b000<000000>K<P03Vc800603V
c8000`000000i/b00>K<P00C0>K<P000>`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800
i/b000`0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00N0>K<P0050000003Vc800
i/b00>K<P00000001`3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000X0i/b000<0
00000>K<P00000000P00000D0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P00=0>K<P0T000004`3Vc8000`000000i/b00>K<P00Q0>K<P0<000001P3V
c8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b001<0i/b0000k0>K<P0030000003Vc800
i/b000d0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800
i/b001d0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800
i/b00180i/b000<000000>K<P03Vc8002P3Vc803000001L0i/b000<000000>K<P03Vc8000`3Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b02P0000050>K<P0040000003Vc800
i/b00>K<P0H000003@3Vc8000`000000i/b00>K<P00T0>K<P0800000103Vc8000`000000i/b00>K<
P00H0>K<P0030000003Vc800i/b00180i/b0000j0>K<P0030000003Vc800i/b000d0i/b000<00000
0>K<P03Vc8003@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001d0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b00100i/b00P00000:
0>K<P0<000000P3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b000<0i/b000@00000
0>K<P03Vc800i/b01P00000@0>K<P0030000003Vc800i/b000H0i/b01P0000080>K<P0030000003V
c800i/b002<0i/b000<000000>K<P00000000P0000020>K<P0030000003Vc800i/b001L0i/b000<0
00000>K<P03Vc8004P3Vc80003X0i/b00`00000<0>K<P0030000003Vc800i/b000d0i/b000<00000
0>K<P03Vc800303Vc8000`000000i/b00>K<P00M0>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc800203Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000L0i/b00`000006
0>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8000`3Vc80010000000i/b000000000
00020>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800303Vc80600000080i/b000<0
00000>K<P03Vc800903Vc80010000000i/b00>K<P03Vc803000001T0i/b000<000000>K<P03Vc800
4P3Vc80003X0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00=0>K<P0030000003V
c800i/b000`0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P0040>K<P0030000003V
c800i/b000P0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P0040>K<P0@000002@3V
c8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b00080i/b00P0000040>K<P0030000003V
c800i/b00180i/b000<000000>K<P03Vc8004@3Vc805000002D0i/b000<000000>K<P03Vc8000P3V
c802000001P0i/b000<000000>K<P03Vc8004P3Vc80003X0i/b000<000000>K<P03Vc8002`3Vc800
0`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8007@3Vc800
0`000000i/b00>K<P0050>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8002`3Vc800
0`000000i/b00>K<P0020>K<P0<000003P3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800
i/b00080000000<0i/b00000003Vc800103Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800
i/b001D0i/b01000000S0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8005@3Vc800
0`000000i/b00>K<P00B0>K<P000>P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00N0>K<P0030000003Vc800i/b0
00D0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b0
00<000004P3Vc8000`000000i/b00>K<P00E0>K<P0800000103Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800503Vc80010000000i/b00>K<P03Vc803
00000200i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800
i/b00180i/b0000j0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8003@3Vc8000`00
0000i/b00>K<P00;0>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc8001P3Vc8000`00
0000i/b00>K<P00:0>K<P0030000003Vc800i/b000P0i/b01000000E0>K<P0030000003Vc800i/b0
01<0i/b00`0000050>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004@3Vc8000`00
0000i/b00>K<P00E0>K<P0030000003Vc800i/b000<0i/b00P00000O0>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00B0>K<P000>P3Vc8000`000000
i/b00>K<P0080>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800303Vc8000`000000
i/b00>K<P00M0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8002`3Vc8000`000000
i/b00>K<P0050>K<P0<000006@3Vc8000`000000i/b00>K<P00@0>K<P08000000`3Vc8000`000000
i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004P3Vc8000`000000
i/b00>K<P00D0>K<P0030000003Vc800i/b000D0i/b00`00000M0>K<P0030000003Vc800i/b00080
i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00B0>K<P000>@3Vc8000`000000i/b0
0>K<P0080>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800303Vc8000`000000i/b0
0>K<P00M0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800303Vc80010000000i/b0
0>K<P03Vc804000001/0i/b000<000000>K<P03Vc8003P3Vc802000000D0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00140i/b000<000000>K<P03V
c8005@3Vc8000`000000i/b00>K<P0070>K<P0<000006`3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b001@0i/b000<000000>K<P03Vc8004@3Vc80003T0i/b000<000000>K<P03Vc800
1`3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800
7@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000`0i/b0100000000`3Vc8000000
0>K<P00M0>K<P0030000003Vc800i/b000/0i/b00P0000080>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b001@0i/b0
00<000000>K<P03Vc8002P3Vc803000001P0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P00C0>K<P0030000003Vc800i/b00140i/b0000i0>K<P0030000003Vc800i/b000L0i/b000<0
00000>K<P03Vc800303Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001d0i/b000<0
00000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0090>K<P0<0000000D0i/b00000003Vc800i/b0
0000000O0>K<P0030000003Vc800i/b000T0i/b00P00000:0>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b001D0i/b0
00<000000>K<P03Vc800303Vc803000001H0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P00C0>K<P0030000003Vc800i/b00140i/b0000i0>K<P0<000001P3Vc8000`000000i/b00>K<
P00<0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<
P00;0>K<P0030000003Vc800i/b000H0i/b00`0000040>K<P0030000003Vc80000000240i/b000<0
00000>K<P03Vc8001P3Vc802000000d0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<
P00?0>K<P0<00000503Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00180i/b000<0
00000>K<P03Vc8004@3Vc80003T0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00=
0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00<
0>K<P0030000003Vc800i/b000<0i/b00`0000080>K<P0030000003Vc800i/b00200i/b000<00000
0>K<P03Vc800103Vc802000000l0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00A
0>K<P0<000004P3Vc8001@000000i/b00>K<P03Vc800000001@0i/b000<000000>K<P03Vc8004@3V
c8000240i/b00`0000050>K<P0800000103Vc806000000@0i/b000<000000>K<P03Vc800103Vc800
0`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800703Vc800
0`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000<000002P3Vc8000`000000i/b00000000R
0>K<P0040000003Vc800i/b00>K<P08000004P3Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00D0>K<P0030000003V
c800i/b001@0i/b00P00000A0>K<P0050000003Vc800i/b00>K<P00000004`3Vc8000`000000i/b0
0>K<P00A0>K<P000803Vc80010000000i/b00>K<P00000050>K<P08000001@3Vc8001@000000i/b0
0>K<P03Vc800000000@0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00;0>K<P003
0000003Vc800i/b000`0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00<0>K<P0@0
0000303Vc80010000000i/b00>K<P000000R0>K<P0040000003Vc8000000000001@0i/b000<00000
0>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00140i/b000<00000
0>K<P03Vc8005@3Vc8000`000000i/b00>K<P00E0>K<P0<000003P3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8004@3Vc80001l0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000D0i/b000<000000>K<
P03Vc8001P3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000`0i/b000<000000>K<
P03Vc8007@3Vc8000`000000i/b00>K<P00:0>K<P0<0000000<0i/b00000003Vc800303Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8005@3Vc8000`00
0000i/b00>K<P0030>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004P3Vc8000`00
0000i/b00>K<P00E0>K<P0030000003Vc800i/b001L0i/b00`00000<0>K<P0050000003Vc800i/b0
0>K<P00000004P3Vc8000`000000i/b00>K<P00A0>K<P0007`3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000/0i/b00P0000040>K<P0030000003Vc800i/b000P0i/b000<000000>K<
P03Vc8001`3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001d0i/b000<000000>K<
P03Vc800203Vc803000000@0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0040>K<
P0030000003Vc800i/b001h0i/b000<000000>K<P00000005P3Vc8000`000000i/b00>K<P0030>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00E0>K<
P0030000003Vc800i/b001X0i/b00`00000:0>K<P0050000003Vc800i/b00>K<P00000004P3Vc800
0`000000i/b00>K<P00@0>K<P0007`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b0
00`0i/b00P0000030>K<P0030000003Vc800i/b000T0i/b00P0000060>K<P0030000003Vc800i/b0
00`0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P0060>K<P0<000001`3Vc8000`00
0000i/b00>K<P0090>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800703Vc8020000
0080i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b0
01`0i/b00`0000080>K<P0040000003Vc800i/b000000180i/b000<000000>K<P03Vc800403Vc800
01l0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00=0>K<P0050000003Vc800i/b0
0>K<P00000003@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000/0i/b000<00000
0>K<P03Vc8007@3Vc8000`000000i/b00>K<P0040>K<P0<000002P3Vc8000`000000i/b00>K<P008
0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00O
0>K<P0<000001@3Vc8001@000000i/b00>K<P03Vc80000000140i/b000<000000>K<P03Vc800403V
c8000200i/b000@000000>K<P03Vc80000002`3Vc8000`000000i/b00>K<P0020>K<P0050000003V
c800i/b00>K<P00000003P3Vc8001@000000i/b00>K<P03Vc800000000d0i/b000<000000>K<P03V
c8007@3Vc80010000000i/b00>K<P03Vc804000000d0i/b000<000000>K<P03Vc800203Vc8000`00
0000i/b00>K<P0070>K<P0030000003Vc800i/b001T0i/b000<000000>K<P03Vc800103Vc8000`00
0000i/b00>K<P00E0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P00B0>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8008@3Vc8030000
00<0i/b000D000000>K<P03Vc800i/b00000000@0>K<P0030000003Vc800i/b00100i/b0000P0>K<
P0@000002`3Vc805000000@0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00000000>0>K<
P0030000003Vc800i/b001`0i/b000<000000>K<P00000000P00000A0>K<P0030000003Vc800i/b0
00L0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b0
00H0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b0
02@0i/b00P0000020>K<P0040000003Vc800i/b000000100i/b000<000000>K<P03Vc800403Vc800
03P0i/b00P00000?0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc800703Vc8030000
01<0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
01D0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b0
01D0i/b000<000000>K<P03Vc8009@3Vc80400000080i/b000<000000>K<P03Vc8003@3Vc8000`00
0000i/b00>K<P00@0>K<P000>03Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b000X0
i/b000<000000>K<P03Vc8006P3Vc803000001H0i/b000<000000>K<P03Vc8001P3Vc8000`000000
i/b00>K<P00<0>K<P0030000003Vc800i/b001<0i/b00P00000;0>K<P0030000003Vc800i/b001@0
i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00140
i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00X0>K<P0@000003`3Vc8000`000000
i/b00>K<P00@0>K<P000>03Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000P0i/b0
00<000000>K<P03Vc800603Vc803000000030>K<P0000000i/b001H0i/b000<000000>K<P03Vc800
1@3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800
303Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P00?0>K<P0X000004@3Vc8000`000000i/b00>K<P00X0>K<P0040000
003Vc8000000000000h0i/b000<000000>K<P03Vc800403Vc80003L0i/b000<000000>K<P03Vc800
4P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001D0i/b0100000040>K<P0030000
003Vc800i/b001D0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00@0>K<P0030000
003Vc800i/b000l0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00D0>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0080>K<P0H00000
2P3Vc80<000000D0i/b000<000000>K<P03Vc800:@3Vc80010000000i/b00>K<P000000>0>K<P003
0000003Vc800i/b000l0i/b0000g0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc800
103Vc8000`000000i/b00>K<P00C0>K<P0<000001`3Vc8000`000000i/b00>K<P00F0>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00>0>K<P0030000
003Vc800i/b000l0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8000P3Vc806000001`0i/b02000000Z0>K<P0030000
003Vc800000000h0i/b000<000000>K<P03Vc8003`3Vc80003L0i/b000<000000>K<P03Vc800503V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b00100i/b00`0000090>K<P0030000003V
c800i/b001L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00C0>K<P0030000003V
c800i/b000`0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00D0>K<P0030000003V
c800i/b000<0i/b000@000000>K<P03Vc800i/b01P00000Z0>K<P0<000009`3Vc80010000000i/b0
0>K<P000000=0>K<P0030000003Vc800i/b000l0i/b0000g0>K<P0030000003Vc800i/b001D0i/b0
00D000000>K<P03Vc800i/b00000000@0>K<P0<000002`3Vc8000`000000i/b00>K<P00H0>K<P005
0000003Vc800i/b00>K<P00000005`3Vc8000`000000i/b00>K<P0090>K<P0800000503Vc8000`00
0000i/b00>K<P00D0>K<P0030000003Vc800i/b00080i/b01000000c0>K<P0<000009@3Vc8000`00
0000i/b00000000=0>K<P0030000003Vc800i/b000l0i/b0000g0>K<P0030000003Vc800i/b001H0
i/b000<000000>K<P00000003P3Vc803000000d0i/b000<000000>K<P03Vc8006@3Vc80010000000
i/b00>K<P000000H0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800503Vc8000`00
0000i/b00>K<P00D0>K<P0030000003Vc800i/b000800000>P3Vc803000002<0i/b000<000000>K<
P0000000303Vc8000`000000i/b00>K<P00?0>K<P000=`3Vc8000`000000i/b00>K<P00G0>K<P003
0000003Vc800i/b000T0i/b01000000?0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P000
00006P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03V
c8004`3Vc803000003l0i/b00`00000Q0>K<P0800000303Vc8000`000000i/b00>K<P00?0>K<P000
=`3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b000D0i/b00`00000B0>K<P0030000
003Vc800i/b001/0i/b00P00000K0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800
5`3Vc8000`000000i/b00>K<P00A0>K<P0800000A@3Vc804000001d0i/b000<000000>K<P0000000
2`3Vc8000`000000i/b00>K<P00?0>K<P000=P3Vc803000001X0i/b000@000000>K<P03Vc800i/b0
0`00000D0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b001T0i/b000<000000>K<P03Vc8003P3Vc802000004/0i/b0
0`00000K0>K<P08000002`3Vc8000`000000i/b00>K<P00?0>K<P000=P3Vc8000`000000i/b00>K<
P00K0>K<P0<000005P3Vc8000`000000i/b00>K<P00M0>K<P0030000003Vc800i/b001`0i/b000<0
00000>K<P03Vc8000P00000M0>K<P0030000003Vc800i/b000/0i/b00P00001@0>K<P0<000006@3V
c802000000/0i/b000<000000>K<P03Vc8003P3Vc80003H0i/b000<000000>K<P03Vc800603Vc803
000000030>K<P0000000i/b001H0i/b000<000000>K<P03Vc800703Vc802000001h0i/b000<00000
0>K<P00000007`3Vc8000`000000i/b00>K<P0090>K<P0800000E@3Vc803000001L0i/b000<00000
0>K<P03Vc8002@3Vc8000`000000i/b00>K<P00>0>K<P000=P3Vc8000`000000i/b00>K<P00D0>K<
P0@000001@3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b001`0i/b000<000000>K<
P00000007`3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b000H0i/b00P00001J0>K<
P0<00000503Vc802000000X0i/b000<000000>K<P03Vc8003P3Vc80003H0i/b000<000000>K<P03V
c8004@3Vc803000000X0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00L0>K<P004
0000003Vc800i/b0000001h0i/b000<000000>K<P0000000803Vc8000`000000i/b00>K<P0040>K<
P0800000G`3Vc80300000180i/b00P0000090>K<P0030000003Vc800i/b000h0i/b0000f0>K<P003
0000003Vc800i/b000h0i/b00`00000>0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03V
c800703Vc8001@000000i/b00>K<P03Vc800000001d0i/b000@000000>K<P03Vc80000008@3Vc800
10000000i/b00>K<P03Vc802000006@0i/b00`00000@0>K<P0030000003Vc800i/b000L0i/b000<0
00000>K<P03Vc8003P3Vc80003H0i/b000<000000>K<P03Vc8002`3Vc80300000180i/b000<00000
0>K<P03Vc8003@3Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b00080i/b000<00000
0>K<P03Vc8006P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001h0i/b000@00000
0>K<P00000000000J@3Vc803000000h0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<
P00>0>K<P000=P3Vc8000`000000i/b00>K<P0080>K<P0<000005@3Vc8000`000000i/b00>K<P00<
0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00I
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P01/
0>K<P0<000002`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000h0i/b0000e0>K<
P0030000003Vc800i/b000D0i/b01000000I0>K<P0030000003Vc800i/b000X0i/b000<000000>K<
P03Vc800703Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b001P0i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P00L0>K<P0800000LP3Vc804000000P0i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P00>0>K<P000=@3Vc8000`000000i/b00>K<P0020>K<P0<0
00007P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03V
c800103Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03V
c8006P3Vc8000`000000i/b00>K<P01f0>K<P0<000001@3Vc802000000L0i/b000<000000>K<P03V
c8003@3Vc80003D0i/b01@00000R0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800
703Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b001L0i/b000<000000>K<P03Vc800
203Vc8000`000000i/b00>K<P00I0>K<P0030000003Vc800i/b007X0i/b00`0000030>K<P0800000
1P3Vc8000`000000i/b00>K<P00=0>K<P000=@3Vc802000002H0i/b000<000000>K<P03Vc8001@3V
c8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8005P3V
c8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b001H0i/b00P0000200>K<P0D000001P3V
c8000`000000i/b00>K<P00=0>K<P000=P3Vc8000`000000i/b00>K<P00U0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800
i/b001D0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800
i/b008<0i/b00`0000050>K<P0030000003Vc800i/b000d0i/b0000g0>K<P08000009P3Vc8001@00
0000i/b00>K<P03Vc800000001d0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00D
0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P027
0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8003@3Vc80003T0i/b000<000000>K<
P03Vc800903Vc8000`000000i/b00000000N0>K<P0030000003Vc800i/b000P0i/b000<000000>K<
P03Vc8004`3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b00100i/b00P00002;0>K<
P0050000003Vc800i/b00>K<P00000003`3Vc80003X0i/b000<000000>K<P03Vc800903Vc8000`00
0000i/b00>K<P00L0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8004P3Vc8000`00
0000i/b00>K<P00@0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800R`3Vc8001@00
0000i/b00>K<P03Vc800000000l0i/b0000k0>K<P08000009@3Vc8000`000000i/b00>K<P00J0>K<
P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00B0>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800S@3Vc80010000000i/b00>K<P000000?
0>K<P000?@3Vc8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b001P0i/b000<000000>K<
P03Vc8002`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001@0i/b000<000000>K<
P03Vc8002P3Vc80200000940i/b000@000000>K<P03Vc80000003P3Vc80003h0i/b000<000000>K<
P03Vc8008P3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b000`0i/b000<000000>K<
P03Vc8003`3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000T0i/b000<000000>K<
P03Vc800TP3Vc8000`000000i/b00000000>0>K<P000?`3Vc802000002<0i/b000<000000>K<P03V
c8005@3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03V
c8005`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b009<0i/b000<000000>K<P000
00003P3Vc8000440i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P00C0>K<P0030000
003Vc800i/b000h0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00I0>K<P0030000
003Vc800i/b000@0i/b00P00002G0>K<P08000003P3Vc8000480i/b000<000000>K<P03Vc8008@3V
c8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800303V
c8000`000000i/b00>K<P00J0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800U`3V
c802000000h0i/b000130>K<P08000008@3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800
i/b00100i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00L0>K<P0050000003Vc800
i/b00>K<P0000000UP3Vc80400000100i/b000150>K<P0030000003Vc800i/b001l0i/b000<00000
0>K<P03Vc8003P3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000X0i/b000<00000
0>K<P03Vc8007@3Vc80010000000i/b000000000002C0>K<P0@00000503Vc80004H0i/b000<00000
0>K<P03Vc8007`3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b00180i/b000<00000
0>K<P03Vc8002@3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b008l0i/b01000000H
0>K<P000A`3Vc80200000200i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00C0>K<
P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P02<0>K<
P0@00000703Vc80004T0i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P0080>K<P003
0000003Vc800i/b001@0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00O0>K<P003
0000003Vc800i/b008T0i/b01000000P0>K<P000BP3Vc8000`000000i/b00>K<P00M0>K<P0030000
003Vc800i/b000P0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P0070>K<P0030000
003Vc800i/b001h0i/b000<000000>K<P03Vc800QP3Vc804000002@0i/b0001;0>K<P0030000003V
c800i/b001d0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00D0>K<P0030000003V
c800i/b000L0i/b000<000000>K<P03Vc8007P3Vc8000`000000i/b00>K<P0240>K<P0<00000:03V
c80004`0i/b00P00000N0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8005@3Vc800
0`000000i/b00>K<P0060>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc800P@3Vc804
000002/0i/b0001>0>K<P0030000003Vc800i/b001`0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P00F0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8007P3Vc8000`00
0000i/b00>K<P01n0>K<P0@00000;`3Vc80004l0i/b000<000000>K<P03Vc8006`3Vc8001@000000
i/b00>K<P03Vc800000001T0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00N0>K<
P0030000003Vc800i/b007/0i/b01000000c0>K<P000D03Vc802000001`0i/b000<000000>K<P000
00006P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03V
c800N03Vc804000003L0i/b0001B0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc800
6@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc800
M@3Vc804000003/0i/b0001C0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc800603V
c8001@000000i/b00>K<P03Vc80000000200i/b000<000000>K<P03Vc800LP3Vc804000003l0i/b0
001D0>K<P08000006`3Vc8000`000000i/b00>K<P00G0>K<P0040000003Vc800i/b000000200i/b0
00<000000>K<P03Vc800L03Vc803000004<0i/b0001F0>K<P0030000003Vc800i/b001P0i/b000<0
00000>K<P03Vc8005`3Vc8000`000000i/b00000000P0>K<P0030000003Vc800i/b006d0i/b01000
00160>K<P000E`3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b001H0i/b00P00000P
0>K<P0030000003Vc800i/b006X0i/b01000001:0>K<P000F03Vc802000001T0i/b000<000000>K<
P03Vc8005@3Vc8000`000000i/b00>K<P00N0>K<P0030000003Vc800i/b006L0i/b01000001>0>K<
P000FP3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b001<0i/b00P00000O0>K<P003
0000003Vc800i/b006@0i/b01000001B0>K<P000F`3Vc8000`000000i/b00>K<P00G0>K<P0030000
003Vc800i/b00140i/b000<000000>K<P00000007P3Vc8000`000000i/b00>K<P01Q0>K<P0@00000
EP3Vc80005`0i/b00P00000H0>K<P0030000003Vc800i/b000l0i/b000@000000>K<P03Vc8000000
7@3Vc8000`000000i/b00>K<P01O0>K<P0<00000FP3Vc80005h0i/b000<000000>K<P03Vc8005@3V
c8000`000000i/b00>K<P00>0>K<P0050000003Vc800i/b00>K<P0000000703Vc8000`000000i/b0
0>K<P01L0>K<P0@00000G@3Vc80005l0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<
P00<0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8006@3Vc8000`000000i/b00>K<
P01I0>K<P0@00000H@3Vc8000600i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00:
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P01F
0>K<P0@00000I@3Vc8000640i/b00P00000F0>K<P0030000003Vc800i/b000P0i/b000<000000>K<
P03Vc800103Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b005<0i/b01000001Y0>K<
P000H`3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03V
c8001@3Vc8000`000000i/b00>K<P00E0>K<P0800000DP3Vc804000006d0i/b0001T0>K<P0030000
003Vc800i/b001@0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0050>K<P0030000
003Vc800i/b001D0i/b000<000000>K<P03Vc800CP3Vc80400000740i/b0001U0>K<P0800000503V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800503V
c8000`000000i/b00>K<P01<0>K<P0<00000M@3Vc80006L0i/b000<000000>K<P03Vc8004P3Vc800
1@000000i/b00>K<P03Vc800000000T0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<
P0190>K<P0@00000N03Vc80006P0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00000000:
0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800AP3Vc804000007`0i/b0001Y0>K<
P08000004`3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00140i/b000<000000>K<
P03Vc800@`3Vc80400000800i/b0001[0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03V
c800203Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b00400i/b0100000240>K<P000
K03Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800
3`3Vc8000`000000i/b00>K<P00m0>K<P0@00000R03Vc80006d0i/b00P00000A0>K<P0030000003V
c800i/b000L0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00j0>K<P0@00000S03V
c80006l0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800
i/b000d0i/b000<000000>K<P03Vc800>03Vc80300000900i/b0001`0>K<P0030000003Vc800i/b0
00l0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b0
03D0i/b01000002C0>K<P000L@3Vc80200000100i/b000<000000>K<P03Vc800103Vc8000`000000
i/b00>K<P00;0>K<P0030000003Vc800i/b00380i/b01000002G0>K<P000L`3Vc8000`000000i/b0
0>K<P00=0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b0
0>K<P00_0>K<P0@00000V`3Vc80007@0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<
P0030>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800;03Vc804000009l0i/b0001e
0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P008
0>K<P0030000003Vc800i/b002T0i/b01000002S0>K<P000MP3Vc802000000h0i/b000D000000>K<
P03Vc800i/b0000000090>K<P0030000003Vc800i/b002H0i/b01000002W0>K<P000N03Vc8000`00
0000i/b00>K<P00<0>K<P0040000003Vc800i/b0000000P0i/b000<000000>K<P03Vc800903Vc803
00000:/0i/b0001i0>K<P0030000003Vc800i/b000/0i/b000@000000>K<P03Vc80000001`3Vc800
0`000000i/b00>K<P00Q0>K<P0@00000[P3Vc80007X0i/b00P00000<0>K<P0030000003Vc8000000
00H0i/b000<000000>K<P03Vc8007P3Vc80400000;80i/b0001l0>K<P0030000003Vc800i/b000X0
i/b00P0000050>K<P0030000003Vc800i/b001/0i/b01000002f0>K<P000O@3Vc8000`000000i/b0
0>K<P0090>K<P0800000103Vc8000`000000i/b00>K<P00H0>K<P0@00000^P3Vc80007h0i/b00P00
00090>K<P08000000`3Vc8000`000000i/b00>K<P00E0>K<P0@00000_P3Vc8000800i/b000<00000
0>K<P03Vc8001P3Vc8001@000000i/b00000003Vc800000001D0i/b00`0000320>K<P000P@3Vc800
0`000000i/b00>K<P0050>K<P0040000003Vc800i/b000000180i/b0100000350>K<P000PP3Vc802
000000D0i/b000<000000>K<P03Vc8003`3Vc80400000<T0i/b000240>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8002`3Vc80400000<d0i/b000250>K<P0050000003Vc800i/b00>K<
P00000002@3Vc80400000=40i/b000260>K<P080000000<0i/b00000003Vc800103Vc80400000=D0
i/b000280>K<P080000000<0i/b00000000000000P00003I0>K<P000R@3Vc80200000=d0i/b0003o
0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003o0>K<P6T0i/b0003D
0>K<P0@00000803Vc805000006/0i/b0003F0>K<P0030000003Vc800i/b00280i/b000<000000>K<
P03Vc800JP3Vc80009@0i/b00`0000020>K<P080000000<0i/b000000000000010000000103Vc800
00000000003Vc803000000<0i/b01P0000070>K<P0D000000`3Vc805000000D0i/b0100000030>K<
P0<0000000<0i/b00000003Vc8000P3Vc806000000<0i/b010000000103Vc8000000000000000002
0>K<P0<000000P3Vc804000000D0i/b000<000000>K<P03Vc800JP3Vc80009D0i/b000@000000>K<
P03Vc80000000`3Vc8001@000000i/b00>K<P03Vc800000000<0i/b00P0000030>K<P0030000003V
c800i/b000<0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0050>K<P0030000003V
c800i/b000@0i/b000<000000>K<P03Vc800103Vc80010000000i/b00>K<P03Vc80200000080i/b0
00<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<P03Vc800000000H0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P002000000<0i/b00P0000030>K<P0800000J`3Vc80009D0i/b0
00@000000>K<P03Vc80000000`3Vc8001@000000i/b00>K<P03Vc800000000<0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000T0i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000D0i/b000<000000>K<
P03Vc8000P3Vc80010000000i/b00>K<P00000040>K<P0040000003Vc800i/b0000000L0i/b000<0
00000>K<P03Vc8000P3Vc80010000000i/b00>K<P00000080>K<P0040000003Vc800i/b0000006X0
i/b0002E0>K<P0<000001@3Vc804000000<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P0030>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b0
0>K<P0030>K<P0H000000P3Vc8000`000000i/b00>K<P0020>K<P0040000003Vc800i/b0000000@0
i/b000<000000>K<P03Vc8001P0000020>K<P0030000003Vc800i/b00080i/b000@000000>K<P03V
c8000000203Vc8001@000000i/b00>K<P03Vc800000006T0i/b0002E0>K<P0030000003Vc800i/b0
008000001P3Vc80010000000i/b00>K<P03Vc802000000<0i/b000<000000>K<P03Vc8000`3Vc800
0`000000i/b00>K<P0090>K<P0030000003Vc800i/b000D0i/b00P0000040>K<P0030000003Vc800
i/b00080i/b000@000000>K<P03Vc80000000`3Vc80200000080i/b000<000000>K<P03Vc8000P3V
c80010000000i/b00>K<P00000040>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<P03V
c8000P0000030>K<P0040000003Vc800i/b0000000@0i/b000<000000>K<P03Vc800I`3Vc80009D0
i/b000D000000>K<P03Vc800i/b0000000030>K<P0@000000`3Vc8000`000000i/b0000000020000
00@0i/b00`0000090>K<P0D000000`3Vc803000000030>K<P0000000000000<0i/b0100000040>K<
P0<0000000<0i/b00000000000000P0000030>K<P08000000`3Vc80400000080i/b01P0000040>K<
P0D0000000@0i/b000000000000000000`3Vc802000006P0i/b0002E0>K<P0050000003Vc800i/b0
0>K<P00000002P3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b00:X0i/b0002D0>K<
P0D000002P3Vc802000001H0i/b01000002Y0>K<P000[P3Vc8000`000000i/b00>K<P02g0>K<P000
[P3Vc8000`000000i/b00>K<P02g0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<
P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<
P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<
P000o`3Vc81Y0>K<P000o`3Vc81Y0>K<P000\
\>"],
  ImageRangeCache->{{{0, 359}, {324.125, 0}} -> {-0.183558, -0.0742616, \
0.00425261, 0.00425261}}]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save plot to ps-file", "Subsubsection"],

Cell[BoxData[{
    \(\(SetDirectory["\<~/mathem\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<rabifreq.eps\>", plFreq, "\<EPS\>"];\)\)}], "Input"],

Cell["\<\

The amplitude of the Rabi oscillation:\
\>", "Text"],

Cell[CellGroupData[{

Cell[BoxData[
    \(\(plAmp = 
        Show[Graphics3D[{Line /@ 
                Transpose[colldata[\([All, All, {2, 1, 4}]\)]], 
              Line /@ colldata[\([All, All, {2, 1, 4}]\)]}\ , 
            Axes \[Rule] True, 
            AxesLabel \[Rule] {\*"\"\<\[Omega]/\!\(\[Omega]\_0\)\>\"", \
\*"\"\<\[Omega]1/\!\(\[Omega]\_0\)\>\"", "\<\>"}, 
            AxesEdge \[Rule] {{\(-1\), \(-1\)}, {1, \(-1\)}, {\(-1\), \
\(-1\)}}, PlotLabel -> "\<Amplitude\>"]];\)\)], "Input"],

Cell[GraphicsData["PostScript", "\<\
%!
%%Creator: Mathematica
%%AspectRatio: 1.25199 
MathPictureStart
/Mabs {
Mgmatrix idtransform
Mtmatrix dtransform
} bind def
/Mabsadd { Mabs
3 -1 roll add
3 1 roll add
exch } bind def
%% Graphics3D
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10  scalefont  setfont
% Scaling calculations
-0.128737 1.26513 -1.72876e-16 1.26513 [
[.5 1.26449 -29 0 ]
[.5 1.26449 29 10.125 ]
[.08486 .23812 -17.4329 -9 ]
[.08486 .23812 .56708 0 ]
[.2306 .18068 -16.8038 -9 ]
[.2306 .18068 1.19621 0 ]
[.38246 .12085 -5.39155 -9 ]
[.38246 .12085 .60845 0 ]
[.54084 .05848 -15.5455 -9 ]
[.54084 .05848 2.45447 0 ]
[.70616 -0.00659 -14.9164 -9 ]
[.70616 -0.00659 3.08361 0 ]
[.33317 .05902 -24.7675 -9.8125 ]
[.33317 .05902 2.79505 0 ]
[.7903 .06173 0 -6.2174 ]
[.7903 .06173 18 2.7826 ]
[.86367 .17463 0 -6.13678 ]
[.86367 .17463 18 2.86322 ]
[.93166 .27928 0 -6.0634 ]
[.93166 .27928 18 2.9366 ]
[.92006 .11991 0 -6.71199 ]
[.92006 .11991 33.5625 3.10051 ]
[.0651 .27682 -6 -2.74332 ]
[.0651 .27682 0 6.25668 ]
[.03697 .54751 -18 -2.90936 ]
[.03697 .54751 0 6.09064 ]
[.00489 .85637 -18 -3.10045 ]
[.00489 .85637 0 5.89955 ]
[ 0 0 0 0 ]
[ 1 1.25199 0 0 ]
] MathScale
% Start of Graphics
1 setlinecap
1 setlinejoin
newpath
0 g
gsave
.5 1.26449 -90 -4 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 18.125 translate 1 -1 scale
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(Amplitude) show
117.000 11.562 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
/Courier findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
[ ] 0 setdash
.08146 .25523 m
.73171 0 L
s
.09567 .24966 m
.10107 .25543 L
s
[(0.8)] .08486 .23812 .93699 1 Mshowa
.24096 .19263 m
.24614 .1986 L
s
[(0.9)] .2306 .18068 .86709 1 Mshowa
.39232 .13322 m
.39724 .1394 L
s
[(1)] .38246 .12085 .79718 1 Mshowa
.55014 .07127 m
.55479 .07767 L
s
[(1.1)] .54084 .05848 .72728 1 Mshowa
.71484 .00662 m
.71919 .01323 L
s
[(1.2)] .70616 -0.00659 .65738 1 Mshowa
.125 Mabswid
.12426 .23844 m
.12748 .24192 L
s
.15308 .22712 m
.15627 .23063 L
s
.18213 .21572 m
.1853 .21925 L
s
.21142 .20422 m
.21456 .20778 L
s
.27073 .18094 m
.27381 .18455 L
s
.30075 .16916 m
.3038 .17279 L
s
.33102 .15728 m
.33404 .16094 L
s
.36154 .1453 m
.36453 .14898 L
s
.42335 .12104 m
.42627 .12477 L
s
.45465 .10875 m
.45754 .11251 L
s
.48621 .09636 m
.48907 .10015 L
s
.51804 .08387 m
.52086 .08768 L
s
.58251 .05856 m
.58527 .06242 L
s
.61517 .04574 m
.61789 .04963 L
s
.64811 .03282 m
.65079 .03673 L
s
.68133 .01978 m
.68397 .02371 L
s
gsave
.33317 .05902 -85.7674 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 11.250 moveto
(\\220) show
75.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
81.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
86.562 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.73171 0 m
.9208 .29074 L
s
.77553 .06737 m
.76814 .07019 L
s
[(0.1)] .7903 .06173 -1 .38164 Mshowa
.8488 .18004 m
.84137 .18274 L
s
[(0.2)] .86367 .17463 -1 .36373 Mshowa
.91672 .28447 m
.90925 .28706 L
s
[(0.3)] .93166 .27928 -1 .34742 Mshowa
.125 Mabswid
.79064 .09061 m
.7862 .09229 L
s
.80552 .11349 m
.80108 .11515 L
s
.82017 .13602 m
.81572 .13766 L
s
.8346 .1582 m
.83014 .15983 L
s
.8628 .20155 m
.85833 .20316 L
s
.87658 .22275 m
.87211 .22434 L
s
.89016 .24363 m
.88569 .24521 L
s
.90354 .2642 m
.89906 .26577 L
s
.76017 .04376 m
.75574 .04547 L
s
.74457 .01978 m
.74015 .0215 L
s
gsave
.92006 .11991 -61 -10.712 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(1) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
75.000 11.250 moveto
(\\220) show
81.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
87.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
92.562 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
.25 Mabswid
.08146 .25523 m
0 1.04559 L
s
.07983 .27107 m
.08719 .2682 L
s
[(0)] .0651 .27682 1 -0.39037 Mshowa
.05188 .54224 m
.05933 .5396 L
s
[(0.2)] .03697 .54751 1 -0.35348 Mshowa
.01999 .85167 m
.02754 .84932 L
s
[(0.4)] .00489 .85637 1 -0.31101 Mshowa
.125 Mabswid
.07317 .33567 m
.0776 .33398 L
s
.0663 .40233 m
.07075 .40067 L
s
.05921 .47115 m
.06367 .46953 L
s
.04431 .61571 m
.04879 .61416 L
s
.03648 .69168 m
.04098 .69018 L
s
.02837 .77029 m
.03289 .76883 L
s
.0113 .93597 m
.01584 .93461 L
s
.00229 1.02336 m
.00685 1.02205 L
s
.25 Mabswid
.08146 .25523 m
0 1.04559 L
s
0 1.04559 m
.28068 1.25199 L
s
.28068 1.25199 m
.31357 .50112 L
s
.31357 .50112 m
.08146 .25523 L
s
.73171 0 m
.9208 .29074 L
s
.9208 .29074 m
1 1.07583 L
s
1 1.07583 m
.78056 .82376 L
s
.78056 .82376 m
.73171 0 L
s
.08146 .25523 m
0 1.04559 L
s
0 1.04559 m
.78056 .82376 L
s
.78056 .82376 m
.73171 0 L
s
.73171 0 m
.08146 .25523 L
s
.31357 .50112 m
.9208 .29074 L
s
.9208 .29074 m
1 1.07583 L
s
1 1.07583 m
.28068 1.25199 L
s
.28068 1.25199 m
.31357 .50112 L
s
0 0 m
1 0 L
1 1.25199 L
0 1.25199 L
closepath
clip
newpath
.5 Mabswid
.26996 .65783 m
.31084 .75488 L
s
.31084 .75488 m
.45334 .94115 L
s
.22875 .55721 m
.26996 .65783 L
s
.26996 .65783 m
.41039 .83964 L
s
.18697 .45726 m
.22875 .55721 L
s
.22875 .55721 m
.36752 .71475 L
s
.14405 .36368 m
.18697 .45726 L
s
.18697 .45726 m
.32541 .56704 L
s
.12189 .32124 m
.14405 .36368 L
s
.14405 .36368 m
.28438 .40452 L
s
.09908 .28281 m
.12189 .32124 L
s
.12189 .32124 m
.26398 .32563 L
s
.09908 .28281 m
.24321 .25516 L
s
.24321 .25516 m
.26398 .32563 L
s
.24321 .25516 m
.31467 .32145 L
s
.26398 .32563 m
.28438 .40452 L
s
.26398 .32563 m
.33358 .4615 L
s
.28438 .40452 m
.32541 .56704 L
s
.28438 .40452 m
.35369 .59031 L
s
.41039 .83964 m
.45334 .94115 L
s
.45334 .94115 m
.53273 1.07727 L
s
.8844 .42837 m
.92418 .53039 L
s
.77647 .83398 m
.92418 .53039 L
s
.32541 .56704 m
.36752 .71475 L
s
.32541 .56704 m
.39728 .78611 L
s
.36752 .71475 m
.41039 .83964 L
s
.41039 .83964 m
.48831 1.00766 L
s
.36752 .71475 m
.44284 .91628 L
s
.84397 .32404 m
.8844 .42837 L
s
.7339 .72529 m
.8844 .42837 L
s
.80319 .22134 m
.84397 .32404 L
s
.68989 .59414 m
.84397 .32404 L
s
.76228 .12497 m
.80319 .22134 L
s
.64508 .44251 m
.80319 .22134 L
s
.31467 .32145 m
.33358 .4615 L
s
.31467 .32145 m
.3624 .80663 L
s
.55613 .13139 m
.57808 .20119 L
s
.55613 .13139 m
.72126 .03956 L
s
.47479 .25656 m
.55613 .13139 L
s
.57808 .20119 m
.60025 .27941 L
s
.57808 .20119 m
.74179 .08064 L
s
.49688 .39584 m
.57808 .20119 L
s
.74179 .08064 m
.76228 .12497 L
s
.60025 .27941 m
.76228 .12497 L
s
.60025 .27941 m
.64508 .44251 L
s
.51968 .52552 m
.60025 .27941 L
s
.7339 .72529 m
.77647 .83398 L
s
.70012 1.03083 m
.77647 .83398 L
s
.72126 .03956 m
.74179 .08064 L
s
.48831 1.00766 m
.53273 1.07727 L
s
.53273 1.07727 m
.60037 1.13863 L
s
.64508 .44251 m
.68989 .59414 L
s
.56624 .72618 m
.64508 .44251 L
s
.33358 .4615 m
.35369 .59031 L
s
.33358 .4615 m
.3868 .89346 L
s
.68989 .59414 m
.7339 .72529 L
s
.65711 .95729 m
.7339 .72529 L
s
.61239 .86152 m
.68989 .59414 L
s
.47479 .25656 m
.49688 .39584 L
s
.39831 .79475 m
.47479 .25656 L
s
.44284 .91628 m
.48831 1.00766 L
s
.48831 1.00766 m
.55613 1.09827 L
s
.35369 .59031 m
.39728 .78611 L
s
.35369 .59031 m
.41205 .94159 L
s
.49688 .39584 m
.51968 .52552 L
s
.42289 .88245 m
.49688 .39584 L
s
.65711 .95729 m
.70012 1.03083 L
s
.63442 1.13015 m
.70012 1.03083 L
s
.39728 .78611 m
.44284 .91628 L
s
.44284 .91628 m
.51 1.05454 L
s
.55613 1.09827 m
.60037 1.13863 L
s
.60037 1.13863 m
.61744 1.13817 L
s
.39728 .78611 m
.46193 1.00513 L
s
.57345 1.09933 m
.61744 1.13817 L
s
.61744 1.13817 m
.63442 1.13015 L
s
.59069 1.08938 m
.63442 1.13015 L
s
.51968 .52552 m
.56624 .72618 L
s
.44804 .93109 m
.51968 .52552 L
s
.61239 .86152 m
.65711 .95729 L
s
.59069 1.08938 m
.65711 .95729 L
s
.51 1.05454 m
.55613 1.09827 L
s
.55613 1.09827 m
.57345 1.09933 L
s
.56624 .72618 m
.61239 .86152 L
s
.54507 1.04521 m
.61239 .86152 L
s
.49749 .99537 m
.56624 .72618 L
s
.52754 1.05856 m
.57345 1.09933 L
s
.57345 1.09933 m
.59069 1.08938 L
s
.54507 1.04521 m
.59069 1.08938 L
s
.46193 1.00513 m
.51 1.05454 L
s
.51 1.05454 m
.52754 1.05856 L
s
.47959 1.01577 m
.52754 1.05856 L
s
.52754 1.05856 m
.54507 1.04521 L
s
.49749 .99537 m
.54507 1.04521 L
s
.41205 .94159 m
.46193 1.00513 L
s
.46193 1.00513 m
.47959 1.01577 L
s
.44804 .93109 m
.49749 .99537 L
s
.47959 1.01577 m
.49749 .99537 L
s
.42947 .97085 m
.47959 1.01577 L
s
.3868 .89346 m
.41205 .94159 L
s
.41205 .94159 m
.42947 .97085 L
s
.3624 .80663 m
.3868 .89346 L
s
.3624 .80663 m
.37704 .92361 L
s
.42289 .88245 m
.44804 .93109 L
s
.42947 .97085 m
.44804 .93109 L
s
.3868 .89346 m
.40356 .94752 L
s
.39831 .79475 m
.42289 .88245 L
s
.37704 .92361 m
.39831 .79475 L
s
.40356 .94752 m
.42947 .97085 L
s
.40356 .94752 m
.42289 .88245 L
s
.37704 .92361 m
.40356 .94752 L
s
.25 Mabswid
.73171 0 m
.9208 .29074 L
s
.9208 .29074 m
1 1.07583 L
s
1 1.07583 m
.78056 .82376 L
s
.78056 .82376 m
.73171 0 L
s
.08146 .25523 m
0 1.04559 L
s
0 1.04559 m
.78056 .82376 L
s
.78056 .82376 m
.73171 0 L
s
.73171 0 m
.08146 .25523 L
s
.08146 .25523 m
.73171 0 L
s
.09567 .24966 m
.10107 .25543 L
s
[(0.8)] .08486 .23812 .93699 1 Mshowa
.24096 .19263 m
.24614 .1986 L
s
[(0.9)] .2306 .18068 .86709 1 Mshowa
.39232 .13322 m
.39724 .1394 L
s
[(1)] .38246 .12085 .79718 1 Mshowa
.55014 .07127 m
.55479 .07767 L
s
[(1.1)] .54084 .05848 .72728 1 Mshowa
.71484 .00662 m
.71919 .01323 L
s
[(1.2)] .70616 -0.00659 .65738 1 Mshowa
.125 Mabswid
.12426 .23844 m
.12748 .24192 L
s
.15308 .22712 m
.15627 .23063 L
s
.18213 .21572 m
.1853 .21925 L
s
.21142 .20422 m
.21456 .20778 L
s
.27073 .18094 m
.27381 .18455 L
s
.30075 .16916 m
.3038 .17279 L
s
.33102 .15728 m
.33404 .16094 L
s
.36154 .1453 m
.36453 .14898 L
s
.42335 .12104 m
.42627 .12477 L
s
.45465 .10875 m
.45754 .11251 L
s
.48621 .09636 m
.48907 .10015 L
s
.51804 .08387 m
.52086 .08768 L
s
.58251 .05856 m
.58527 .06242 L
s
.61517 .04574 m
.61789 .04963 L
s
.64811 .03282 m
.65079 .03673 L
s
.68133 .01978 m
.68397 .02371 L
s
gsave
.33317 .05902 -85.7674 -13.8125 Mabsadd m
1 1 Mabs scale
currentpoint translate
0 17.8125 translate 1 -1 scale
/MISOfy
{
    /newfontname exch def
    /oldfontname exch def

    oldfontname findfont
    dup length dict begin
        {1 index /FID ne {def} {pop pop} ifelse} forall
        /Encoding ISOLatin1Encoding def
        currentdict
    end

    newfontname exch definefont pop
} def
63.000 11.250 moveto
%%IncludeResource: font Courier
%%IncludeFont: Courier
%%BeginResource: font Courier-MISO
%%BeginFont: Courier-MISO
/Courier /Courier-MISO MISOfy
%%EndFont
%%EndResource
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
63.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
%%IncludeResource: font Math2Mono
%%IncludeFont: Math2Mono
/Math2Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
69.000 11.250 moveto
(\\220) show
75.000 11.250 moveto
%%IncludeResource: font Math1Mono
%%IncludeFont: Math1Mono
/Math1Mono findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(w) show
81.000 12.750 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 7.125 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
(0) show
86.562 11.250 moveto
%%IncludeResource: font Courier-MISO
%%IncludeFont: Courier-MISO
/Courier-MISO findfont 10.000 scalefont
[1 0 0 -1 0 0 ] makefont setfont
0.000 0.000 0.000 setrgbcolor
0.000 0.000 rmoveto
1.000 setlinewidth
grestore
% End of Graphics
MathPictureEnd
\
\>"], "Graphics",
  ImageSize->{230, 287.938},
  ImageMargins->{{35, 0}, {0, 0}},
  ImageRegion->{{0, 1}, {0, 1}},
  ImageCache->GraphicsData["Bitmap", "\<\
CF5dJ6E]HGAYHf4PAg9QL6QYHg<PAVmbKF5d0`40004O0001Ib000`400?l00000o`00003oo`3Vc80P
0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000o`3Vc80P
0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000o`3Vc80P
0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000o`3Vc80P0>K<P000[@3Vc806000000@0i/b00P00
00040>K<P0H00000G03Vc8000;00i/b000<000000>K<P03Vc800103Vc802000000D0i/b000D00000
0>K<P03Vc800i/b00000001L0>K<P000/03Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800
i/b005d0i/b0002`0>K<P0030000003Vc800i/b000d0i/b00P00001M0>K<P000/03Vc8000`000000
i/b00>K<P00>0>K<P0800000G03Vc8000;00i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b0
0>K<P01J0>K<P000/03Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc800FP3Vc8000:h0i/b00`00000<0>K<P0D00000G@3Vc8000?l0i/b0803Vc8000?l0
i/b0803Vc8000?l0i/b0803Vc8000?l0i/b0803Vc8000<D0i/b00P00001H0>K<P000`P3Vc8030000
00030>K<P0000000000005L0i/b000300>K<P0<000000`3Vc802000005L0i/b0002n0>K<P0800000
0`3Vc8001P000000i/b00>K<P0000000i/b0000005H0i/b0001R0>K<P0800000803Vc806000000@0
i/b00P0000040>K<P0H000008@3Vc803000000P0i/b000@000000>K<P03Vc8000000E@3Vc80005<0
i/b000<000000>K<P03Vc8002`3Vc80010000000i/b00>K<P000000R0>K<P0030000003Vc800i/b0
00@0i/b00P0000070>K<P0030000003Vc800i/b001l0i/b00P00000;0>K<P0040000003Vc8000000
000005D0i/b0001:0>K<P0D000001@3Vc8000`000000i/b00>K<P0020>K<P0D000000`3Vc8001000
0000i/b00>K<P000000R0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800703Vc803
00000080i/b000<000000>K<P03Vc800203Vc8001@000000i/b00>K<P03Vc800000005@0i/b00019
0>K<P0040000003Vc800i/b000000080i/b000<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<
P03Vc80000000080i/b000@000000>K<P03Vc80000000P3Vc80010000000i/b00>K<P000000R0>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8006P3Vc80200000100i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P01A0>K<P000B@3Vc80010000000i/b00>K<P00000020>K<
P0030000003Vc800i/b000<0i/b000@000000>K<P03Vc80000000P3Vc80010000000i/b00>K<P000
00020>K<P0040000003Vc800i/b000000280i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b0
0>K<P00G0>K<P0<000004P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00540i/b0
00190>K<P0040000003Vc800i/b000000080i/b000<000000>K<P03Vc8000`3Vc80010000000i/b0
0>K<P00000020>K<P0040000003Vc800i/b0000000<0i/b00P00000S0>K<P0030000003Vc800i/b0
00d0i/b000<000000>K<P03Vc800503Vc80300000080i/b000<000000>K<P03Vc8003P3Vc8001000
0000i/b00>K<P00000040>K<P0030000003Vc800i/b000T0i/b00`0000050>K<P0800000103Vc806
000003<0i/b0001:0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8001@00
0000i/b00>K<P03Vc800000000@0i/b000<000000>K<P03Vc8009P3Vc8000`000000i/b00>K<P00=
0>K<P0030000003Vc800i/b00180i/b00P00000D0>K<P0<000000P3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b000L0i/b000@000000>K<P03Vc80000001@3Vc802000000L0i/b000<0
00000>K<P03Vc800<`3Vc80004/0i/b000D000000>K<P03Vc800i/b0000000060>K<P0050000003V
c800i/b00>K<P00000000`3Vc8000`000000i/b00>K<P00T0>K<P0<000003@3Vc80300000140i/b0
0`00000D0>K<P08000000`3Vc8000`000000i/b0000000040>K<P0800000203Vc8000`000000i/b0
0>K<P0020>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc800<`3Vc80005H0i/b000<0
00000>K<P03Vc800CP3Vc80200000080i/b000<000000>K<P03Vc800403Vc802000000D0i/b000<0
00000>K<P00000001P3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00c0>K<P000E`3Vc8000`000000i/b00>K<P01:
0>K<P0<000005P3Vc8000`000000i/b00>K<P0060>K<P08000001`3Vc8000`000000i/b00>K<P004
0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00c
0>K<P000XP3Vc802000001L0i/b00P0000090>K<P08000001`3Vc8000`000000i/b00>K<P0040>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00c0>K<
P000W`3Vc803000000030>K<P0000000i/b001@0i/b00P00000<0>K<P0030000003Vc800i/b000H0
i/b000<000000>K<P03Vc800103Vc80010000000i/b00>K<P000000>0>K<P0030000003Vc800i/b0
03<0i/b0002M0>K<P0800000603Vc802000000h0i/b000<000000>K<P03Vc8001P3Vc802000000D0
i/b01000000<0>K<P0<00000=@3Vc80009X0i/b00`00000I0>K<P0030000003Vc800i/b000h0i/b0
0P0000060>K<P0030000003Vc800000004d0i/b0002H0>K<P0<000006@3Vc80200000140i/b00P00
00090>K<P0030000003Vc800i/b004X0i/b0001[0>K<P0H00000903Vc803000000<0i/b000<00000
0>K<P03Vc800503Vc802000001<0i/b000<000000>K<P0000000203Vc8000`000000i/b00>K<P01:
0>K<P000KP3Vc8000`000000i/b00>K<P00R0>K<P08000006`3Vc802000001D0i/b00`0000090>K<
P0030000003Vc800i/b004T0i/b0001^0>K<P0030000003Vc800i/b001l0i/b01000000K0>K<P003
0000003Vc800i/b001@0i/b00P0000020>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03V
c800B03Vc80006h0i/b000<000000>K<P03Vc8007@3Vc802000001d0i/b00P00000F0>K<P0030000
003Vc80000000080i/b000<000000>K<P03Vc8001`3Vc802000004T0i/b0001^0>K<P0030000003V
c800i/b001X0i/b00`00000M0>K<P08000005P3Vc80200000080i/b000D000000>K<P03Vc800i/b0
000000090>K<P0030000003Vc800i/b003l0i/b00P0000060>K<P000KP3Vc8000`000000i/b00>K<
P00G0>K<P0@000007P3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b00080i/b000D0
00000>K<P03Vc800i/b00000000:0>K<P0030000003Vc800i/b002l0i/b000<000000>K<P03Vc800
2`3Vc80010000000i/b00>K<P00000050>K<P000KP3Vc8000`000000i/b00>K<P00E0>K<P0800000
803Vc802000001L0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b000L0i/b000<000000>K<P03Vc8007`3Vc805000000<0i/b01P0000030>K<P0030000
003Vc800i/b00080i/b01@0000030>K<P0040000003Vc800i/b0000000D0i/b0001/0>K<P0<00000
503Vc80300000200i/b00P00000G0>K<P08000001`3Vc8001@000000i/b00>K<P03Vc800000000X0
i/b000<000000>K<P03Vc8007@3Vc80010000000i/b00>K<P00000020>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8000`3Vc8001@000000i/b00>K<P03Vc80000000080i/b000@00000
0>K<P03Vc80000000P3Vc80010000000i/b00>K<P00000050>K<P000P@3Vc802000000030>K<P000
0000i/b001h0i/b00P00000H0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b001`0i/b000@000000>K<P03Vc8000000
0P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000@0i/b000@000000>K<P03Vc800
00000P3Vc80010000000i/b00>K<P00000020>K<P0040000003Vc800i/b0000000D0i/b0001n0>K<
P0<000008P3Vc8000`000000i/b00>K<P00G0>K<P0030000003Vc800i/b000P0i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b00>K<P0070>K<P08000007P3Vc80010000000i/b00>K<P0000002
0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800103Vc80010000000i/b00>K<P000
00020>K<P0040000003Vc800i/b0000000<0i/b00P0000060>K<P000O03Vc802000002<0i/b00P00
000H0>K<P08000002`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000P0i/b000<0
00000>K<P03Vc800703Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<0
00000>K<P03Vc800103Vc8001@000000i/b00>K<P03Vc800000000@0i/b000<000000>K<P03Vc800
2@3Vc80007T0i/b01000000R0>K<P08000006@3Vc8000`000000i/b00>K<P00;0>K<P0030000003V
c800i/b000<0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00L0>K<P0050000003V
c800i/b00>K<P00000001@3Vc8000`000000i/b00>K<P0050>K<P0050000003Vc800i/b00>K<P000
00000`3Vc8000`000000i/b00>K<P0090>K<P000M`3Vc802000002@0i/b00P00000J0>K<P0030000
003Vc800i/b000`0i/b000<000000>K<P03Vc8000P3Vc802000000/0i/b000<000000>K<P03Vc800
9P3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00140i/b0001d0>K<P0<000009@3V
c8000`000000i/b00>K<P00H0>K<P08000003`3Vc8001@000000i/b00>K<P03Vc80000000080i/b0
00<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00S0>K<P0<00000203Vc8000`000000i/b0
0>K<P00@0>K<P000LP3Vc803000002H0i/b00P00000I0>K<P0030000003Vc800i/b000l0i/b000@0
00000>K<P03Vc80000000`3Vc8000`000000i/b00>K<P0090>K<P0800000@P3Vc80003T0i/b00`00
00050>K<P0800000103Vc803000002D0i/b00`0000030>K<P0030000003Vc800i/b002<0i/b000<0
00000>K<P00000005`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800000000D0i/b000<0
00000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0100>K<P000>03Vc80010000000i/b00>K<P000
00050>K<P08000001`3Vc8000`000000i/b00>K<P00P0>K<P0800000:`3Vc80010000000i/b00>K<
P000000E0>K<P08000004`3Vc802000000H0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b0
0>K<P00o0>K<P000=`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000`0i/b000<0
00000>K<P03Vc800703Vc804000002/0i/b000D000000>K<P03Vc800i/b00000000D0>K<P0030000
003Vc800i/b001<0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00:0>K<P0030000
003Vc800i/b003h0i/b0000g0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002@3V
c804000001`0i/b00P00000_0>K<P0050000003Vc800i/b00>K<P00000004`3Vc8000`000000i/b0
0>K<P00C0>K<P0800000203Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000P0i/b0
0`0000050>K<P0800000103Vc80600000280i/b0000g0>K<P0030000003Vc800i/b00080i/b000<0
00000>K<P03Vc800203Vc8001@000000i/b00>K<P03Vc800000001T0i/b00`00000`0>K<P0030000
003Vc800i/b000<0i/b000<000000>K<P03Vc8003P3Vc802000001D0i/b000<000000>K<P0000000
203Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000H0i/b000@000000>K<P03Vc800
00001@3Vc802000000D0i/b000D000000>K<P03Vc800i/b00000000R0>K<P000=`3Vc8000`000000
i/b00>K<P0020>K<P0030000003Vc800i/b000P0i/b000D000000>K<P03Vc800i/b00000000F0>K<
P0<0000000<0i/b00000003Vc800;`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b0
00d0i/b000<000000>K<P03Vc8004`3Vc80200000080i/b000<000000>K<P03Vc8001`3Vc8000`00
0000i/b00>K<P0090>K<P0030000003Vc800000000H0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P00:0>K<P0030000003Vc800i/b002<0i/b0000h0>K<P0040000003Vc800i/b00000
00/0i/b000D000000>K<P03Vc800i/b00000000D0>K<P0800000=@3Vc8000`000000i/b00>K<P004
0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P004
0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc802000002<0i/b0000h0>K<
P0@00000303Vc80300000180i/b00`00000f0>K<P0030000003Vc800i/b000H0i/b000<000000>K<
P03Vc8002@3Vc802000001D0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0080>K<
P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000`0i/b00P00000R0>K<P000F`3Vc80200000080i/b000<000000>K<P03V
c800<`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03V
c800503Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03V
c800303Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8003@3Vc8000`000000i/b00>K<P00P0>K<P000F03Vc803000003X0i/b000<000000>K<P03Vc800
1`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc800
1P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000/0i/b00P0000040>K<P0040000
003Vc800i/b0000000/0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00P0>K<P000
EP3Vc802000003`0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0040>K<P0800000
5P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800
2P3Vc8000`000000i/b0000000040>K<P0@000002`3Vc805000002<0i/b0001C0>K<P0<0000000<0
i/b00000003Vc800>P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000<0i/b000<0
00000>K<P03Vc8005@3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000T0i/b000<0
00000>K<P03Vc800303Vc8000`000000i/b00>K<P00h0>K<P000C`3Vc80010000000i/b000000000
00100>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<
P00E0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<
P00<0>K<P0030000003Vc800i/b003P0i/b0001>0>K<P0<00000@@3Vc8000`000000i/b00>K<P00;
0>K<P0030000003Vc800i/b0008000005`3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800
i/b000T0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00g0>K<P0005@3Vc8030000
00D0i/b00P0000050>K<P0@00000903Vc802000000<0i/b000<000000>K<P03Vc800?@3Vc8000`00
0000i/b00>K<P00=0>K<P0800000603Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00X0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00f0>K<P000503Vc80010000000
i/b00>K<P00000050>K<P0800000103Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b0
01d0i/b0100000150>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8005P3Vc8000`00
0000i/b00>K<P00<0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc800303Vc8020000
03P0i/b0000C0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc8000`000000
i/b00>K<P0020>K<P0030000003Vc800i/b001`0i/b00`0000160>K<P0030000003Vc800i/b000h0
i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000/0
i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00e0>K<P0004`3Vc8000`000000i/b0
0>K<P0020>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8000P00000K0>K<P0<00000
B03Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800000001D0i/b000<000000>K<P03Vc800
3P3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc800
=03Vc80001<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0090>K<P0@000006@3V
c803000004/0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00000000D0>K<P0030000003V
c800i/b000l0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00=0>K<P0030000003V
c800i/b003@0i/b0000C0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800203Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b001@0i/b01000001;0>K<P0030000003Vc800
i/b000h0i/b000@000000>K<P03Vc80000004`3Vc8000`000000i/b00>K<P00@0>K<P0030000003V
c800i/b000`0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00c0>K<P000503Vc800
10000000i/b00>K<P000000;0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004@3V
c803000004h0i/b000<000000>K<P03Vc8003`3Vc80010000000i/b00>K<P000000B0>K<P0030000
003Vc800i/b00140i/b000<000000>K<P03Vc8002`3Vc802000000l0i/b00P00000e0>K<P000503V
c804000000`0i/b01000000B0>K<P0800000D@3Vc8000`000000i/b00>K<P00>0>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00B0>K<P0030000003V
c800i/b000/0i/b000<000000>K<P0000000403Vc8000`000000i/b00>K<P00b0>K<P000=`3Vc803
000000030>K<P0000000i/b004l0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00:
0>K<P0040000003Vc800i/b000000140i/b000<000000>K<P03Vc800<@3Vc80003D0i/b00P00001D
0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<
0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc800<@3Vc8000380i/b00`00001F0>K<
P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00:0>K<
P08000005`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8003`3Vc8000`000000i/b00>K<P00`0>K<P000<03Vc802000005P0i/b000<000000>K<P03V
c800403Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03V
c800603Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c8003`3Vc80200000340i/b0000/0>K<P0@00000F@3Vc8000`000000i/b00>K<P00@0>K<P0030000
003Vc800i/b000D0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00I0>K<P0030000
003Vc800i/b000H0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00?0>K<P0030000
003Vc800i/b002l0i/b0000[0>K<P0800000G03Vc8000`000000i/b00>K<P00@0>K<P0030000003V
c800i/b000D0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00J0>K<P0030000003V
c800i/b000D0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00@0>K<P0030000003V
c800i/b002h0i/b0000Y0>K<P08000000P3Vc8000`000000i/b00>K<P00N0>K<P0<00000=`3Vc800
0`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8001@3Vc800
0`000000i/b00>K<P00K0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8001`3Vc800
0`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000P0i/b00`0000050>K<P0800000103Vc804
000001<0i/b0000Y0>K<P08000007@3Vc80600000080i/b00P00000f0>K<P0030000003Vc800i/b0
0100i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
01`0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b0
0100i/b000<000000>K<P03Vc8001`3Vc80010000000i/b00>K<P00000050>K<P0800000203Vc800
0`000000i/b00>K<P00@0>K<P000:@3Vc8000`000000i/b00000000F0>K<P0H000002@3Vc8020000
03D0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
00T0i/b000<000000>K<P03Vc800403Vc802000000L0i/b000<000000>K<P03Vc8000P3Vc8000`00
0000i/b00>K<P00<0>K<P0030000003Vc800i/b00100i/b0000Y0>K<P080000000<0i/b00000003V
c8003P3Vc806000000l0i/b000<000000>K<P0000000=03Vc8000`000000i/b00>K<P00?0>K<P003
0000003Vc800i/b000P0i/b000D000000>K<P03Vc800i/b00000000P0>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b0
00@0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b0
0100i/b0000X0>K<P08000000`3Vc8000`000000i/b00>K<P0060>K<P0H000005@3Vc80010000000
i/b00>K<P000000b0>K<P0030000003Vc80000000100i/b000<000000>K<P03Vc800203Vc8001000
0000i/b00>K<P000000Q0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8002`3Vc800
0`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8000P3Vc800
0`000000i/b00>K<P00:0>K<P08000004`3Vc8000200i/b00`0000050>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P00000001@00000K0>K<P0050000003Vc800i/b00>K<P0000000<@3Vc800
0`000000i/b00000000?0>K<P0030000003Vc800i/b000X0i/b00P00000R0>K<P0050000003Vc800
i/b00>K<P00000003`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000<0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b00100i/b0000O
0>K<P0040000003Vc800i/b0000000D0i/b000<000000>K<P03Vc8000P3Vc80300000280i/b000D0
00000>K<P03Vc800i/b00000000`0>K<P0030000003Vc800000000l0i/b000<000000>K<P03Vc800
2P3Vc8000`000000i/b00>K<P00Q0>K<P0040000003Vc800i/b000000100i/b000<000000>K<P03V
c8004P3Vc8000`000000i/b00>K<P0030>K<P0040000003Vc800i/b0000000l0i/b000<000000>K<
P03Vc800403Vc80001h0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b00080i/b000@000000>K<P03Vc80000008@3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b002d0i/b000<000000>K<P00000003P3Vc8000`000000i/b00>K<P00;0>K<
P0030000003Vc800i/b00240i/b000<000000>K<P00000004@3Vc8000`000000i/b00>K<P00@0>K<
P0<000001@3Vc804000000/0i/b01000000C0>K<P0007P3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc80010000000i/b00>K<P000000P0>K<
P0030000003Vc800i/b000<0i/b00P00000]0>K<P0030000003Vc800000000h0i/b000<000000>K<
P03Vc8002P3Vc8000`000000i/b00000000R0>K<P0030000003Vc80000000180i/b000<000000>K<
P03Vc8004@3Vc802000002X0i/b0000N0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P0030>K<P0050000003Vc800i/b00>K<P0000000803Vc8000`00
0000i/b00>K<P0040>K<P0030000003Vc800i/b002X0i/b000<000000>K<P00000003P3Vc8000`00
0000i/b00>K<P00:0>K<P0030000003Vc80000000280i/b00P00000C0>K<P0030000003Vc800i/b0
00h0i/b00`0000000`3Vc80000000>K<P00Y0>K<P0007P3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b00080i/b000<000000>K<P03Vc800103Vc80010000000i/b00>K<P000000P0>K<
P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800:@3Vc8000`000000i/b00000000=0>K<
P0030000003Vc800i/b000/0i/b000<000000>K<P00000008P3Vc8000`000000i/b00>K<P00C0>K<
P0030000003Vc800i/b000X0i/b00`0000040>K<P0030000003Vc800i/b002P0i/b0000O0>K<P004
0000003Vc800i/b0000000D0i/b000<000000>K<P03Vc800103Vc8001@000000i/b00>K<P03Vc800
000001l0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00W0>K<P0050000003Vc800
i/b00>K<P0000000303Vc8000`000000i/b00>K<P00:0>K<P0040000003Vc800i/b000000280i/b0
00<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P0070>K<P0<000001`3Vc8000`000000i/b0
0>K<P00X0>K<P0007`3Vc804000000D0i/b000<000000>K<P03Vc8001@3Vc8001@000000i/b00>K<
P03Vc800000001l0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00V0>K<P0050000
003Vc800i/b00>K<P00000002`3Vc8000`000000i/b00>K<P00;0>K<P0050000003Vc800i/b00>K<
P0000000803Vc802000001D0i/b000<000000>K<P03Vc8001@3Vc802000000X0i/b000<000000>K<
P03Vc800:03Vc80002P0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b001`0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00U0>K<P005
0000003Vc800i/b00>K<P00000002`3Vc8000`000000i/b00>K<P00;0>K<P0050000003Vc800i/b0
0>K<P00000007`3Vc8000`000000i/b00000000F0>K<P0040000003Vc800i/b00>K<P0<00000303V
c8000`000000i/b00>K<P00X0>K<P000:03Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800
i/b00080i/b000<000000>K<P03Vc8006`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800
i/b002@0i/b000D000000>K<P03Vc800i/b00000000;0>K<P0030000003Vc800i/b000X0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00L0>K<P0050000003Vc800i/b00>K<P0000000
5@3Vc80400000100i/b000<000000>K<P03Vc8009`3Vc80002L0i/b000<000000>K<P03Vc8001`3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8002@3V
c8000`000000i/b00>K<P00S0>K<P0050000003Vc800i/b00>K<P00000002P3Vc8000`000000i/b0
0>K<P00;0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8006`3Vc8001@000000i/b0
0>K<P03Vc800000001<0i/b01000000B0>K<P0030000003Vc800i/b002L0i/b0000W0>K<P0030000
003Vc800i/b000P0i/b04P00000A0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800
8P3Vc8001@000000i/b00>K<P03Vc800000000X0i/b000<000000>K<P03Vc8002`3Vc8000`000000
i/b00>K<P0030>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P00>0>K<P0<000000`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b002L0
i/b0000W0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P0080>K<P18000002`3Vc8000`000000i/b00>K<P00R0>K<P0050000003Vc800i/b00>K<P000
00002@3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03V
c8006@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000/0i/b00`0000050>K<P080
00004P3Vc8000`000000i/b00>K<P00W0>K<P0009`3Vc8000`000000i/b00>K<P0090>K<P0030000
003Vc800i/b000@0i/b000<000000>K<P03Vc800603Vc802000000X0i/b000<000000>K<P03Vc800
8@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800
2`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b001T0i/b000<000000>K<P03Vc800
0`3Vc8000`000000i/b00>K<P0080>K<P0<00000203Vc8000`000000i/b00000000A0>K<P0030000
003Vc800i/b002L0i/b0000W0>K<P08000002`3Vc8000`000000i/b00>K<P0040>K<P0030000003V
c800i/b001P0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00Q0>K<P0030000003V
c800i/b000<0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00<0>K<P0030000003V
c800i/b000D0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P0040>K<P0030000003V
c800i/b000D0i/b00`00000:0>K<P0040000003Vc800i/b000000140i/b000<000000>K<P03Vc800
9`3Vc80002L0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0050>K<P0030000003V
c800i/b001L0i/b00P0000090>K<P08000008P3Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b000D0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P0060>K<P0030000003V
c800i/b001H0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0020>K<P0<000003@3V
c80010000000i/b00>K<P000000A0>K<P0030000003Vc800i/b002L0i/b0000W0>K<P0030000003V
c800i/b000/0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00F0>K<P08000002P3V
c8000`000000i/b00>K<P00P0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8001@3V
c8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8005@3V
c8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b0008000003`3Vc8000`000000i/b00>K<
P0020>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8009`3Vc80002L0i/b000<00000
0>K<P03Vc800303Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b001D0i/b000<00000
0>K<P00000002@3Vc8000`000000i/b00>K<P00P0>K<P0030000003Vc800i/b000<0i/b000<00000
0>K<P03Vc800103Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000L0i/b000<00000
0>K<P03Vc800503Vc8000`000000i/b00>K<P0060>K<P0<000004@3Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8009`3Vc80002L0i/b000<000000>K<
P03Vc800303Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b001D0i/b00P0000090>K<
P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P0040>K<
P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00C0>K<
P0030000003Vc800i/b000@0i/b01000000B0>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8003P3Vc8000`000000i/b00>K<P00W0>K<P0009P3Vc8000`000000i/b00>K<P00>0>K<P003
0000003Vc800i/b000H0i/b000<000000>K<P03Vc800503Vc8000`000000i/b0000000080>K<P003
0000003Vc800i/b00200i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b000`0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00B0>K<P003
0000003Vc800i/b00080i/b00`0000030>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03V
c8001@3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b002H0i/b0000V0>K<P0030000
003Vc800i/b000h0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00C0>K<P0030000
003Vc800000000P0i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P0050>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P0080>K<P0030000
003Vc800i/b00140i/b000<000000>K<P03Vc8000`0000060>K<P0030000003Vc800i/b000l0i/b0
00<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b002H0i/b0
000V0>K<P0030000003Vc800i/b000l0i/b00P0000080>K<P0030000003Vc800i/b00180i/b000@0
00000>K<P03Vc80000001`3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b000D0i/b0
00D000000>K<P03Vc800i/b00000000?0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03V
c800403Vc803000000T0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P0060>K<P003
0000003Vc800i/b000h0i/b000<000000>K<P03Vc8009P3Vc80002H0i/b000<000000>K<P03Vc800
3`3Vc8000`000000i/b000000003000000D0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b0
000000070>K<P0800000803Vc8000`000000i/b00>K<P0050>K<P0050000003Vc800i/b00>K<P000
00003P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000d0i/b00`00000<0>K<P003
0000003Vc800i/b000h0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00=0>K<P003
0000003Vc800i/b002H0i/b0000V0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc800
0P3Vc803000000<0i/b000<000000>K<P03Vc8004@3Vc80010000000i/b00>K<P00000060>K<P080
0000803Vc8000`000000i/b00>K<P0050>K<P0050000003Vc800i/b00>K<P00000003P3Vc8000`00
0000i/b00>K<P00:0>K<P0030000003Vc800i/b000X0i/b00`0000000`3Vc80000000>K<P00<0>K<
P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00=0>K<
P0030000003Vc800i/b002H0i/b0000V0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03V
c8001@3Vc803000000030>K<P0000000i/b00140i/b000@000000>K<P03Vc80000001P3Vc8020000
0200i/b000<000000>K<P03Vc8001@3Vc80010000000i/b00>K<P000000?0>K<P0030000003Vc800
i/b000X0i/b000<000000>K<P03Vc800203Vc802000000@0i/b000<000000>K<P03Vc8002`3Vc800
0`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8003@3Vc800
0`000000i/b00>K<P00V0>K<P0009P3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b0
00L0i/b01000000@0>K<P0050000003Vc800i/b00>K<P00000001@3Vc80200000200i/b000<00000
0>K<P03Vc8001@3Vc80010000000i/b00>K<P000000>0>K<P0030000003Vc800i/b000`0i/b000<0
00000>K<P03Vc800103Vc803000000D0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<
P00;0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<
P00V0>K<P0009P3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000T0i/b000<00000
0>K<P00000000P00000>0>K<P0040000003Vc800i/b0000000H0i/b000<000000>K<P03Vc8007P3V
c8000`000000i/b00>K<P0060>K<P08000003`3Vc8000`000000i/b00>K<P00<0>K<P0040000003V
c800i/b00>K<P0<000001`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000X0i/b0
00<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b002H0i/b0
000V0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8002@3Vc80010000000i/b00>K<
P03Vc804000000X0i/b000D000000>K<P03Vc800i/b0000000050>K<P0030000003Vc800i/b001d0
i/b000<000000>K<P03Vc8001`3Vc802000000l0i/b000<000000>K<P03Vc800303Vc804000000T0
i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000`0
i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00V0>K<P0009P3Vc8000`000000i/b0
0>K<P00B0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc800103Vc803000000L0i/b0
00D000000>K<P03Vc800i/b0000000050>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03V
c8001`3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000/0i/b01000000;0>K<P003
0000003Vc800i/b000l0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00=0>K<P003
0000003Vc800i/b000/0i/b000<000000>K<P03Vc8009P3Vc80002D0i/b000<000000>K<P03Vc800
4`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000H0i/b00`0000040>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8000P3Vc802000001h0i/b000<000000>K<P03Vc800
1`3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000P0i/b00`0000030>K<P0030000
003Vc800i/b000P0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P0090>K<P0030000
003Vc800i/b000d0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00U0>K<P0009@3V
c802000001D0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P0080>K<P0@0000000<0
i/b00000003Vc8000P3Vc8000`000000i/b00>K<P0020>K<P08000007P3Vc8000`000000i/b00>K<
P0070>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8001@3Vc803000000H0i/b000<0
00000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000P0i/b000<0
00000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b002D0i/b0000U
0>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00;
0>K<P0800000103Vc80010000000i/b00>K<P03Vc802000001h0i/b000<000000>K<P03Vc8001`3V
c8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000<0i/b00`0000090>K<P0030000003V
c800i/b000L0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P0070>K<P0030000003V
c800i/b00100i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00U0>K<P0009@3Vc800
0`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8002`3Vc800
0`000000i/b00>K<P0020>K<P0040000003Vc800i/b00>K<P08000007P3Vc8000`000000i/b00>K<
P0070>K<P08000003@3Vc8000`000000i/b00>K<P003000000d0i/b000<000000>K<P03Vc8001@3V
c8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800403V
c8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b002D0i/b0000U0>K<P0030000003Vc800
i/b001D0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800
i/b00080i/b000<000000>K<P03Vc8000P00000M0>K<P0030000003Vc800i/b000L0i/b000<00000
0>K<P00000003@3Vc80300000100i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00C
0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00:
0>K<P0030000003Vc800i/b002D0i/b0000U0>K<P0030000003Vc800i/b001H0i/b000<000000>K<
P03Vc8003@3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8000P00000M0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P00000002`3Vc8030000
0180i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00D0>K<P0030000003Vc800i/b0
00H0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b0
02D0i/b0000U0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc8003P3Vc8000`000000
i/b00>K<P0090>K<P0800000103Vc8001@000000i/b00000003Vc800000001`0i/b000<000000>K<
P03Vc8001`3Vc8000`000000i/b0000000080>K<P0<0000000<0i/b00000003Vc8004`3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc8001@3Vc8000`00
0000i/b00>K<P00C0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8009@3Vc80002D0
i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000P0
i/b00P0000040>K<P0030000003Vc800i/b000800000703Vc8000`000000i/b00>K<P0070>K<P003
0000003Vc800000000D0i/b00`0000040>K<P0030000003Vc800i/b00180i/b000D000000>K<P03V
c800i/b00000000G0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800503Vc8000`00
0000i/b00>K<P0090>K<P0030000003Vc800i/b002D0i/b0000U0>K<P0030000003Vc800i/b001L0
i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000<0
i/b000@000000>K<P00000000000703Vc8000`000000i/b00>K<P0070>K<P0050000003Vc800i/b0
0000003Vc8000`0000060>K<P0030000003Vc800i/b001<0i/b000@000000>K<P03Vc8000000603V
c8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8002@3V
c8000`000000i/b00>K<P00U0>K<P000903Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800
i/b00100i/b000<000000>K<P03Vc8001`3Vc802000000@0i/b000@000000>K<P00000000000703V
c8000`000000i/b00>K<P0070>K<P0030000003Vc8000000008000002@3Vc8000`000000i/b00>K<
P00C0>K<P0030000003Vc800000001T0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<
P00F0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8009@3Vc80002@0i/b000<00000
0>K<P03Vc8006@3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000H0i/b00P000005
0>K<P0<00000703Vc8000`000000i/b00>K<P0060>K<P0<0000000<0i/b00000003Vc8002@3Vc800
0`000000i/b00>K<P00D0>K<P08000006@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800
i/b001D0i/b000<000000>K<P00000002`3Vc8000`000000i/b00>K<P00T0>K<P000903Vc8000`00
0000i/b00>K<P00I0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8001@3Vc8020000
00D0i/b00`00000K0>K<P0030000003Vc800i/b000@0i/b0100000030>K<P0030000003Vc800i/b0
00L0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P00H0>K<P0030000003Vc800i/b0
0080i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b00000000;0>K<P0030000003Vc800i/b0
02@0i/b0000T0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8004@3Vc8000`000000
i/b00>K<P0050>K<P08000001@3Vc802000001/0i/b000<000000>K<P03Vc8000P3Vc802000000<0
i/b000D000000>K<P03Vc800i/b0000000090>K<P0030000003Vc800i/b001D0i/b000<000000>K<
P03Vc800603Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001D0i/b000D000000>K<
P03Vc800i/b00000000:0>K<P0030000003Vc800i/b002@0i/b0000T0>K<P0030000003Vc800i/b0
01X0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P0040>K<P08000001@3Vc8000`00
0000i/b00000000J0>K<P0030000003Vc8000000008000001@3Vc8000`000000i/b00>K<P0020>K<
P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00000000J0>K<
P0040000003Vc800i/b0000001P0i/b000D000000>K<P03Vc800i/b00000000:0>K<P0030000003V
c800i/b002@0i/b0000T0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8004P3Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800000000@0i/b00`00000I0>K<P0<00000203Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8005@3Vc800
0`000000i/b00000000J0>K<P0040000003Vc800i/b0000001L0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b002@0i/b0000T0>K<P0030000003Vc800
i/b001/0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
000000@0i/b00`00000F0>K<P0<0000000<0i/b00000003Vc800203Vc8000`000000i/b00>K<P002
0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00000000J
0>K<P0030000003Vc800000001P0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P007
0>K<P0030000003Vc800i/b002@0i/b0000T0>K<P0030000003Vc800i/b001/0i/b00P00000D0>K<
P0030000003Vc800i/b000<0i/b00P0000040>K<P0030000003Vc800000001<0i/b00`0000040>K<
P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0050>K<
P0030000003Vc800i/b001D0i/b000<000000>K<P00000006P3Vc802000001P0i/b000<000000>K<
P03Vc800103Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b002@0i/b0000T0>K<P003
0000003Vc800i/b001`0i/b00`00000C0>K<P0030000003Vc800i/b00080i/b000<000000>K<P000
0000103Vc80200000100i/b00`0000070>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b001@0i/b000D000000>K<P03V
c800i/b00000000I0>K<P0800000603Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b0
00H0i/b000<000000>K<P03Vc800903Vc80002<0i/b00P00000N0>K<P0040000003Vc800i/b00000
01<0i/b000L000000>K<P03Vc800i/b00000003Vc800000000@0i/b00P00000=0>K<P0<000002@3V
c8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800103V
c8000`000000i/b00>K<P00E0>K<P0050000003Vc800i/b00>K<P00000006@3Vc8000`000000i/b0
0>K<P00F0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b0
0>K<P00T0>K<P0008`3Vc8000`000000i/b00>K<P00N0>K<P0040000003Vc800i/b0000001<0i/b0
00H000000>K<P03Vc80000000>K<P00000040>K<P08000002P3Vc803000000`0i/b000<000000>K<
P03Vc8001`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8005@3Vc8001@000000i/b00>K<P03Vc800000001T0i/b000<000000>K<P03Vc8005P3Vc800
0`000000i/b00>K<P0070>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800903Vc800
02<0i/b000<000000>K<P03Vc8007P3Vc80010000000i/b00>K<P03Vc80200000180i/b000H00000
0>K<P03Vc80000000>K<P00000030>K<P0<000001P3Vc803000000l0i/b000<000000>K<P03Vc800
1`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800
5@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b001D0i/b00P00000G0>K<P0030000
003Vc800i/b000P0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00S0>K<P0008`3V
c8000`000000i/b00>K<P00N0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800403V
c8001@000000i/b00000003Vc800000000<0i/b000<000000>K<P0000000103Vc80200000180i/b0
00<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00080i/b0
00<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b001D0i/b0
0P00000G0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b0
0>K<P00S0>K<P0008`3Vc8000`000000i/b00>K<P00O0>K<P0030000003Vc800i/b000<0i/b000<0
00000>K<P03Vc800403Vc80200000080i/b000L000000>K<P03Vc80000000>K<P0000000i/b000<0
0000503Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c800503Vc8000`000000i/b00000000F0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03V
c8001@3Vc8000`000000i/b00>K<P00S0>K<P0008`3Vc8000`000000i/b00>K<P00O0>K<P0030000
003Vc800i/b000@0i/b00P00000A0>K<P0040000003Vc800i/b000000080i/b01000000G0>K<P003
0000003Vc800i/b000H0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b001D0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00B0>K<P004
0000003Vc800i/b0000001H0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0050>K<
P0030000003Vc800i/b002<0i/b0000S0>K<P0030000003Vc800i/b00200i/b000<000000>K<P03V
c8001@3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800000000<0000000<0i/b00000003V
c8005`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000H0i/b000@000000>K<P03V
c80000005`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00180i/b000@000000>K<
P03Vc80000005@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000@0i/b000<00000
0>K<P03Vc8008`3Vc80002<0i/b000<000000>K<P03Vc800803Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800i/b000h0i/b010000000103Vc80000000>K<P000000G0>K<P0030000003Vc800
i/b000L0i/b000<000000>K<P03Vc8001P3Vc80010000000i/b00>K<P000000G0>K<P0030000003V
c800i/b000D0i/b000<000000>K<P03Vc8004@3Vc8001@000000i/b00>K<P03Vc800000001D0i/b0
00<000000>K<P03Vc800303Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b002<0i/b0
000S0>K<P0030000003Vc800i/b00240i/b000<000000>K<P03Vc8001P3Vc802000000h0i/b00P00
0000103Vc80000000>K<P03Vc803000001H0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b0
0>K<P0060>K<P0040000003Vc800i/b0000001L0i/b000<000000>K<P03Vc8001@3Vc8000`000000
i/b00>K<P00A0>K<P0050000003Vc800i/b00>K<P0000000503Vc8000`000000i/b00>K<P00=0>K<
P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8008`3Vc80002<0i/b000<000000>K<P03V
c8008@3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000/0i/b00P000000103Vc800
00000>K<P03Vc803000001H0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800000001P0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00?0>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P00>0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8008`3Vc80002<0i/b000<000000>K<P03V
c8008@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000/0i/b000D000000>K<P03V
c80000000>K<P003000001H0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800000001L0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00?0>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00?0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8008`3Vc8000280i/b000<000000>K<P03V
c8008`3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000X0i/b000P000000>K<P03V
c80000000>K<P0000000i/b0000001H0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<
P0070>K<P08000005`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000h0i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b00100i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00S0>K<P0008P3Vc8000`000000i/b00>K<P00S
0>K<P0030000003Vc800i/b000X0i/b00P00000:0>K<P0040000003Vc800i/b00>K<P080000000<0
i/b00000003Vc8005@3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000P0i/b000<0
00000>K<P03Vc8005P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000`0i/b000<0
00000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b00140i/b000<0
00000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00R0>K<P0008P3Vc8000`000000i/b00>K<P00T
0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8001`3Vc80010000000i/b00>K<P03V
c802000000030>K<P0000000i/b001D0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<
P0080>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<
P00<0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<
P00B0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8008P3Vc8000280i/b000<00000
0>K<P03Vc800903Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000H0i/b00P000002
0>K<P080000000<0i/b0000000000000503Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800
i/b000P0i/b000<000000>K<P03Vc8005@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800
i/b000/0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800
i/b001<0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00R0>K<P0008P3Vc8000`00
0000i/b00>K<P00T0>K<P0030000003Vc800i/b000d0i/b00P0000060>K<P08000000`3Vc8001000
0000i/b000000000000D0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800203Vc800
0`000000i/b00>K<P00E0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8002P3Vc800
0`000000i/b00>K<P0060>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8004`3Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b00280i/b0000R0>K<P0030000003Vc800i/b0
02D0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P0030>K<P08000000`3Vc8001000
0000i/b000000000000D0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8001`3Vc800
0`000000i/b00000000F0>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8002@3Vc800
0`000000i/b00>K<P0070>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc8004`3Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800i/b00280i/b0000Q0>K<P0<000009P3Vc8000`00
0000i/b00>K<P00?0>K<P0030000003Vc800i/b00080i/b00P0000030>K<P0040000003Vc8000000
000001@0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800
000001D0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800
i/b000P0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800
i/b000<0i/b000<000000>K<P03Vc8008P3Vc8000280i/b000<000000>K<P03Vc8009P3Vc8000`00
0000i/b00>K<P00?0>K<P08000000P3Vc8000`000000i/b0000000030>K<P0<00000503Vc8000`00
0000i/b00>K<P0070>K<P0030000003Vc800i/b000L0i/b000<000000>K<P00000005@3Vc8000`00
0000i/b00>K<P00;0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800203Vc8000`00
0000i/b00>K<P00<0>K<P0030000003Vc800i/b001<0i/b000<000000>K<P03Vc800103Vc8000`00
0000i/b00>K<P00R0>K<P0002@3Vc803000000D0i/b00P0000040>K<P0H000001@3Vc8000`000000
i/b00>K<P00V0>K<P0030000003Vc800i/b00140i/b00P0000020>K<P0070000003Vc800i/b00>K<
P0000000i/b00000000D0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800203Vc800
0`000000i/b00000000E0>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8001P3Vc800
0`000000i/b00>K<P0090>K<P0030000003Vc800i/b000`0i/b000<000000>K<P03Vc8004`3Vc800
0`000000i/b00>K<P0040>K<P0030000003Vc800i/b00280i/b000080>K<P0040000003Vc800i/b0
000000D0i/b00P0000050>K<P0050000003Vc800i/b00>K<P0000000103Vc8000`000000i/b00>K<
P00X0>K<P0030000003Vc800i/b00140i/b000@000000>K<P03Vc80000000`3Vc804000001<0i/b0
00<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0080>K<P0040000003Vc800i/b0000001@0
i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000T0
i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000D0
i/b000<000000>K<P03Vc8008P3Vc80000L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P00:0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800:03Vc8000`000000i/b0
0>K<P00A0>K<P0@000000`3Vc80400000180i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b0
0>K<P0080>K<P0040000003Vc800i/b0000001<0i/b000<000000>K<P03Vc8003@3Vc8000`000000
i/b00>K<P0050>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8002`3Vc8000`000000
i/b00>K<P00C0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8008P3Vc80000L0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00;0>K<P08000001@3Vc8000`000000i/b0
0>K<P00X0>K<P08000004P3Vc8000`000000i/b00>K<P00200000080i/b01000000B0>K<P0030000
003Vc800i/b000L0i/b000<000000>K<P03Vc8001`3Vc8001@000000i/b00>K<P03Vc800000001<0
i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000X0
i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000L0
i/b000<000000>K<P03Vc8008@3Vc80000L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b0
0>K<P00<0>K<P0800000103Vc8000`000000i/b00>K<P00Y0>K<P08000004@3Vc8001@000000i/b0
0>K<P03Vc80000000080i/b000@000000>K<P000000000004P3Vc8000`000000i/b00>K<P0070>K<
P0030000003Vc800i/b000L0i/b000D000000>K<P03Vc800i/b00000000C0>K<P0030000003Vc800
i/b000h0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800
i/b000X0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800
i/b00240i/b000070>K<P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8003@3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b002T0i/b000<000000>K<P0000000403Vc8001@00
0000i/b00>K<P03Vc80000000080i/b000@000000>K<P000000000004P3Vc8000`000000i/b00>K<
P0070>K<P0030000003Vc800i/b000L0i/b000D000000>K<P03Vc800i/b00000000B0>K<P0030000
003Vc800i/b000l0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<0>K<P0030000
003Vc800i/b000T0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P0080>K<P0030000
003Vc800i/b00240i/b000080>K<P0040000003Vc800i/b0000000/0i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b002X0i/b000<000000>K<P0000000
3`3Vc8000`000000i/b00>K<P0020>K<P0040000003Vc80000000>K<P08000004P3Vc8000`000000
i/b00>K<P0060>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P00?0>K<P0030000003Vc800i/b00100i/b000D000000>K<P03Vc800i/b00000000>0>K<
P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P0080>K<
P0030000003Vc800i/b00240i/b000080>K<P0@000002`3Vc805000000D0i/b000<000000>K<P03V
c800:P3Vc8000`000000i/b00000000?0>K<P0030000003Vc800i/b00080i/b000@000000>K<P000
0000i/b00`00000A0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800203Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800403Vc8001000
0000i/b00>K<P000000?0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8004`3Vc800
0`000000i/b00>K<P0090>K<P0030000003Vc800i/b00240i/b0000Q0>K<P0030000003Vc800i/b0
02X0i/b000@000000>K<P03Vc80000003P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
00000080i/b00P00000A0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800203Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800403Vc800
10000000i/b00>K<P000000?0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8004`3V
c8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00240i/b0000Q0>K<P0030000003Vc800
i/b002/0i/b000@000000>K<P03Vc80000003@3Vc8000`000000i/b00>K<P0020>K<P080000000<0
i/b00000003Vc8000P00000@0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8001`3V
c8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8004@3V
c8000`000000i/b00000000A0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8004`3V
c8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00240i/b0000Q0>K<P0030000003Vc800
i/b002/0i/b000D000000>K<P03Vc800i/b00000000<0>K<P0030000003Vc800i/b000<0i/b000@0
00000>K<P0000000i/b00P00000@0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800
1`3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800
4P3Vc80200000140i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00C0>K<P0030000
003Vc800i/b000X0i/b000<000000>K<P03Vc8008@3Vc8000200i/b000<000000>K<P03Vc800;@3V
c8001@000000i/b00>K<P03Vc800000000/0i/b000<000000>K<P03Vc8000`3Vc80010000000i/b0
0000003Vc80200000100i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0070>K<P003
0000003Vc800i/b000@0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00B0>K<P003
0000003Vc800i/b00100i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00C0>K<P003
0000003Vc800i/b000/0i/b000<000000>K<P03Vc8008@3Vc8000200i/b000<000000>K<P03Vc800
;@3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800
0`3Vc803000000030>K<P000000000000100i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b0
0>K<P0070>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b0
0>K<P00B0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b0
0>K<P00C0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8008@3Vc8000200i/b000<0
00000>K<P03Vc800;P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000L0i/b000<0
00000>K<P03Vc8000`3Vc803000000040>K<P00000000000000000l0i/b000<000000>K<P03Vc800
1P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc800
303Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc80000000140i/b000<000000>K<P03Vc800
103Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800
803Vc8000200i/b000<000000>K<P03Vc800;P3Vc8000`000000i/b00>K<P0030>K<P0030000003V
c800i/b000H0i/b000<000000>K<P03Vc800103Vc802000000040>K<P0000000i/b0000000l0i/b0
00<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000@0i/b0
00<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc80000000140i/b0
00<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b000d0i/b0
00<000000>K<P03Vc800803Vc8000200i/b000<000000>K<P03Vc800;P3Vc8000`000000i/b00>K<
P0040>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800103Vc802000000040>K<P000
0000i/b0000000l0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0070>K<P0030000
003Vc800i/b000H0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00B0>K<P0030000
003Vc80000000140i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000
003Vc800i/b000h0i/b000<000000>K<P03Vc800803Vc8000200i/b00P00000`0>K<P0030000003V
c800i/b000@0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0040>K<P08000000P3V
c802000000h0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0070>K<P0030000003V
c800i/b000H0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P00C0>K<P0040000003V
c800i/b000000100i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00C0>K<P0030000
003Vc800i/b000h0i/b000<000000>K<P03Vc800803Vc8000200i/b000<000000>K<P03Vc800;`3V
c8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8001@3V
c8000`000000i/b00>K<P002000000h0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<
P0070>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<
P00B0>K<P0050000003Vc800i/b00>K<P0000000403Vc8000`000000i/b00>K<P0020>K<P0030000
003Vc800i/b001<0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00P0>K<P000803V
c8000`000000i/b00>K<P00`0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8000`3V
c8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000<000003@3Vc8000`000000i/b00>K<
P0070>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<
P00:0>K<P0030000003Vc800i/b00180i/b000D000000>K<P03Vc800i/b00000000@0>K<P0030000
003Vc800i/b00080i/b000<000000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00?0>K<P0030000
003Vc800i/b00200i/b0000P0>K<P0030000003Vc800i/b00300i/b000<000000>K<P03Vc8001@3V
c8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000D0i/b00P000000103Vc80000000000
0000000=0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800203Vc8000`000000i/b0
0>K<P0070>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b0
0>K<P0020>K<P0030000003Vc800i/b000d0i/b000D000000>K<P03Vc800i/b00000000E0>K<P003
0000003Vc800i/b00100i/b000<000000>K<P03Vc800803Vc80001l0i/b000<000000>K<P03Vc800
<@3Vc8000`000000i/b00>K<P0060>K<P0050000003Vc800i/b00>K<P00000001`3Vc80200000004
0>K<P0000000i/b0000000d0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0080>K<
P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00B0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8003@3Vc8001@000000i/b00>K<P03Vc800
000001D0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00P0>K<P0007`3Vc8000`00
0000i/b00>K<P00b0>K<P0030000003Vc800i/b000H0i/b000@000000>K<P03Vc8000000203Vc800
1@000000i/b00000003Vc800000000d0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<
P0070>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<
P00B0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc8003@3Vc80010000000i/b00>K<
P000000E0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800803Vc80001l0i/b000<0
00000>K<P03Vc800<P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800000000P0i/b00`00
00000`3Vc80000000000000<0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8001`3V
c8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8004P3V
c8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b000`0i/b000@000000>K<P03Vc8000000
5@3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b00200i/b0000O0>K<P0030000003V
c800i/b003<0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0070>K<P0<0000000<0
i/b00000000000002`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000L0i/b000<0
00000>K<P03Vc8002@3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b00140i/b000<0
00000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800000001D0i/b000<0
00000>K<P03Vc8004`3Vc8000`000000i/b00>K<P00O0>K<P0007`3Vc8000`000000i/b00>K<P00c
0>K<P0030000003Vc800i/b000L0i/b00P0000080>K<P080000000@0i/b000000000000000002`3V
c8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8002@3V
c8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8001@3V
c8000`000000i/b00>K<P00<0>K<P0030000003Vc800000001D0i/b000<000000>K<P03Vc8004`3V
c8000`000000i/b00>K<P00O0>K<P0007`3Vc8000`000000i/b00>K<P00d0>K<P0030000003Vc800
i/b000H0i/b000<000000>K<P00000001`3Vc806000000/0i/b000<000000>K<P03Vc8001`3Vc800
0`000000i/b00>K<P0070>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8001P3Vc800
0`000000i/b00>K<P00B0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8002`3Vc802
000001D0i/b000<000000>K<P03Vc800503Vc8000`000000i/b00>K<P00O0>K<P0007`3Vc8000`00
0000i/b00>K<P00d0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P00000001`3Vc8040000
00030>K<P0000000i/b000X0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0080>K<
P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00B0>K<
P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00C0>K<
P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc8007`3Vc80001l0i/b000<000000>K<P03V
c800=03Vc802000000L0i/b000@000000>K<P03Vc80000001P3Vc804000000030>K<P00000000000
00X0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b0
00X0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b0
00L0i/b000<000000>K<P03Vc8002`3Vc802000001@0i/b000<000000>K<P03Vc8005@3Vc8000`00
0000i/b00>K<P00O0>K<P0007`3Vc8000`000000i/b00>K<P00e0>K<P08000001P3Vc8001@000000
i/b00>K<P03Vc800000000H0i/b00`0000000`3Vc80000000000000:0>K<P0030000003Vc800i/b0
00H0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b0
00@0i/b000<000000>K<P03Vc8004P3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b0
00X0i/b00P00000D0>K<P0030000003Vc800i/b001D0i/b000<000000>K<P03Vc8007`3Vc80001l0
i/b000<000000>K<P03Vc800=@3Vc802000000H0i/b000<000000>K<P03Vc8000P3Vc8000`000000
i/b00>K<P0030>K<P0<0000000<0i/b00000000000002@3Vc8000`000000i/b00>K<P0070>K<P003
0000003Vc800i/b000L0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P0040>K<P003
0000003Vc800i/b00180i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P0090>K<P003
0000003Vc800000001<0i/b000<000000>K<P03Vc8005P3Vc8000`000000i/b00>K<P00O0>K<P000
7P3Vc8000`000000i/b00>K<P00g0>K<P08000001@3Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b00080i/b00`0000000`3Vc8000000000000090>K<P0030000003Vc800i/b000L0i/b0
00<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000@0i/b0
00<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000P0i/b0
00<000000>K<P00000004`3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b001l0i/b0
000N0>K<P0030000003Vc800i/b003L0i/b000<000000>K<P0000000103Vc8000`000000i/b00>K<
P0040>K<P0040000003Vc800i/b00>K<P0H000002@3Vc8000`000000i/b00>K<P0070>K<P0030000
003Vc800i/b000L0i/b000<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b00180i/b000<000000>K<P03Vc8002P3Vc8000`000000i/b00>K<P0070>K<P0040000
003Vc800i/b000000180i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b00>K<P00O0>K<P000
7P3Vc8000`000000i/b00>K<P00g0>K<P0040000003Vc800i/b0000000<0i/b000<000000>K<P03V
c8001@3Vc8001@000000i/b00>K<P0000000i/b00080000000<0i/b0000000000000203Vc8000`00
0000i/b00>K<P0060>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8003@3Vc8000`00
0000i/b00>K<P0020>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc8002P3Vc8000`00
0000i/b00>K<P0070>K<P0040000003Vc800i/b000000180i/b000<000000>K<P03Vc8005`3Vc800
0`000000i/b00>K<P00O0>K<P0007P3Vc8000`000000i/b00>K<P00h0>K<P0030000003Vc8000000
00<0i/b000<000000>K<P03Vc8001P3Vc80010000000i/b00000003Vc802000000030>K<P0000000
000000P0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800
i/b000d0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800
i/b000/0i/b000<000000>K<P03Vc8001@3Vc8001@000000i/b00>K<P03Vc80000000180i/b000<0
00000>K<P03Vc800603Vc8000`000000i/b00>K<P00N0>K<P0007P3Vc802000003T0i/b000@00000
0>K<P03Vc80000000P3Vc8000`000000i/b00>K<P0070>K<P080000000<0i/b00000000000000`00
00080>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<
P00=0>K<P0050000003Vc800i/b00>K<P0000000503Vc8000`000000i/b00>K<P00<0>K<P0030000
003Vc800i/b000D0i/b000D000000>K<P03Vc800i/b00000000A0>K<P0030000003Vc800i/b001T0
i/b000<000000>K<P03Vc8007P3Vc80001h0i/b000<000000>K<P03Vc800>@3Vc8001P000000i/b0
0>K<P0000000i/b0000000X0i/b000<000000>K<P03Vc800100000080>K<P0030000003Vc800i/b0
00H0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00=0>K<P0050000003Vc800i/b0
0>K<P0000000503Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b000@0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b001T0i/b000<00000
0>K<P03Vc8007P3Vc80001h0i/b000<000000>K<P03Vc800>@3Vc80010000000i/b00>K<P03Vc802
000000X0i/b000<000000>K<P03Vc8000`0000000`3Vc80000000>K<P0050>K<P0030000003Vc800
i/b000L0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00=0>K<P0050000003Vc800
i/b00>K<P0000000503Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b000<0i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b001X0i/b000<0
00000>K<P03Vc8007P3Vc80001h0i/b000<000000>K<P03Vc800>P3Vc8000`000000i/b00>K<P002
000000X0i/b00P0000001P3Vc80000000>K<P0000000i/b0000000H0i/b000<000000>K<P03Vc800
1`3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000h0i/b000@000000>K<P03Vc800
00004`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b00080i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03V
c8007P3Vc80001h0i/b000<000000>K<P03Vc800>P3Vc8001@000000i/b00>K<P03Vc800000000/0
i/b00`000000103Vc80000000000000000060>K<P0030000003Vc800i/b000L0i/b000<000000>K<
P03Vc8001P3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800000001@0i/b000<000000>K<
P03Vc8003P3Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc8003@3Vc8000`000000i/b00>K<P00K0>K<P0030000003Vc800i/b001h0i/b0000M0>K<P003
0000003Vc800i/b003/0i/b000@000000>K<P03Vc800i/b00P00000:0>K<P0030000003Vc8000000
00@000001P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000L0i/b000<000000>K<
P03Vc8003`3Vc8000`000000i/b00000000D0>K<P0030000003Vc800i/b000l0i/b000@000000>K<
P03Vc80000001P3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b001/0i/b000<00000
0>K<P03Vc8007P3Vc80001d0i/b000<000000>K<P03Vc800?03Vc8001P000000i/b00>K<P0000000
i/b0000000T0i/b000D000000>K<P03Vc80000000>K<P002000000H0i/b000<000000>K<P03Vc800
1P3Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000l0i/b000<000000>K<P0000000
503Vc8000`000000i/b00>K<P00?0>K<P0040000003Vc800i/b0000000H0i/b000<000000>K<P03V
c800303Vc8000`000000i/b00>K<P00L0>K<P0030000003Vc800i/b001h0i/b0000M0>K<P0030000
003Vc800i/b003`0i/b000@000000>K<P03Vc80000000P3Vc8000`000000i/b00>K<P0060>K<P008
0000003Vc800i/b00000003Vc80000000>K<P00000050>K<P0030000003Vc800i/b000H0i/b000<0
00000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00@0>K<P08000004`3Vc8000`000000i/b00>K<
P00@0>K<P0030000003Vc800000000L0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<
P00L0>K<P0030000003Vc800i/b001h0i/b0000M0>K<P0030000003Vc800i/b003d0i/b000<00000
0>K<P00000000P3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000<0000000<0i/b0
0000003Vc800103Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000L0i/b000<00000
0>K<P03Vc800403Vc8000`000000i/b00>K<P00B0>K<P0030000003Vc800i/b00140i/b00P000007
0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00N
0>K<P0007@3Vc8000`000000i/b00>K<P00m0>K<P0030000003Vc800000000<0i/b000<000000>K<
P03Vc8001@3Vc8000`000000i/b00>K<P005000000@0i/b000<000000>K<P03Vc8001`3Vc8000`00
0000i/b00>K<P0070>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8004P3Vc8000`00
0000i/b00>K<P00A0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8002P3Vc8000`00
0000i/b00>K<P00N0>K<P0030000003Vc800i/b001d0i/b0000M0>K<P0030000003Vc800i/b003d0
i/b000<000000>K<P0000000103Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00080
000000<0i/b0000000000000103Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800i/b000H0
i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b00180
i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b001l0
i/b000<000000>K<P03Vc8007@3Vc80001d0i/b000<000000>K<P03Vc800?P3Vc802000000D0i/b0
00<000000>K<P03Vc8000`3Vc8001@000000i/b00>K<P0000000i/b000<00000103Vc8000`000000
i/b00>K<P0060>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc8004@3Vc80200000180
i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b0000000080>K<P0030000003Vc800i/b000T0
i/b000<000000>K<P03Vc8007`3Vc8000`000000i/b00>K<P00M0>K<P0007@3Vc8000`000000i/b0
0>K<P00n0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8000`3Vc8001@000000i/b0
0>K<P0000000i/b00080000000<0i/b00000003Vc8000P3Vc8000`000000i/b00>K<P0060>K<P003
0000003Vc800i/b000L0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00000000B0>K<P003
0000003Vc800i/b00140i/b000<000000>K<P0000000203Vc8000`000000i/b00>K<P0080>K<P003
0000003Vc800i/b00200i/b000<000000>K<P03Vc8007@3Vc80001d0i/b000<000000>K<P03Vc800
?P3Vc802000000H0i/b000<000000>K<P03Vc8000P3Vc8001@000000i/b00>K<P0000000i/b000@0
00000`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03V
c800403Vc8000`000000i/b00000000A0>K<P0030000003Vc800i/b00180i/b000@000000>K<P03V
c80000001`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b00200i/b000<000000>K<
P03Vc8007@3Vc80001d0i/b000<000000>K<P03Vc800?P3Vc802000000L0i/b000<000000>K<P03V
c8000P3Vc8001@000000i/b00>K<P0000000i/b000<000000`3Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800403Vc80010000000i/b00>K<P000000@
0>K<P0030000003Vc800i/b00140i/b000D000000>K<P03Vc800i/b0000000070>K<P0030000003V
c800i/b000L0i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P00M0>K<P000703Vc800
0`000000i/b00>K<P00o0>K<P0030000003Vc800000000L0i/b000D000000>K<P03Vc800i/b00000
00020>K<P0030000003Vc8000000008000000`3Vc8000`000000i/b00>K<P0060>K<P0030000003V
c800i/b000L0i/b000<000000>K<P03Vc800403Vc80010000000i/b00>K<P000000@0>K<P0030000
003Vc800i/b00140i/b000D000000>K<P03Vc800i/b0000000070>K<P0030000003Vc800i/b000L0
i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b00>K<P00M0>K<P000703Vc8000`000000i/b0
0>K<P00o0>K<P0030000003Vc800000000P0i/b000@000000>K<P03Vc80000000P3Vc8000`000000
i/b000000003000000030>K<P0000000i/b000P0i/b000<000000>K<P03Vc8001P3Vc8000`000000
i/b00>K<P00@0>K<P0050000003Vc800i/b00>K<P0000000403Vc8000`000000i/b00>K<P00A0>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800i/b00280i/b000<000000>K<P03Vc8007@3Vc80001`0i/b000<000000>K<P03V
c800?`3Vc80010000000i/b00>K<P00000070>K<P0040000003Vc800i/b000000080i/b000<00000
0>K<P03Vc8000`0000000`3Vc80000000>K<P0080>K<P0030000003Vc800i/b000H0i/b000<00000
0>K<P03Vc800403Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800i/b000`0i/b000<00000
0>K<P03Vc8004@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000@0i/b000<00000
0>K<P03Vc8001P3Vc8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b001d0i/b0000L0>K<
P0030000003Vc800i/b003l0i/b000D000000>K<P03Vc800i/b0000000070>K<P0030000003Vc800
00000080i/b000<000000>K<P03Vc8000`0000000`3Vc80000000>K<P0070>K<P0030000003Vc800
i/b000L0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P0020>K<P0030000003Vc800
i/b000`0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800
i/b000@0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00S0>K<P0030000003Vc800
i/b001d0i/b0000L0>K<P0800000@03Vc8001@000000i/b00>K<P03Vc800000000P0i/b00P000002
0>K<P0030000003Vc800i/b000<0000000<0i/b00000003Vc8001`3Vc8000`000000i/b00>K<P007
0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00<
0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800903Vc8000`000000i/b00>K<P00L
0>K<P000703Vc8000`000000i/b00>K<P00o0>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8001P3Vc80010000000i/b00>K<P00000020>K<P0<0000000<0i/b00000003Vc8001`3Vc800
0`000000i/b00>K<P0070>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800103Vc800
0`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8001@3Vc800
0`000000i/b00>K<P0030>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8009@3Vc800
0`000000i/b00>K<P00L0>K<P000703Vc8000`000000i/b00>K<P00o0>K<P0030000003Vc800i/b0
00<0i/b000<000000>K<P03Vc8001@3Vc80010000000i/b00>K<P00000020>K<P0D00000203Vc800
0`000000i/b00>K<P0070>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800103Vc800
0`000000i/b00>K<P00:0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc8001P3Vc800
0`000000i/b00>K<P0020>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8009@3Vc800
0`000000i/b00>K<P00L0>K<P000703Vc8000`000000i/b00>K<P00o0>K<P0030000003Vc800i/b0
00@0i/b000<000000>K<P03Vc800103Vc80200000080i/b000<000000>K<P03Vc800100000080>K<
P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P0040>K<
P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800i/b00080i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00V0>K<
P0030000003Vc800i/b001`0i/b0000L0>K<P0030000003Vc800i/b003l0i/b000<000000>K<P03V
c800103Vc8000`000000i/b00>K<P0040>K<P0050000003Vc80000000>K<P00000000P3Vc8030000
00T0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b0
00D0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b0
00L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b0
02H0i/b000<000000>K<P03Vc800703Vc80001/0i/b000<000000>K<P03Vc800@03Vc8000`000000
i/b00>K<P0050>K<P0030000003Vc800i/b000@0i/b000@000000>K<P000000000000P3Vc8030000
00T0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b0
00H0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b0
00P0i/b000D000000>K<P03Vc800i/b0000000040>K<P0030000003Vc800i/b002L0i/b000<00000
0>K<P03Vc800703Vc80001/0i/b000<000000>K<P03Vc800@03Vc8000`000000i/b00>K<P0060>K<
P0030000003Vc800i/b000<0i/b000@000000>K<P000000000000P3Vc804000000L0i/b000<00000
0>K<P03Vc8001`3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b000H0i/b000<00000
0>K<P03Vc800203Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000P0i/b000<00000
0>K<P03Vc8000P3Vc8001@000000i/b00>K<P03Vc800000002T0i/b000<000000>K<P03Vc800703V
c80001/0i/b000<000000>K<P03Vc800@03Vc8000`000000i/b00>K<P0070>K<P0030000003Vc800
i/b00080i/b000@000000>K<P03Vc80000000P3Vc80010000000i/b00000000000070>K<P0030000
003Vc800i/b000L0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P0070>K<P0030000
003Vc800i/b000L0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00:0>K<P0050000
003Vc800i/b00>K<P00000000P3Vc8000`000000i/b00>K<P00X0>K<P0030000003Vc800i/b001`0
i/b0000K0>K<P0030000003Vc800i/b00400i/b000<000000>K<P03Vc800203Vc8001@000000i/b0
0>K<P03Vc80000000080i/b00P0000000`3Vc80000000>K<P002000000L0i/b000<000000>K<P03V
c8001P3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03V
c8001P3Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000X0i/b000D000000>K<P03V
c800i/b0000000020>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc800703Vc80001/0
i/b000<000000>K<P03Vc800@03Vc8000`000000i/b00>K<P0080>K<P0050000003Vc800i/b00>K<
P00000000P3Vc80010000000i/b00000003Vc804000000H0i/b000<000000>K<P03Vc8001P3Vc800
0`000000i/b00>K<P00?0>K<P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8001P3Vc800
0`000000i/b00>K<P00A0>K<P0030000003Vc800i/b000X0i/b000L000000>K<P03Vc800i/b00000
003Vc800000002/0i/b000<000000>K<P03Vc800703Vc80001/0i/b000<000000>K<P03Vc800@03V
c8000`000000i/b00>K<P0090>K<P0040000003Vc800i/b000000080i/b000<000000>K<P03Vc800
1@0000060>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b0
0>K<P0090>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800403Vc8000`000000i/b0
0>K<P00<0>K<P0060000003Vc800i/b00000003Vc8000000;03Vc8000`000000i/b00>K<P00K0>K<
P0006`3Vc8000`000000i/b00>K<P0100>K<P0030000003Vc800i/b000X0i/b000@000000>K<P000
000000000P3Vc8001@000000i/b0000000000000i/b0008000001P3Vc8000`000000i/b00>K<P006
0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8002@3Vc8000`000000i/b00>K<P005
0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P002
000002d0i/b000<000000>K<P03Vc8006`3Vc80001/0i/b000<000000>K<P03Vc800@03Vc8000`00
0000i/b00>K<P00;0>K<P0<000000P3Vc8001@000000i/b00>K<P0000000i/b000<00000103Vc800
0`000000i/b00>K<P0070>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8002@3Vc800
0`000000i/b00>K<P0040>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800303Vc800
0`000000i/b00>K<P002000002d0i/b000<000000>K<P03Vc8006`3Vc80001/0i/b000<000000>K<
P03Vc800@03Vc8000`000000i/b00>K<P00;0>K<P0<000000P3Vc8000`000000i/b00>K<P0020000
00030>K<P0000000000000@0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00>0>K<
P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P00@0>K<
P0030000003Vc800i/b000h0i/b000<000000>K<P0000000;P3Vc8000`000000i/b00>K<P00K0>K<
P0006`3Vc8000`000000i/b00>K<P0100>K<P0030000003Vc800i/b000`0i/b00P0000020>K<P005
0000003Vc800i/b00000003Vc8000`0000040>K<P0030000003Vc800i/b000H0i/b000<000000>K<
P03Vc8003`3Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800i/b000<0i/b000<000000>K<
P03Vc800403Vc8000`000000i/b00>K<P00>0>K<P0<00000;P3Vc8000`000000i/b00>K<P00K0>K<
P0006P3Vc8000`000000i/b00>K<P0110>K<P0030000003Vc800i/b000d0i/b00P000000103Vc800
00000>K<P03Vc806000000<0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b00>K<P00?0>K<
P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00A0>K<
P0030000003Vc800i/b000/0i/b01@0000000`3Vc80000000>K<P00/0>K<P0030000003Vc800i/b0
01/0i/b0000J0>K<P0030000003Vc800i/b00400i/b000<000000>K<P03Vc8003P3Vc80200000004
0>K<P0000000i/b00>K<P080000000@0i/b000000000000000000`3Vc8000`000000i/b00>K<P006
0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800303Vc8001@000000i/b00>K<P03V
c80000000180i/b000<000000>K<P03Vc8002@3Vc803000000@0i/b000@000000>K<P03Vc8000000
;03Vc8000`000000i/b00>K<P00K0>K<P0006P3Vc8000`000000i/b00>K<P0100>K<P0030000003V
c800i/b000h0i/b010000000103Vc80000000>K<P00000020>K<P08000000`3Vc8000`000000i/b0
0>K<P0060>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8003@3Vc8001@000000i/b0
0>K<P03Vc80000000180i/b000<000000>K<P03Vc8001@3Vc804000000L0i/b000D000000>K<P03V
c800i/b00000000[0>K<P0030000003Vc800i/b001/0i/b0000J0>K<P0030000003Vc800i/b00400
i/b000<000000>K<P03Vc8003P3Vc804000000040>K<P0000000i/b000000080i/b00`0000020>K<
P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00=0>K<
P0040000003Vc800i/b0000001<0i/b000@000000>K<P03Vc800i/b01000000:0>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc800:@3Vc8000`000000i/b00>K<P00K0>K<P0006P3Vc800
0`000000i/b00>K<P0100>K<P0030000003Vc800i/b000h0i/b000<000000>K<P00000000`000000
103Vc80000000>K<P03Vc803000000030>K<P0000000i/b000P0i/b000<000000>K<P03Vc8003P3V
c8000`000000i/b00>K<P00>0>K<P0030000003Vc80000000180i/b000<000000>K<P00000000P00
000>0>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800:03Vc8000`000000i/b00>K<
P00K0>K<P0006P3Vc80200000440i/b000<000000>K<P03Vc8003P3Vc80010000000i/b00000003V
c802000000030>K<P0000000i/b00080i/b00P0000000`3Vc80000000>K<P0070>K<P0030000003V
c800i/b000l0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00000000@0>K<P0@000004@3V
c8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b002P0i/b000<000000>K<P03Vc8006P3V
c80000040>K<P00000000000000000D0i/b00P0000060>K<P0<000001P3Vc8000`000000i/b00>K<
P0100>K<P0030000003Vc800i/b000h0i/b000@000000>K<P0000000i/b00P0000020>K<P0030000
003Vc800i/b000@00000203Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000l0i/b0
00<000000>K<P00000003@3Vc803000000030>K<P0000000i/b00140i/b000<000000>K<P03Vc800
1P3Vc8000`000000i/b00>K<P00W0>K<P0030000003Vc800i/b001X0i/b0000010000000i/b00>K<
P00000050>K<P08000001`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b00400i/b0
00<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00300000080i/b000<000000>K<P03Vc800
100000080>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc800403Vc8000`000000i/b0
0>K<P0080>K<P0@00000103Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000L0i/b0
00<000000>K<P03Vc8009P3Vc8000`000000i/b00>K<P00J0>K<P000103Vc8000`000000i/b00>K<
P0080>K<P0D000001P3Vc8000`000000i/b00>K<P0100>K<P0030000003Vc800i/b000h0i/b000<0
00000>K<P03Vc8000P000000103Vc80000000>K<P00000030>K<P0<00000203Vc8000`000000i/b0
0>K<P00>0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8001@3Vc803000000P0i/b0
00<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b002D0i/b0
00<000000>K<P03Vc8006P3Vc80000@0i/b000<000000>K<P03Vc800203Vc80010000000i/b00>K<
P00000070>K<P0030000003Vc800i/b00400i/b000<000000>K<P03Vc8003`3Vc80010000000i/b0
0000000000020>K<P08000000`3Vc803000000P0i/b000<000000>K<P03Vc8003P3Vc8000`000000
i/b00>K<P00@0>K<P0040000003Vc800i/b00>K<P0@000002P3Vc8000`000000i/b00>K<P00@0>K<
P0030000003Vc800i/b000X0i/b000<000000>K<P03Vc800903Vc8000`000000i/b00>K<P00J0>K<
P000103Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800000000H0i/b000<000000>K<P03V
c800@@3Vc8000`000000i/b00>K<P00?0>K<P0040000003Vc8000000000000<0i/b000@000000>K<
P03Vc800i/b00`0000080>K<P0030000003Vc800i/b000d0i/b000<000000>K<P03Vc800403Vc805
000000h0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00;0>K<P0030000003Vc800
i/b002<0i/b000<000000>K<P03Vc8006P3Vc80000@0i/b000<000000>K<P03Vc8002P3Vc8020000
00H0i/b000<000000>K<P03Vc800@@3Vc8000`000000i/b00>K<P00?0>K<P0040000003Vc800i/b0
000000<0i/b00P0000020>K<P0@000001P3Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800
i/b000h0i/b00`0000000`3Vc80000000>K<P00?0>K<P0030000003Vc800i/b000l0i/b000<00000
0>K<P03Vc800303Vc8000`000000i/b00>K<P00S0>K<P0030000003Vc800i/b001X0i/b000001000
0000i/b00>K<P000000=0>K<P08000001P3Vc8000`000000i/b00>K<P0110>K<P0030000003Vc800
i/b000l0i/b000<000000>K<P03Vc8000P0000030>K<P0040000003Vc800i/b00>K<P0<000001P3V
c8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000X0i/b0100000020>K<P0040000003V
c800i/b0000000h0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P00=0>K<P0030000
003Vc800i/b00280i/b000<000000>K<P03Vc8006P3Vc80000@000003P3Vc8000`000000i/b00>K<
P0040>K<P0030000003Vc800i/b00440i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<
P002000000<0i/b00P0000020>K<P0<000001P3Vc8000`000000i/b00>K<P00>0>K<P0030000003V
c800i/b000L0i/b00`0000050>K<P0050000003Vc800i/b00>K<P00000003P3Vc8000`000000i/b0
0>K<P00@0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8008@3Vc8000`000000i/b0
0>K<P00J0>K<P0006@3Vc8000`000000i/b00>K<P0110>K<P0030000003Vc800i/b000l0i/b000<0
00000>K<P00000000P0000030>K<P0040000003Vc80000000>K<P0@000001@3Vc8000`000000i/b0
0>K<P00=0>K<P0030000003Vc800i/b000@0i/b0100000080>K<P0030000003Vc800i/b00080i/b0
00<000000>K<P03Vc8002`3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b00100i/b0
00<000000>K<P03Vc800803Vc8000`000000i/b00>K<P00J0>K<P0006@3Vc8000`000000i/b00>K<
P0110>K<P0030000003Vc800i/b000l0i/b000D000000>K<P0000000i/b0000000030>K<P0030000
003Vc800i/b000D000001@3Vc8000`000000i/b00>K<P00=0>K<P0040000003Vc800i/b00>K<P0<0
00002`3Vc8000`000000i/b00>K<P0030>K<P0030000003Vc800i/b000X0i/b000<000000>K<P03V
c800403Vc8000`000000i/b00>K<P00A0>K<P0030000003Vc800i/b00200i/b000<000000>K<P03V
c8006@3Vc80001T0i/b000<000000>K<P03Vc800@@3Vc8000`000000i/b00>K<P00?0>K<P0050000
003Vc80000000>K<P00000000`3Vc80010000000i/b00>K<P00000020>K<P08000001@3Vc8000`00
0000i/b00>K<P00=0>K<P0@000003P3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b0
00T0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00C0>K<P0030000003Vc800i/b0
01l0i/b000<000000>K<P03Vc8006@3Vc80001T0i/b000<000000>K<P03Vc800@@3Vc8000`000000
i/b00>K<P00?0>K<P0040000003Vc80000000>K<P08000000P3Vc8000`000000i/b00>K<P0020000
00040>K<P0000000i/b0000000<0i/b000<000000>K<P03Vc8002`3Vc80400000140i/b000<00000
0>K<P03Vc800103Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b000l0i/b000<00000
0>K<P03Vc800503Vc8000`000000i/b00>K<P00N0>K<P0030000003Vc800i/b001T0i/b0000I0>K<
P0030000003Vc800i/b00440i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b0000000020>K<
P00:0000003Vc800i/b00>K<P0000000i/b00000003Vc80000000>K<P08000000`3Vc8000`000000
i/b00>K<P0070>K<P0@000000P3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b000H0
i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b001D0
i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b00>K<P00I0>K<P000603Vc8000`000000i/b0
0>K<P0120>K<P0030000003Vc800i/b00100i/b00P0000020>K<P08000000P3Vc8000`000000i/b0
000000020>K<P0@000000P3Vc8000`000000i/b00>K<P0030>K<P0@000001P3Vc8000`000000i/b0
0>K<P00?0>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b0
0>K<P00?0>K<P0030000003Vc800i/b001H0i/b000<000000>K<P03Vc8007@3Vc8000`000000i/b0
0>K<P00I0>K<P000603Vc8000`000000i/b00>K<P0120>K<P0030000003Vc800i/b00100i/b000@0
00000>K<P03Vc800i/b00P0000020>K<P0800000103Vc80300000080i/b000<000000>K<P03Vc800
0`00000:0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8001`3Vc8000`000000i/b0
0>K<P0060>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8005`3Vc8000`000000i/b0
0>K<P00L0>K<P0030000003Vc800i/b001T0i/b0000H0>K<P0030000003Vc800i/b00480i/b000<0
00000>K<P03Vc800403Vc8000`000000i/b00>K<P0020>K<P080000000<0i/b0000000000000103V
c8000`000000i/b000000005000000d0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<
P0080>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<
P00H0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8006@3Vc80001P0i/b000<00000
0>K<P03Vc800@P3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b00080i/b00P000000
0`3Vc8000000000000050>K<P0<0000000<0i/b00000003Vc8003@3Vc8000`000000i/b00>K<P00?
0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P00?
0>K<P0030000003Vc800i/b001X0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P00I
0>K<P000603Vc8000`000000i/b00>K<P0110>K<P0030000003Vc800i/b00140i/b000<000000>K<
P03Vc8000P3Vc8000`000000i/b000000002000000030>K<P0000000000000H000003`3Vc8000`00
0000i/b00>K<P00?0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03Vc800103Vc8000`00
0000i/b00>K<P00?0>K<P0030000003Vc800i/b001/0i/b000<000000>K<P03Vc8006@3Vc8000`00
0000i/b00>K<P00I0>K<P000603Vc8000`000000i/b00>K<P0110>K<P0030000003Vc800i/b00180
i/b000H000000>K<P03Vc800i/b00000003Vc804000000@0i/b000@000000>K<P000000000003`3V
c8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000P3V
c8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b001d0i/b000<000000>K<P03Vc800603V
c8000`000000i/b00>K<P00I0>K<P000603Vc8000`000000i/b00>K<P0110>K<P0030000003Vc800
i/b001<0i/b000<000000>K<P00000001@0000060>K<P0@000003P3Vc8000`000000i/b00>K<P00>
0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00?
0>K<P0030000003Vc800i/b001h0i/b000<000000>K<P03Vc800603Vc8000`000000i/b00>K<P00H
0>K<P000603Vc80200000480i/b000<000000>K<P03Vc8004@3Vc805000000030>K<P0000000i/b0
008000001P3Vc804000000d0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00=0>K<
P0050000003Vc800i/b00>K<P00000004@3Vc8000`000000i/b00>K<P00N0>K<P0030000003Vc800
i/b001P0i/b000<000000>K<P03Vc800603Vc80001P0i/b000<000000>K<P03Vc800@@3Vc8000`00
0000i/b00>K<P00>0>K<P0<000001@3Vc802000000030>K<P0000000000000H0i/b00P0000000`3V
c80000000000000<0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03Vc8003@3Vc8001000
0000i/b00>K<P000000A0>K<P0030000003Vc800i/b00200i/b000<000000>K<P03Vc8005`3Vc800
0`000000i/b00>K<P00H0>K<P000603Vc8000`000000i/b00>K<P0110>K<P0030000003Vc800i/b0
00X0i/b0100000090>K<P08000000P3Vc8000`000000i/b00>K<P0030>K<P080000000<0i/b00000
00000000303Vc8000`000000i/b00>K<P00>0>K<P0030000003Vc800i/b000h0i/b000<000000>K<
P00000004@3Vc8000`000000i/b00>K<P00Q0>K<P0030000003Vc800i/b001H0i/b000<000000>K<
P03Vc800603Vc80001L0i/b000<000000>K<P03Vc800@P3Vc8000`000000i/b00>K<P0070>K<P0<0
00003P3Vc80010000000i/b00>K<P00000050>K<P08000000P3Vc802000000/0i/b000<000000>K<
P03Vc8003@3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc80000000140i/b000<000000>K<
P03Vc8008P3Vc8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b001P0i/b0000G0>K<P003
0000003Vc800i/b00480i/b000<000000>K<P03Vc8000`3Vc80400000180i/b000@000000>K<P03V
c80000000`3Vc8000`000000i/b0000000020>K<P0<000002@3Vc8000`000000i/b00>K<P00>0>K<
P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00T0>K<
P0030000003Vc800i/b001@0i/b000<000000>K<P03Vc800603Vc80001L0i/b000<000000>K<P03V
c800@P3Vc8000`000000i/b00>K<P003000001L0i/b000@000000>K<P000000000000P3Vc8000`00
0000i/b0000000030>K<P0030000003Vc800000000P0i/b000<000000>K<P03Vc8003P3Vc8000`00
0000i/b00>K<P00@0>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc8009@3Vc8000`00
0000i/b00>K<P00C0>K<P0030000003Vc800i/b001P0i/b0000G0>K<P0030000003Vc800i/b00440
i/b01000000K0>K<P0D000000`3Vc8000`000000i/b00>K<P002000000030>K<P0000000i/b000H0
i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00A0>K<P08000003`3Vc8000`000000
i/b00>K<P00W0>K<P0030000003Vc800i/b00180i/b000<000000>K<P03Vc800603Vc80001L0i/b0
00<000000>K<P03Vc800?@3Vc804000000030>K<P0000000i/b001h0i/b00`0000030>K<P0070000
003Vc800i/b00>K<P0000000i/b0000000070>K<P0030000003Vc800i/b000d0i/b000<000000>K<
P03Vc800403Vc8000`000000i/b00000000?0>K<P0030000003Vc800i/b002P0i/b000<000000>K<
P03Vc8004@3Vc8000`000000i/b00>K<P00H0>K<P0005`3Vc8000`000000i/b00>K<P00j0>K<P0<0
00001@3Vc8000`000000i/b00>K<P00N0>K<P08000000`3Vc80010000000i/b00>K<P03Vc8020000
00030>K<P0000000i/b000@0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<P00@0>K<
P0040000003Vc800i/b0000000h0i/b000<000000>K<P03Vc800:03Vc8000`000000i/b00>K<P00A
0>K<P0030000003Vc800i/b001P0i/b0000G0>K<P0030000003Vc800i/b003H0i/b0100000080>K<
P0030000003Vc800i/b001l0i/b00P0000030>K<P0040000003Vc800i/b00>K<P080000000<0i/b0
0000003Vc8000`3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b00100i/b000D00000
0>K<P03Vc800i/b00000000=0>K<P0030000003Vc800i/b002X0i/b000<000000>K<P03Vc8004@3V
c8000`000000i/b00>K<P00G0>K<P0005`3Vc8000`000000i/b00>K<P00c0>K<P0<00000303Vc800
0`000000i/b00>K<P00P0>K<P08000000P3Vc80010000000i/b00>K<P03Vc80200000080i/b000D0
00000>K<P03Vc800i/b00000000?0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc800
0P3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b002/0i/b000<000000>K<P03Vc800
403Vc8000`000000i/b00>K<P00G0>K<P0005`3Vc8000`000000i/b00>K<P00_0>K<P0@000003`3V
c8000`000000i/b00>K<P00Q0>K<P0040000003Vc800i/b0000000@0i/b00P0000020>K<P0040000
003Vc800i/b0000000h0i/b000<000000>K<P03Vc800403Vc8000`000000i/b00>K<P0040>K<P003
0000003Vc800i/b000T0i/b000<000000>K<P03Vc800;03Vc8000`000000i/b00>K<P00?0>K<P003
0000003Vc800i/b001L0i/b0000F0>K<P0030000003Vc800i/b002d0i/b00`00000C0>K<P0030000
003Vc800i/b00280i/b000@000000>K<P03Vc80000000`3Vc80200000080i/b000<000000>K<P000
00003`3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03V
c800203Vc8000`000000i/b00>K<P00^0>K<P0030000003Vc800i/b000h0i/b000<000000>K<P03V
c8005`3Vc80001H0i/b000<000000>K<P03Vc800:@3Vc804000001H0i/b000<000000>K<P03Vc800
8`3Vc8000`000000i/b0000000040>K<P08000000P3Vc802000000l0i/b000<000000>K<P03Vc800
3`3Vc8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b000L0i/b000<000000>K<P03Vc800
;`3Vc8000`000000i/b00>K<P00=0>K<P0030000003Vc800i/b001L0i/b0000F0>K<P0030000003V
c800i/b002H0i/b00`00000J0>K<P0030000003Vc800i/b002@0i/b00P0000040>K<P08000000`3V
c8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b00100i/b000<000000>K<P03Vc8001P3V
c8000`000000i/b00>K<P0060>K<P0030000003Vc800i/b00340i/b000<000000>K<P03Vc800303V
c8000`000000i/b00>K<P00G0>K<P0005P3Vc8000`000000i/b00>K<P00R0>K<P0@000007@3Vc800
0`000000i/b00>K<P00T0>K<P0<00000103Vc802000000040>K<P0000000i/b0000000d0i/b000<0
00000>K<P03Vc8003`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000D0i/b000<0
00000>K<P03Vc800<@3Vc8000`000000i/b00>K<P00<0>K<P0030000003Vc800i/b001L0i/b0000F
0>K<P0030000003Vc800i/b001h0i/b01000000Q0>K<P0030000003Vc800i/b002D0i/b00`000003
0>K<P0<000000`3Vc8000`000000i/b00>K<P00:0>K<P0030000003Vc800i/b000l0i/b000<00000
0>K<P03Vc8002@3Vc8000`000000i/b00>K<P0040>K<P0030000003Vc800i/b00380i/b000<00000
0>K<P03Vc8002`3Vc8000`000000i/b00>K<P00G0>K<P0005P3Vc8000`000000i/b00>K<P00K0>K<
P0<000009@3Vc8000`000000i/b00>K<P00V0>K<P0030000003Vc800000000<0i/b00P0000040>K<
P0030000003Vc800i/b000P0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00:0>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800=03Vc8000`000000i/b00>K<P00:0>K<
P0030000003Vc800i/b001L0i/b0000F0>K<P0030000003Vc800i/b001L0i/b01000000X0>K<P003
0000003Vc800i/b002L0i/b00`0000000`3Vc800000000000002000000@0i/b000<000000>K<P03V
c8001`3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800i/b000/0i/b000<000000>K<P03V
c8000P3Vc8000`000000i/b00>K<P00e0>K<P0030000003Vc800i/b000T0i/b000<000000>K<P03V
c8005`3Vc80001H0i/b000<000000>K<P03Vc800503Vc803000002`0i/b000<000000>K<P03Vc800
:03Vc80300000080i/b00P0000050>K<P0030000003Vc800i/b000H0i/b000<000000>K<P03Vc800
3P3Vc8000`000000i/b00>K<P00=0>K<P0050000003Vc800i/b00>K<P0000000>03Vc8000`000000
i/b00>K<P0090>K<P0030000003Vc800i/b001H0i/b0000F0>K<P0030000003Vc800i/b00100i/b0
1000000^0>K<P0030000003Vc800i/b002X0i/b000@000000>K<P0000000i/b00`0000040>K<P003
0000003Vc800i/b000D0i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P00=0>K<P004
0000003Vc800i/b0000003X0i/b000<000000>K<P03Vc800203Vc8000`000000i/b00>K<P00F0>K<
P0005@3Vc802000000l0i/b00`00000b0>K<P0030000003Vc800i/b002/0i/b000@000000>K<P000
0000i/b00`0000040>K<P0030000003Vc800i/b000@0i/b000<000000>K<P03Vc8003P3Vc8000`00
0000i/b00>K<P00?0>K<P0030000003Vc800000003/0i/b000<000000>K<P03Vc8001`3Vc8000`00
0000i/b00>K<P00F0>K<P0005@3Vc8000`000000i/b00>K<P00:0>K<P0@00000=@3Vc8000`000000
i/b00>K<P00/0>K<P0030000003Vc800000000<000001@3Vc8000`000000i/b00>K<P0020>K<P003
0000003Vc800i/b000l0i/b000<000000>K<P03Vc8003`3Vc802000003d0i/b000<000000>K<P03V
c8001P3Vc8000`000000i/b00>K<P00F0>K<P0005@3Vc8000`000000i/b00>K<P0060>K<P0@00000
>@3Vc8000`000000i/b00>K<P00]0>K<P0030000003Vc800000000<000001@3Vc8001@000000i/b0
0>K<P03Vc80000000100i/b000<000000>K<P03Vc8004@3Vc8000`000000i/b00>K<P00k0>K<P003
0000003Vc800i/b000H0i/b000<000000>K<P03Vc8005P3Vc80001D0i/b000<000000>K<P03Vc800
0`3Vc803000003d0i/b000<000000>K<P03Vc800;P3Vc8001@000000i/b00000003Vc800000000H0
i/b000@000000>K<P03Vc8000000403Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b0
03d0i/b000<000000>K<P03Vc8001@3Vc8000`000000i/b00>K<P00F0>K<P0005@3Vc8000`000000
i/b00000000300000400i/b000<000000>K<P03Vc800;`3Vc8000`000000i/b000000002000000H0
i/b00P00000@0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800?P3Vc8000`000000
i/b00>K<P0040>K<P0030000003Vc800i/b001H0i/b0000E0>K<P0800000A03Vc8000`000000i/b0
0>K<P00`0>K<P080000000<0i/b00000000000001P3Vc8000`000000i/b00>K<P00>0>K<P0030000
003Vc800i/b00100i/b000<000000>K<P03Vc800@03Vc8000`000000i/b00>K<P0030>K<P0030000
003Vc800i/b001H0i/b0000F0>K<P0030000003Vc800i/b00480i/b000<000000>K<P03Vc800<@3V
c805000000@0i/b000<000000>K<P00000003P3Vc8000`000000i/b00>K<P00@0>K<P0030000003V
c800i/b00480i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P00F0>K<P0005`3Vc802
00000480i/b000<000000>K<P03Vc800<P3Vc80010000000i/b00000000000030>K<P0050000003V
c800i/b00>K<P00000003@3Vc8000`000000i/b00>K<P00@0>K<P0030000003Vc800i/b004<0i/b0
00D000000>K<P03Vc800i/b00000000H0>K<P0006@3Vc8000`000000i/b00>K<P00o0>K<P0030000
003Vc800i/b003<0i/b0100000000`3Vc80000000>K<P0040>K<P0030000003Vc800i/b000T0i/b0
00<000000>K<P03Vc800403Vc8000`000000i/b00>K<P0150>K<P0050000003Vc800i/b00>K<P000
00005`3Vc80001X0i/b000<000000>K<P03Vc800?P3Vc8000`000000i/b00>K<P00d0>K<P0@00000
1`3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800
A`3Vc80010000000i/b00>K<P000000G0>K<P0006`3Vc802000003h0i/b000<000000>K<P03Vc800
=@3Vc802000000030>K<P0000000i/b000H0i/b000<000000>K<P03Vc8001P3Vc8000`000000i/b0
0>K<P00@0>K<P0030000003Vc800i/b004L0i/b000@000000>K<P03Vc80000005`3Vc80001d0i/b0
00<000000>K<P03Vc800>`3Vc8000`000000i/b00>K<P00f0>K<P080000000<0i/b0000000000000
1P3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000l0i/b000<000000>K<P03Vc800
B@3Vc8000`000000i/b00000000G0>K<P0007P3Vc8000`000000i/b00>K<P00j0>K<P0030000003V
c800i/b003L0i/b000D000000>K<P0000000i/b0000000060>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P01;0>K<P08000005`3Vc80001l0i/b00P00
000j0>K<P0030000003Vc800i/b003P0i/b00`0000000`3Vc80000000>K<P0050>K<P0030000003V
c800i/b00080i/b000<000000>K<P03Vc8003`3Vc8000`000000i/b00>K<P01:0>K<P0<000005`3V
c8000240i/b000<000000>K<P03Vc800=`3Vc8000`000000i/b00>K<P00i0>K<P0<0000000<0i/b0
0000003Vc8001@3Vc80010000000i/b00>K<P000000A0>K<P0030000003Vc800i/b004L0i/b01000
000J0>K<P0008P3Vc8000`000000i/b00>K<P00f0>K<P0030000003Vc800i/b003X0i/b00`000000
0`3Vc80000000>K<P0050>K<P0030000003Vc80000000100i/b000<000000>K<P03Vc800A03Vc804
000001h0i/b0000S0>K<P0800000=P3Vc8000`000000i/b00>K<P00k0>K<P08000000P3Vc8020000
00@0i/b00P00000A0>K<P0030000003Vc800i/b00400i/b01000000R0>K<P0009@3Vc8000`000000
i/b00>K<P00c0>K<P0030000003Vc800i/b003`0i/b00P0000030>K<P0040000003Vc80000000000
0080i/b000<000000>K<P03Vc8003@3Vc8000`000000i/b00>K<P00m0>K<P0@000009P3Vc80002H0
i/b000<000000>K<P03Vc800<P3Vc8000`000000i/b00>K<P00m0>K<P0H000001@3Vc8000`000000
i/b00>K<P00;0>K<P0030000003Vc800i/b003X0i/b01000000Z0>K<P0009`3Vc80200000380i/b0
00<000000>K<P03Vc800?P3Vc802000000<0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b0
0>K<P00:0>K<P0030000003Vc800i/b003H0i/b01000000^0>K<P000:@3Vc8000`000000i/b00>K<
P00_0>K<P0030000003Vc800i/b003l0i/b00P0000030>K<P0030000003Vc800i/b000<0i/b000<0
00000>K<P03Vc800203Vc8000`000000i/b00>K<P00c0>K<P0@00000<P3Vc80002X0i/b000<00000
0>K<P03Vc800;P3Vc8000`000000i/b00>K<P0100>K<P08000000`3Vc8000`000000i/b00>K<P003
0>K<P08000001`3Vc8000`000000i/b00>K<P00`0>K<P0@00000=P3Vc80002/0i/b00P00000]0>K<
P0030000003Vc800i/b004<0i/b000D000000>K<P03Vc800i/b0000000060>K<P0030000003Vc800
i/b000@0i/b000<000000>K<P03Vc800;03Vc804000003X0i/b0000]0>K<P0030000003Vc800i/b0
02X0i/b000<000000>K<P03Vc800A03Vc80010000000i/b00>K<P03Vc802000000D0i/b000<00000
0>K<P03Vc8000P3Vc8000`000000i/b00>K<P00Y0>K<P0@00000?P3Vc80002h0i/b000<000000>K<
P03Vc800:@3Vc8000`000000i/b00>K<P0150>K<P0030000003Vc800i/b00080i/b000<000000>K<
P03Vc8000`3Vc80010000000i/b00>K<P000000X0>K<P0@00000@P3Vc80002l0i/b00P00000Y0>K<
P0030000003Vc800i/b004H0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0030>K<
P0030000003Vc800000002@0i/b0100000160>K<P000<@3Vc8000`000000i/b00>K<P00V0>K<P003
0000003Vc800i/b004L0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0020>K<P080
00008@3Vc804000004X0i/b0000b0>K<P0030000003Vc800i/b002D0i/b000<000000>K<P03Vc800
B03Vc8000`000000i/b00>K<P0020>K<P0040000003Vc8000000000001l0i/b01000001>0>K<P000
<`3Vc802000002D0i/b000<000000>K<P03Vc800B@3Vc806000001d0i/b01000001B0>K<P000=@3V
c8000`000000i/b00>K<P00R0>K<P0030000003Vc800i/b006P0i/b01000001F0>K<P000=P3Vc800
0`000000i/b00>K<P00Q0>K<P0030000003Vc800i/b006@0i/b01000001J0>K<P000=`3Vc8020000
0240i/b000<000000>K<P03Vc800H03Vc804000005h0i/b0000i0>K<P0030000003Vc800i/b001h0
i/b000<000000>K<P03Vc800G03Vc80400000680i/b0000j0>K<P0030000003Vc800i/b001d0i/b0
00<000000>K<P03Vc800F03Vc804000006H0i/b0000k0>K<P08000007@3Vc8000`000000i/b00>K<
P01C0>K<P0D00000JP3Vc80003d0i/b000<000000>K<P03Vc8006P3Vc8000`000000i/b00>K<P01?
0>K<P0@00000K`3Vc80003h0i/b000<000000>K<P03Vc8006@3Vc8000`000000i/b00>K<P01;0>K<
P0@00000L`3Vc80003l0i/b00P00000I0>K<P0030000003Vc800i/b004L0i/b01000001g0>K<P000
@@3Vc8000`000000i/b00>K<P00F0>K<P0030000003Vc800i/b004<0i/b01000001k0>K<P000@P3V
c8000`000000i/b00>K<P00E0>K<P0030000003Vc800i/b003l0i/b01000001o0>K<P000@`3Vc802
000001D0i/b000<000000>K<P03Vc800>`3Vc804000008<0i/b000150>K<P0030000003Vc800i/b0
0180i/b000<000000>K<P03Vc800=`3Vc804000008L0i/b000160>K<P0030000003Vc800i/b00140
i/b000<000000>K<P03Vc800<`3Vc804000008/0i/b000170>K<P08000004@3Vc8000`000000i/b0
0>K<P00_0>K<P0@00000S`3Vc80004T0i/b000<000000>K<P03Vc8003P3Vc8000`000000i/b00>K<
P00[0>K<P0@00000T`3Vc80004X0i/b000<000000>K<P03Vc800303Vc8000`000000i/b00>K<P00X
0>K<P0@00000U`3Vc80004/0i/b00P00000<0>K<P0030000003Vc800i/b002@0i/b01000002K0>K<
P000C@3Vc8000`000000i/b00>K<P0090>K<P0030000003Vc800i/b00200i/b01000002O0>K<P000
CP3Vc8000`000000i/b00>K<P0080>K<P0030000003Vc800i/b001`0i/b01000002S0>K<P000C`3V
c802000000P0i/b000<000000>K<P03Vc800603Vc80400000:L0i/b0001A0>K<P0030000003Vc800
i/b000D0i/b000<000000>K<P03Vc800503Vc80400000:/0i/b0001B0>K<P0030000003Vc800i/b0
00@0i/b000<000000>K<P03Vc800403Vc80400000:l0i/b0001C0>K<P0800000103Vc8000`000000
i/b00>K<P00<0>K<P0@00000/`3Vc80005D0i/b000D000000>K<P03Vc800i/b00000000:0>K<P0@0
0000]`3Vc80005H0i/b000@000000>K<P03Vc80000001P3Vc80400000;/0i/b0001G0>K<P0<00000
0P3Vc80400000;l0i/b0001I0>K<P0<00000``3Vc8000?l0i/b0803Vc8000?l0i/b0803Vc8000?l0
i/b0803Vc8000?l0i/b0803Vc80007`0i/b01000002O0>K<P000O@3Vc8000`000000i/b00>K<P02O
0>K<P000K03Vc80300000080i/b01P000000203Vc80000000000003Vc80000000>K<P0000000i/b0
0`0000030>K<P0H000000P3Vc806000000@0i/b0100000030>K<P0H000000P3Vc803000000030>K<
P0000000000000<0i/b01000001/0>K<P000K@3Vc8000`000000i/b00>K<P0020>K<P0040000003V
c800i/b000000080i/b000D000000>K<P03Vc80000000>K<P002000000<0i/b000<000000>K<P03V
c8000`3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000<0i/b000<000000>K<P03V
c800103Vc8000`000000i/b00>K<P0020>K<P0040000003Vc800i/b0000000<0i/b00P0000030>K<
P0030000003Vc800i/b006h0i/b0001]0>K<P0H000000P3Vc80010000000i/b00>K<P00000020>K<
P0030000003Vc800000000D0i/b000<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0050>K<
P0030000003Vc800i/b000<0i/b000<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0020>K<
P0040000003Vc800i/b0000000@0i/b000@000000>K<P03Vc8000000L@3Vc80006h0i/b000@00000
0>K<P03Vc80000000`3Vc80010000000i/b00>K<P00000020>K<P0030000003Vc800000000D0i/b0
00<000000>K<P03Vc8000P3Vc8000`000000i/b00>K<P0050>K<P0030000003Vc800i/b000<0i/b0
00<000000>K<P03Vc800103Vc8000`000000i/b00>K<P0020>K<P0040000003Vc800i/b0000000@0
i/b000<000000>K<P03Vc8001P00001/0>K<P000KP3Vc80010000000i/b00>K<P00000030>K<P004
0000003Vc800i/b000000080i/b000@000000>K<P000000000000`3Vc8000`000000i/b00>K<P003
0>K<P0030000003Vc800i/b000D0i/b000<000000>K<P03Vc8000`3Vc8000`000000i/b00>K<P004
0>K<P0030000003Vc800i/b00080i/b000@000000>K<P03Vc80000000`3Vc80200000080i/b000<0
00000>K<P03Vc8000P3Vc8000`000000i/b00>K<P01Z0>K<P000K`3Vc8000`000000i/b000000002
0>K<P0@0000000@0i/b0000000000000i/b00P000000103Vc80000000000000000060>K<P0030000
003Vc800i/b000<0i/b00`0000040>K<P0D000000P3Vc802000000<0i/b00P0000030>K<P0<00000
00<0i/b00000003Vc8000P3Vc804000006d0i/b0001_0>K<P08000005`3Vc8000`000000i/b00>K<
P00;0>K<P0030000003Vc800i/b00140i/b000<000000>K<P03Vc800LP3Vc80006d0i/b01000000E
0>K<P0<000003@3Vc8000`000000i/b00>K<P00?0>K<P0030000003Vc800000007@0i/b0002?0>K<
P0030000003Vc800i/b008d0i/b0002?0>K<P0030000003Vc800i/b008d0i/b0003o0>K<P200i/b0
003o0>K<P200i/b0003o0>K<P200i/b0003o0>K<P200i/b0003o0>K<P200i/b0003o0>K<P200i/b0
003o0>K<P200i/b0003o0>K<P200i/b0003o0>K<P200i/b0003o0>K<P200i/b0003o0>K<P200i/b0
003o0>K<P200i/b00000\
\>"],
  ImageRangeCache->{{{0, 286.5}, {358.875, 0}} -> {0.0323187, -0.0851408, \
0.00407227, 0.00407227}}]
}, Open  ]],

Cell[TextData[{
  "We see, that the oscillation is stronger for \[Omega] close to ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega]\_0\)]],
  ". For ",
  Cell[BoxData[
      \(TraditionalForm\`\[Omega] = \[Omega]\_0\)]],
  ", all particles go from |+z\[RightAngleBracket] at the beginning to |-z\
\[RightAngleBracket] at ",
  Cell[BoxData[
      \(TraditionalForm\`\[Pi]/\[Omega]\_R\)]],
  ". Outside this resonance, some particles remain in the |+z\
\[RightAngleBracket] state."
}], "Text"]
}, Open  ]],

Cell[CellGroupData[{

Cell["Save plot to ps-file", "Subsubsection"],

Cell[BoxData[{
    \(\(SetDirectory["\<~/mathem\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<rabiamp.eps\>", plAmp, "\<EPS\>"];\)\)}], "Input"],

Cell[BoxData[
    \(\(\(\[IndentingNewLine]\)\(colldata[\([All, All, 1]\)] = 
      colldata[\([All, All, 1]\)]\^2; 
    colldata[\([All, All, 3]\)] = colldata[\([All, All, 3]\)]\^2; 
    colldata[\([All, All, 2]\)] = 
      Sign[1 - colldata[\([All, All, 
                2]\)]] \((1 - colldata[\([All, All, 2]\)])\)\^2;\)\)\)], \
"Input"],

Cell[BoxData[
    \(\(plFreq = 
        Show[Graphics3D[{Line /@ colldata[\([All, All, {2, 1, 3}]\)], 
              Line /@ Transpose[colldata[\([All, All, {2, 1, 3}]\)]]}\ , 
            Boxed \[Rule] True, Axes \[Rule] True, 
            AxesLabel \[Rule] {\*"\"\<(\[Omega]-\!\(\[Omega]\_0\)\!\(\()\^2\)\
\)\>\"", \*"\"\<\!\(\[Omega]1\^2\)\>\"", \*"\"\<\!\(\[Omega]\_R\^2\)\>\""}, 
            AxesEdge \[Rule] {{\(-1\), \(-1\)}, {1, \(-1\)}, {\(-1\), \
\(-1\)}}, PlotLabel \[Rule] None]];\)\)], "Input"],

Cell[BoxData[{
    \(\(SetDirectory["\<~/mathem\>"];\)\), "\[IndentingNewLine]", 
    \(\(Export["\<rabcomp.eps\>", plAmp, "\<EPS\>"];\)\)}], "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
},
FrontEndVersion->"4.1 for X",
ScreenRectangle->{{0, 1280}, {0, 1024}},
WindowToolbars->"EditBar",
WindowSize->{1269, 916},
WindowMargins->{{0, Automatic}, {Automatic, 28}},
Magnification->1.25,
StyleDefinitions -> "PastelColor.nb"
]

(*******************************************************************
Cached data follows.  If you edit this Notebook file directly, not
using Mathematica, you must remove the line containing CacheID at
the top of  the file.  The cache data will then be recreated when
you save this file from within Mathematica.
*******************************************************************)

(*CellTagsOutline
CellTagsIndex->{}
*)

(*CellTagsIndex
CellTagsIndex->{}
*)

(*NotebookFileOutline
Notebook[{

Cell[CellGroupData[{
Cell[1727, 52, 45, 1, 130, "Title"],

Cell[CellGroupData[{
Cell[1797, 57, 31, 0, 61, "Section"],
Cell[1831, 59, 1071, 19, 169, "Text"],
Cell[2905, 80, 243, 4, 87, "Input"]
}, Open  ]],

Cell[CellGroupData[{
Cell[3185, 89, 51, 0, 61, "Section"],
Cell[3239, 91, 4710, 141, 475, "Text"],
Cell[7952, 234, 565, 16, 60, "Input"],
Cell[8520, 252, 196, 4, 88, "Input"],
Cell[8719, 258, 2221, 65, 192, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[10977, 328, 37, 0, 61, "Section"],
Cell[11017, 330, 96, 3, 36, "Text"],
Cell[11116, 335, 867, 15, 194, "Input"],

Cell[CellGroupData[{
Cell[12008, 354, 713, 12, 131, "Input"],
Cell[12724, 368, 59736, 2113, 243, 28337, 1721, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[72475, 2484, 243, 5, 88, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[72755, 2494, 33, 0, 61, "Section"],
Cell[72791, 2496, 192, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[73008, 2506, 1180, 20, 351, "Input"],
Cell[74191, 2528, 181, 3, 28, "Message"],
Cell[74375, 2533, 181, 3, 28, "Message"],
Cell[74559, 2538, 185, 3, 28, "Message"]
}, Open  ]],

Cell[CellGroupData[{
Cell[74781, 2546, 269, 4, 66, "Input"],
Cell[75053, 2552, 27987, 659, 243, 5397, 376, "GraphicsData", "PostScript", \
"Graphics"]
}, Open  ]],
Cell[103055, 3214, 160, 4, 62, "Text"],

Cell[CellGroupData[{
Cell[103240, 3222, 93, 1, 45, "Input"],
Cell[103336, 3225, 201, 4, 47, "Print"]
}, Open  ]],
Cell[103552, 3232, 221, 4, 62, "Text"],
Cell[103776, 3238, 844, 14, 227, "Input"],

Cell[CellGroupData[{
Cell[104645, 3256, 1226, 21, 256, "Input"],
Cell[105874, 3279, 190, 3, 28, "Message"],
Cell[106067, 3284, 52046, 1548, 243, 18744, 1132, "GraphicsData", \
"PostScript", "Graphics"],
Cell[158116, 4834, 287, 6, 47, "Print"],
Cell[158406, 4842, 214, 4, 47, "Print"],
Cell[158623, 4848, 351, 7, 47, "Print"]
}, Open  ]]
}, Open  ]],

Cell[CellGroupData[{
Cell[159023, 4861, 39, 0, 61, "Section"],
Cell[159065, 4863, 197, 4, 36, "Text"],
Cell[159265, 4869, 405, 7, 108, "Input"],
Cell[159673, 4878, 40, 0, 36, "Text"],

Cell[CellGroupData[{
Cell[159738, 4882, 928, 15, 255, "Input"],
Cell[160669, 4899, 191, 3, 28, "Message"],
Cell[160863, 4904, 197, 3, 28, "Message"]
}, Open  ]],
Cell[161075, 4910, 198, 6, 36, "Text"],

Cell[CellGroupData[{
Cell[161298, 4920, 463, 8, 66, "Input"],
Cell[161764, 4930, 96048, 2019, 346, 17438, 1044, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],

Cell[CellGroupData[{
Cell[257849, 6954, 45, 0, 37, "Subsubsection"],
Cell[257897, 6956, 152, 2, 66, "Input"],
Cell[258052, 6960, 63, 3, 62, "Text"],

Cell[CellGroupData[{
Cell[258140, 6967, 477, 9, 66, "Input"],
Cell[258620, 6978, 109335, 2115, 380, 15187, 948, "GraphicsData", \
"PostScript", "Graphics"]
}, Open  ]],
Cell[367970, 9096, 494, 13, 62, "Text"]
}, Open  ]],

Cell[CellGroupData[{
Cell[368501, 9114, 45, 0, 37, "Subsubsection"],
Cell[368549, 9116, 150, 2, 66, "Input"],
Cell[368702, 9120, 340, 7, 89, "Input"],
Cell[369045, 9129, 507, 8, 67, "Input"],
Cell[369555, 9139, 150, 2, 66, "Input"]
}, Open  ]]
}, Open  ]]
}, Open  ]]
}
]
*)



(*******************************************************************
End of Mathematica Notebook file.
*******************************************************************)

